/*-- Copyright (c) 2014 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved. --*/ 
/*
Model         Creditrisk 48 Datamodel
Subject Area  Mapping
Model Version 
Macro Name    ddl_script_mapping.sas
DBMS          SAS
Created       12/05/2013 9:43:41 AM
     Copyright (c) 2013 by SAS Institute Inc., Cary, NC 27513   */

/* Assign a libname to the location to store the mapping tables   */
/* and set the macro var LIBNAME to the libref name               */

PROC SQL;

CREATE TABLE &LIBNAME..MAP_ADD_ON_SET_TYPE
(
   ADD_ON_SET_TYPE_CD   CHARACTER(3)
      LABEL = 'Add On Set Type Code',
   VALID_FROM_DTTM      DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid From Datetime',
   ADD_ON_SET_TYPE      CHARACTER(10)
      LABEL = 'Add On Set Type',
   VALID_TO_DTTM        DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid To Datetime',
   CONSTRAINT PRIM_KEY PRIMARY KEY (ADD_ON_SET_TYPE_CD,VALID_FROM_DTTM)
);



CREATE TABLE &LIBNAME..MAP_ADDON_TYPE
(
   ADDON_TYPE           CHARACTER(20)
      LABEL = 'Addon Type',
   VALID_FROM_DTTM      DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid From Datetime',
   DESCRIPTION          CHARACTER(40)
      LABEL = 'Description',
   VALID_TO_DTTM        DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid To Datetime',
   OFF_BALANCE_SHEET_TYPE_CD CHARACTER(3)
      LABEL = 'Off Balance Sheet Type Code',
   ADD_ON_SET_ID        VARCHAR(32)
      LABEL = 'Add On Set Id',
   CONSTRAINT PRIM_KEY PRIMARY KEY (ADD_ON_SET_ID,OFF_BALANCE_SHEET_TYPE_CD,VALID_FROM_DTTM)
);



CREATE TABLE &LIBNAME..MAP_APPROACH_CLASS
(
   REGLTRY_COUNTERPARTY_TYPE_CD CHARACTER(3)
      LABEL = 'Regulatory Counterparty Type Code',
   REGULATORY_PRODUCT_CD CHARACTER(3)
      LABEL = 'Regulatory Product Code',
   CONFIGURATION_ID     VARCHAR(32)
      LABEL = 'Configuration Id',
   APPROACH_CLASS       CHARACTER(32)
      LABEL = 'Approach Class',
   VALID_FROM_DTTM      DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid From Datetime',
   VALID_TO_DTTM        DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid To Datetime'
);


CREATE TABLE &LIBNAME..MAP_CAPITAL_SCALING_FACTOR
(
   APPROACH             CHARACTER(16)
      LABEL = 'Approach',
   CONFIGURATION_ID     CHARACTER(32)
      LABEL = 'Configuration Id',
   IRB_CAPITAL_SCALING_FLG NUMERIC(8)
      LABEL = 'IRB Capital Scaling Flag',
   IRB_CAPITAL_DEF_SCALING_FLG NUMERIC(8)
      LABEL = 'IRB Capital Default Case Scaling Flag',
   VALID_FROM_DTTM      DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid From Datetime',
   VALID_TO_DTTM        DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid To Datetime'
);


CREATE TABLE &LIBNAME..MAP_CCF_BUCKET_TYPE
(
   CCF_SET_ID           CHARACTER(32)
      LABEL = 'CCF Set Id',
   CCF_BUCKET_TYPE_CD   CHARACTER(3)
      LABEL = 'CCF Bucket Type Code',
   VALID_FROM_DTTM      DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid From Datetime',
   CCF_BUCKET_TYPE      CHARACTER(32)
      LABEL = 'CCF Bucket Type',
   VALID_TO_DTTM        DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid To Datetime',
   CONSTRAINT PRIM_KEY PRIMARY KEY (CCF_SET_ID,CCF_BUCKET_TYPE_CD,VALID_FROM_DTTM)
);



CREATE TABLE &LIBNAME..MAP_CCF_BUCKETS_REGRPT
(
   CONFIGURATION_ID     CHARACTER(32)
      LABEL = 'Configuration Id',
   APPROACH             CHARACTER(16)
      LABEL = 'Approach',
   CCF_START            NUMERIC(8)
      LABEL = 'CCF Start',
   CCF_END              NUMERIC(8)
      LABEL = 'CCF End',
   CCF_BUCKET           CHARACTER(16)
      LABEL = 'CCF Bucket',
   VALID_FROM_DTTM      DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid From Datetime',
   VALID_TO_DTTM        DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid To Datetime'
);



CREATE TABLE &LIBNAME..MAP_CCF_BUCKETS_REGRPT_SEC
(
   CONFIGURATION_ID     CHARACTER(32)
      LABEL = 'Configuration Id',
   APPROACH             CHARACTER(16)
      LABEL = 'Approach',
   CCF_START            NUMERIC(8)
      LABEL = 'CCF Start',
   CCF_END              NUMERIC(8)
      LABEL = 'CCF End',
   CCF_BUCKET           CHARACTER(16)
      LABEL = 'CCF Bucket',
   VALID_FROM_DTTM      DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid From Datetime',
   VALID_TO_DTTM        DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid To Datetime'
);



CREATE TABLE &LIBNAME..MAP_CCF_TYPE
(
   OFF_BALANCE_SHEET_TYPE_CD VARCHAR(3)
      LABEL = 'Off Balance Sheet Type Code',
   VALID_FROM_DTTM      DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid From Datetime',
   CCF_TYPE             CHARACTER(32)
      LABEL = 'CCF Type',
   DESCRIPTION          VARCHAR(73)
      LABEL = 'Description',
   VALID_TO_DTTM        DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid To Datetime',
   CCF_SET_ID           VARCHAR(32)
      LABEL = 'CCF Set Id',
   REG_Y_CCF_TYPE       CHARACTER(32)
      LABEL = 'Regulatory Y CCF Type',
   CONSTRAINT PRIM_KEY PRIMARY KEY (CCF_SET_ID,OFF_BALANCE_SHEET_TYPE_CD,VALID_FROM_DTTM)
);



CREATE TABLE &LIBNAME..MAP_CCF_TYPE_STD_CCR
(
   VALID_FROM_DTTM      DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid From Datetime',
   VALID_TO_DTTM        DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid To Datetime',
   HEDGING_SET_TYPE_CD  VARCHAR(3)
      FORMAT = $4.
      INFORMAT = $4.
      LABEL = 'Hedging set type code',
   CCF_TYPE             VARCHAR(32)
      FORMAT = $19.
      INFORMAT = $19.
      LABEL = 'CCF Type',
   CCF_SET_ID           VARCHAR(32)
      FORMAT = $10.
      INFORMAT = $10.
      LABEL = 'CCF Set Id',
   DESCRIPTION          CHARACTER(40)
      FORMAT = $53.
      INFORMAT = $53.
      LABEL = 'Description',
   CONSTRAINT PRIM_KEY PRIMARY KEY (CCF_SET_ID,HEDGING_SET_TYPE_CD,VALID_FROM_DTTM)
);



CREATE TABLE &LIBNAME..MAP_CCR_APPROACH
(
   CONFIGURATION_ID     VARCHAR(32)
      LABEL = 'Configuration Id',
   APPROACH             CHARACTER(16)
      LABEL = 'Approach',
   VALID_FROM_DTTM      DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid From Datetime',
   VALID_TO_DTTM        DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid To Datetime',
   APPROACH_CLASS       VARCHAR(32)
      LABEL = 'Approach Class',
   CONSTRAINT PRIM_KEY PRIMARY KEY (APPROACH_CLASS,CONFIGURATION_ID,VALID_FROM_DTTM)
);



CREATE TABLE &LIBNAME..MAP_CLEAN_UP_CALL_TYPE
(
   CONFIGURATION_ID     CHARACTER(32)
      LABEL = 'Configuration Id',
   CLEAN_UP_CALL_TYPE_CD CHARACTER(3)
      LABEL = 'Clean Up Call Type Code',
   CLEAN_UP_CALL_TYPE   CHARACTER(32)
      LABEL = 'Clean Up Call Type',
   ELIGIBLE_CLEAN_UP_CALL_FLG NUMERIC(8)
      LABEL = 'Eligible Clean Up Call Flag',
   VALID_FROM_DTTM      DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid From Datetime',
   VALID_TO_DTTM        DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid To Datetime'
);



CREATE TABLE &LIBNAME..MAP_CONFIG_SIMULATION
(
   CONFIGURATION_ID     VARCHAR(32)
      LABEL = 'Configuration ID',
   VALID_FROM_DTTM      DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid From Datetime',
   VALID_TO_DTTM        DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid To Datetime',
   SIMULATION_NM        VARCHAR(40)
      LABEL = 'Simulation Name',
   CONSTRAINT PRIM_KEY PRIMARY KEY (CONFIGURATION_ID,VALID_FROM_DTTM)
);



CREATE TABLE &LIBNAME..MAP_COUNTERPARTY_CLASS
(
   REGLTRY_COUNTERPARTY_TYPE_CD CHARACTER(3)
      LABEL = 'Regulatory Counterparty Type Code',
   CONFIGURATION_ID     CHARACTER(32)
      LABEL = 'Configuration Id',
   VALID_FROM_DTTM      DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid From Datetime',
   DESCRIPTION          CHARACTER(87)
      LABEL = 'Description',
   COUNTERPARTY_CLASS   CHARACTER(32)
      LABEL = 'Counterparty Class',
   COUNTERPARTY_SUBCLASS CHARACTER(32)
      LABEL = 'Counterparty Subclass',
   VALID_TO_DTTM        DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid To Datetime',
   BASELI_COUNTERPARTY  CHARACTER(14)
      LABEL = 'Basel I counterparty class',
   ELIGIBLE_DD_TREAT_GUARANTOR CHARACTER(1)
      LABEL = 'Eligible Dd Treat Guarantor',
   ELIGIBLE_DD_TREAT_OBLIGOR CHARACTER(1)
      LABEL = 'Eligible Dd Treat Obligor',
   CONSTRAINT PRIM_KEY PRIMARY KEY (REGLTRY_COUNTERPARTY_TYPE_CD,CONFIGURATION_ID,VALID_FROM_DTTM)
);



CREATE TABLE &LIBNAME..MAP_COUNTERPARTY_RELATION_TYPE
(
   CONFIGURATION_ID     CHARACTER(32)
      LABEL = 'Configuration Id',
   COUNTERPARTY_RELATION_TYPE CHARACTER(16)
      LABEL = 'Counterparty Relation Type',
   COUNTERPARTY_RELATION_TYPE_CD CHARACTER(3)
      LABEL = 'Counterparty Relation Type Code',
   DESCRIPTION          CHARACTER(60)
      LABEL = 'Description',
   VALID_FROM_DTTM      DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid From Datetime',
   VALID_TO_DTTM        DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid To Datetime'
);



CREATE TABLE &LIBNAME..MAP_COUNTERPARTY_TYPE
(
   COUNTERPARTY_TYPE_CD CHARACTER(3)
      LABEL = 'Counterparty Type Code',
   VALID_FROM_DTTM      DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid From Datetime',
   CONFIGURATION_ID     CHARACTER(32)
      LABEL = 'Configuration Id',
   COUNTERPARTY_TYPE    CHARACTER(32)
      LABEL = 'Counterparty Type',
   LARGE_FI_ENTITY_FLAG     NUMERIC(8)
      LABEL = 'Large Financial Entity Flag',
   VALID_TO_DTTM        DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid To Datetime',
   CONSTRAINT PRIM_KEY PRIMARY KEY (COUNTERPARTY_TYPE_CD,VALID_FROM_DTTM,CONFIGURATION_ID)
);



CREATE TABLE &LIBNAME..MAP_COVERED_RISK_TYPE
(
   COVERED_RISK_TYPE_CD CHARACTER(3)
      LABEL = 'Covered Risk Type Code',
   VALID_FROM_DTTM      DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid From Datetime',
   CONFIGURATION_ID     CHARACTER(32)
      LABEL = 'Configuration Id',
   COVERED_RISK_TYPE    CHARACTER(8)
      LABEL = 'Covered Risk Type',
   VALID_TO_DTTM        DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid To Datetime',
   CONSTRAINT PRIM_KEY PRIMARY KEY (COVERED_RISK_TYPE_CD,VALID_FROM_DTTM,CONFIGURATION_ID)
);



CREATE TABLE &LIBNAME..MAP_CRM_TYPE
(
   CRM_TYPE_CD          CHARACTER(3)
      LABEL = 'Crm Type Code',
   CRM_SUBTYPE_CD       CHARACTER(3)
      LABEL = 'Crm Subtype Code',
   VALID_FROM_DTTM      DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid From Datetime',
   CONFIGURATION_ID     CHARACTER(32)
      LABEL = 'Configuration Id',
   CRM_TYPE             CHARACTER(32)
      LABEL = 'Crm Type',
   CRM_SUBTYPE          CHARACTER(32)
      LABEL = 'Crm Subtype',
   VALID_TO_DTTM        DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid To Datetime',
   ELIGIBLE_DD_TREAT_CRM CHARACTER(1)
      LABEL = 'Eligible Dd Treat Crm',
   CONSTRAINT PRIM_KEY PRIMARY KEY (CONFIGURATION_ID,CRM_TYPE_CD,CRM_SUBTYPE_CD,VALID_FROM_DTTM)
);



CREATE TABLE &LIBNAME..MAP_CURRENCY_GROUP
(
   CONFIGURATION_ID     CHARACTER(32)
      LABEL = 'configuration ID',
   CURRENCY             CHARACTER(3)
      LABEL = 'currency code',
   GROUP                CHARACTER(8)
      LABEL = 'Currency group',
   VALID_FROM_DTTM      DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'valid from date',
   VALID_TO_DTTM        DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'valid to date',
   CONSTRAINT PRIM_KEY PRIMARY KEY (CONFIGURATION_ID,CURRENCY)
);


 create table &LIBNAME..MAP_CVA_STD_RW_BUCKET 
(
   EXT_MAP_RATING       CHARACTER(6)
      LABEL = 'Ext Map Rating',
   REGULATORY_RISK_WEIGHT_SET_ID CHARACTER(32)
      LABEL = 'Regulatory Risk Weight Set Id',
   CVA_STD_BUCKET     CHARACTER(8)
      LABEL = 'CVA Std Bucket',
   VALID_FROM_DTTM      DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid From Datetime',
   VALID_TO_DTTM        DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid To Datetime',
   CONSTRAINT PRIM_KEY PRIMARY KEY (EXT_MAP_RATING,REGULATORY_RISK_WEIGHT_SET_ID,VALID_FROM_DTTM)
);

CREATE TABLE &LIBNAME..MAP_DAY_BASIS
(
   DAY_BASIS_CD         VARCHAR(10)
      LABEL = 'Day Basis Code',
   VALID_FROM_DTTM      DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid From Datetime',
   DAY_BASIS            CHARACTER(7)
      LABEL = 'Day Basis',
   VALID_TO_DTTM        DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid To Datetime',
   CONSTRAINT PRIM_KEY PRIMARY KEY (DAY_BASIS_CD,VALID_FROM_DTTM)
);



CREATE TABLE &LIBNAME..MAP_ELIGIBLE_CRM_TYPE
(
   ELIGIBLE_CRM_TYPE_CD CHARACTER(3)
      LABEL = 'Eligible Crm Type Code',
   CONFIGURATION_ID     CHARACTER(32)
      LABEL = 'Configuration Id',
   ELIGIBLE_CRM_TYPE    CHARACTER(32)
      LABEL = 'Eligible Crm Type',
   VALID_FROM_DTTM      DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid From Datetime',
   VALID_TO_DTTM        DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid To Datetime',
   CONSTRAINT PRIM_KEY PRIMARY KEY (ELIGIBLE_CRM_TYPE_CD,CONFIGURATION_ID,VALID_FROM_DTTM)
);



CREATE TABLE &LIBNAME..MAP_ELIGIBLE_RATING_AGENCY
(
   CONFIGURATION_ID     VARCHAR(32)
      LABEL = 'Configuration ID',
   RATING_AGENCY_CD     VARCHAR(3)
      LABEL = 'Rating Agency Code',
   VALID_FROM_DTTM      DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid From Datetime',
   VALID_TO_DTTM        DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid To Datetime',
   ELIGIBLE_ECA_FLG     CHARACTER(1)
      LABEL = 'ELIGIBLE_ECA_FLG',
   CONSTRAINT PRIM_KEY PRIMARY KEY (CONFIGURATION_ID,RATING_AGENCY_CD,VALID_FROM_DTTM)
);



CREATE TABLE &LIBNAME..MAP_EQUITY_POSITION_TYPE
(
   CONFIGURATION_ID     CHARACTER(32)
      LABEL = 'Configuration Id',
   DESCRIPTION          CHARACTER(60)
      LABEL = 'Description',
   EQUITY_POSITION_TYPE CHARACTER(16)
      LABEL = 'Equity Position Type',
   EQUITY_POSITION_TYPE_CD CHARACTER(3)
      LABEL = 'Equity Position Type Code',
   VALID_FROM_DTTM      DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid From Datetime',
   VALID_TO_DTTM        DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid To Datetime',
   CONSTRAINT PRIM_KEY PRIMARY KEY (CONFIGURATION_ID,EQUITY_POSITION_TYPE_CD)
);



CREATE TABLE &LIBNAME..MAP_EXCHANGE_TYPE
(
   CONFIGURATION_ID     CHARACTER(32)
      LABEL = 'Configuration Id',
   EXCHANGE_CD          CHARACTER(10)
      LABEL = 'Exchange Code',
   EXCHANGE_ELIGIBILITY_TYPE CHARACTER(10)
      LABEL = 'Exchange Eligibility Type',
   VALID_FROM_DTTM      DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid From Datetime',
   VALID_TO_DTTM        DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid To Datetime',
   CONSTRAINT PRIM_KEY PRIMARY KEY (CONFIGURATION_ID,EXCHANGE_CD)
);



CREATE TABLE &LIBNAME..MAP_EXP_CLASS_LEVEL_1_REGRPT
(
   CONFIGURATION_ID     CHARACTER(32)
      LABEL = 'Configuration Id',
   REGLTRY_COUNTERPARTY_TYPE_CD CHARACTER(3)
      LABEL = 'Regulatory Counterparty Type Code',
   REGULATORY_PRODUCT_CD CHARACTER(3)
      LABEL = 'Regulatory Product Code',
   EXPOSURE_CLASS_LEVEL_1 CHARACTER(16)
      LABEL = 'Exposure Class Level 1',
   VALID_FROM_DTTM      DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid From Datetime',
   VALID_TO_DTTM        DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid To Datetime'
);



CREATE TABLE &LIBNAME..MAP_EXP_CLASS_LEVEL_2_REGRPT
(
   CONFIGURATION_ID     CHARACTER(32)
      LABEL = 'Configuration Id',
   REGLTRY_COUNTERPARTY_TYPE_CD CHARACTER(3)
      LABEL = 'Regulatory Counterparty Type Code',
   REGULATORY_PRODUCT_CD CHARACTER(3)
      LABEL = 'Regulatory Product Code',
   EXPOSURE_CLASS_LEVEL_2 CHARACTER(16)
      LABEL = 'Exposure Class Level 2',
   VALID_FROM_DTTM      DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid From Datetime',
   VALID_TO_DTTM        DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid To Datetime'
);



CREATE TABLE &LIBNAME..MAP_EXP_CLASS_LEVEL_3_REGRPT
(
   CONFIGURATION_ID     CHARACTER(32)
      LABEL = 'Configuration Id',
   REGLTRY_COUNTERPARTY_TYPE_CD CHARACTER(3)
      LABEL = 'Regulatory Counterparty Type Code',
   REGULATORY_PRODUCT_CD CHARACTER(3)
      LABEL = 'Regulatory Product Code',
   EXPOSURE_CLASS_LEVEL_3 CHARACTER(16)
      LABEL = 'Exposure Class Level 3',
   VALID_FROM_DTTM      DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid From Datetime',
   VALID_TO_DTTM        DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid To Datetime'
);



CREATE TABLE &LIBNAME..MAP_EXT_RATINGS
(
   CONFIGURATION_ID     VARCHAR(32)
      LABEL = 'Configuration Id',
   S_P                  VARCHAR(4)
      LABEL = 'S P',
   VALID_FROM_DTTM      DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid From Datetime',
   MDY                  VARCHAR(4)
      LABEL = 'Mdy',
   FIT                  VARCHAR(4)
      LABEL = 'Fit',
   INT                  VARCHAR(2)
      LABEL = 'Int',
   INVESTMENT_FLG       CHARACTER(1)
      LABEL = 'Investment Flag',
   EXT_MAP_RATING       VARCHAR(5)
      LABEL = 'Ext Map Rating',
   VALID_TO_DTTM        DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid To Datetime'
);



CREATE TABLE &LIBNAME..MAP_EXT_RATINGS_SEC_CATEGORY
(
   CONFIGURATION_ID     CHARACTER(32)
      LABEL = 'Configuration Id',
   EXT_MAP_RATING       CHARACTER(8)
      LABEL = 'External Map Rating',
   EXT_RATING_CATEGORY  CHARACTER(32)
      LABEL = 'External Rating Category',
   DEDUCTION_FLG        CHARACTER(8)
      LABEL = 'Deduction Flag',
   VALID_FROM_DTTM      DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid From Datetime',
   VALID_TO_DTTM        DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid To Datetime'
);



CREATE TABLE &LIBNAME..MAP_EXT_SHORTTERM_RATINGS
(
   CONFIGURATION_ID     VARCHAR(32)
      LABEL = 'Configuration Id',
   S_P                  VARCHAR(4)
      LABEL = 'S P',
   VALID_FROM_DTTM      DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid From Datetime',
   MDY                  VARCHAR(4)
      LABEL = 'Mdy',
   FIT                  VARCHAR(4)
      LABEL = 'Fit',
   INT                  VARCHAR(2)
      LABEL = 'Int',
   EXT_MAP_RATING       VARCHAR(5)
      LABEL = 'Ext Map Rating',
   VALID_TO_DTTM        DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid To Datetime'
);



CREATE TABLE &LIBNAME..MAP_FINANCIAL_RPT_LINE_ITEM
(
   CONFIGURATION_ID     CHARACTER(32)
      LABEL = 'Configuration Id',
   PRODUCT_CD           CHARACTER(16)
      LABEL = 'Product Code',
   SUBPRODUCT_CD        CHARACTER(16)
      LABEL = 'Subproduct Code',
   REPORT_DATA_ITEM     CHARACTER(32)
      LABEL = 'Report Data Item',
   DESCRIPTION          CHARACTER(20)
      LABEL = 'Description',
   VALID_FROM_DTTM      DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid From Datetime',
   VALID_TO_DTTM        DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid To Datetime'
);



CREATE TABLE &LIBNAME..MAP_FUNDS_UNDERLYING_TYPE
(
   CONFIGURATION_ID     CHARACTER(32)
      LABEL = 'Configuration Id',
   UNDERLYING_FND_ASSET_TYPE_CD CHARACTER(3)
      LABEL = 'Underlying assets code of Investment Funds',
   DESCRIPTION          CHARACTER(256)
      LABEL = 'Description',
   UNDERLYING_ASSET_TYPE CHARACTER(32)
      LABEL = 'Underlying assets of Investment Funds',
   UNDERLYING_ASSET_RW_RATING NUMERIC(8)
      LABEL = 'Maximum value describes highest risk weight',
   VALID_FROM_DTTM      NUMERIC(8)
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid From Datetime',
   VALID_TO_DTTM        NUMERIC(8)
      LABEL = 'Valid To Datetime',
   CONSTRAINT PRIM_KEY PRIMARY KEY (CONFIGURATION_ID,UNDERLYING_FND_ASSET_TYPE_CD)
);



CREATE TABLE &LIBNAME..MAP_FX_TYPE
(
   FX_MARKET_TYPE_CD    CHARACTER(3)
      LABEL = 'Fx Market Type Code',
   VALID_FROM_DTTM      DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid From Datetime',
   FX_MARKET_TYPE       CHARACTER(12)
      LABEL = 'Fx Market Type',
   VALID_TO_DTTM        DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid To Datetime',
   CONSTRAINT PRIM_KEY PRIMARY KEY (FX_MARKET_TYPE_CD,VALID_FROM_DTTM)
);



CREATE TABLE &LIBNAME..MAP_HAIRCUT_TYPE
(
   HAIRCUT_SET_ID       CHARACTER(32)
      LABEL = 'Haircut Set Id',
   PRODUCT_CD           CHARACTER(5)
      LABEL = 'Product Code',
   SUBPRODUCT_CD        CHARACTER(3)
      LABEL = 'Subproduct Code',
   VALID_FROM_DTTM      DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid From Datetime',
   HAIRCUT_TYPE         CHARACTER(32)
      LABEL = 'Haircut Type',
   VALID_TO_DTTM        DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid To Datetime'
);



CREATE TABLE &LIBNAME..MAP_HEDGING_SET_TYPE
(
   CONFIGURATION_ID     VARCHAR(32)
      LABEL = 'Configuration ID',
   HEDGING_SET_TYPE_CD  VARCHAR(3)
      LABEL = 'HEDGING SET TYPE CODE',
   VALID_FROM_DTTM      DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid From Datetime',
   HEDGING_SET_TYPE     VARCHAR(20)
      LABEL = 'Hedging Set Type',
   VALID_TO_DTTM        DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid To Datetime',
   RISK_POSITION_INSTTYPE VARCHAR(32)
      LABEL = 'Risk Position Insttype',
   CONSTRAINT PRIM_KEY PRIMARY KEY (CONFIGURATION_ID,HEDGING_SET_TYPE_CD,VALID_FROM_DTTM)
);



CREATE TABLE &LIBNAME..MAP_HORIZON_LIST
(
   HORIZON_LIST_ID      VARCHAR(32)
      LABEL = 'Horizon List ID',
   HORIZON_NO           NUMERIC(10)
      LABEL = 'Horizon Number',
   VALID_FROM_DTTM      DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid From Datetime',
   VALID_TO_DTTM        DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid To Datetime',
   CONSTRAINT PRIM_KEY PRIMARY KEY (HORIZON_LIST_ID,HORIZON_NO,VALID_FROM_DTTM)
);



CREATE TABLE &LIBNAME..MAP_IR_TYPE
(
   IR_MARKET_TYPE_CD    CHARACTER(3)
      LABEL = 'Ir Market Type Code',
   VALID_FROM_DTTM      DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid From Datetime',
   IR_MARKET_TYPE       CHARACTER(12)
      LABEL = 'Ir Market Type',
   VALID_TO_DTTM        DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid To Datetime',
   CONSTRAINT PRIM_KEY PRIMARY KEY (IR_MARKET_TYPE_CD,VALID_FROM_DTTM)
);



CREATE TABLE &LIBNAME..MAP_IRB_ALTERNATIVE_RW
(
   IRB_ALTER_TREAT_ELIGIB_TYPE_CD CHARACTER(3)
      LABEL = 'IRB Alter Treat Eligib Type Code',
   CONFIGURATION_ID     CHARACTER(32)
      LABEL = 'Configuration Id',
   VALID_FROM_DTTM      DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid From Datetime',
   RW_PCT               NUMERIC(8)
      LABEL = 'Rw Percent',
   VALID_TO_DTTM        DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid To Datetime',
   CONSTRAINT PRIM_KEY PRIMARY KEY (CONFIGURATION_ID,IRB_ALTER_TREAT_ELIGIB_TYPE_CD,VALID_FROM_DTTM)
);



CREATE TABLE &LIBNAME..MAP_IRB_EQU2_REGRPT
(
   CONFIGURATION_ID     CHARACTER(32)
      LABEL = 'Configuration Id',
   RW_START             CHARACTER(8)
      LABEL = 'Rw Start',
   RW_END               CHARACTER(8)
      LABEL = 'Rw End',
   RW_BUCKET            CHARACTER(20)
      LABEL = 'Rw Bucket',
   VALID_FROM_DTTM      DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid From Datetime',
   VALID_TO_DTTM        DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid To Datetime'
);



CREATE TABLE &LIBNAME..MAP_IRB_RW_BUCKETS
(
   EXT_MAP_RATING       CHARACTER(6)
      LABEL = 'Ext Map Rating',
   IRB_RW_BUCKET_SL     CHARACTER(8)
      LABEL = 'IRB Rw Bucket Sl',
   VALID_FROM_DTTM      DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid From Datetime',
   SHORTTERM_FLG        NUMERIC(3)
      LABEL = 'Shortterm Flag',
   IRB_RW_BUCKET_SEC    CHARACTER(8)
      LABEL = 'IRB Rw Bucket Sec',
   IRB_RW_BUCKET_SEC_SHORT CHARACTER(8)
      LABEL = 'IRB Rw Bucket Sec Short',
   REGULATORY_RISK_WEIGHT_SET_ID CHARACTER(32)
      LABEL = 'Regulatory Risk Weight Set Id',
   VALID_TO_DTTM        DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid To Datetime',
   CONSTRAINT PRIM_KEY PRIMARY KEY (EXT_MAP_RATING,REGULATORY_RISK_WEIGHT_SET_ID,VALID_FROM_DTTM,SHORTTERM_FLG)
);



CREATE TABLE &LIBNAME..MAP_IRB_RW_BUCKETS_EQUITY
(
   REGULATORY_RISK_WEIGHT_SET_ID VARCHAR(32)
      LABEL = 'Regulatory Risk Weight Set Id',
   REGULATORY_APPROACH  CHARACTER(16)
      LABEL = 'Regulatory Approach',
   EQUITY_POSITION_TYPE_CD CHARACTER(3)
      LABEL = 'Equity Position Type Code',
   REGULATORY_PRODUCT_CD CHARACTER(3)
      LABEL = 'Regulatory Product Code',
   IRB_RW_BUCKET_EQUITY CHARACTER(8)
      LABEL = 'IRB Rw Bucket Equity',
   VALID_FROM_DTTM      DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid From Datetime',
   VALID_TO_DTTM        DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid To Datetime'
);



CREATE TABLE &LIBNAME..MAP_IRB_RW_BUCKETS_INV_FUNDS
(
   REGULATORY_RISK_WEIGHT_SET_ID CHARACTER(32)
      LABEL = 'Regulatory Risk Weight Set Id',
   REGULATORY_APPROACH  CHARACTER(16)
      LABEL = 'Regulatory Approach',
   UNDERLYING_FND_ASSET_TYPE_CD CHARACTER(3)
      LABEL = 'Underlying assets code of Investment Funds',
   REGULATORY_PRODUCT_CD CHARACTER(3)
      LABEL = 'Regulatory Product Code',
   IRB_RW_BUCKET_FUNDS  CHARACTER(8)
      LABEL = 'IRB Rw Bucket Investment Funds',
   VALID_FROM_DTTM      NUMERIC(8)
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid From Datetime',
   VALID_TO_DTTM        NUMERIC(8)
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid To Datetime'
);



CREATE TABLE &LIBNAME..MAP_LGD_BUCKETS
(
   LGD_BUCKET           CHARACTER(10)
      LABEL = 'LGD Bucket',
   CONFIGURATION_ID     VARCHAR(32)
      LABEL = 'Configuration Id',
   LGD_START            NUMERIC(8)
      LABEL = 'LGD Start',
   VALID_FROM_DTTM      DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid From Datetime',
   LGD_END              NUMERIC(8)
      LABEL = 'LGD End',
   VALID_TO_DTTM        DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid To Datetime',
   CONSTRAINT PRIM_KEY PRIMARY KEY (LGD_BUCKET,CONFIGURATION_ID,VALID_FROM_DTTM)
);



CREATE TABLE &LIBNAME..MAP_LGD_BUCKETS_IRB_EQUITY
(
   REGULATORY_LGD_SET_ID CHARACTER(32)
      LABEL = 'Regulatory LGD Set Id',
   EQUITY_POSITION_TYPE_CD CHARACTER(3)
      LABEL = 'Equity Position Type Code',
   REGULATORY_PRODUCT_CD CHARACTER(3)
      LABEL = 'Regulatory Product Code',
   IRB_LGD_BUCKET_EQ_PD_LGD CHARACTER(8)
      LABEL = 'IRB LGD Bucket Eq Pd Lgd',
   VALID_FROM_DTTM      DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid From Datetime',
   VALID_TO_DTTM        DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid To Datetime'
);



CREATE TABLE &LIBNAME..MAP_LGD_BUCKETS_REGRPT
(
   CONFIGURATION_ID     CHARACTER(32)
      LABEL = 'Configuration Id',
   LGD_LOW_END          CHARACTER(8)
      LABEL = 'LGD Low End',
   LGD_HIGH_END         CHARACTER(8)
      LABEL = 'LGD High End',
   MAT_BUCKET           CHARACTER(16)
      LABEL = 'Mat Bucket',
   VALID_FROM_DTTM      DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid From Datetime',
   VALID_TO_DTTM        DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid To Datetime'
);



CREATE TABLE &LIBNAME..MAP_MARKET_DATA
(
   MARKET_DATA_ID       VARCHAR(32)
      LABEL = 'MARKET_DATA_ID',
   SOURCE_DATA_LIBREF_NM VARCHAR(8)
      LABEL = 'SOURCE_DATA_LIBREF_NM',
   VALID_FROM_DTTM      DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid From Datetime',
   VALID_TO_DTTM        DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid To Datetime',
   SOURCE_DATA_NM       VARCHAR(40)
      LABEL = 'SOURCE_DATA_NM',
   MARKET_DATA_TYPE_NM  VARCHAR(40)
      LABEL = 'MARKET_DATA_TYPE_NM',
   CONSTRAINT PRIM_KEY PRIMARY KEY (MARKET_DATA_ID,VALID_FROM_DTTM)
);



CREATE TABLE &LIBNAME..MAP_MARKET_DATA_LIST
(
   MARKET_DATA_LIST_ID  VARCHAR(32)
      LABEL = 'Market Data List ID',
   MARKET_DATA_ID       VARCHAR(32)
      LABEL = 'Market Data ID',
   VALID_FROM_DTTM      DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid From Datetime',
   VALID_TO_DTTM        DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid To Datetime',
   CONSTRAINT PRIM_KEY PRIMARY KEY (MARKET_DATA_LIST_ID,MARKET_DATA_ID,VALID_FROM_DTTM)
);



CREATE TABLE &LIBNAME..MAP_MAT_BUCKETS_SL_REGRPT
(
   CONFIGURATION_ID     CHARACTER(32)
      LABEL = 'Configuration Id',
   MAT_START            CHARACTER(8)
      LABEL = 'Mat Start',
   MAT_END              CHARACTER(8)
      LABEL = 'Mat End',
   MAT_BUCKET           CHARACTER(16)
      LABEL = 'Mat Bucket',
   VALID_FROM_DTTM      DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid From Datetime',
   VALID_TO_DTTM        DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid To Datetime'
);



CREATE TABLE &LIBNAME..MAP_MODEL_LIST
(
   MODEL_LIST_ID        VARCHAR(32)
      LABEL = 'MODEL_LIST_ID',
   MODEL_RK             NUMERIC(10)
      FORMAT = 12.
      INFORMAT = 12.
      LABEL = 'MODEL_RK',
   VALID_FROM_DTTM      DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid From Datetime',
   VALID_TO_DTTM        DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid To Datetime',
   CONSTRAINT PRIM_KEY PRIMARY KEY (MODEL_LIST_ID,MODEL_RK,VALID_FROM_DTTM)
);



CREATE TABLE &LIBNAME..MAP_MTM_INSTTYPE
(
   CONFIGURATION_ID     CHARACTER(32)
      LABEL = 'Configuration Id',
   PRODUCT_CD           CHARACTER(16)
      LABEL = 'Product Code',
   SUBPRODUCT_CD        CHARACTER(16)
      LABEL = 'Subproduct Code',
   INSTTYPE             CHARACTER(32)
      LABEL = 'Insttype',
   DESCRIPTION          CHARACTER(100)
      LABEL = 'Description',
   VALID_FROM_DTTM      DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid From Datetime',
   VALID_TO_DTTM        DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid To Datetime'
);


CREATE TABLE &LIBNAME..MAP_NATIONAL_DISCRETION
(
   COUNTRY_CD           VARCHAR(3)
      LABEL = 'COUNTRY_CD',
   COUNTRY_CURRENCY_1_CD VARCHAR(3)
      LABEL = 'COUNTRY_CURRENCY_1_CD',
   VALID_FROM_DTTM      DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid From Datetime',
   VALID_TO_DTTM        DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid To Datetime',
   COUNTRY_CURRENCY_2_CD VARCHAR(3)
      LABEL = 'Country Currency 2 Code',
   COUNTRY_CURRENCY_3_CD VARCHAR(3)
      LABEL = 'Country Currency 3 Code',
   EEA_MEMBER_FLG VARCHAR(3) 
      LABEL = 'EEA Member Country Flag',   
   STD_SOV_DOM_PREF_TREATMENT VARCHAR(3)
      LABEL = 'Std Sov Dom Pref Treatment',
   STD_BANK_DOM_PREF_TREATMENT VARCHAR(3)
      LABEL = 'STD_BANK_DOM_PREF_TREATMENT',
   MORTGAGE_LTV_PCT     NUMERIC(9,4)
      FORMAT = NLNUM9.4
      INFORMAT = NLNUM9.4
      LABEL = 'Mortgage Ltv Percent',
   COUNTRY_NM           VARCHAR(40)
      LABEL = 'COUNTRY NAME',
   CONSTRAINT PRIM_KEY PRIMARY KEY (COUNTRY_CD,VALID_FROM_DTTM)
);


CREATE TABLE &LIBNAME..MAP_OBSI_TYPE
(
   CONFIGURATION_ID     CHARACTER(32)
      LABEL = 'Configuration Id',
   OFF_BALANCE_SHEET_TYPE_CD CHARACTER(3)
      LABEL = 'Off Balance Sheet Type Code',
   OFF_BALANCE_SHEET_TYPE CHARACTER(32)
      LABEL = 'Off Balance Sheet Type',
   VALID_FROM_DTTM      DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid From Datetime',
   VALID_TO_DTTM        DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid To Datetime'
);



CREATE TABLE &LIBNAME..MAP_OECD_COUNTRIES
(
   COUNTRY_CD           CHARACTER(3)
      LABEL = 'Country Code',
   FULL_COUNTRY_NAME    CHARACTER(32)
      LABEL = 'Full Country Name',
   VALID_FROM_DTTM      DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid From Datetime',
   VALID_TO_DTTM        DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid To Datetime'
);



CREATE TABLE &LIBNAME..MAP_OPTION_TYPE_CD
(
   OPTION_TYPE_CD       VARCHAR(3)
      LABEL = 'Option Type Code',
   OPTION_TYPE_DESC     VARCHAR(100)
      LABEL = 'Option Type Description',
   VALID_FROM_DTTM      DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid From Datetime',
   VALID_TO_DTTM        DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid To Datetime',
   CONSTRAINT PRIM_KEY PRIMARY KEY (OPTION_TYPE_CD,VALID_FROM_DTTM)
);



CREATE TABLE &LIBNAME..MAP_PAYMENT_LEG_TYPE
(
   PAYMENT_LEG_TYPE_CD  VARCHAR(3)
      LABEL = 'Payment Leg Type Code',
   PAYMENT_LEG_TYPE_DESC VARCHAR(100)
      LABEL = 'Payment Leg Type Description',
   VALID_FROM_DTTM      DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid From Datetime',
   VALID_TO_DTTM        DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid To Datetime',
   CONSTRAINT PRIM_KEY PRIMARY KEY (PAYMENT_LEG_TYPE_CD,VALID_FROM_DTTM)
);



CREATE TABLE &LIBNAME..MAP_PD_BUCKETS
(
   PD_BUCKET            CHARACTER(10)
      LABEL = 'Pd Bucket',
   CONFIGURATION_ID     CHARACTER(32)
      LABEL = 'Configuration Id',
   PD_START             NUMERIC(8)
      LABEL = 'Pd Start',
   VALID_FROM_DTTM      DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid From Datetime',
   PD_END               NUMERIC(8)
      LABEL = 'Pd End',
   VALID_TO_DTTM        DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid To Datetime',
   CONSTRAINT PRIM_KEY PRIMARY KEY (PD_BUCKET,CONFIGURATION_ID,VALID_FROM_DTTM)
);



CREATE TABLE &LIBNAME..MAP_PD_BUCKETS_IRB_EQUITY
(
   REGULATORY_PD_SET_ID CHARACTER(32)
      LABEL = 'Regulatory Pd Set Id',
   EQUITY_POSITION_TYPE_CD CHARACTER(3)
      LABEL = 'Equity Position Type Code',
   REGULATORY_PRODUCT_CD CHARACTER(3)
      LABEL = 'Regulatory Product Code',
   IRB_PD_BUCKET_EQ_PD_LGD CHARACTER(8)
      LABEL = 'IRB Pd Bucket Eq Pd Lgd',
   VALID_FROM_DTTM      DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid From Datetime',
   VALID_TO_DTTM        DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid To Datetime'
);



CREATE TABLE &LIBNAME..MAP_PD_BUCKETS_REGRPT
(
   CONFIGURATION_ID     CHARACTER(32)
      LABEL = 'Configuration Id',
   MAT_START            CHARACTER(8)
      LABEL = 'Mat Start',
   MAT_END              CHARACTER(8)
      LABEL = 'Mat End',
   MAT_BUCKET           CHARACTER(16)
      LABEL = 'Mat Bucket',
   VALID_FROM_DTTM      DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid From Datetime',
   VALID_TO_DTTM        DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid To Datetime'
);



CREATE TABLE &LIBNAME..MAP_PD_RANGE
(
   PD_START             NUMERIC(8)
      LABEL = 'PD Range Lower Limit',
   PD_END               NUMERIC(8)
      LABEL = 'PD Range Upper Limit',
   PD_RANGE             CHARACTER(256)
      LABEL = 'PD Range',
   SCHED                CHARACTER(3)
      LABEL = '',
   CONFIGURATION_ID     CHARACTER(32)
      LABEL = 'Configuration ID',
   VALID_FROM_DTTM      NUMERIC(8)
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid From Datetime',
   VALID_TO_DTTM        NUMERIC(8)
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid To Datetime'
);



CREATE TABLE &LIBNAME..MAP_POSITION_TYPE
(
   VALID_FROM_DTTM      DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid From Datetime',
   SHORTPOSITION        NUMERIC(8)
      LABEL = 'Shortposition',
   VALID_TO_DTTM        DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid To Datetime',
   POSITION_TYPE_CD     CHARACTER(5)
      LABEL = 'Position Type Code',
   SECURITIZATION_POSITION CHARACTER(1)
      LABEL = 'Securitization Position',
   CONSTRAINT PRIM_KEY PRIMARY KEY (VALID_FROM_DTTM,POSITION_TYPE_CD)
);



CREATE TABLE &LIBNAME..MAP_PRODUCT_CLASS
(
   REGULATORY_PRODUCT_CD CHARACTER(3)
      LABEL = 'Regulatory Product Code',
   CONFIGURATION_ID     CHARACTER(32)
      LABEL = 'Configuration Id',
   VALID_FROM_DTTM      DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid From Datetime',
   STD_PRODUCT_CLASS    CHARACTER(32)
      LABEL = 'Std Product Class',
   STD_PRODUCT_SUBCLASS CHARACTER(32)
      LABEL = 'Std Product Subclass',
   IRB_PRODUCT_CLASS    CHARACTER(32)
      LABEL = 'IRB Product Class',
   IRB_PRODUCT_SUBCLASS CHARACTER(32)
      LABEL = 'IRB Product Subclass',
   DESCRIPTION          CHARACTER(256)
      LABEL = 'Description',
   VALID_TO_DTTM        DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid To Datetime',
   REG_Y_PRODUCT_CLASS  CHARACTER(32)
      LABEL = 'Regulatory Y Product Class',
   REG_Y_PRODUCT_SUBCLASS CHARACTER(32)
      LABEL = 'Regulatory Y Product Sub Class',
   CONSTRAINT PRIM_KEY PRIMARY KEY (REGULATORY_PRODUCT_CD,CONFIGURATION_ID,VALID_FROM_DTTM)
);



CREATE TABLE &LIBNAME..MAP_PROVISION_TYPE
(
   PROVISION_TYPE_CD    CHARACTER(3)
      LABEL = 'Provision Type Code',
   VALID_FROM_DTTM      DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid From Datetime',
   PROVISION_TYPE       CHARACTER(18)
      LABEL = 'Provision Type',
   VALID_TO_DTTM        DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid To Datetime',
   CONFIGURATION_ID     CHARACTER(32)
      LABEL = 'Configuration Id',
   CONSTRAINT PRIM_KEY PRIMARY KEY (PROVISION_TYPE_CD,CONFIGURATION_ID,VALID_FROM_DTTM)
);



CREATE TABLE &LIBNAME..MAP_REG_Y_RISK_WEIGHT
(
   REG_Y_PRODUCT_CLASS  CHARACTER(32)
      LABEL = 'Regulatory Y Product Class',
   REG_Y_PRODUCT_SUBCLASS CHARACTER(32)
      LABEL = 'Regulatory Y Product Subclass',
   REGULATORY_COUNTERPARTY_TYPE CHARACTER(32)
      LABEL = 'Regulatory Counterparty Type',
   REG_Y_RISK_WEIGHT    CHARACTER(32)
      LABEL = 'Regulatory Y Risk Weight',
   VALID_FROM_DTTM      DATE
      LABEL = 'Valid From Datetime',
   VALID_TO_DTTM        DATE
      LABEL = 'Valid To Datetime'
);



CREATE TABLE &LIBNAME..MAP_REGULATORY_APPROACH
(
   APPROACH_CLASS       CHARACTER(32)
      LABEL = 'Approach Class',
   VALID_FROM_DTTM      DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid From Datetime',
   APPROACH             CHARACTER(16)
      LABEL = 'Approach',
   APPROACH_USAGE_CD    CHARACTER(3)
      LABEL = 'Approach Usage Code',
   CONFIGURATION_ID     CHARACTER(32)
      LABEL = 'Configuration Id',
   VALID_TO_DTTM        DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid To Datetime',
   CONSTRAINT PRIM_KEY PRIMARY KEY (APPROACH_CLASS,CONFIGURATION_ID,VALID_FROM_DTTM)
);



CREATE TABLE &LIBNAME..MAP_RW_BUCKETS
(
   RW_BUCKET            CHARACTER(10)
      LABEL = 'Rw Bucket',
   CONFIGURATION_ID     VARCHAR(32)
      LABEL = 'Configuration Id',
   RW_START             NUMERIC(8)
      LABEL = 'Rw Start',
   VALID_FROM_DTTM      DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid From Datetime',
   RW_END               NUMERIC(8)
      LABEL = 'Rw End',
   VALID_TO_DTTM        DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid To Datetime',
   CONSTRAINT PRIM_KEY PRIMARY KEY (RW_BUCKET,CONFIGURATION_ID,VALID_FROM_DTTM)
);



CREATE TABLE &LIBNAME..MAP_RW_BUCKETS_REGRPT
(
   CONFIGURATION_ID     CHARACTER(32)
      LABEL = 'Configuration Id',
   APPROACH             CHARACTER(16)
      LABEL = 'Approach',
   RW_START             NUMERIC(8)
      LABEL = 'Rw Start',
   RW_END               NUMERIC(8)
      LABEL = 'Rw End',
   RW_BUCKET            CHARACTER(16)
      LABEL = 'Rw Bucket',
   VALID_FROM_DTTM      DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid From Datetime',
   VALID_TO_DTTM        DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid To Datetime'
);



CREATE TABLE &LIBNAME..MAP_RW_BUCKETS_REGRPT_IRB_SEC
(
   CONFIGURATION_ID     CHARACTER(32)
      LABEL = 'Configuration Id',
   APPROACH             CHARACTER(16)
      LABEL = 'Approach',
   RW_START             NUMERIC(8)
      LABEL = 'Rw Start',
   RW_END               NUMERIC(8)
      LABEL = 'Rw End',
   RW_BUCKET            CHARACTER(20)
      LABEL = 'Rw Bucket',
   VALID_FROM_DTTM      DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid From Datetime',
   VALID_TO_DTTM        DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid To Datetime'
);



CREATE TABLE &LIBNAME..MAP_RW_BUCKETS_REGRPT_SEC
(
   CONFIGURATION_ID     CHARACTER(32)
      LABEL = 'Configuration Id',
   APPROACH             CHARACTER(16)
      LABEL = 'Approach',
   RW_START             NUMERIC(8)
      LABEL = 'Rw Start',
   RW_END               NUMERIC(8)
      LABEL = 'Rw End',
   RW_BUCKET            CHARACTER(16)
      LABEL = 'Rw Bucket',
   VALID_FROM_DTTM      DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid From Datetime',
   VALID_TO_DTTM        DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid To Datetime'
);



CREATE TABLE &LIBNAME..MAP_SEC_BANK_ROLE
(
   BANK_ROLE_CD         CHARACTER(3)
      LABEL = 'Bank Role Code',
   VALID_FROM_DTTM      DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid From Datetime',
   CONFIGURATION_ID     CHARACTER(32)
      LABEL = 'Configuration Id',
   BANK_ROLE            CHARACTER(32)
      LABEL = 'Bank Role',
   VALID_TO_DTTM        DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid To Datetime',
   CONSTRAINT PRIM_KEY PRIMARY KEY (BANK_ROLE_CD,VALID_FROM_DTTM,CONFIGURATION_ID)
);



CREATE TABLE &LIBNAME..MAP_SEC_EAP_TYPE
(
   EARLY_AMORTIZATION_TYPE_CD CHARACTER(3)
      LABEL = 'Early Amortization Type Code',
   VALID_FROM_DTTM      DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid From Datetime',
   CCF_EAP_SET_ID       CHARACTER(32)
      LABEL = 'CCF Eap Set Id',
   EARLY_AMORTIZATION_TYPE CHARACTER(32)
      LABEL = 'Early Amortization Type',
   VALID_TO_DTTM        DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid To Datetime',
   EAP_CAPITAL_REQUIRED CHARACTER(1)
      LABEL = 'Eap Capital Required',
   CONSTRAINT PRIM_KEY PRIMARY KEY (EARLY_AMORTIZATION_TYPE_CD,VALID_FROM_DTTM,CCF_EAP_SET_ID)
);



CREATE TABLE &LIBNAME..MAP_SEC_STRUCTURE_TYPE
(
   CONFIGURATION_ID     CHARACTER(32)
      LABEL = 'Configuration Id',
   SECURITIZ_STRUC_TYPE_CD CHARACTER(3)
      LABEL = 'Securitiz Struc Type Code',
   SECURITIZ_STRUC_SUBTYPE_CD CHARACTER(3)
      LABEL = 'Securitiz Struc Subtype Code',
   SEC_STRUCTURE_TYPE   CHARACTER(16)
      LABEL = 'Sec Structure Type',
   SEC_STRUCTURE_SUBTYPE CHARACTER(16)
      LABEL = 'Sec Structure Subtype',
   VALID_FROM_DTTM      DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid From Datetime',
   VALID_TO_DTTM        DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid To Datetime',
   ELIGIBLE_SECURITIZATION CHARACTER(1)
      LABEL = 'Eligible Securitization'
);



CREATE TABLE &LIBNAME..MAP_SENIORITY
(
   SENIORITY_CD         CHARACTER(3)
      LABEL = 'Seniority Code',
   VALID_FROM_DTTM      DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid From Datetime',
   CONFIGURATION_ID     CHARACTER(32)
      LABEL = 'Configuration Id',
   DESCRIPTION          CHARACTER(128)
      LABEL = 'Description',
   SENIORITY_FLG        NUMERIC(8)
      LABEL = 'Seniority Flag',
   VALID_TO_DTTM        DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid To Datetime',
   CONSTRAINT PRIM_KEY PRIMARY KEY (SENIORITY_CD,VALID_FROM_DTTM,CONFIGURATION_ID)
);



CREATE TABLE &LIBNAME..MAP_SIMULATIONS_DEFINITION
(
   SIMULATION_NM        VARCHAR(40)
      LABEL = 'Simulation Name',
   SIMULATION_METHOD_NM VARCHAR(40)
      LABEL = 'Method Name',
   MARKET_DATA_LIST_ID  VARCHAR(32)
      LABEL = 'Market Data List ID',
   COVARIANCE_DATA_SET_NM VARCHAR(32)
      LABEL = 'Covariance Data Set Name',
   NDRAW_CNT            NUMERIC(6)
      LABEL = 'Ndraw Count',
   HORIZON_LIST_ID      VARCHAR(32)
      LABEL = 'HORIZON_LIST_TXT',
   HORIZON_INTERVAL_NM  VARCHAR(32)
      LABEL = 'TIME_PERIOD_CD',
   SEED_NO              NUMERIC(10)
      LABEL = 'Seed No',
   MODEL_LIST_ID        VARCHAR(32)
      LABEL = 'MODEL_LIST_ID',
   OTHER_SPEC_TXT       VARCHAR(100)
      LABEL = 'Other Spec Text',
   VALID_FROM_DTTM      DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid From Datetime',
   VALID_TO_DTTM        DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid To Datetime',
   CONSTRAINT PRIM_KEY PRIMARY KEY (SIMULATION_NM,VALID_FROM_DTTM)
);



CREATE TABLE &LIBNAME..MAP_STD_RW_BUCKET_OTHERS_ASSET
(
   REGULATORY_RISK_WEIGHT_SET_ID VARCHAR(32)
      LABEL = 'Regulatory Risk Weight Set Id',
   STD_PRODUCT_SUBCLASS VARCHAR(32)
      LABEL = 'Std Product Subclass',
   STD_RW_BUCKET_OTHERS CHARACTER(8)
      LABEL = 'Std Rw Bucket Others',
   VALID_FROM_DTTM      DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid From Datetime',
   VALID_TO_DTTM        DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid To Datetime'
);



CREATE TABLE &LIBNAME..MAP_STD_RW_BUCKETS
(
   EXT_MAP_RATING       CHARACTER(6)
      LABEL = 'Ext Map Rating',
   STD_RW_BUCKET_SOVEREIGN CHARACTER(8)
      LABEL = 'Std Rw Bucket Sovereign',
   VALID_FROM_DTTM      DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid From Datetime',
   SHORTTERM_FLG        NUMERIC(3)
      LABEL = 'Shortterm Flag',
   STD_RW_BUCKET_CORPORATE CHARACTER(8)
      LABEL = 'Std Rw Bucket Corporate',
   STD_RW_BUCKET_SHORT  CHARACTER(8)
      LABEL = 'Std Rw Bucket Short',
   STD_RW_BUCKET_SEC    CHARACTER(8)
      LABEL = 'Std Rw Bucket Sec',
   STD_RW_BUCKET_SEC_SHORT CHARACTER(8)
      LABEL = 'Std Rw Bucket Sec Short',
   STD_RW_BUCKET_INSTITUTION   CHARACTER(8)  
      LABEL = 'Std Rw Bucket Institution',
   REGULATORY_RISK_WEIGHT_SET_ID CHARACTER(32)
      LABEL = 'Regulatory Risk Weight Set Id',
   VALID_TO_DTTM        DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid To Datetime',
   STD_RW_BUCKET_CIU    CHARACTER(8)
      LABEL = 'Std Rw Bucket CIU',
   STD_RW_BUCKET_COV_BOND    CHARACTER(8)
      LABEL = 'Std Rw Bucket COV_BOND',
   STD_RW_BUCKET_BANK    CHARACTER(8)
      LABEL = 'Std Rw Bucket Bank',
   
      CONSTRAINT PRIM_KEY PRIMARY KEY (EXT_MAP_RATING,REGULATORY_RISK_WEIGHT_SET_ID,VALID_FROM_DTTM,SHORTTERM_FLG)
);



CREATE TABLE &LIBNAME..MAP_STD_RW_BUCKETS_CME
(
   REGULATORY_RISK_WEIGHT_SET_ID CHARACTER(32)
      LABEL = 'Regulatory Risk Weight Set Id',
   REGULATORY_PRODUCT_CD CHARACTER(3)
      LABEL = 'Regulatory Product Code',
   STD_RW_BUCKET_CME    CHARACTER(8)
      LABEL = 'Std Rw Bucket Cme',
   VALID_FROM_DTTM      DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid From Datetime',
   VALID_TO_DTTM        DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid To Datetime'
);



CREATE TABLE &LIBNAME..MAP_STD_RW_BUCKETS_HIRISK_PREF
(
   REGULATORY_RISK_WEIGHT_SET_ID VARCHAR(32)
      LABEL = 'REGULATORY_RISK_WEIGHT_SET_ID',
   STD_RW_BUCKET_HIGH_RISK CHARACTER(18)
      LABEL = 'STD_RW_BUCKET_HIGH_RISK',
   VALID_FROM_DTTM      DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid From Datetime',
   VALID_TO_DTTM        DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid To Datetime',
   VALUE_ADJUSTMENT_START_PCT NUMERIC(9,4)
      FORMAT = NLNUM9.4
      INFORMAT = NLNUM9.4
      LABEL = 'Value Adjustment Start Percent',
   VALUE_ADJUSTMENT_END_PCT NUMERIC(9,4)
      FORMAT = NLNUM9.4
      INFORMAT = NLNUM9.4
      LABEL = 'Value Adjustment End Percent',
   CONSTRAINT PRIM_KEY PRIMARY KEY (REGULATORY_RISK_WEIGHT_SET_ID,STD_RW_BUCKET_HIGH_RISK,VALID_FROM_DTTM)
);



CREATE TABLE &LIBNAME..MAP_STD_RW_BUCKETS_OTHERS
(
   REGULATORY_RISK_WEIGHT_SET_ID CHARACTER(32)
      LABEL = 'Regulatory Risk Weight Set Id',
   REGULATORY_PRODUCT_CD CHARACTER(3)
      LABEL = 'Regulatory Product Code',
   STD_RW_BUCKET_OTHERS CHARACTER(8)
      LABEL = 'Std Rw Bucket Others',
   VALID_FROM_DTTM      DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid From Datetime',
   VALID_TO_DTTM        DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid To Datetime'
);



CREATE TABLE &LIBNAME..MAP_STD_RW_BUCKETS_PASTDUE
(
   REGULATORY_RISK_WEIGHT_SET_ID CHARACTER(32)
      LABEL = 'Regulatory Risk Weight Set Id',
   PAST_DUE_CATEGORY    CHARACTER(32)
      LABEL = 'Past Due Category',
   VALUE_ADJUSTMENT_PCT_START NUMERIC(8)
      LABEL = 'Value Adjustment Percent Start',
   VALUE_ADJUSTMENT_PCT_END NUMERIC(8)
      LABEL = 'Value Adjustment Percent End',
   VALID_FROM_DTTM      DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid From Datetime',
   STD_RW_BUCKET_PASTDUE CHARACTER(8)
      LABEL = 'Std Rw Bucket Pastdue',
   VALID_TO_DTTM        DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid To Datetime'
);



CREATE TABLE &LIBNAME..MAP_STD_RW_BUCKETS_RETAIL
(
   REGULATORY_RISK_WEIGHT_SET_ID CHARACTER(32)
      LABEL = 'Regulatory Risk Weight Set Id',
   REGULATORY_PRODUCT_CD CHARACTER(3)
      LABEL = 'Regulatory Product Code',
   STD_RW_BUCKET_RETAIL CHARACTER(8)
      LABEL = 'Std Rw Bucket Retail',
   VALID_FROM_DTTM      DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid From Datetime',
   VALID_TO_DTTM        DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid To Datetime'
);



CREATE TABLE &LIBNAME..MAP_STD_RW_BUCKETS_RME
(
   REGULATORY_RISK_WEIGHT_SET_ID CHARACTER(32)
      LABEL = 'Regulatory Risk Weight Set Id',
   REGULATORY_PRODUCT_CD CHARACTER(3)
      LABEL = 'Regulatory Product Code',
   STD_RW_BUCKET_RME    CHARACTER(8)
      LABEL = 'Std Rw Bucket Rme',
   VALID_FROM_DTTM      DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid From Datetime',
   VALID_TO_DTTM        DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid To Datetime',
   LTV_START_PCT        NUMERIC(9,4)
      FORMAT = NLNUM9.4
      INFORMAT = NLNUM9.4
      LABEL = 'Ltv Start Percent',
   LTV_END_PCT          NUMERIC(9,4)
      FORMAT = NLNUM9.4
      INFORMAT = NLNUM9.4
      LABEL = 'Ltv End Percent'
);



CREATE TABLE &LIBNAME..MAP_TIME_UNIT
(
   TIME_UNIT_CD         CHARACTER(3)
      LABEL = 'Time Unit Code',
   VALID_FROM_DTTM      DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid From Datetime',
   TIME_UNIT            CHARACTER(8)
      LABEL = 'Time Unit',
   VALID_TO_DTTM        DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid To Datetime',
   CONSTRAINT PRIM_KEY PRIMARY KEY (TIME_UNIT_CD,VALID_FROM_DTTM)
);


CREATE TABLE &LIBNAME..MAP_SA_CLASS
(
   CONFIGURATION_ID CHARACTER(32)
      LABEL = 'Configuration Id',
   REGLTRY_COUNTERPARTY_TYPE_CD CHARACTER(3)
      LABEL = 'Regulatory Counterparty Type Code',
   REGULATORY_PRODUCT_CD    CHARACTER(3)
      LABEL = 'Regulatory Product Code',
   SA_CLASS    CHARACTER(32)
      LABEL = 'SA Class',
   SA_CLASS_DESCRIPTION    CHARACTER(100)
      LABEL = 'SA Class Description',
   VALID_FROM_DTTM      DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid From Datetime',
   VALID_TO_DTTM      DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid To Datetime'
);

CREATE TABLE &LIBNAME..MAP_IRB_CLASS
(
   EXPOSURE_CLASS_LEVEL_1 CHARACTER(40)
      LABEL = 'Exposure Class Level 1',
   EXPOSURE_CLASS_LEVEL_2 CHARACTER(40)
      LABEL = 'Exposure Class Level 2',
   OWN_LGD_CCF_ESTIMATES  CHARACTER(10)
      LABEL = 'Specifies whether Own LGD and/or CCF values are used (YES/NO)',
   SME_SUPPORT_FACTOR  CHARACTER(20)
      	LABEL = 'Specifies whether SME_SUPPORT_FACTOR  used ',
   IRB_CLASS CHARACTER(75)
      LABEL = 'Format for IRB Reporting Template',
   EXPOSURE_CLASS_IRB_LEVEL_1 CHARACTER(40)
      LABEL = 'Exposure Class IRB Level 1',
   VALID_FROM_DTTM      DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid From Datetime',
   VALID_TO_DTTM      DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid To Datetime'
);

CREATE TABLE &LIBNAME..MAP_COUNTRY_INFO
(
   CONFIG_ID           CHARACTER(32)
      LABEL = 'Config Id',
   VALID_FROM_DTTM      DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid From Datetime',
   COUNTRY_CD          CHARACTER(3)
      LABEL = 'Country Code',
   VALID_TO_DTTM        DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid To Datetime',
   COUNTRY_NM CHARACTER(40)
      LABEL = 'Country Name',
   COUNTRY_CURRENCY_1_CD CHARACTER(3)
      LABEL = 'Country Currency 1 Code',
   COUNTRY_CURRENCY_2_CD CHARACTER(3)
      LABEL = 'Country Currency 2 Code',
   COUNTRY_CURRENCY_3_CD CHARACTER(3)
      LABEL = 'Country Currency 3 Code',
   TGT_OECD_COUNTRY_FLG CHARACTER(1)
      LABEL = 'Target Oecd Country Flag',
   TGT_EEA_COUNTRY_FLG CHARACTER(1)
      LABEL = 'Target Eea Country Flag'
);


CREATE TABLE &LIBNAME..MAP_CPTY_SECTOR_LE
(
   CONFIGURATION_ID  CHARACTER(32)
      LABEL = 'Configuration Id',
   SECTOR          CHARACTER(32)
      LABEL = 'Sector',
   VALID_FROM_DTTM      DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid From Datetime',
   VALID_TO_DTTM        DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid To Datetime',
   DESCRIPTION    CHARACTER(256)
      LABEL = 'Description',
   LE_SECTOR          CHARACTER(32)
      LABEL = 'LE Sector'
);

CREATE TABLE &LIBNAME..MAP_LE_CLASS_REGRPT
(
   CONFIGURATION_ID  CHARACTER(32)
      LABEL = 'Configuration Id',
   REGULATORY_PRODUCT_CD     CHARACTER(32)
      LABEL = 'Regulatory Product Code',
   VALID_FROM_DTTM      DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid From Datetime',
   VALID_TO_DTTM        DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid To Datetime',
   LE_PRODUCT_CLASS   CHARACTER(32)
      LABEL = 'LE Product Class'
);

CREATE TABLE &LIBNAME..MAP_LE_OBSI_TYPE_REGRPT
(
   CONFIGURATION_ID  CHARACTER(32)
      LABEL = 'Configuration Id',
   OFF_BALANCE_SHEET_TYPE_CD     CHARACTER(32)
      LABEL = 'Off Balance Sheet Code',
   VALID_FROM_DTTM      DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid From Datetime',
   VALID_TO_DTTM        DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid To Datetime',
   LE_OBSI_TYPE   CHARACTER(32)
      LABEL = 'LE OBSI Type',
   REGULATORY_PRODUCT_CD     CHARACTER(3)
      LABEL = 'Regulatory Product Code'
);

CREATE TABLE &LIBNAME..MAP_RW_BUCKETS_REGRPT_LR
(
   CONFIGURATION_ID  CHARACTER(32)
      LABEL = 'Configuration Id',
   RW_START     NUMERIC(8)
      LABEL = 'RW Start',
   RW_END     NUMERIC(8)
      LABEL = 'RW End',
   RW_BUCKET   CHARACTER(16)
      LABEL = 'RW_BUCKET',
   VALID_FROM_DTTM      DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid From Datetime',
   VALID_TO_DTTM        DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid To Datetime'

);

CREATE TABLE &LIBNAME..MAP_MAT_BUCKETS_LE_REGRPT
(
   CONFIGURATION_ID  CHARACTER(32)
      LABEL = 'Configuration Id',
   MAT_START     NUMERIC(8)
      LABEL = 'Start of maturity bucket(in months)',
   MAT_END     NUMERIC(8)
      LABEL = 'End of maturity bucket(in months)',
   MAT_DESCRIPTION     CHARACTER(36)
      LABEL = 'Maturity bucket mapping definition',
   VALID_FROM_DTTM      DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid From Datetime',
   VALID_TO_DTTM        DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid To Datetime'
);

CREATE TABLE &LIBNAME..MAP_CQS_EXT_RATING
(
   CONFIGURATION_ID     CHARACTER(32)
      	LABEL = 'Configuration Id',
   EXT_MAP_RATING       VARCHAR(5)
       LABEL = 'Ext Map Rating',
   CQS_IRB_SEC 	  VARCHAR(5)
	LABEL = 'Credit Quality Step - IRB',   
   CQS_STD_SEC 	  VARCHAR(5)
 	LABEL = 'Credit Quality Step - STD',   
   VALID_FROM_DTTM      DATE
	FORMAT = NLDATM21.
	INFORMAT = NLDATM21.
	LABEL = 'Valid From Datetime',
   VALID_TO_DTTM        DATE
	FORMAT = NLDATM21.
	INFORMAT = NLDATM21.
	LABEL = 'Valid To Datetime'
);

CREATE TABLE &LIBNAME..MAP_FINANCIAL_BOOK_TYPE   
(
   CONFIGURATION_ID     CHARACTER(32)
      	LABEL = 'Configuration Id',   
FINANCIAL_BOOK_TYPE_CD      CHARACTER(16)
      LABEL = 'Financial Book Type Code',
   SECURITIZATION_TREATMENT_TYPE      CHARACTER(1)
      LABEL = 'Securitization Treatment Type',
   VALID_FROM_DTTM      DATE
	FORMAT = NLDATM21.
	INFORMAT = NLDATM21.
	LABEL = 'Valid From Datetime',
   VALID_TO_DTTM        DATE
	FORMAT = NLDATM21.
	INFORMAT = NLDATM21.
	LABEL = 'Valid To Datetime',
CONSTRAINT PRIM_KEY PRIMARY KEY (CONFIGURATION_ID,FINANCIAL_BOOK_TYPE_CD,VALID_FROM_DTTM) 
);

CREATE TABLE &LIBNAME..MAP_SEC_ACCTNG_TREATMENT   
(
   CONFIGURATION_ID     CHARACTER(32)
      	LABEL = 'Configuration Id',   
   ACCTING_TREATMENT_CD      CHARACTER(3)
     	 LABEL = 'Accounting Treatment Code',
   SEC_ACCTING_TREATMENT      CHARACTER(1)
     	 LABEL = 'Securitization Accounting Treatment',
   VALID_FROM_DTTM      DATE
	FORMAT = NLDATM21.
	INFORMAT = NLDATM21.
	LABEL = 'Valid From Datetime',
   VALID_TO_DTTM        DATE
	FORMAT = NLDATM21.
	INFORMAT = NLDATM21.
	LABEL = 'Valid To Datetime',
CONSTRAINT PRIM_KEY PRIMARY KEY (CONFIGURATION_ID,ACCTING_TREATMENT_CD,VALID_FROM_DTTM)
);

CREATE TABLE &LIBNAME..MAP_SEC_PORTFOLIO_TYPE  
(
   CONFIGURATION_ID     CHARACTER(32)
      	LABEL = 'Configuration Id',   
   SEC_PORTFOLIO_TYPE_CD      CHARACTER(16)
     	 LABEL = 'Securitization Portfolio Type Code',
   SEC_PORTFOLIO_TYPE      CHARACTER(2)
      	LABEL = 'Securitization Portfolio Type',
   VALID_FROM_DTTM      DATE
	FORMAT = NLDATM21.
	INFORMAT = NLDATM21.
	LABEL = 'Valid From Datetime',
   VALID_TO_DTTM        DATE
	FORMAT = NLDATM21.
	INFORMAT = NLDATM21.
	LABEL = 'Valid To Datetime',
CONSTRAINT PRIM_KEY PRIMARY KEY (CONFIGURATION_ID,SEC_PORTFOLIO_TYPE_CD,VALID_FROM_DTTM)
);

CREATE TABLE &LIBNAME..MAP_SEC_RETENTION_TYPE   
(
   CONFIGURATION_ID     CHARACTER(32)
      	LABEL = 'Configuration Id',   
   RETENTION_TYPE_CD      CHARACTER(16)
	LABEL = 'Retention Type Code',
   SEC_RETENTION_TYPE      CHARACTER(1)
      LABEL = 'Securitization Retention Type',
   VALID_FROM_DTTM      DATE
	FORMAT = NLDATM21.
	INFORMAT = NLDATM21.
	LABEL = 'Valid From Datetime',
   VALID_TO_DTTM        DATE
	FORMAT = NLDATM21.
	INFORMAT = NLDATM21.
	LABEL = 'Valid To Datetime',
CONSTRAINT PRIM_KEY PRIMARY KEY (CONFIGURATION_ID,RETENTION_TYPE_CD,VALID_FROM_DTTM)
);

CREATE TABLE &LIBNAME..MAP_INVESTMENT_FIRM_TYPE   
(
   CONFIGURATION_ID     CHARACTER(32)
      	LABEL = 'Configuration Id',   
   BUSINESS_TYPE_CD     CHARACTER(40)
      LABEL = 'Code Identifying Type of Business, Such as Investment Firm With Limited
 Authorization to Provide Service',
   INVESTMENT_FIRM_TYPE      CHARACTER(32)
      LABEL = 'Type of investment firm',
   VALID_FROM_DTTM      DATE
	FORMAT = NLDATM21.
	INFORMAT = NLDATM21.
	LABEL = 'Valid From Datetime',
   VALID_TO_DTTM        DATE
	FORMAT = NLDATM21.
	INFORMAT = NLDATM21.
	LABEL = 'Valid To Datetime',
CONSTRAINT PRIM_KEY PRIMARY KEY (CONFIGURATION_ID,BUSINESS_TYPE_CD,VALID_FROM_DTTM)
);

CREATE TABLE &LIBNAME..MAP_OBSI_SEC_DETAIL_REGRPT
(
   CONFIGURATION_ID  CHARACTER(32)
      LABEL = 'Configuration Id',
   OFF_BALANCE_SHEET_TYPE_CD CHARACTER(3)
      LABEL = 'Off Balance Sheet Type Code',
   SEC_DETAIL_OBSI_TYPE CHARACTER(3)
      LABEL = 'Sec Detail OBSI Type',
   VALID_FROM_DTTM      DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid From Datetime',
   VALID_TO_DTTM        DATE
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid To Datetime'
);
QUIT;
