/*****************************************************************************
 * Copyright (c) 2013 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME: stored_process_regrpt_prj_run_crd4.sas
 *
 * PURPOSE: Runs extra projects for internal report data
 *
 *   USAGE: 
 *
 *   NOTES: 1. This runs data for regulatory report projects
 *  MODIFIED:V4.8 12/25/05
 * UPDATES:
  *****************************************************************************/

%crmbinit;
%global regrpt_input_name CUBE_OUTPUT;
%let CUBE_OUTPUT=NO;

%macro projrun (projectname);
   

	%if %upcase(&projectname)=CAPITAL_CRSA_CRD4  %then %e10_proj_regrpt_cap_crsa_crd4;
	%else %if %upcase(&projectname)=CAPITAL_CRIRBA_CRD4 %then %e10_proj_regrpt_cap_crirb_crd4;
	%else %if %upcase(&projectname)=CAPITAL_CREQU_CRD4 %then %e10_project_regrpt_cr_equ_crd4;
	%else %if %upcase(&projectname)=CAPITAL_CRGB_SA_CRD4    %then %e10_prj_regrpt_cap_crgb_sa_crd4;
 	%else %if %upcase(&projectname)=CAPITAL_CA_CRD4 %then  %e10_proj_regrpt_capital_ca_crd4;
	%else %if %upcase(&projectname)=CAPITAL_CRGB_IRBA_CRD4   %then %e10_prj_regrpt_cap_gb_irba_crd4;
	%else %if %upcase(&projectname)=CAPITAL_CRGB_3_CRD4   %then %e10_proj_regrpt_cap_gb3_crd4;
/*	%else %if %upcase(&projectname)=CAPITAL_LE1_CRD4 %then %e10_project_regrpt_le1_crd4;*/
	%else %if %upcase(&projectname)=CAPITAL_LE2_CRD4 %then %e10_project_regrpt_le2_crd4;
	%else %if %upcase(&projectname)=CAPITAL_LE3_CRD4 %then %e10_project_regrpt_le3_crd4;
	%else %if %upcase(&projectname)=CAPITAL_LE4_CRD4 %then %e10_project_regrpt_le4_crd4;
	%else %if %upcase(&projectname)=CAPITAL_LE5_CRD4 %then %e10_project_regrpt_le5_crd4;
	%else %if %upcase(&projectname)=CAPITAL_LE_LIMITS %then %e10_proj_regrpt_le_limits_crd4;
	%else %if %upcase(&projectname)=CAPITAL_LR2 %then %e10_proj_regrpt_cap_lr2_crd4;
	%else %if %upcase(&projectname)=CAPITAL_LR4 %then %e10_proj_regrpt_cap_lr4_crd4;
	%else %if %upcase(&projectname)=CAPITAL_CVA_CRD4 %then %e10_project_regrpt_cva_crd4;
	%else %if %upcase(&projectname)=CAPITAL_CRSEC_SA_CRD4 %then %e10_proj_regrpt_cap_sec_sa_crd4;
	%else %if %upcase(&projectname)=CAPITAL_CRSEC_IRB_CRD4 %then %e10_proj_regrpt_cap_secirb_crd4;
	%else %if %upcase(&projectname)=CAPITAL_CRSEC_DET_CRD4 %then %e10_project_regrpt_sec_det_crd4;
	

    

%mend projrun;





%macro regrpt; 
%local STP_NAME;
%let STP_NAME=Refresh regulatory report data;
/*---------------------------------------------------------------------------
 * Step 1.
 *
 * Invoke autoexec to define libraries
 * 
 * -------------------------------------------------------------------------*/

%autoexec_criskm (sysid=&system_id, usrtype=&usertype, usrname=&_metauser,reg_ctxt=CRD4);
%criskm_update_stp_status(STP_NAME=&STP_NAME,
								  PORTFOLIO_FILTER_ID=&FILTER_ID,
								  STP_STATUS=Progress,
 								  STATUS_PCT=5%         ,
								  LOG_FILE_NAME=%sysget(LOGFILE)   ,
								  UPDATE_DTTM_FLG=Y     );

%u00_recreate_macro_definitions;
%u_00_prepare_portfolio_header;
 


/*---------------------------------------------------------------------------
 * Step 3. - Optional Run the setup if user requests
 *
 * Define library to regulatory project catalog and environments
 * We need to check to see if the portfolio was created
 * -------------------------------------------------------------------------*/
%if &SYSTEM_FATAL_ERROR EQ N %then %do;
%let orig_regproject=&REGPROJECTNAME;
%if &REFRESH ne NO %then %do;
  %if &SYSTEM_FATAL_ERROR NE Y %then  %a00_initial_regrpt;
  %if &SYSTEM_FATAL_ERROR NE Y %then  %a10_create_regrpt_fmt_crd4;
  
  %if &SYSTEM_FATAL_ERROR NE Y %then  %b15_prep_regrpt_port_crequ_crd4;
  %if &SYSTEM_FATAL_ERROR NE Y %then  %b20_prep_regrpt_port_sec_sa_crd4;
  %if &SYSTEM_FATAL_ERROR NE Y %then  %b20_prep_regrpt_port_crgb3_crd4;
  %if &SYSTEM_FATAL_ERROR NE Y %then  %b20_prep_regrpt_port_secirb_crd4;
  %if &SYSTEM_FATAL_ERROR NE Y %then  %b25_prep_regrpt_port_crirb_crd4;
  %if &SYSTEM_FATAL_ERROR NE Y %then  %b30_prep_regrpt_port_crsa_crd4;
				%criskm_update_stp_status(STP_NAME=&STP_NAME,
										  STP_STATUS=Progress,STATUS_PCT=25% );   
  %if &SYSTEM_FATAL_ERROR NE Y %then  %b35_prep_regrpt_port_ca_crd4;
  %if &SYSTEM_FATAL_ERROR NE Y %then  %b25_prepare_regrpt_port_le_crd4;
  %if &SYSTEM_FATAL_ERROR NE Y %then  %b30_prep_regrpt_port_le45_crd4;
  %if &SYSTEM_FATAL_ERROR NE Y %then  %b30_prep_regrpt_le_limits_crd4;
  %if &SYSTEM_FATAL_ERROR NE Y %then  %b40_prepare_regrpt_port_lr_crd4;
  %if &SYSTEM_FATAL_ERROR NE Y %then  %b35_prep_regrpt_port_cva_crd4;
  %if &SYSTEM_FATAL_ERROR NE Y %then  %b45_prepare_regrpt_sec_det_crd4;
 /*  %if &SYSTEM_FATAL_ERROR NE Y %then  %b25_prepare_regrpt_port_crgb;*/
              %criskm_update_stp_status(STP_NAME=&STP_NAME,
										  STP_STATUS=Progress,STATUS_PCT=50% );   
  %if &SYSTEM_FATAL_ERROR NE Y %then  %c00_create_regrpt_environment;
  %if &SYSTEM_FATAL_ERROR NE Y %then  %c10_def_regrpt_inst_var_crd4;
  %if &SYSTEM_FATAL_ERROR NE Y %then  %c10_def_regrpt_output_var_crd4;
  %if &SYSTEM_FATAL_ERROR NE Y %then  %c20_def_regrpt_ccvars_crd4;
  %if &SYSTEM_FATAL_ERROR NE Y %then  %d00_pm_regrpt_crd4;
  %if &SYSTEM_FATAL_ERROR NE Y %then %d00_pm_regrpt_rollup_crd4;
  %if &SYSTEM_FATAL_ERROR NE Y %then  %d10_def_regrpt_inst_types_crd4;
  %if &SYSTEM_FATAL_ERROR NE Y %then  %d20_create_regrpt_portfolios;
%end;

        %criskm_update_stp_status(STP_NAME=&STP_NAME,
										  STP_STATUS=Progress,STATUS_PCT=75% );    
/*---------------------------------------------------------------------------
 * Step 4.
 *
 * Run the Risk Dimensions projects for each of the major reports requested
 * Only run the project if the portfolio exists and no major errors are reported
 * -------------------------------------------------------------------------*/

/* Set fileref tmprpt for report invocation statements */
filename projrun catalog 'work.temp.projects.source'; 

/*---------------------------------------------------------------------------
 * Step 5.
 *
 * Define library to internal reports catalog and environments
 * We need to check to see if the portfolio was created
 * -------------------------------------------------------------------------*/

data _null_;
 file projrun;
 put '%macro runproject;';
/* put 'libname _tmp_ "%sysget(CRISKMUSER)&pathsep.env&pathsep.projects";';*/
/* put 'proc catalog cat=_tmp_.regrpt;';*/
/* put 'contents out= _regcat_ (keep=name type where=(type="RISK10"));';*/
/* put 'quit;';*/
/**/
 put 'libname _tmp_ "%sysget(CRISKMUSER)&pathsep.env&pathsep.projects&pathsep.regrpt";';
 put 'data _regcat_(keep = portfolio_nm type rename=(portfolio_nm=name ));';
 put 'set _tmp_.rd_portfolio;';
 put 'type="RISK10";';
 put 'run;';

 put 'data _null_;';
 put ' set work._regcat_;';
 put ' call symput (name,type);';
 put 'run;';

/*---------------------------------------------------------------------------
 * Step 6.
 *
 * Print out the projects we are updating
 * -------------------------------------------------------------------------*/
 put '%stpbegin;';
 put 'options leftmargin=.75in rightmargin=.75in topmargin=.5in bottommargin=.5in;';
 put '%ODSHEADER (%sysget(CRISKMUSER)&pathsep.reports&pathsep.projreports,reg_project_update_list);';
 put '%get_regrpt_nls_strings';
 put 'title1 "&_regportfolios" ;';
 put 'title2 "&_regport_update_desc";';
 put 'footnote2  "&generated : %sysfunc(putn(%sysfunc(datetime()), NLDATMAP.))";';
 put 'proc print data=work._regcat_;';
 put 'run;';
 put 'ods _all_ close;';
/* put '%if %symglobl(_criskm_outputLoc) eq 0 %then %do;';*/
/* put '            %global _criskm_outputLoc;';*/
/* put '        data _NULL_;';*/
/* put '            call symput( "_criskm_outputLoc", */
/*''/buildTree.do?libname=projrps&fileExt=.html&fileExt=.pdf&exclude_dirs=graphics&show_empty_dirs=false&task_key=Results&menu_key=Project_Reports'' );';*/
/* put '        run;';*/
/* put '       %end;';*/
 put '%stpend;';
run;



%if %upcase(&REGPROJECTNAME) eq ALL %then %do;
data _null_;
 set rd_nls.regulatory_report_list_&reporting_language ;
 file projrun mod;
 put '%let regprojectname=' rpt_cd ';';
 put '%let regrpt_input_name=' rpt_cd ';';
 put '%if %symglobl (' rpt_cd ') NE 0 %then %do;';
 put '%if (&SYSTEM_FATAL_ERROR NE Y) and (&&' rpt_cd ' eq RISK10)  %then %projrun (' rpt_cd ');';
 put '%end;%else %do;';
 put '%print_msg (WARNING,3,68);';
 put '%put &regrpt_input_name;';
 put '%end;';
 where upcase (allocation_method) eq "%upcase(&mitigants_allocation_method)" 
  AND  upcase (config_set) eq "%upcase(&config_set)";
run;

%goto FINISH;
        
%end;
%else;
%if %upcase(&REGPROJECTNAME) eq STD %then %do;
data _null_;
 set rd_nls.regulatory_report_list_&reporting_language ;
 file projrun mod;
 put '%let regprojectname=' rpt_cd ';';
 put '%let regrpt_input_name=' rpt_cd ';';
 put '%if %symglobl (' rpt_cd ') NE 0 %then %do;';
 put '%if (&SYSTEM_FATAL_ERROR NE Y) and (&&' rpt_cd ' eq RISK10)  %then %projrun (' rpt_cd ');';
 put '%end;%else %do;';
 put '%print_msg (WARNING,3,68);';
 put '%put &regrpt_input_name;';
 put '%end;';
 where (upcase(report_group) eq 'STD') and upcase (allocation_method) eq "%upcase(&mitigants_allocation_method)"
  AND  upcase (config_set) eq "%upcase(&config_set)";
run;
  
%goto FINISH;
      
%end;%else
%if %upcase(&REGPROJECTNAME) eq IRB %then %do;
data _null_;
 set rd_nls.regulatory_report_list_&reporting_language ;
 file projrun mod;
 put '%let regprojectname=' rpt_cd ';';
 put '%let regrpt_input_name=' rpt_cd ';';
 put '%if %symglobl (' rpt_cd ') NE 0 %then %do;';
 put '%if (&SYSTEM_FATAL_ERROR NE Y) and (&&' rpt_cd ' eq RISK10)  %then %projrun (' rpt_cd ');';
 put '%end;%else %do;';
 put '%print_msg (WARNING,3,68);';
 put '%put &regrpt_input_name;';
 put '%end;';
 where (upcase(report_group) eq 'IRB') and upcase (allocation_method) eq "%upcase(&mitigants_allocation_method)"
  AND  upcase (config_set) eq "%upcase(&config_set)";
run;
 
%goto FINISH;
      
%end;%else
%if %upcase(&REGPROJECTNAME) eq SEC %then %do;
data _null_;
 set rd_nls.regulatory_report_list_&reporting_language ;
 file projrun mod ;
 put '%let regprojectname=' rpt_cd ';';
 put '%let regrpt_input_name=' rpt_cd ';';
 put '%if %symglobl (' rpt_cd ') NE 0 %then %do;';
 put '%if (&SYSTEM_FATAL_ERROR NE Y) and (&&' rpt_cd ' eq RISK10)  %then %projrun (' rpt_cd ');';
 put '%end;%else %do;';
 put '%print_msg (WARNING,3,68);';
 put '%put &regrpt_input_name;';
 put '%end;';
 where (upcase(report_group) eq 'SEC') and upcase (allocation_method) eq "%upcase(&mitigants_allocation_method)"
  AND  upcase (config_set) eq "%upcase(&config_set)";
run;

%goto FINISH;
        
%end;
%else %do;
data _null_;
 set rd_nls.regulatory_report_list_&reporting_language ;
file projrun mod;

 put '%let regrpt_input_name=' rpt_cd ';';
 put '%if %symglobl (' rpt_cd ') NE 0 %then %do;';
 put '%if (&SYSTEM_FATAL_ERROR NE Y) and (&&' rpt_cd ' eq RISK10)  %then %projrun (' rpt_cd ');';
 put '%end;%else %do;';
 put '%print_msg (WARNING,3,68);';
 put '%put &regrpt_input_name;';
 put '%end;';
where (upcase(rpt_cd) eq "%upcase(&REGPROJECTNAME)") and upcase (allocation_method) eq "%upcase(&mitigants_allocation_method)"
  AND  upcase (config_set) eq "%upcase(&config_set)";
run;
%end;
   
%goto FINISH;
     

%end;
 %else
    %if &SYSTEM_FATAL_ERROR EQ Y %then %do;
		%error_occured:
		%print_msg (error,1,5);
		%criskm_update_stp_status(STP_NAME=&STP_NAME,
								  PORTFOLIO_FILTER_ID=&FILTER_ID,
								  LOG_FILE_NAME=%sysget(LOGFILE)   ,
										  STP_STATUS=Failed,STATUS_PCT=0%, UPDATE_DTTM_FLG=Y );
    %end;

%ERREXIT:
     %print_msg(ERROR,2,99);
%FINISH:
data _null_;
 file projrun mod;
 put '%mend runproject;';
 put '%runproject;';
 put '%criskm_update_stp_status(STP_NAME=Refresh regulatory report data,STP_STATUS=Complete,STATUS_PCT=100%,UPDATE_DTTM_FLG=Y);';
run;

%mend regrpt;

%regrpt;

%inc projrun;
