/*****************************************************************************
 * Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME: a05_define_natl_disc_fmt_crd4.sas
 *
 * PURPOSE: Creates formats for options left to national regulators.
 *
 *   USAGE: Create formats to map option values for regulatory options on a
 *          country by country basis.
 *
 *   NOTES: 
 *          
 *
 *****************************************************************************/

%macro a05_define_natl_disc_fmt_crd4;

/*-  add Format for EEA member flag CRR Article 114 -*/
data fmt (keep = FMTNAME START END LABEL TYPE HLO);
set RD_MAP.map_national_discretion end=lastobs;
      FMTNAME          = 'MAP_EEA_MEMBER_FLG' ;
      START            = compress(COUNTRY_CD);
      END              = START          ;
      LABEL            = EEA_MEMBER_FLG;
      TYPE             = 'C' ;
      output ;
      if lastobs then do;
         START            ='**OTHER**' ;
         END              = START;
         HLO              ='O' ;
         LABEL            ='';
         output ;
      end;
run;

proc format cntlin=fmt lib=RD_ENV; run;

/*- Format for preferential treatment for domestic sovereigns (BII,p54) -*/
data fmt (keep = FMTNAME START END LABEL TYPE HLO);
set RD_MAP.map_national_discretion end=lastobs;
      FMTNAME          = 'MAP_SOV_DOM_PREF_TREAT' ;
      START            = compress(COUNTRY_CD);
      END              = START          ;
      LABEL            = STD_SOV_DOM_PREF_TREATMENT;
      TYPE             = 'C' ;
      output ;
      if lastobs then do;
         START            ='**OTHER**' ;
         END              = START;
         HLO              ='O' ;
         LABEL            ='';
         output ;
      end;
run;

proc format cntlin=fmt lib=RD_ENV; run;

data fmt (keep = FMTNAME START END LABEL TYPE HLO);
set RD_MAP.map_national_discretion end=lastobs;
      FMTNAME          = 'MAP_SOV_GUARANTEE_PREF_TREAT' ;
      START            = compress(COUNTRY_CD);
      END              = START          ;
      LABEL            = STD_SOV_DOM_PREF_TREATMENT;
      TYPE             = 'C' ;
      output ;
      if lastobs then do;
         START            ='**OTHER**' ;
         END              = START;
         HLO              ='O' ;
         LABEL            ='';
         output ;
      end;
run;

proc format cntlin=fmt lib=RD_ENV; run;


/*- Format for conditional preferential treatment of short-term -*/
/*- bank exposures in the domestic currency (BII,p.64) -*/
data fmt (keep = FMTNAME START END LABEL TYPE HLO) ;
set RD_MAP.map_national_discretion end = lastobs ;
      FMTNAME          = 'MAP_STD_DOM_PREF_TREAT' ;
      START            = compress(COUNTRY_CD);
      END              = START          ;
      LABEL            = STD_BANK_DOM_PREF_TREATMENT ;
      TYPE             = 'C' ;
      output ;
      if lastobs then do;
         START            ='**OTHER**' ;
         END              = START;
         HLO              ='O' ;
         LABEL            ='';
         output ;
      end;
run;

proc format cntlin=fmt lib=RD_ENV; run;

/* Format for concatenating the domestic currencies for each country into a single variable */
data fmt (keep = FMTNAME START END LABEL TYPE HLO) ;
set RD_MAP.map_national_discretion end = lastobs ;
      FMTNAME          = 'MAP_COUNTRY_CURRENCY' ;
      START            = compress(COUNTRY_CD);
      END              = START          ;
      LABEL            = catx(' ',COUNTRY_CURRENCY_1_CD,COUNTRY_CURRENCY_2_CD,COUNTRY_CURRENCY_3_CD) ;
      TYPE             = 'C' ;
      output ;
      if lastobs then do;
         START            ='**OTHER**' ;
         END              = START;
         HLO              ='O' ;
         LABEL            ='';
         output ;
      end;
run;

proc format cntlin=fmt lib=RD_ENV; run;
%mend a05_define_natl_disc_fmt_crd4;
