
/*****************************************************************************
* Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
*
*    NAME: a10_create_regrpt_fmt_crd4.sas
*
* PURPOSE: Create mapping formats for regulatory reports.
*
*   USAGE:
*
*   NOTES:
*
*
*****************************************************************************/
%macro a10_create_regrpt_fmt_crd4; 
/*- 0. initialize options and reporting language strings         -*/
%a00_init_options;
%get_regrpt_nls_strings;
 
/*- 1. format for risk weight bucket mapping under standardized approach -*/
data fmt (keep=FMTNAME START END LABEL TYPE HLO SEXCL EEXCL);
length FMTNAME $32. START END 8. LABEL $16. HLO $8. TYPE SEXCL EEXCL $1.;
set RD_CONF.map_rw_buckets_regrpt(where=(APPROACH='STD')) end=lastobs;
FMTNAME = 'MAP_STD_RW_BUCKET_REGRPT' ;
START   = RW_START ;
END     = RW_END ;
LABEL   = RW_BUCKET ;
TYPE    = 'N' ;
SEXCL   = 'N' ;
EEXCL   = 'N' ;
output ;
if lastobs then do;
HLO = 'O';
LABEL = "&regport_undef";
output;
end;
run;
 
proc format cntlin=fmt lib=RD_ENV; run;
 
/*- format for risk weight bucket mapping under STD securitization  -*/
data fmt (keep=FMTNAME START END LABEL TYPE HLO SEXCL EEXCL);
length FMTNAME $32. START END 8. LABEL $16. HLO $8. TYPE SEXCL EEXCL $1.;
set RD_CONF.map_rw_buckets_regrpt_sec(where=(APPROACH='STD')) end=lastobs;
FMTNAME = 'MAP_STD_RW_BUCKET_REGRPT_SEC' ;
START   = RW_START ;
END     = RW_END ;
LABEL   = RW_BUCKET ;
TYPE    = 'N' ;
SEXCL   = 'N' ;
EEXCL   = 'N' ;
output ;
if lastobs then do;
HLO = 'O';
LABEL = "&regport_undef";
output;
end;
run;
 
proc format cntlin=fmt lib=RD_ENV; run;
 
 
/*- format for risk weight bucket mapping under IRB-SLOTTING criteria, CR template -*/
data MAP_IRB_RW_BUCKET_SL_CAREGRPT;
set RD_CONF.map_rw_buckets_regrpt(where=(APPROACH='IRB_SLOTTING'));
/*
if index(RW_BUCKET, 'RW1') then RW_END = 50;
else if index(RW_BUCKET, 'RW2') then RW_END = 70;
else if index(RW_BUCKET, 'RW3') then RW_END = 90;
else if index(RW_BUCKET, 'RW4') then RW_END = 115;
else if index(RW_BUCKET, 'RW5') then RW_END = 250;
else RW_END = 1250;
*/
RW_BUCKET = compress('RW_'||RW_START||'_'||RW_END);
run;
    
data fmt (keep=FMTNAME START END LABEL TYPE HLO SEXCL EEXCL);
length FMTNAME $32. START END 8. LABEL $16. HLO $8. TYPE SEXCL EEXCL $1.;
set MAP_IRB_RW_BUCKET_SL_CAREGRPT end=lastobs;
FMTNAME = 'MAP_IRB_RW_BUCKET_SL_CAREGRPT' ;
START   = RW_START ;
END     = RW_END ;
LABEL   = RW_BUCKET ;
TYPE    = 'N' ;
SEXCL   = 'N' ;
EEXCL   = 'N' ;
output ;
if lastobs then do;
HLO = 'O';
LABEL = "&regport_undef";
output;
end;
run;
 
proc format cntlin=fmt lib=RD_ENV; run;
 

 data fmt (keep=FMTNAME START END LABEL TYPE HLO SEXCL EEXCL);
 length FMTNAME $32. START END 8. LABEL $16. HLO $8. TYPE SEXCL EEXCL $1.;
 set RD_CONF.MAP_RW_BUCKETS_REGRPT_LR end=lastobs;
 FMTNAME = 'MAP_RW_BUCKETS_REGRPT_LR' ;
 START   = RW_START ;
 END     = RW_END ;
 LABEL   = RW_BUCKET ;
 TYPE    = 'N' ;
 SEXCL   = 'Y' ;
 EEXCL   = 'N' ;
 output ;
 if lastobs then do;
 HLO = 'O';
 LABEL = "&regport_undef";
 output;
 end;
 run;
  
 proc format cntlin=fmt lib=RD_ENV; run;

 
 
/*- 2. format for CCF bucket mapping -*/
data fmt (keep=FMTNAME START END LABEL TYPE HLO SEXCL EEXCL);
length FMTNAME $32. START END 8. LABEL $16. HLO $8. TYPE SEXCL EEXCL $1.;
set RD_CONF.map_ccf_buckets_regrpt end=lastobs;
FMTNAME = 'MAP_CCF_BUCKET_REGRPT' ;
START   = CCF_START ;
END     = CCF_END ;
LABEL   = CCF_BUCKET ;
TYPE    = 'N' ;
SEXCL   = 'N' ;
EEXCL   = 'N' ;
output ;
if lastobs then do;
HLO = 'O';
/*LABEL = "&regport_no_ccf";*/
LABEL = "&regport_undef";
output;
end;
run;
 
proc format cntlin=fmt lib=RD_ENV; run;
 
 
 
/*- 2. format for CCF bucket mapping CRSEC template -*/
data fmt (keep=FMTNAME START END LABEL TYPE HLO SEXCL EEXCL);
length FMTNAME $32. START END 8. LABEL $16. HLO $8. TYPE SEXCL EEXCL $1.;
set RD_CONF.map_ccf_buckets_regrpt_SEC end=lastobs;
FMTNAME = 'MAP_CCF_BUCKETS_REGRPT_SEC' ;
START   = CCF_START ;
END     = CCF_END ;
LABEL   = CCF_BUCKET ;
TYPE    = 'N' ;
SEXCL   = 'Y' ;
EEXCL   = 'N' ;
output ;
if lastobs then do;
HLO = 'O';
LABEL = "&regport_undef";
output;
end;
run;
 
proc format cntlin=fmt lib=RD_ENV; run;
 
/*- Format for guarantee type mapping (funded or unfunded), CR template -*/
data fmt_FUNDED_UNFUNDED;
length UNFUNDED_FLG 3.;
LENGTH LABEL $15;
UNFUNDED_FLG = 0;
LABEL="FUNDED";
output;
UNFUNDED_FLG = 1;
LABEL="UNFUNDED";
output;
run;


data fmt (keep=FMTNAME START END LABEL TYPE HLO SEXCL EEXCL);
length FMTNAME $32. START END $20. LABEL $16. HLO $8. TYPE SEXCL EEXCL $1.;
set FMT_FUNDED_UNFUNDED end=lastobs;
FMTNAME = 'MAP_GUARANTEE_FLAG_REGRPT' ;
START   = UNFUNDED_FLG ;
END     = START ;
TYPE    = 'N' ;
SEXCL   = 'N' ;
EEXCL   = 'N' ;
output ;
if lastobs then do;
    START = '**OTHER**';
END   = START;
HLO = 'O';
LABEL = "**OTHER**";
output;
end;
run; 
 
proc format cntlin=fmt lib=RD_ENV; run;
 
 
/*- Format for LGD Adjusted CRMs, CR template -*/
data fmt_lgd_adjusted;
length LGD_FLAG 3.;
LGD_FLAG = 0;
output;
LGD_FLAG = 1;
output;
run;
 
data fmtlgd (keep=FMTNAME START END LABEL TYPE HLO SEXCL EEXCL);
length FMTNAME  START END $32. LABEL $16. HLO $8. TYPE SEXCL EEXCL $1.;
set fmt_lgd_adjusted end=lastobs;
FMTNAME = 'MAP_LGD_ADJUSTED_REGRPT' ;
START   = LGD_FLAG ;
END     = START ;
if START EQ 0 then LABEL   = "NOT_ADJ";
if START EQ 1 then LABEL   = "LGD_ADJ";
TYPE    = 'N' ;
SEXCL   = 'N' ;
EEXCL   = 'N' ;
output ;
if lastobs then do;
    START   = '**OTHER**' ;
    END     = START ;
HLO = 'O';
LABEL = "&regport_undef";
output;
end;
run;
 
proc format cntlin=fmtlgd lib=RD_ENV; run;
 
 
 
/*- Format for RW Groups, used in CR-SA -*/
/*
data work.map_rw_group;
length RW 5.;
RW = 0;   output;
RW = 2;   output;
RW = 10;  output;
RW = 20;  output;
RW = 35;  output;
RW = 50;  output;
RW = 70;  output;
RW = 75;  output;
RW = 100; output;
RW = 150; output;
RW = 250; output;
RW = 1250; output;
run;
 
data fmt (keep=FMTNAME START END LABEL TYPE HLO SEXCL EEXCL);
length FMTNAME $32. START END $16. LABEL $16. HLO $8. TYPE SEXCL EEXCL $1.;
set work.map_rw_group end=lastobs;
FMTNAME = 'MAP_RW_GROUP' ;
START   = RW ;
END     = START ;
LABEL   = compress('RW_SA_'||RW);   
TYPE    = 'N' ;
SEXCL   = 'N' ;
EEXCL   = 'N' ;
output ;
if lastobs then do;
    START = '**OTHER**';
END   = START;
HLO = 'O';
LABEL = "OTHER";
output;
end;
run;
 
 
 
proc format cntlin=fmt lib=RD_ENV; run;
*/ 
 
/*- 3. format for exposure class mapping -*/
 
/**********************************************************************************************
* Either REGLTRY_COUNTERPARTY_TYPE_CD or REGULATORY_PRODUCT_CD can be missing but not both.
* In this case, the target mapping applies to the cd for all other codes for the variable with
* missing value except for the cases where some codes are explictly specified.
**********************************************************************************************/
 
%macro create_exposure_class_mapping(LIB, DS, TARGET, FMTNAME);
 
/*- macros for numbers of CPTY and PRODUCT CD -*/
%local N_CPTY_CD N_PROD_CD;
 
/*- find number of REGLTRY_COUNTERPARTY_TYPE_CD -*/
%let N_CPTY_CD = %attrn(RD_CONF.map_counterparty_class, NOBS);
 
/*- find number of REGULATORY_PRODUCT_CD -*/
%let N_PROD_CD = %attrn(RD_CONF.map_product_class, NOBS);
 
/*- 1: Both codes cannot be missing -*/
data &LIB..&DS._ext;
set &LIB..&DS(where=(REGLTRY_COUNTERPARTY_TYPE_CD NE '' or REGULATORY_PRODUCT_CD NE ''));
 
/*- flag for later use -*/
HANDLED = 0;
 
if REGLTRY_COUNTERPARTY_TYPE_CD = '' then do;
do i=1 to &N_CPTY_CD;
set RD_CONF.map_counterparty_class(keep=REGLTRY_COUNTERPARTY_TYPE_CD) point=i;
output;
end;
end;
else if REGULATORY_PRODUCT_CD = '' then do;
do j = 1 to &N_PROD_CD;
set RD_CONF.map_product_class(keep=REGULATORY_PRODUCT_CD) point=j;
output;
end;
end;
else do;
output;
end;
 
run;
 
/*- 2: remove inconsistent cases -*/
proc sql;
 
/*- delete cases where bothe codes are explictly specified -*/
delete from &LIB..&DS._ext as a
where REGLTRY_COUNTERPARTY_TYPE_CD in
(select REGLTRY_COUNTERPARTY_TYPE_CD from &LIB..&DS as b
where a.REGLTRY_COUNTERPARTY_TYPE_CD = b.REGLTRY_COUNTERPARTY_TYPE_CD and
a.REGULATORY_PRODUCT_CD = b.REGULATORY_PRODUCT_CD  and
a.&TARGET NE b.&TARGET
);
 
/*- set HANDLED flag -*/
update &LIB..&DS._ext as a
set HANDLED = 1
where REGLTRY_COUNTERPARTY_TYPE_CD in
(select REGLTRY_COUNTERPARTY_TYPE_CD from &LIB..&DS as b
where a.REGLTRY_COUNTERPARTY_TYPE_CD = b.REGLTRY_COUNTERPARTY_TYPE_CD and
a.REGULATORY_PRODUCT_CD = b.REGULATORY_PRODUCT_CD and
a.&TARGET = b.&TARGET
);
 
/*- When inconsitent, REGULATORY_PRODUCT_CD determined APPROACH_CLASS takes precedence -*/
/*- This can be changed to REGLTRY_COUNTERPARTY_TYPE_CD taking precedence by using  -*/
/*- the commented code and commenting out the following SQL step.                      -*/
delete from &LIB..&DS._ext as a
where REGULATORY_PRODUCT_CD in
(select REGULATORY_PRODUCT_CD from &LIB..&DS as b
where b.REGLTRY_COUNTERPARTY_TYPE_CD = '' and
a.REGULATORY_PRODUCT_CD = b.REGULATORY_PRODUCT_CD  and
a.&TARGET = b.&TARGET
)
 
and
 
HANDLED NE 1
;
 
alter table &LIB..&DS._ext
drop HANDLED;
 
quit;
 
data fmt(keep=FMTNAME START END LABEL TYPE HLO);
length FMTNAME START END $32. LABEL $16. HLO $8. TYPE $1.;
set &LIB..&DS._ext end=last;
FMTNAME = "&FMTNAME" ;
START   = compress(REGLTRY_COUNTERPARTY_TYPE_CD || REGULATORY_PRODUCT_CD) ;
END     = START;
LABEL   = &TARGET;
TYPE    = 'C' ;
output;
if last then do;
HLO   = 'O';
LABEL = '';
output;
end;
run;
 
proc format cntlin=fmt lib=RD_ENV; run;
 
%mend create_exposure_class_mapping;
 
/*- format for exposure class: level 1 -*/
%create_exposure_class_mapping(RD_CONF, map_exp_class_level_1_regrpt, EXPOSURE_CLASS_LEVEL_1, MAP_EXPOSURE_CLASS_1_REGRPT);
 
/*- format for exposure class: level 2 -*/
%create_exposure_class_mapping(RD_CONF, map_exp_class_level_2_regrpt, EXPOSURE_CLASS_LEVEL_2, MAP_EXPOSURE_CLASS_2_REGRPT);
 
/*- format for exposure class: level 3 -*/
%create_exposure_class_mapping(RD_CONF, map_exp_class_level_3_regrpt, EXPOSURE_CLASS_LEVEL_3, MAP_EXPOSURE_CLASS_3_REGRPT);
 
  
/*-format for SA exposure classes*/
/*-datalines statement replaced with file infile statements while moving to MVA code -*/

proc sql;
create table allpairs as
select table1.REGLTRY_COUNTERPARTY_TYPE_CD,
table2.REGULATORY_PRODUCT_CD
from   rd_conf.map_counterparty_class as table1
cross join
rd_conf.map_product_class as table2
order by table1.REGLTRY_COUNTERPARTY_TYPE_CD
;
 
create table onlyprod as
select table1.REGLTRY_COUNTERPARTY_TYPE_CD,
       table1.REGULATORY_PRODUCT_CD,
       table2.SA_CLASS  
from   work.allpairs table1,
rd_map.map_sa_class table2
where (table2.REGULATORY_PRODUCT_CD = table1.REGULATORY_PRODUCT_CD)
;
 
create table onlycpty as
select table1.REGLTRY_COUNTERPARTY_TYPE_CD,
       table1.REGULATORY_PRODUCT_CD,
       table2.SA_CLASS  
from work.allpairs table1,
rd_map.map_sa_class table2
where (table2.REGLTRY_COUNTERPARTY_TYPE_CD = table1.REGLTRY_COUNTERPARTY_TYPE_CD
and table1.REGULATORY_PRODUCT_CD NOT IN (select REGULATORY_PRODUCT_CD from rd_map.map_sa_class ))
;
 
quit;
data work.map_sa_class;
set onlycpty onlyprod;
run;
 
data fmt (keep=FMTNAME START END LABEL TYPE HLO SEXCL EEXCL);
length FMTNAME  START END $32. LABEL $16. HLO $8. TYPE SEXCL EEXCL $1.;
set work.map_sa_class  end=lastobs;
FMTNAME = 'MAP_SA_EXPOSURE_CLASS';
START   = compress(REGLTRY_COUNTERPARTY_TYPE_CD || REGULATORY_PRODUCT_CD);
END     = START;
LABEL   = SA_CLASS;
TYPE    = 'C' ;
output ;
if lastobs then do;
HLO = 'O';
LABEL = "OTHER";
output;
end;
run;
 
proc format cntlin=fmt lib=RD_ENV; run;
 
 
/*- format for internal org key mapping -*/
data fmt (keep=FMTNAME START END LABEL TYPE HLO SEXCL EEXCL);
length FMTNAME $32. START END 8. LABEL $16. HLO $8. TYPE SEXCL EEXCL $1.;
set RD_STAGE.internal_org_mart end=lastobs;
FMTNAME = 'MAP_INTERNAL_ORG_RK_CARPT' ;
START   = INTERNAL_ORG_RK ;
END     = INTERNAL_ORG_RK ;
LABEL   = BUSINESS_UNIT ;
TYPE    = 'N' ;
SEXCL   = 'N' ;
EEXCL   = 'N' ;
output ;
if lastobs then do;
HLO = 'O';
LABEL = "&regport_undef";
output;
end;
run;
 
proc format cntlin=fmt lib=RD_ENV; run;
 
/*- Format for converting numeric PD buckets, e.g. BUCKET001 to a list, e.g. "Obligor Grade:1" -*/
proc format library=rd_env fmtlib out= work.MAP_PD_BUCKET noprint;
select MAP_PD_BUCKET;
run;
 
data work._new_format_2;
length _new_label_ $32.;
set work.MAP_PD_BUCKET;
if LABEL NE 'UNDEFINED' then _new_label_=putc(LABEL, 12.);
else _new_label_=.;
run;
 
data work._new_format_2(rename=(LABEL=AVG_PD));
length _label_ $3.;
set work._new_format_2 nobs=maxobs;
_label_=_n_;
if _n_=maxobs then _label_=.;
run;
data fmt (keep=FMTNAME START END LABEL TYPE HLO);
length  FMTNAME $32. START END $32. LABEL $24;
set work._new_format_2;
FMTNAME            = 'MAP_OBLIGOR_POOL_REGRPT' ;
START              = _new_label_;
END                = _new_label_;
LABEL              = "&obligor_grade"||':'||' '||compress(_label_);
TYPE               = 'C' ;
if _label_ EQ . then 
do;
  START='**OTHER**';
  END='**OTHER**';
  TYPE='';
  HLO='O' ;
  LABEL="&obligor_grade"||':'||' '||"&regport_undef";   
end;
output ;
run;
 
proc format cntlin=fmt lib=rd_env; run;


/*Format to retrieve the mapped counterparty code from cpty class, subclass*/
data fmt (keep=FMTNAME START END LABEL TYPE HLO SEXCL EEXCL);
length FMTNAME $32. START END $32. LABEL $16. HLO $8. TYPE SEXCL EEXCL $1.;
set rd_conf.map_counterparty_class(keep=COUNTERPARTY_CLASS COUNTERPARTY_SUBCLASS 
                                       REGLTRY_COUNTERPARTY_TYPE_CD ) end=lastobs;
FMTNAME = 'MAPPED_CPTY_CD' ;
if COUNTERPARTY_SUBCLASS NE '' then do;
   START   = compress(COUNTERPARTY_CLASS||'_'||COUNTERPARTY_SUBCLASS);
end;
else do;
  START   = compress(COUNTERPARTY_CLASS);
end;
END     = START;
LABEL   = REGLTRY_COUNTERPARTY_TYPE_CD;
TYPE    = 'C' ;
SEXCL   = 'N' ;
EEXCL   = 'N' ;
output ;
if lastobs then do;
START='**OTHER**';
END='**OTHER**';
HLO = 'O';
LABEL = "UNDEFINED";
output;
end;
run;
proc sort data=fmt nodupkey;by START;quit;
proc format cntlin=fmt lib=RD_ENV; run;



/*Format to retrieve the mapped product code from product class, subclass(IRB Case)*/
data fmt (keep=FMTNAME START END LABEL TYPE HLO SEXCL EEXCL);
length FMTNAME $32. START END $32. LABEL $16. HLO $8. TYPE SEXCL EEXCL $1.;
set rd_conf.map_product_class(keep=IRB_PRODUCT_CLASS IRB_PRODUCT_SUBCLASS 
                                       REGULATORY_PRODUCT_CD) end=lastobs;
FMTNAME = 'MAPPED_IRB_PRODUCT_CD' ;
if IRB_PRODUCT_SUBCLASS NE '' then do;
    START   = compress(IRB_PRODUCT_CLASS||'_'||IRB_PRODUCT_SUBCLASS);
end;
else do;
    START   = compress(IRB_PRODUCT_CLASS);
end;
END     = START;
LABEL   = REGULATORY_PRODUCT_CD;
TYPE    = 'C' ;
SEXCL   = 'N' ;
EEXCL   = 'N' ;
output ;
if lastobs then do;
START='**OTHER**';
END='**OTHER**';
HLO = 'O';
LABEL = "UNDEFINED";
output;
end;
run;
proc sort data=fmt nodupkey;by START;quit;
proc format cntlin=fmt lib=RD_ENV; run;


/*Format to retrieve the mapped product code from product class, subclass(STD Case)*/
data fmt (keep=FMTNAME START END LABEL TYPE HLO SEXCL EEXCL);
length FMTNAME $32. START END $32. LABEL $16. HLO $8. TYPE SEXCL EEXCL $1.;
set rd_conf.map_product_class(keep=STD_PRODUCT_CLASS STD_PRODUCT_SUBCLASS 
                                       REGULATORY_PRODUCT_CD) end=lastobs;
FMTNAME = 'MAPPED_STD_PRODUCT_CD' ;
if STD_PRODUCT_SUBCLASS NE '' then do;
    START   = compress(STD_PRODUCT_CLASS||'_'||STD_PRODUCT_SUBCLASS);
end;
else do;
   START   = compress(STD_PRODUCT_CLASS);
end;
END     = START;
LABEL   = REGULATORY_PRODUCT_CD;
TYPE    = 'C' ;
SEXCL   = 'N' ;
EEXCL   = 'N' ;
output ;
if lastobs then do;
START='**OTHER**';
END='**OTHER**';
HLO = 'O';
LABEL = "UNDEFINED";
output;
end;
run;
proc sort data=fmt nodupkey;by START;quit;
proc format cntlin=fmt lib=RD_ENV; run; 


/*- format for risk weight bucket mapping under IRB-SLOTTING criteria -*/
data fmt (keep=FMTNAME START END LABEL TYPE HLO SEXCL EEXCL);
length FMTNAME $32. START END 8. LABEL $16. HLO $8. TYPE SEXCL EEXCL $1.;
set RD_CONF.map_rw_buckets_regrpt_irb_sec(where=(APPROACH='IRB')) end=lastobs;
FMTNAME = 'MAP_RW_BUCKETS_SEC_IRB_REGRPT' ;
START   = RW_START ;
END     = RW_END ;
LABEL   = RW_BUCKET ;
TYPE    = 'N' ;
SEXCL   = 'N' ;
EEXCL   = 'N' ;
output ;
if lastobs then do;
HLO = 'O';
LABEL = "&regport_undef";
output;
end;
run;
 
proc format cntlin=fmt lib=RD_ENV; run;

/* format for obligor grade buckets - LOWER BOUND for IRB regulatory report -*/
data fmt (keep=FMTNAME START END LABEL TYPE HLO SEXCL EEXCL);
length FMTNAME  START  $32. LABEL $16. HLO $8. TYPE SEXCL EEXCL $1.;
set RD_stage.rating_grade(where=(model_type='PD')) end=lastobs;
FMTNAME = 'MAP_OBLIGOR_LOWER_REGRPT' ;
START   = CATS(MODEL_ID,RATING_GRADE) ;
END     = CATS(MODEL_ID,RATING_GRADE) ;
LABEL   = PUT(RATING_GRADE_MIN_VALUE,best12.-L) ;
TYPE    = 'C' ;
SEXCL   = 'N' ;
EEXCL   = 'N' ;
output ;
if lastobs then do;
HLO = 'O';
LABEL = "&regport_undef";
start='';
output;
end;
RUN;
 
proc format cntlin=fmt lib=RD_ENV; run;
 
/*- format for obligor grade buckets - UPPER BOUND for IRB regulatory report -*/
 
data fmt (keep=FMTNAME START END LABEL TYPE HLO SEXCL EEXCL);
length FMTNAME  START END $32. LABEL $16. HLO $8. TYPE SEXCL EEXCL $1.;
set RD_stage.rating_grade(where=(model_type='PD')) end=lastobs;
FMTNAME = 'MAP_OBLIGOR_UPPER_REGRPT' ;
START   = CATS(MODEL_ID,RATING_GRADE) ;
END     = CATS(MODEL_ID,RATING_GRADE) ;
LABEL   = PUT(RATING_GRADE_MAX_VALUE,best12.-L) ;
TYPE    = 'C' ;
SEXCL   = 'N' ;
EEXCL   = 'N' ;
output ;
if lastobs then do;
HLO = 'O';
LABEL = "&regport_undef";
output;
end;
RUN;
proc format cntlin=fmt lib=RD_ENV; run;
 
/*- format for obligor grade buckets - AVERAGE for IRB regulatory report -*/
 
data fmt (keep=FMTNAME START END LABEL TYPE HLO SEXCL EEXCL);
length FMTNAME  START END $32. LABEL $16. HLO $8. TYPE SEXCL EEXCL $1.;
set RD_stage.rating_grade(where=(model_type='PD')) end=lastobs;
FMTNAME = 'MAP_OBLIGOR_AVG_REGRPT' ;
START   = CATS(MODEL_ID,RATING_GRADE) ;
END     = CATS(MODEL_ID,RATING_GRADE) ;
LABEL   = PUT(RATING_GRADE_AVG_VALUE,best12.-L) ;
TYPE    = 'C' ;
SEXCL   = 'N' ;
EEXCL   = 'N' ;
output ;
if lastobs then do;
HLO = 'O';
LABEL = "&regport_undef";
output;
end;
run;
 
 
proc format cntlin=fmt lib=RD_ENV; run;

data fmt (keep=FMTNAME START END LABEL TYPE HLO SEXCL EEXCL);
length FMTNAME $32. START END $32. LABEL $32. HLO $8. TYPE SEXCL EEXCL $1.;
set RD_ROOT.REPORT_LINE_SEQ(where=(VARIABLE_NAME="RISK_WEIGHTS" AND REPORT_NAME="CRSA" and CONFIG_ID="&CONFIG_SET" )) end=lastobs;
FMTNAME = 'RW_FMT' ;
START   = VARIABLE_VALUE ;
END     = VARIABLE_VALUE ;
LABEL   = REPORT_LINE_TEXT;
TYPE    = 'C' ;
SEXCL   = 'N' ;
EEXCL   = 'N' ;
output ;
if lastobs then do;
HLO = 'O';
LABEL = "OTHER";
output;
end;
run;
 
proc format cntlin=fmt lib=RD_ENV; run;

data fmt (keep=FMTNAME START END LABEL TYPE HLO SEXCL EEXCL);
length FMTNAME $32. START END $32. LABEL $16. HLO $8. TYPE SEXCL EEXCL $1.;
set RD_ROOT.REPORT_LINE_SEQ(where=(VARIABLE_NAME="RISK_WEIGHTS" AND REPORT_NAME="CRSA" and CONFIG_ID="&CONFIG_SET" )) end=lastobs;
FMTNAME = 'MAP_RW_GROUP' ;
START   = compress(REPORT_LINE_TEXT,"%") ;
END     = compress(REPORT_LINE_TEXT,"%") ;
LABEL   = VARIABLE_VALUE;
TYPE    = 'N' ;
SEXCL   = 'N' ;
EEXCL   = 'N' ;
output ;
if lastobs then do;
HLO = 'O';
LABEL = "OTHER";
output;
end;
run;

proc format cntlin=fmt lib=RD_ENV; run;

/*- Format for Country Codes for CR-GB reporting -*/

data fmt (keep = FMTNAME START END LABEL TYPE HLO) ;
set RD_MAP.MAP_NATIONAL_DISCRETION end = lastobs ;
      FMTNAME          = 'MAP_COUNTRY_INFO' ;
      START            = compress(COUNTRY_CD);
      END              = START          ;
      LABEL            = COUNTRY_NM ;
      TYPE             = 'C' ;
      output ;
      if lastobs then do;
         START            ='**OTHER**' ;
         END              = START;
         HLO              ='O' ;
         LABEL            ='';
         output ;
      end;
run;

proc format cntlin=fmt lib=RD_ENV; run;

data fmt (keep=FMTNAME START END LABEL TYPE HLO SEXCL EEXCL);
length FMTNAME $32. START END $50. LABEL $80. HLO $8. TYPE SEXCL EEXCL $1.;
set RD_MAP.MAP_IRB_CLASS end=lastobs;
FMTNAME = 'MAP_IRB_GROUP' ;
START   = compress(EXPOSURE_CLASS_LEVEL_1||EXPOSURE_CLASS_LEVEL_2||OWN_LGD_CCF_ESTIMATES||SME_SUPPORT_FACTOR) ;
END     = compress(EXPOSURE_CLASS_LEVEL_1||EXPOSURE_CLASS_LEVEL_2||OWN_LGD_CCF_ESTIMATES||SME_SUPPORT_FACTOR) ;
LABEL   = IRB_CLASS;
TYPE    = 'C' ;
SEXCL   = 'N' ;
EEXCL   = 'N' ;
output ;
if lastobs then do;
START='**OTHER**';
END='**OTHER**';
HLO = 'O';
LABEL = "OTHER";
output;
end;
run;

proc format cntlin=fmt lib=RD_ENV; run;

data fmt (keep=FMTNAME START END LABEL TYPE HLO SEXCL EEXCL);
length FMTNAME $32. START END $32. LABEL $16. HLO $8. TYPE SEXCL EEXCL $1.;
set rd_conf.map_regulatory_approach end=lastobs;
FMTNAME = 'MAP_APPROACH_USAGE' ;
START   = compress(APPROACH_CLASS||APPROACH);
END     = START;
LABEL   = APPROACH_USAGE_CD;
TYPE    = 'C' ;
SEXCL   = 'N' ;
EEXCL   = 'N' ;
output ;
if lastobs then do;
START='**OTHER**';
END='**OTHER**';
HLO = 'O';
LABEL = "UNDEFINED";
output;
end;
run;
proc sort data=fmt nodupkey;
by START;
run;
proc format cntlin=fmt lib=RD_ENV; run;

proc sort data=rd_map.MAP_IRB_CLASS out=MAP_IRB_CLASS1 nodupkey;
    by EXPOSURE_CLASS_LEVEL_1;
run;

data fmt (keep=FMTNAME START END LABEL TYPE HLO SEXCL EEXCL);
length FMTNAME $32. START END $32. LABEL $50. HLO $8. TYPE SEXCL EEXCL $1.;
set MAP_IRB_CLASS1 end=lastobs;
FMTNAME = 'MAP_IRB_GB_CLASS' ;
START   = EXPOSURE_CLASS_LEVEL_1;
END     = EXPOSURE_CLASS_LEVEL_1;
LABEL   = EXPOSURE_CLASS_IRB_LEVEL_1;
TYPE    = 'C' ;
SEXCL   = 'N' ;
EEXCL   = 'N' ;
output ;
if lastobs then do;
START='**OTHER**';
END='**OTHER**';
HLO = 'O';
LABEL = "OTHER";
output;
end;
run;

proc format cntlin=fmt lib=RD_ENV; run;


data fmt (keep=FMTNAME START END LABEL TYPE HLO);
length FMTNAME $32. START END $32. LABEL $50. HLO $8. TYPE  $1.;
set rd_map.MAP_CQS_EXT_RATING end=lastobs;
FMTNAME          = 'MAP_CQS_EXT_RATING_STD' ;
START            = EXT_MAP_RATING;
END              = START;
LABEL            = CQS_STD_SEC;
TYPE             = 'C' ;
output;
if lastobs then do;
START='**OTHER**';
END='**OTHER**';
HLO = 'O';
LABEL = "OTHER";
output;
end;
run;

proc format cntlin=fmt lib=RD_ENV; run;


data fmt (keep=FMTNAME START END LABEL TYPE HLO);
length FMTNAME $32. START END $32. LABEL $50. HLO $8. TYPE $1. ;
set rd_map.MAP_CQS_EXT_RATING end=lastobs;
FMTNAME          = 'MAP_CQS_EXT_RATING_IRB' ;
START            = EXT_MAP_RATING;
END              = START;
LABEL            = CQS_IRB_SEC;
TYPE             = 'C' ;
output;
if lastobs then do;
START='**OTHER**';
END='**OTHER**';
HLO = 'O';
LABEL = "OTHER";
output;
end;

run;

proc format cntlin=fmt lib=RD_ENV; run;

data fmt;
length FMTNAME $32. START END $32. LABEL $50. HLO $8. TYPE $1. ;
START=40;   LABEL="RW1=40%"  ;OUTPUT;
START=100;  LABEL="RW2=100%" ;OUTPUT;
START=225;  LABEL="RW3=225%" ;OUTPUT;
START=650;  LABEL="RW4=650%" ;OUTPUT;
START=1250; LABEL="RW5=1250%";OUTPUT;
run;
data fmt (keep=FMTNAME START END LABEL TYPE HLO);
length FMTNAME $32. START END $32. LABEL $50. HLO $8. TYPE $1. ;
set fmt end=lastobs;
FMTNAME          = 'MAP_RW_REGRPT_RESEC' ;
END              = START;
TYPE             = 'N' ;
output;
if lastobs then do;
START='**OTHER**';
END='**OTHER**';
HLO = 'O';
LABEL = "OTHER";
output;
end;

run;

proc format cntlin=fmt lib=RD_ENV; run;

/* This format is added for SEC-SA CCF buckets as existing format is not working for range 0<=0 */
data fmt (keep=FMTNAME START END LABEL TYPE HLO SEXCL EEXCL);
length FMTNAME $32. START END 8. LABEL $16. HLO $8. TYPE SEXCL EEXCL $1.;
set RD_CONF.map_ccf_buckets_regrpt_SEC end=lastobs;
FMTNAME = 'MAP_CCF_REGRPT_SEC' ;
START   = CCF_START ;
END     = CCF_END ;
LABEL   = CCF_BUCKET ;
TYPE    = 'N' ;
if START EQ END then
SEXCL   = 'N' ;
else 
SEXCL   = 'Y' ;
EEXCL   = 'N' ;
output ;
if lastobs then do;
HLO = 'O';
LABEL = "&regport_undef";
output;
end;
run;

proc format cntlin=fmt lib=RD_ENV; run;



/*format to create maturity buckets*/
data fmt (keep=FMTNAME START END LABEL TYPE SEXCL EEXCL HLO);
set rd_map.MAP_MAT_BUCKETS_LE_REGRPT end=lastobs;
FMTNAME          = 'MAP_MAT_BUCKETS_LE' ;
START            = MAT_START;
END              = MAT_END;
LABEL            = MAT_DESCRIPTION;
TYPE             = 'N' ;
SEXCL   = 'Y' ;
EEXCL   = 'N' ;
output;
if lastobs then do;
HLO = 'O';
LABEL = "Undefined_Maturity";
output;
end;
run;

proc format cntlin=fmt lib=RD_ENV; run;

/*- Format for mapping off balance sheet types to the values needed for classification -*/
/*- on SEC Details. -*/
data fmt (keep=FMTNAME START END LABEL TYPE HLO);
length FMTNAME $32. START END $8. LABEL $16. HLO $8. TYPE $1.;
set RD_CONF.map_obsi_sec_detail_regrpt end=lastobs;
FMTNAME = 'MAP_OBSI_SEC_DETAIL_REGRPT' ;
START   = OFF_BALANCE_SHEET_TYPE_CD ;
END     = START ;
LABEL   = SEC_DETAIL_OBSI_TYPE ;
TYPE    = 'C';
output;
if last then do;
HLO   = 'OTH';
LABEL = 'OTH';
output;
end;
run;

proc format cntlin=fmt lib=RD_ENV; run;


%mend a10_create_regrpt_fmt_crd4;
