/*****************************************************************************
 * Copyright (c) 2013 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME: append_cva_risk_amts_crd4.sas
 *
 * PURPOSE: Code to calculate CVA risk amounts for CVA under standardized     
 *          approach.
 *                   
 *   USAGE: %append_cva_risk_amts_crd4(CRMAPP=) ;
 *                     CRMAPP : CRM approach applied (OPTIMAL or BY_RANK)
 *
 *           
 *   NOTES: 
 *          
 *****************************************************************************/
%macro append_cva_risk_amts_crd4(CRMAPP=);

/*- The results must be stored at the aggregate level. For BY_RANK -*/
/*- this information can be retrieved from the RD data model. -*/
/*- For OPTIMAL, this is a dummied '+' for EXP_ID -*/
%if &CRMAPP = OPTIMAL %then %do ; 
   data _cva_ccvs_ ; 
   length EXP_ID $ 32 ; 
   EXP_ID = '+' ; 
   run ;
%end ; 
%else %if &CRMAPP = BY_RANK %then %do ; 
   /*- Get a list of the CC variables in a macro variable -*/
   proc sql noprint ; 
   select distinct NAME into : _ccv_lst_ separated by ' ' from &RESLIB1.._rd_by_variables ; 
   quit ; 

   /*Create a data set containing the CC variables with + as the value*/
   data _cva_ccvs_ ;
       %let i = 1 ;  
       %do %while(%sysfunc(scan(&_ccv_lst_,&i)) ne ) ;
           %let _tmp_var_ = %sysfunc(scan(&_ccv_lst_,&i)) ; 
           &_tmp_var_ = '+' ;
           %let i = %eval(&i+1) ;
       %end ;
   run ;
%end ; 

/*- Set the data set with the variables with the CVA results -*/
data _cva_calc_final_ ; 
   merge _cva_calc_final_ _cva_ccvs_ ;
run ; 

/* Add variables for CVA to the capital detail table. These are populated by then */
/* append which follows. */
proc sql noprint ; 
   alter table _intds.capital_detail_&CRMAPP. ADD CVA_CHARGE_AMT NUMERIC ; 
   alter table _intds.capital_detail_&CRMAPP. ADD CVA_COUNTERPARTY_COUNT NUMERIC ; 
   alter table _intds.capital_detail_&CRMAPP. ADD CVA_INDEX_NOTIONAL_AMT NUMERIC ; 
   alter table _intds.capital_detail_&CRMAPP. ADD CVA_CDS_NOTIONAL_AMT NUMERIC ; 
   alter table _intds.capital_detail_&CRMAPP. ADD CVA_CALCULATION_METHOD_TYPE CHARACTER 3 ; 
   alter table _intds.capital_detail_&CRMAPP. ADD EAD_ADJ NUMERIC ;  
   alter table _intds.capital_detail_&CRMAPP. ADD CVA_EAD_ADJ_OTC NUMERIC ;  
   alter table _intds.capital_detail_&CRMAPP. ADD CVA_EAD_ADJ_SFT NUMERIC ;  
quit ;

/*- Add variables to the CVA results table. This necessary to remove warnings from -*/
/*- the log. It does not have any impact on the calculations -*/
proc sql noprint ; 
   alter table work._cva_calc_final_ ADD ADD_ON NUMERIC ;
   alter table work._cva_calc_final_ ADD APPROACH CHARACTER 16 ;
   alter table work._cva_calc_final_ ADD CAPITAL NUMERIC ;
   alter table work._cva_calc_final_ ADD CAPITAL_NO_CRM NUMERIC ;
   alter table work._cva_calc_final_ ADD CCF NUMERIC ;
   alter table work._cva_calc_final_ ADD CCY CHARACTER 3 ;
   alter table work._cva_calc_final_ ADD COUNTERPARTY_CLASS CHARACTER 32 ;
   alter table work._cva_calc_final_ ADD COUNTERPARTY_COUNTRY CHARACTER 3 ;
   alter table work._cva_calc_final_ ADD COUNTERPARTY_RK NUMERIC ;
   alter table work._cva_calc_final_ ADD COUNTERPARTY_SUBCLASS CHARACTER 32 ;
   alter table work._cva_calc_final_ ADD CPTY_PD_MODEL_ID CHARACTER 32 ;
   alter table work._cva_calc_final_ ADD CPTY_PD_RATING_GRADE CHARACTER 20 ;
   alter table work._cva_calc_final_ ADD CRM_USED_AMT NUMERIC ;
   alter table work._cva_calc_final_ ADD CRM_USED_AMT_EFF NUMERIC ;
   alter table work._cva_calc_final_ ADD EAD NUMERIC ;
   alter table work._cva_calc_final_ ADD EARLY_AMORTIZATION_TYPE CHARACTER 14 ;
   alter table work._cva_calc_final_ ADD EL NUMERIC ;
   alter table work._cva_calc_final_ ADD EL_EFF NUMERIC ;
   alter table work._cva_calc_final_ ADD EXPECTED_LOSS_PERCENT NUMERIC ;
   alter table work._cva_calc_final_ ADD EXP_ID CHARACTER 32 ;
   alter table work._cva_calc_final_ ADD EXP_VALUE NUMERIC ;
   alter table work._cva_calc_final_ ADD EXT_ISSUE_MAP_RATING CHARACTER 8 ;
   alter table work._cva_calc_final_ ADD EXT_MAP_RATING CHARACTER 8 ;
   alter table work._cva_calc_final_ ADD HAIRCUT_EXP NUMERIC ;
   alter table work._cva_calc_final_ ADD INCEPTION_DATE NUMERIC ;
   alter table work._cva_calc_final_ ADD IN_DEFAULT_FLG NUMERIC ;
   alter table work._cva_calc_final_ ADD IRB_PRODUCT_CLASS CHARACTER 32 ;
   alter table work._cva_calc_final_ ADD IRB_PRODUCT_SUBCLASS CHARACTER 32 ;
   alter table work._cva_calc_final_ ADD InstNumber NUMERIC ;
   alter table work._cva_calc_final_ ADD LGD_EFF NUMERIC ;
   alter table work._cva_calc_final_ ADD LGD_EXP NUMERIC ;
   alter table work._cva_calc_final_ ADD BANKRUPTCY_REMOTE_FLG CHARACTER 1 ;
   alter table work._cva_calc_final_ ADD MATURITY_DATE NUMERIC ;
   alter table work._cva_calc_final_ ADD MAT_EFF NUMERIC ;
   alter table work._cva_calc_final_ ADD OFF_BALANCE_SHEET_TYPE_CD CHARACTER 3 ;
   alter table work._cva_calc_final_ ADD ORIGINAL_MATURITY NUMERIC ;
   alter table work._cva_calc_final_ ADD PAST_DUE_CLAIM_FLG NUMERIC ;
   alter table work._cva_calc_final_ ADD PD_EFF NUMERIC ;
   alter table work._cva_calc_final_ ADD PD_EXP NUMERIC ;
   alter table work._cva_calc_final_ ADD PRIMARY_BANK_ROLE CHARACTER 32 ;
   alter table work._cva_calc_final_ ADD REGULATORY_COUNTERPARTY_TYPE_CD CHARACTER 3 ;
   alter table work._cva_calc_final_ ADD REGULATORY_PRODUCT_CD CHARACTER 3 ;
   alter table work._cva_calc_final_ ADD RESIDUAL_MATURITY NUMERIC ;
   alter table work._cva_calc_final_ ADD RW NUMERIC ;
   alter table work._cva_calc_final_ ADD RWA NUMERIC ;
   alter table work._cva_calc_final_ ADD RWA_NO_CRM NUMERIC ;
   alter table work._cva_calc_final_ ADD RWA_SECURED NUMERIC ;
   alter table work._cva_calc_final_ ADD RWA_UNSECURED NUMERIC ;
   alter table work._cva_calc_final_ ADD RW_EXP NUMERIC ;
   alter table work._cva_calc_final_ ADD RW_NO_CRM NUMERIC ;
   alter table work._cva_calc_final_ ADD SECTOR CHARACTER 32 ;
   alter table work._cva_calc_final_ ADD SEC_STRUCTURE_TYPE CHARACTER 32 ;
   alter table work._cva_calc_final_ ADD SPECIFIC_PROVISION NUMERIC ;
   alter table work._cva_calc_final_ ADD STD_PRODUCT_CLASS CHARACTER 32 ;
   alter table work._cva_calc_final_ ADD STD_PRODUCT_SUBCLASS CHARACTER 32 ;
   alter table work._cva_calc_final_ ADD STD_RW_FROM_CENTGOV_FLG NUMERIC ;
   alter table work._cva_calc_final_ ADD STD_RW_FROM_ECAI_FLG NUMERIC ;
   alter table work._cva_calc_final_ ADD TRADE_EXP_FLG NUMERIC ;
   alter table work._cva_calc_final_ ADD TRADING_BOOK_FLG CHARACTER 1 ;
   alter table work._cva_calc_final_ ADD TRANCHE_FACE_VALUE_AMT NUMERIC ;
   alter table work._cva_calc_final_ ADD TRANCHE_LOSS_RANK NUMERIC ;
   alter table work._cva_calc_final_ ADD TRANCHE_SENIORITY_RANK NUMERIC ;
quit ; 
/*- Append the new data to the capital detail table associated with the -*/
/*- CRM allocation approach (i.e., OPTIMAL or BY_RANK) -*/
proc append base = _intds.capital_detail_&CRMAPP. data = _cva_calc_final_ force nowarn ;
run ;

%mend append_cva_risk_amts_crd4 ; 
