/*****************************************************************************
 * Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME: apply_system_filter_config.sas
 *
 * PURPOSE: Apply system filter for the given system hierarchy. 
 *
 *
 *   USAGE: %apply_system_filter_config
 *          
 *
 *   NOTES: This macro filters out related configuration and mapping data 
 *          for the given top group according to the hierarchy file 
 *          created according to the system id
 *          
 *
 *****************************************************************************/

%macro apply_system_filter_config;
%local ACTIVE_FILTER FILTER1;

/*- all data sets should be moved for MAIN -*/
%if "&SYSTEM_ID"="main" %then %do;
    proc copy in=STATIC out=RD_STAT
              NOCLONE CONSTRAINT=YES INDEX=YES;
    run;          
    proc copy in=MAPPING out=RD_MAP
              NOCLONE CONSTRAINT=YES INDEX=YES;
    run;
%end;

/*- check for existence of the hierarchy file -*/
%else %if "&SYSTEM_ORG_RK" NE "" %then %do;
   
    %let ACTIVE_FILTER=where INTERNAL_ORG_RK=&SYSTEM_ORG_RK;
    
    /*- get all the config_id that are used by the internal_org -*/
    %apply_data_filter(INLIB=STATIC, DATA=configuration_x_internal_org, 
                       OUTLIB=RD_STAT, FILTER=&ACTIVE_FILTER);
    %apply_data_filter(INLIB=STATIC, DATA=entity_system_id, 
                       OUTLIB=RD_STAT, FILTER=&ACTIVE_FILTER);
    
    proc sql noprint;
    select distinct CONFIGURATION_ID into : ACTIVE_FILTER separated by "','"
    from RD_STAT.configuration_x_internal_org;
    quit;
    
    %let ACTIVE_FILTER=where CONFIGURATION_ID in (%quote_list(list=&ACTIVE_FILTER, case=));
    
    /*- get the configurations given the configuration id -*/
    %apply_data_filter(INLIB=STATIC,   DATA=configuration, 
                       OUTLIB=RD_STAT, FILTER=&ACTIVE_FILTER);
    %apply_data_filter(INLIB=STATIC,   DATA=Entity_x_configuration, 
                       OUTLIB=RD_STAT, FILTER=&ACTIVE_FILTER);
    %apply_data_filter(INLIB=STATIC,   DATA=hedging_set_type, 
                       OUTLIB=RD_STAT, FILTER=&ACTIVE_FILTER);
    %apply_data_filter(INLIB=STATIC,   DATA=hedging_set_type_x_mat_band, 
                       OUTLIB=RD_STAT, FILTER=&ACTIVE_FILTER);
                       
    /*- get the mapping tables given the configuration id -*/
    %apply_data_filter(INLIB=MAPPING, DATA=map_approach_class, 
                       OUTLIB=RD_MAP, FILTER=&ACTIVE_FILTER);
    %apply_data_filter(INLIB=MAPPING, DATA=map_clean_up_call_type, 
                       OUTLIB=RD_MAP, FILTER=&ACTIVE_FILTER);                   
    %apply_data_filter(INLIB=MAPPING, DATA=map_counterparty_class, 
                       OUTLIB=RD_MAP, FILTER=&ACTIVE_FILTER);
    %apply_data_filter(INLIB=MAPPING, DATA=map_counterparty_type, 
                       OUTLIB=RD_MAP, FILTER=&ACTIVE_FILTER);
    %apply_data_filter(INLIB=MAPPING, DATA=map_cpty_sector_le, 
                       OUTLIB=RD_MAP, FILTER=&ACTIVE_FILTER);
    %apply_data_filter(INLIB=MAPPING, DATA=map_counterparty_relation_type, 
                       OUTLIB=RD_MAP, FILTER=&ACTIVE_FILTER);
    %apply_data_filter(INLIB=MAPPING, DATA=map_covered_risk_type, 
                       OUTLIB=RD_MAP, FILTER=&ACTIVE_FILTER);
    %apply_data_filter(INLIB=MAPPING, DATA=map_crm_type, 
                       OUTLIB=RD_MAP, FILTER=&ACTIVE_FILTER);
    %apply_data_filter(INLIB=MAPPING, DATA=map_day_basis, 
                       OUTLIB=RD_MAP, FILTER=);
    %apply_data_filter(INLIB=MAPPING, DATA=map_eligible_crm_type, 
                       OUTLIB=RD_MAP, FILTER=&ACTIVE_FILTER);
    %apply_data_filter(INLIB=MAPPING, DATA=map_equity_position_type, 
                       OUTLIB=RD_MAP, FILTER=&ACTIVE_FILTER);
    %apply_data_filter(INLIB=MAPPING, DATA=map_exchange_type, 
                       OUTLIB=RD_MAP, FILTER=&ACTIVE_FILTER);
    %apply_data_filter(INLIB=MAPPING, DATA=map_ext_ratings, 
                       OUTLIB=RD_MAP, FILTER=&ACTIVE_FILTER);
    %apply_data_filter(INLIB=MAPPING, DATA=map_ext_shortterm_ratings, 
                       OUTLIB=RD_MAP, FILTER=&ACTIVE_FILTER);
    %apply_data_filter(INLIB=MAPPING, DATA=map_financial_book_type,  
                           OUTLIB=RD_MAP, FILTER=&ACTIVE_FILTER);
    %apply_data_filter(INLIB=MAPPING, DATA=map_fx_type, 
                       OUTLIB=RD_MAP, FILTER=);
    %apply_data_filter(INLIB=MAPPING, DATA=map_irb_alternative_rw, 
                       OUTLIB=RD_MAP, FILTER=&ACTIVE_FILTER); 
    %apply_data_filter(INLIB=MAPPING, DATA=map_ir_type, 
                       OUTLIB=RD_MAP, FILTER=);
    %apply_data_filter(INLIB=MAPPING, DATA=map_lgd_buckets, 
                       OUTLIB=RD_MAP, FILTER=&ACTIVE_FILTER);
    %apply_data_filter(INLIB=MAPPING, DATA=map_mtm_insttype, 
                       OUTLIB=RD_MAP, FILTER=&ACTIVE_FILTER);
    %apply_data_filter(INLIB=MAPPING, DATA=map_obsi_type, 
                       OUTLIB=RD_MAP, FILTER=&ACTIVE_FILTER);                   
    %apply_data_filter(INLIB=MAPPING, DATA=map_pd_buckets, 
                       OUTLIB=RD_MAP, FILTER=&ACTIVE_FILTER);
    %apply_data_filter(INLIB=MAPPING, DATA=map_position_type, 
                       OUTLIB=RD_MAP, FILTER=);
    %apply_data_filter(INLIB=MAPPING, DATA=map_product_class, 
                       OUTLIB=RD_MAP, FILTER=&ACTIVE_FILTER);
    %apply_data_filter(INLIB=MAPPING, DATA=map_provision_type, 
                       OUTLIB=RD_MAP, FILTER=&ACTIVE_FILTER);
    %apply_data_filter(INLIB=MAPPING, DATA=map_regulatory_approach, 
                       OUTLIB=RD_MAP, FILTER=&ACTIVE_FILTER);
    %apply_data_filter(INLIB=MAPPING, DATA=map_rw_buckets, 
                       OUTLIB=RD_MAP, FILTER=&ACTIVE_FILTER);
    %apply_data_filter(INLIB=MAPPING, DATA=map_sec_bank_role, 
                       OUTLIB=RD_MAP, FILTER=&ACTIVE_FILTER);
    %apply_data_filter(INLIB=MAPPING, DATA=map_sec_structure_type, 
                       OUTLIB=RD_MAP, FILTER=&ACTIVE_FILTER);
    %apply_data_filter(INLIB=MAPPING, DATA=map_sec_acctng_treatment,  
                       OUTLIB=RD_MAP, FILTER=&ACTIVE_FILTER);
    %apply_data_filter(INLIB=MAPPING, DATA=map_sec_portfolio_type,  
                       OUTLIB=RD_MAP, FILTER=&ACTIVE_FILTER);
    %apply_data_filter(INLIB=MAPPING, DATA=map_sec_retention_type,  
                       OUTLIB=RD_MAP, FILTER=&ACTIVE_FILTER);
    %apply_data_filter(INLIB=MAPPING, DATA=map_seniority, 
                       OUTLIB=RD_MAP, FILTER=&ACTIVE_FILTER);
    %apply_data_filter(INLIB=MAPPING, DATA=map_time_unit, 
                       OUTLIB=RD_MAP, FILTER=);
    %apply_data_filter(INLIB=MAPPING, DATA=map_capital_scaling_factor,
                       OUTLIB=RD_MAP, FILTER=&ACTIVE_FILTER);
    %apply_data_filter(INLIB=MAPPING, DATA=map_oecd_countries,
                       OUTLIB=RD_MAP, FILTER=);
    %apply_data_filter(INLIB=MAPPING, DATA=map_currency_group,
                       OUTLIB=RD_MAP, FILTER=&ACTIVE_FILTER);  
    %apply_data_filter(INLIB=MAPPING, DATA=map_eligible_rating_agency,
                       OUTLIB=RD_MAP, FILTER=&ACTIVE_FILTER);  
    %apply_data_filter(INLIB=MAPPING, DATA=map_ccr_approach,
                       OUTLIB=RD_MAP, FILTER=&ACTIVE_FILTER); 
    %apply_data_filter(INLIB=MAPPING, DATA=map_hedging_set_type,
                       OUTLIB=RD_MAP, FILTER=&ACTIVE_FILTER);  
    %apply_data_filter(INLIB=MAPPING, DATA=map_config_simulation,
                       OUTLIB=RD_MAP, FILTER=&ACTIVE_FILTER);                     
                       
/*additional Mapping tables required in CRD4 and USFINAL  */     

    %apply_data_filter(INLIB=MAPPING, DATA=map_country_info,
                       OUTLIB=RD_MAP, FILTER=);                     
    %apply_data_filter(INLIB=MAPPING, DATA=map_cva_std_rw_bucket,
                       OUTLIB=RD_MAP, FILTER=);                     
    %apply_data_filter(INLIB=MAPPING, DATA=map_ext_ratings_sec_category,
                       OUTLIB=RD_MAP, FILTER=);                     
    %apply_data_filter(INLIB=MAPPING, DATA=map_financial_rpt_line_item,
                       OUTLIB=RD_MAP, FILTER=);                     
    %apply_data_filter(INLIB=MAPPING, DATA=map_funds_underlying_type,
                       OUTLIB=RD_MAP, FILTER=);                     
    %apply_data_filter(INLIB=MAPPING, DATA=map_irb_class,
                       OUTLIB=RD_MAP, FILTER=);            
    %apply_data_filter(INLIB=MAPPING, DATA=map_irb_rw_buckets_inv_funds,
                       OUTLIB=RD_MAP, FILTER=);            
    %apply_data_filter(INLIB=MAPPING, DATA=map_le_class_regrpt,
                       OUTLIB=RD_MAP, FILTER=);            
    %apply_data_filter(INLIB=MAPPING, DATA=map_le_obsi_type_regrpt,
                       OUTLIB=RD_MAP, FILTER=);            
    %apply_data_filter(INLIB=MAPPING, DATA=map_pd_buckets_regrpt,
                       OUTLIB=RD_MAP, FILTER=);            
    %apply_data_filter(INLIB=MAPPING, DATA=map_pd_range,
                       OUTLIB=RD_MAP, FILTER=);            
    %apply_data_filter(INLIB=MAPPING, DATA=map_reg_y_risk_weight,
                       OUTLIB=RD_MAP, FILTER=);            
    %apply_data_filter(INLIB=MAPPING, DATA=map_sa_class,
                       OUTLIB=RD_MAP, FILTER=);            
                                
                       
                       
    /*- mapping tables for regulatory reports -*/
    %apply_data_filter(INLIB=MAPPING, DATA=map_rw_buckets_regrpt, 
                       OUTLIB=RD_MAP, FILTER=&ACTIVE_FILTER);
    %apply_data_filter(INLIB=MAPPING, DATA=map_rw_buckets_regrpt_sec, 
                       OUTLIB=RD_MAP, FILTER=&ACTIVE_FILTER);
    %apply_data_filter(INLIB=MAPPING, DATA=map_exp_class_level_1_regrpt, 
                       OUTLIB=RD_MAP, FILTER=&ACTIVE_FILTER);
    %apply_data_filter(INLIB=MAPPING, DATA=map_exp_class_level_2_regrpt, 
                       OUTLIB=RD_MAP, FILTER=&ACTIVE_FILTER);
    %apply_data_filter(INLIB=MAPPING, DATA=map_exp_class_level_3_regrpt, 
                       OUTLIB=RD_MAP, FILTER=&ACTIVE_FILTER);
    %apply_data_filter(INLIB=MAPPING, DATA=map_mat_buckets_sl_regrpt, 
                       OUTLIB=RD_MAP, FILTER=&ACTIVE_FILTER);
    %apply_data_filter(INLIB=MAPPING, DATA=map_ccf_buckets_regrpt, 
                       OUTLIB=RD_MAP, FILTER=&ACTIVE_FILTER);
    %apply_data_filter(INLIB=MAPPING, DATA=map_ccf_buckets_regrpt_sec, 
                       OUTLIB=RD_MAP, FILTER=&ACTIVE_FILTER);
    %apply_data_filter(INLIB=MAPPING, DATA=map_rw_buckets_regrpt_irb_sec, 
                       OUTLIB=RD_MAP, FILTER=&ACTIVE_FILTER);
    %apply_data_filter(INLIB=MAPPING, DATA=map_irb_equ2_regrpt, 
                       OUTLIB=RD_MAP, FILTER=&ACTIVE_FILTER); 
    %apply_data_filter(INLIB=MAPPING, DATA=map_lgd_buckets_regrpt, 
                       OUTLIB=RD_MAP, FILTER=&ACTIVE_FILTER);
    %apply_data_filter(INLIB=MAPPING, DATA=map_rw_buckets_regrpt_lr,
                           OUTLIB=RD_MAP, FILTER=&ACTIVE_FILTER);                           
    %apply_data_filter(INLIB=MAPPING, DATA=map_obsi_sec_detail_regrpt,
                       OUTLIB=RD_MAP, FILTER=&ACTIVE_FILTER);

                           
    /*- get add-on -*/
    proc sql noprint;
    select distinct ADD_ON_SET_ID into : ACTIVE_FILTER separated by "','"
    from RD_STAT.configuration;
    quit;
    
    %let ACTIVE_FILTER=where ADD_ON_SET_ID in (%quote_list(list=&ACTIVE_FILTER, case=));
    
    %apply_data_filter(INLIB=STATIC,   DATA=add_on,
                       OUTLIB=RD_STAT, FILTER=&ACTIVE_FILTER);                       
    %apply_data_filter(INLIB=STATIC,   DATA=add_on_set,
                       OUTLIB=RD_STAT, FILTER=&ACTIVE_FILTER);   
    %apply_data_filter(INLIB=STATIC,   DATA=add_on_set_type,
                       OUTLIB=RD_STAT, FILTER=);   
    %apply_data_filter(INLIB=MAPPING,  DATA=map_addon_type,
                       OUTLIB=RD_MAP,  FILTER=&ACTIVE_FILTER);
    %apply_data_filter(INLIB=MAPPING,  DATA=map_add_on_set_type,
                       OUTLIB=RD_MAP,  FILTER=);
    
    /*- get LE multipler -*/
    proc sql noprint;
    select distinct LE_CAP_MULT_SET_ID into : ACTIVE_FILTER separated by "','"
    from RD_STAT.configuration;
    quit;
        
    %let ACTIVE_FILTER=where LE_CAP_MULT_SET_ID in (%quote_list(list=&ACTIVE_FILTER, case=));
        
    %apply_data_filter(INLIB=STATIC,   DATA=le_cap_mult,
                       OUTLIB=RD_STAT, FILTER=&ACTIVE_FILTER);                       
    %apply_data_filter(INLIB=STATIC,   DATA=le_cap_mult_set,
                       OUTLIB=RD_STAT, FILTER=&ACTIVE_FILTER);    
    %apply_data_filter(INLIB=STATIC,   DATA=le_cap_mult_set_type,
                       OUTLIB=RD_STAT, FILTER=);    
                                          

    
    /*- get ccf -*/
    proc sql noprint;
    select distinct CCF_SET_ID into : ACTIVE_FILTER separated by "','"
    from RD_STAT.configuration;
    quit;
    
    %let ACTIVE_FILTER=where CCF_SET_ID in (%quote_list(list=&ACTIVE_FILTER, case=));
        
    %apply_data_filter(INLIB=STATIC,   DATA=ccf,
                       OUTLIB=RD_STAT, FILTER=&ACTIVE_FILTER);  
    %apply_data_filter(INLIB=MAPPING,  DATA=map_ccf_type,
                       OUTLIB=RD_MAP,  FILTER=&ACTIVE_FILTER);

    %apply_data_filter(INLIB=STATIC,   DATA=ccf_set,
                       OUTLIB=RD_STAT, FILTER=);                   
    %apply_data_filter(INLIB=MAPPING,  DATA=map_ccf_bucket_type,
                       OUTLIB=RD_MAP,  FILTER=);
    %apply_data_filter(INLIB=MAPPING,  DATA=map_ccf_type_std_ccr,
                       OUTLIB=RD_MAP,  FILTER=&ACTIVE_FILTER);                   
                       
    /*- get ccf_eap -*/
    proc sql noprint;
    select distinct CCF_EAP_SET_ID into : ACTIVE_FILTER separated by "','"
    from RD_STAT.configuration;
    quit;
    
    %let ACTIVE_FILTER=where CCF_EAP_SET_ID in (%quote_list(list=&ACTIVE_FILTER, case=));
        
    %apply_data_filter(INLIB=STATIC,   DATA=ccf_eap,
                       OUTLIB=RD_STAT, FILTER=&ACTIVE_FILTER);                       
    %apply_data_filter(INLIB=STATIC,   DATA=ccf_eap_set,
                       OUTLIB=RD_STAT, FILTER=&ACTIVE_FILTER);  
    %apply_data_filter(INLIB=MAPPING,  DATA=map_sec_eap_type,
                       OUTLIB=RD_MAP,  FILTER=&ACTIVE_FILTER);                   
    
    /*- get haircut -*/
    proc sql noprint;
    select distinct HAIRCUT_SET_ID into : ACTIVE_FILTER separated by "','"
    from RD_STAT.configuration;
    quit;
    
    %let FILTER1=&ACTIVE_FILTER;
    %let ACTIVE_FILTER=where HAIRCUT_SET_ID in (%quote_list(list=&ACTIVE_FILTER, case=));
        
    %apply_data_filter(INLIB=STATIC,   DATA=haircut,
                       OUTLIB=RD_STAT, FILTER=&ACTIVE_FILTER);  

    %apply_data_filter(INLIB=STATIC,   DATA=haircut_set,
                           OUTLIB=RD_STAT, FILTER=);   
    %apply_data_filter(INLIB=MAPPING,  DATA=map_haircut_type,
                       OUTLIB=RD_MAP,  FILTER=);

    /*- get haircut fx -*/
    proc sql noprint;
    select distinct HAIRCUT_FX_SET_ID into : ACTIVE_FILTER separated by "','"
    from RD_STAT.configuration;
    quit;
    
    %let FILTER2=&ACTIVE_FILTER;
    %let ACTIVE_FILTER=where HAIRCUT_FX_SET_ID in (%quote_list(list=&ACTIVE_FILTER, case=));
        
    %apply_data_filter(INLIB=STATIC,   DATA=haircut_fx,
                       OUTLIB=RD_STAT, FILTER=&ACTIVE_FILTER); 
                       
    %let ACTIVE_FILTER=where HAIRCUT_SET_ID in (%quote_list(list=&FILTER1. &FILTER2, case=));
    %apply_data_filter(INLIB=STATIC,   DATA=haircut_set,
                       OUTLIB=RD_STAT, FILTER=&ACTIVE_FILTER);  
    
    /*- get regulatory options -*/
    proc sql noprint;
    select distinct REGULATORY_OPTION_SET_ID into : ACTIVE_FILTER separated by "','"
    from RD_STAT.configuration;
    quit;
    
    %let ACTIVE_FILTER=where REGULATORY_OPTION_SET_ID in (%quote_list(list=&ACTIVE_FILTER, case=));
        
    %apply_data_filter(INLIB=STATIC,   DATA=regulatory_option,
                       OUTLIB=RD_STAT, FILTER=&ACTIVE_FILTER);                       
    %apply_data_filter(INLIB=STATIC,   DATA=regulatory_option_set,
                       OUTLIB=RD_STAT, FILTER=&ACTIVE_FILTER);  
                       
    /*- get regulatory parameters -*/
    proc sql noprint;
    select distinct REGULATORY_PARAMETER_SET_ID into : ACTIVE_FILTER separated by "','"
    from RD_STAT.configuration;
    quit;
        
    %let ACTIVE_FILTER=where REGULATORY_PARAMETER_SET_ID in (%quote_list(list=&ACTIVE_FILTER, case=));
    
    %apply_data_filter(INLIB=STATIC,   DATA=regulatory_parameter,
                       OUTLIB=RD_STAT, FILTER=&ACTIVE_FILTER);                       
    %apply_data_filter(INLIB=STATIC,   DATA=regulatory_parameter_set,
                       OUTLIB=RD_STAT, FILTER=&ACTIVE_FILTER);   
                       
    /*- get risk weight -*/
    proc sql noprint;
    select distinct REGULATORY_RISK_WEIGHT_SET_ID into : ACTIVE_FILTER separated by "','"
    from RD_STAT.configuration;
    quit;
    
    %let ACTIVE_FILTER=where REGULATORY_RISK_WEIGHT_SET_ID in (%quote_list(list=&ACTIVE_FILTER, case=));
        
    %apply_data_filter(INLIB=STATIC,   DATA=regulatory_risk_weight,
                       OUTLIB=RD_STAT, FILTER=&ACTIVE_FILTER);                       
    %apply_data_filter(INLIB=STATIC,   DATA=regulatory_risk_weight_set,
                       OUTLIB=RD_STAT, FILTER=&ACTIVE_FILTER); 
    %apply_data_filter(INLIB=MAPPING,  DATA=map_irb_rw_buckets,
                       OUTLIB=RD_MAP,  FILTER=&ACTIVE_FILTER);
    %apply_data_filter(INLIB=MAPPING,  DATA=map_irb_rw_buckets_equity,
                       OUTLIB=RD_MAP,  FILTER=&ACTIVE_FILTER);
    %apply_data_filter(INLIB=MAPPING,  DATA=map_std_rw_buckets,
                       OUTLIB=RD_MAP,  FILTER=&ACTIVE_FILTER);
    %apply_data_filter(INLIB=MAPPING,  DATA=map_std_rw_buckets_cme,
                       OUTLIB=RD_MAP,  FILTER=&ACTIVE_FILTER);
    %apply_data_filter(INLIB=MAPPING,  DATA=map_std_rw_buckets_others,
                       OUTLIB=RD_MAP,  FILTER=&ACTIVE_FILTER);
    %apply_data_filter(INLIB=MAPPING,  DATA=map_std_rw_buckets_pastdue,
                       OUTLIB=RD_MAP,  FILTER=&ACTIVE_FILTER);
    %apply_data_filter(INLIB=MAPPING,  DATA=map_std_rw_buckets_retail,
                       OUTLIB=RD_MAP,  FILTER=&ACTIVE_FILTER);
    %apply_data_filter(INLIB=MAPPING,  DATA=map_std_rw_buckets_rme,
                       OUTLIB=RD_MAP,  FILTER=&ACTIVE_FILTER);  
    %apply_data_filter(INLIB=MAPPING,  DATA=map_std_rw_buckets_hirisk_pref,
                       OUTLIB=RD_MAP,  FILTER=&ACTIVE_FILTER);
    %apply_data_filter(INLIB=MAPPING,  DATA=map_std_rw_bucket_others_asset,
                       OUTLIB=RD_MAP,  FILTER=&ACTIVE_FILTER);

                       
    /*- get regulatory lgd -*/
    proc sql noprint;
    select distinct REGULATORY_LGD_SET_ID into : ACTIVE_FILTER separated by "','"
    from RD_STAT.configuration;
    quit;
    %let FILTER1=&ACTIVE_FILTER; 
    %let ACTIVE_FILTER=where REGULATORY_LGD_SET_ID in (%quote_list(list=&ACTIVE_FILTER, case=));
       
    %apply_data_filter(INLIB=STATIC,   DATA=regulatory_lgd,
                       OUTLIB=RD_STAT, FILTER=&ACTIVE_FILTER);    
    %apply_data_filter(INLIB=MAPPING,  DATA=map_lgd_buckets_irb_equity,
                       OUTLIB=RD_MAP,  FILTER=&ACTIVE_FILTER);
    
    /*- get minimum lgd -*/
    proc sql noprint;
    select distinct MINIMUM_LGD_SET_ID into : ACTIVE_FILTER separated by "','"
    from RD_STAT.configuration;
    quit;
    
    %let FILTER2=&ACTIVE_FILTER;  
    %let ACTIVE_FILTER=where MINIMUM_LGD_SET_ID in (%quote_list(list=&ACTIVE_FILTER, case=));
      
    %apply_data_filter(INLIB=STATIC,   DATA=minimum_lgd_irb_collateral,
                       OUTLIB=RD_STAT, FILTER=&ACTIVE_FILTER);
    
    %let ACTIVE_FILTER=where REGULATORY_LGD_SET_ID in (%quote_list(list=&FILTER1. &FILTER2, case=));
    %apply_data_filter(INLIB=STATIC,   DATA=regulatory_lgd_set,
                       OUTLIB=RD_STAT, FILTER=&ACTIVE_FILTER);    
    
    /*- get regulatory Pd -*/
    proc sql noprint;
    select distinct REGULATORY_PD_SET_ID into : ACTIVE_FILTER separated by "','"
    from RD_STAT.configuration;
    quit;
    
    %let ACTIVE_FILTER=where REGULATORY_PD_SET_ID in (%quote_list(list=&ACTIVE_FILTER, case=));
        
    %apply_data_filter(INLIB=STATIC,   DATA=regulatory_pd,
                       OUTLIB=RD_STAT, FILTER=&ACTIVE_FILTER);     
    %apply_data_filter(INLIB=MAPPING,  DATA=map_pd_buckets_irb_equity,
                       OUTLIB=RD_MAP,  FILTER=&ACTIVE_FILTER);
    %apply_data_filter(INLIB=STATIC,   DATA=regulatory_pd_set,
                       OUTLIB=RD_STAT, FILTER=&ACTIVE_FILTER);       
                       
    /*- simulation related information -*/
    proc sql noprint;
        select distinct CONFIGURATION_ID into : ACTIVE_FILTER separated by "','"
        from RD_STAT.configuration;
    quit;
    
    %let ACTIVE_FILTER=where CONFIGURATION_ID in (%quote_list(list=&ACTIVE_FILTER, case=));
    %apply_data_filter(INLIB=MAPPING,  DATA=map_config_simulation,
                       OUTLIB=RD_MAP,  FILTER=&ACTIVE_FILTER);
    
    proc sql noprint;
        select distinct SIMULATION_NM into : ACTIVE_FILTER separated by "','"
        from RD_MAP.map_config_simulation;
    quit;
        
    %let ACTIVE_FILTER=where SIMULATION_NM in (%quote_list(list=&ACTIVE_FILTER, case=));
    %apply_data_filter(INLIB=MAPPING,   DATA=map_simulations_definition,
                       OUTLIB=RD_MAP, FILTER=&ACTIVE_FILTER); 
                       
    proc sql noprint;
            select distinct MARKET_DATA_LIST_ID into : ACTIVE_FILTER separated by "','"
            from RD_MAP.map_simulations_definition;
    quit;
            
    %let ACTIVE_FILTER=where MARKET_DATA_LIST_ID in (%quote_list(list=&ACTIVE_FILTER, case=));
    
    %apply_data_filter(INLIB=MAPPING,   DATA=map_market_data_list,
                       OUTLIB=RD_MAP, FILTER=&ACTIVE_FILTER);   
                       
    proc sql noprint;
            select distinct MARKET_DATA_ID into : ACTIVE_FILTER separated by "','"
            from RD_MAP.map_market_data_list;
    quit;
            
    %let ACTIVE_FILTER=where MARKET_DATA_ID in (%quote_list(list=&ACTIVE_FILTER, case=));   
    
    %apply_data_filter(INLIB=MAPPING,   DATA=map_market_data,
                       OUTLIB=RD_MAP, FILTER=&ACTIVE_FILTER); 
                       
    proc sql noprint;
            select distinct MODEL_LIST_ID into : ACTIVE_FILTER separated by "','"
            from RD_MAP.map_simulations_definition;
    quit;
            
    %let ACTIVE_FILTER=where MODEL_LIST_ID in (%quote_list(list=&ACTIVE_FILTER, case=));                   
    %apply_data_filter(INLIB=MAPPING,   DATA=map_model_list,
                       OUTLIB=RD_MAP, FILTER=&ACTIVE_FILTER);     
                       
    proc sql noprint;
            select distinct HORIZON_LIST_ID into : ACTIVE_FILTER separated by "','"
            from RD_MAP.map_simulations_definition;
    quit;
            
    %let ACTIVE_FILTER=where HORIZON_LIST_ID in (%quote_list(list=&ACTIVE_FILTER, case=));                   
    %apply_data_filter(INLIB=MAPPING,   DATA=map_horizon_list,
                       OUTLIB=RD_MAP, FILTER=&ACTIVE_FILTER);        

    /*- all others that do not require filtering -*/
    %apply_data_filter(INLIB=STATIC,   DATA=analytical_model,
                       OUTLIB=RD_STAT, FILTER=);  
    %apply_data_filter(INLIB=STATIC,   DATA=approach_type,
                       OUTLIB=RD_STAT, FILTER=);
    %apply_data_filter(INLIB=STATIC,   DATA=assessment_rating_grade,
                       OUTLIB=RD_STAT, FILTER=);                         
    %apply_data_filter(INLIB=STATIC,   DATA=early_amortization_type,
                       OUTLIB=RD_STAT, FILTER=);
    %apply_data_filter(INLIB=STATIC,   DATA=excess_spread_band,
                       OUTLIB=RD_STAT, FILTER=);
    %apply_data_filter(INLIB=STATIC,   DATA=maturity_band,
                       OUTLIB=RD_STAT, FILTER=);                       
    %apply_data_filter(INLIB=STATIC,   DATA=rating_grade_band,
                       OUTLIB=RD_STAT, FILTER=);    
    %apply_data_filter(INLIB=MAPPING,   DATA=map_option_type_cd,
                       OUTLIB=RD_MAP, FILTER=);  
    %apply_data_filter(INLIB=MAPPING,   DATA=map_payment_leg_type,
                       OUTLIB=RD_MAP, FILTER=);  
    %apply_data_filter(INLIB=MAPPING,   DATA=map_national_discretion,
                       OUTLIB=RD_MAP, FILTER=);                    
%end;

%else %do;
    %print_msg(error, 2, 227);
    %let SYSTEM_FATAL_ERROR=Y;
%end;

%mend apply_system_filter_config;
