/*****************************************************************************
 * Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME: b15_process_counterparty_crd4.sas
 *
 * PURPOSE: Enrich counterparties that have been created in RD_STAGE
 *
 *   USAGE: 
 *
 *   NOTES:  
 *          
 *
 *         
 *          
 *         
 *****************************************************************************/

%macro b15_process_counterparty_crd4;


/*- RD_STAGE.counterparty_ratings needs to be pre-sorted on COUNTERPARTY_RK RATING_AGENCY -*/
%macro get_ext_rating_cpty;
%if &NUM_AGENCIES_CPTY NE 0 %then %do;
   if "&STD_USE_SECOND_BEST_RATING" = "YES" then do;
      %second_best_rating(EXT_RATING, EXT_MAP_RATING, CPTY); 
   end;
   /*- or get the rating grade from the desired rating agency -*/
   else do;
      EXT_MAP_RATING = put(EXT_RATING_&RATING_AGENCY, $&RATING_AGENCY..) ;
   end;
%end;
%mend get_ext_rating_cpty;

%create_counterparty_rating;
  
data _cpty_ 
    (keep = COUNTERPARTY_RK SOVEREIGN_COUNTERPARTY_RK COUNTERPARTY_CLASS COUNTERPARTY_SUBCLASS
            EXT_MAP_RATING SIZE COUNTERPARTY_PD_MODEL_ID COUNTERPARTY_PD_RATING_GRADE
            RISK_WEIGHT CPTYID CPTYTYPE REPORTING_CURRENCY_CD PD_PCT
            STD_RW_BUCKET_CPTY INT_MAP_RATING INT_RATING COUNTERPARTY_COUNTRY
      STD_SOV_DOM_PREF_TREATMENT STD_BANK_DOM_PREF_TREATMENT CPTY_COUNTRY_CURRENCY 
      STD_ZERO_RW_FLG EEA_MEMBER_FLG CENTGOV_TREAT_FLG STD_REGGOV_TREAT_FLG CVA_STD_CPTY_RW_BUCKET
     rename = (PD_PCT=COUNTERPARTY_PD_PCT)
    )
    RD_POS.counterparty_dim 
    (keep = COUNTERPARTY_RK COUNTERPARTY_ID CPTYID COUNTERPARTY_GROUP REGLTRY_COUNTERPARTY_TYPE_CD 
            COUNTERPARTY_COUNTRY INDUSTRY SECTOR COUNTERPARTY_CLASS COUNTERPARTY_SUBCLASS
            CORE_MARKET_PARTICIPANT_FLG EXT_MAP_RATING PD_PCT ELIG_CCR_CENTRAL_CPTY_FLG
            COUNTERPARTY_PD_MODEL_ID COUNTERPARTY_PD_RATING_GRADE COUNTERPARTY_RELATION_TYPE_CD
            ELIGIBLE_DD_TREAT_OBLIGOR ELIGIBLE_DD_TREAT_GUARANTOR HIGH_RISK_CATEGORY_FLG COUNTERPARTY_TYPE_CD LARGE_FI_ENTITY_FLG
            EEA_MEMBER_FLG STD_REGGOV_TREAT_FLG CENTGOV_TREAT_FLG STD_RW_BUCKET_CPTY SME_SUPPORTING_FACTOR_FLG 
            COUNTERPARTY_NAME COUNTERPARTY_GROUP_PARENT_FLG NACE LEGAL_ENTITY_ID COUNTERPARTY_SECTOR  
             CONNECTION_TYPE_CD FINANCIAL_ENTITY_TYPE_CD COUNTERPARTY_CD

     rename = (CPTYID=COUNTERPARTYID COUNTERPARTY_PD_MODEL_ID=CPTY_PD_MODEL_ID 
               COUNTERPARTY_PD_RATING_GRADE=CPTY_PD_RATING_GRADE PD_PCT=CPTY_PD_PCT
               REGLTRY_COUNTERPARTY_TYPE_CD=REGULATORY_COUNTERPARTY_TYPE_CD 
               HIGH_RISK_CATEGORY_FLG=HIGH_RISK_CPTY_FLG 
               STD_RW_BUCKET_CPTY=STD_RW_BUCKET_COUNTERPARTY CENTGOV_TREAT_FLG = CENTGOV_TRT_FLG )
    ) 
    _cpty_sov_
    (keep=COUNTERPARTY_RK STD_RW_BUCKET_CPTY 
     rename=(COUNTERPARTY_RK=SOVEREIGN_COUNTERPARTY_RK STD_RW_BUCKET_CPTY=STD_RW_BUCKET_SOVEREIGN)
    )
    ;
         
   merge RD_STAGE.counterparty_mart(in=b) RD_POS.counterparty_ratings RD_POS.counterparty_int_ratings;
   by COUNTERPARTY_RK;
   if b;

   length EXT_MAP_RATING STD_RW_BUCKET_CPTY INT_MAP_RATING $8. 
          CPTYTYPE COUNTERPARTY_CLASS COUNTERPARTY_SUBCLASS CPTYID $32.
          ELIGIBLE_DD_TREAT_OBLIGOR ELIGIBLE_DD_TREAT_GUARANTOR $1.;

   /*- define counterparty id and counterparty type for RD process -*/
   CPTYID = compress('CP' || input(COUNTERPARTY_RK, $30.));
   CPTYTYPE = 'REGULATORY_CPTY';

   /*- Counterparty class and subclass definition -*/
   COUNTERPARTY_CLASS    = PUT(REGLTRY_COUNTERPARTY_TYPE_CD, $MAP_COUNTERPARTY_CLASS.);      
   COUNTERPARTY_SUBCLASS = PUT(REGLTRY_COUNTERPARTY_TYPE_CD, $MAP_COUNTERPARTY_SUBCLASS.);
   
   /*- Counterparty sector information for LE report -*/
   COUNTERPARTY_SECTOR = PUT(SECTOR, $MAP_CPTY_SECTOR_LE.);
   
   /*- check on counterparty reporting currency -*/
   if  REPORTING_CURRENCY_CD = '' then REPORTING_CURRENCY_CD="&REPORT_CCY" ;
     
   /*- define the size of the counterparty in the report currency -*/
   SIZE = ANNUAL_SALES;
   if "&IRB_USE_TASSETS_AS_FIRM_SIZE" = "YES" and SIZE = . then SIZE = TOTAL_ASSETS;
   
   /*- get mapped external rating grade -*/
   %get_ext_rating_cpty;
   
   /*- get mapped internal rating grade -*/
   INT_MAP_RATING = put(INT_RATING, $INT.);

   /*- get risk weight buckets -*/
   select (COUNTERPARTY_CLASS);
       when ('SOVEREIGN')
           STD_RW_BUCKET_CPTY = put(EXT_MAP_RATING, $MAP_STD_RW_BUCKET_SOVEREIGN.);
       when ('INSTITUTION') 
           STD_RW_BUCKET_CPTY = put(EXT_MAP_RATING, $MAP_STD_RW_BUCKET_INSTITUTION.);                     
       when ('CORPORATE')
           STD_RW_BUCKET_CPTY = put(EXT_MAP_RATING, $MAP_STD_RW_BUCKET_CORPORATE.);                 
       otherwise
           STD_RW_BUCKET_CPTY = '';           
   end;
   
   /*- get double treat eligibility flags -*/
   ELIGIBLE_DD_TREAT_OBLIGOR  =put(REGLTRY_COUNTERPARTY_TYPE_CD, $MAP_ELIGIBLE_DD_TREAT_OBLIGOR.);
   if EXT_MAP_RATING NE 'MISS' and EXT_MAP_RATING < "&DOUBLE_DEF_PROV_MIN_MAP_RATING" then
      ELIGIBLE_DD_TREAT_GUARANTOR=put(REGLTRY_COUNTERPARTY_TYPE_CD, $MAP_ELIGIBLE_DD_TREAT_GUARANTOR.);
   else if INT_MAP_RATING NE 'MISS' and INT_MAP_RATING < "&DOUBLE_DEF_PROV_MIN_MAP_RATING" then
      ELIGIBLE_DD_TREAT_GUARANTOR=put(REGLTRY_COUNTERPARTY_TYPE_CD, $MAP_ELIGIBLE_DD_TREAT_GUARANTOR.);
   else ELIGIBLE_DD_TREAT_GUARANTOR = 'N';

    length STD_SOV_DOM_PREF_TREATMENT $3.;
    length STD_BANK_DOM_PREF_TREATMENT $3.;
    length CPTY_COUNTRY_CURRENCY $32.;
    length EEA_MEMBER_FLG $3.;  
    
    EEA_MEMBER_FLG = put(COUNTERPARTY_COUNTRY,$MAP_EEA_MEMBER_FLG.);      
    STD_SOV_DOM_PREF_TREATMENT = put(COUNTERPARTY_COUNTRY,$MAP_SOV_DOM_PREF_TREAT.) ;
    STD_BANK_DOM_PREF_TREATMENT = put(COUNTERPARTY_COUNTRY,$MAP_STD_DOM_PREF_TREAT.) ;
    CPTY_COUNTRY_CURRENCY = put(COUNTERPARTY_COUNTRY,$MAP_COUNTRY_CURRENCY.) ;

    /*- Get the weight for the CVA calculations for all counterparties. This includes -*/ 
    /*- those which might not have OTC transactions -*/ 
    length CVA_STD_CPTY_RW_BUCKET $32.; 

    CVA_STD_CPTY_RW_BUCKET = put(EXT_MAP_RATING,$MAP_CVA_STD_RW_BUCKET.) ;  


   output _cpty_ ;
   
   /*- all the dimensional data are kept in counterparty_dim for reporting -*/
   LARGE_FI_ENTITY_FLG = input(put(COUNTERPARTY_TYPE_CD, $MAP_LARGE_FI_ENTITY_FLG.), best12.);  
   
   output RD_POS.counterparty_dim;   
   
   /*- get the sovereign counterparty -*/
    if (COUNTERPARTY_SUBCLASS in ('CENTRAL_GOV','CENTRAL_BANK')) then output _cpty_sov_; 
   
run;

/*- get counterparty's sovereign rating -*/
data RD_POS.counterparty(drop=RC);
length SOVEREIGN_COUNTERPARTY_RK 8. STD_RW_BUCKET_SOVEREIGN $8.;

if _N_ = 1 then do;
    declare hash h(hashexp:7, dataset:'work._cpty_sov_');
    RC = h.defineKey('SOVEREIGN_COUNTERPARTY_RK');
    RC = h.defineData('STD_RW_BUCKET_SOVEREIGN');
    RC = h.defineDone();
    call missing(SOVEREIGN_COUNTERPARTY_RK, STD_RW_BUCKET_SOVEREIGN); 
end;

set _cpty_(keep=COUNTERPARTY_RK COUNTERPARTY_CLASS COUNTERPARTY_SUBCLASS SIZE RISK_WEIGHT REPORTING_CURRENCY_CD
                CPTYID CPTYTYPE STD_RW_BUCKET_CPTY COUNTERPARTY_PD_MODEL_ID COUNTERPARTY_PD_RATING_GRADE SOVEREIGN_COUNTERPARTY_RK
                COUNTERPARTY_PD_PCT EXT_MAP_RATING  STD_SOV_DOM_PREF_TREATMENT STD_BANK_DOM_PREF_TREATMENT CPTY_COUNTRY_CURRENCY 
                STD_ZERO_RW_FLG EEA_MEMBER_FLG CENTGOV_TREAT_FLG STD_REGGOV_TREAT_FLG CVA_STD_CPTY_RW_BUCKET 
           rename=(COUNTERPARTY_RK=CPTY_RK COUNTERPARTY_CLASS=CPTY_CLASS COUNTERPARTY_SUBCLASS=CPTY_SUBCLASS
                   SIZE=CPTY_SIZE RISK_WEIGHT=RISK_WEIGHT_CPTY REPORTING_CURRENCY_CD=REPORT_CURRENCY 
                   EXT_MAP_RATING = CPTY_EXT_MAP_RATING)
          ); 

   RC = h.find();
  
run;

/*- delete temporary data sets -*/
%clean_lib;

%mend b15_process_counterparty_crd4;
