/*****************************************************************************
 * Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME: b20_prep_regrpt_port_secirb_crd4.sas
 *
 * PURPOSE: Create portoflio data for regulatory reports for Corep CR SEC IRB Report
 *
 *****************************************************************************/


%macro b20_prep_regrpt_port_secirb_crd4 ;
 
/*---------------------------------------------------------------------------
 * Step 1.
 *
 * Check to see if we user has requested SEC data
 * -------------------------------------------------------------------------*/    


%let HAVEDATA=NO;

   %if %UPCASE(&REGPROJECTNAME) EQ SEC or 
       %UPCASE(&REGPROJECTNAME) EQ ALL or
       %UPCASE(&REGPROJECTNAME) EQ IRB or
       %UPCASE(&REGPROJECTNAME) EQ CAPITAL_CRSEC_IRB or
       %UPCASE(&REGPROJECTNAME) EQ CAPITAL_CRSEC_IRB_CRD4 %then %goto check;
   %else %goto SKIP;;

/*---------------------------------------------------------------------------
 * Step 2.
 *
 * Check to see if we user has requested securitization data
 * -------------------------------------------------------------------------*/   


%SKIP:

%print_msg(NOTE,3,64);
%return;

%CHECK:

%let inputds = crm_allocation_&MITIGANTS_ALLOCATION_METHOD._detail; 

%if %UPCASE(&MITIGANTS_ALLOCATION_METHOD) EQ OPTIMAL
%then %do;
   libname _detail  "&REGPATH";
   %let COSTVAR = _COST_;
/*   %let inputds = all_exposures_before_rollup; */

%end;
 
%else %if %UPCASE(&MITIGANTS_ALLOCATION_METHOD) EQ BY_RANK          
%then %do;
   libname _detail  "!CRISKMRES&PATHSEP.&PROJECT_SET&PATHSEP.&PROJECT_SET._rnk";
   %let COSTVAR = _WEIGHT_;
%end;

%checkdata(_detail, &inputds , (APPROACH IN ('IRB_RBA','IRB_SFA','IRB_IAA')) AND 
                               ((upcase(IRB_PRODUCT_CLASS) EQ 'SEC') OR 
                                (upcase(IRB_PRODUCT_CLASS) EQ 'SECURITIZATION')));
%put &HAVEDATA;
/* If no data then return*/
  %if   (&HAVEDATA = NO)  %then %do;
    %print_msg (NOTE,3,66);  
    %return;   
%end;

/*---------------------------------------------------------------------------
 * Step 3. Creating portfolio for SEC SA report 
 * -------------------------------------------------------------------------*/
 %if &APPLY_CCF_AFTER_CRM EQ NO %then %print_msg (warning,3,111);
 
 DATA WORK._SECDATA;
   set _detail.&inputds;
   where (INDEX(APPROACH, 'IRB') GE 1 ) AND (upcase(IRB_PRODUCT_CLASS) IN ('SEC','SECURITIZATION'));
         %if %UPCASE(&MITIGANTS_ALLOCATION_METHOD) EQ BY_RANK %then %do; 
     if not missing(CRM_ID) then _weight_ = _weight_ ;
     else _weight_ = RW_EXP ;
   %end;

 RUN;
 
 /* The first cross-class is SEC_STRUCTURE_TYPE (already in the dataset) */
 /* The second cross-class is PRIMARY_BANK_ROLE (already in the dataset) */
 DATA _INTDS.CAPITAL_CRSEC_IRB;
    length EXPOSURE_TYPE RATING_STATUS EXPOSURE_SUBTYPE $16. SENIORITY_STATUS CRM_PRODUCT $32. REGRPT_CCF_BUCKET REGRPT_RW_BUCKET_SEC CQS_BUCKET $25.;
    set work._secdata;
  
	  IF CRM_TYPE IN ('FINANCIAL_COLLATERAL') then
          do;   /*need to change */
                if  "&STD_CRM_APPROACH" EQ "SIMPLE"  and  ELIGIBLE_CRM_TYPE EQ 'FINANCIAL_SIMPLE' and INDEX(crm_subtype, 'DEBT_SEC') NE 0 THEN
                              CRM_PRODUCT = 'FIN_COLL_SIMPLE';	
				else if "&STD_CRM_APPROACH" NE "SIMPLE" and CRM_COMP_FLG = 1 then
                              CRM_PRODUCT = 'FIN_COLL_COMPREH';
		  end;
		  
    /*Define the EXPOSURE_TYPE cross-class*/
    if OFF_BALANCE_SHEET_TYPE_CD = '' then EXPOSURE_TYPE = 'ON_BALANCE';
    else EXPOSURE_TYPE = 'OFF_BALANCE';
    if early_amortization_type ne '' then EXPOSURE_TYPE='EARLY_AMT';

	/*Define the EXPOSURE_SUBTYPE cross-class*/
	if RESECURITIZATION_FLG=1 then
	do;
		EXPOSURE_SUBTYPE="RESECURITIZATION";
		/* RW_BUCKET: Used for subsetting the output variables*/
		if EXT_ISSUE_MAP_RATING = 'MISS' AND APPROACH = "IRB_IAA" then
		do;
			REGRPT_RW_BUCKET = put(INT_ISSUE_MAP_RATING, $MAP_CQS_EXT_RATING_IRB.);
			CQS_BUCKET=put(INT_ISSUE_INCEP_MAP_RATING, $MAP_CQS_EXT_RATING_IRB.);
		end;
		ELSE
		do;
			REGRPT_RW_BUCKET = put(EXT_ISSUE_MAP_RATING, $MAP_CQS_EXT_RATING_IRB.);
			CQS_BUCKET=put(EXT_ISSUE_INCEP_MAP_RATING, $MAP_CQS_EXT_RATING_IRB.);
		end;
	end;
	else
	do;
		EXPOSURE_SUBTYPE="SECURITIZATION";
		/* RW_BUCKET: Used for subsetting the output variables*/
		if EXT_ISSUE_MAP_RATING = 'MISS' AND APPROACH = "IRB_IAA" then
		DO;
			REGRPT_RW_BUCKET = put(INT_ISSUE_MAP_RATING, $MAP_CQS_EXT_RATING_IRB.);
			CQS_BUCKET       = put(INT_ISSUE_INCEP_MAP_RATING, $MAP_CQS_EXT_RATING_IRB.);
		END;
		ELSE
		do;
			REGRPT_RW_BUCKET = put(EXT_ISSUE_MAP_RATING, $MAP_CQS_EXT_RATING_IRB.);
			CQS_BUCKET=put(EXT_ISSUE_INCEP_MAP_RATING, $MAP_CQS_EXT_RATING_IRB.);
		end;
		
	end;
		
    /* Define the SENIORITY_STATUS cross-class*/
    /*
    if TRANCHE_SENIORITY_RANK = 1 then SENIORITY_STATUS = '1_Senior';
    else if TRANCHE_LOSS_RANK=1 then SENIORITY_STATUS='3_First losses';
    else SENIORITY_STATUS = '2_Mezanine';
   */  
    
	  if RESECURITIZATION_FLG=1 then
	  do;
	  	 if TRANCHE_SENIORITY_RANK = 1 then
		                 SENIORITY_STATUS = "D" ;   
		    else              
		                 SENIORITY_STATUS = "E" ;   
    end; 
    else do; 
		   	if EFFECTIVE_NUMBER_OF_EXPOSURES < &IRB_SEC_GRANULARITY_THRESHOLD then 
		                 SENIORITY_STATUS = "C" ; 
		    else if TRANCHE_SENIORITY_RANK = 1 then
		                 SENIORITY_STATUS = "A" ;   
		    else              
		                SENIORITY_STATUS = "B" ;   
    end; 	
    
 
    /* CCF BUCKET: Used for subsetting the output variables*/
    if EXPOSURE_TYPE EQ 'ON_BALANCE' then   
    REGRPT_CCF_BUCKET = 'NOT_APPLICABLE';
    else 
    REGRPT_CCF_BUCKET = put(CCF, MAP_CCF_REGRPT_SEC.);


    /* RW_BUCKET: Used for subsetting the output variables*/
    REGRPT_RW_BUCKET_SEC = put(RW_EXP, MAP_RW_BUCKETS_SEC_IRB_REGRPT.);

    /* Map rated/unrated into cross-classification variable */
    if EXT_ISSUE_MAP_RATING NE 'MISS' then RATING_STATUS='RATED';
    else if INT_ISSUE_MAP_RATING NE 'MISS' and SEC_STRUCTURE_SUBTYPE = 'ABCP' then RATING_STATUS='RATED';
    else RATING_STATUS='UNRATED';

    INSTID = compress('crsec_irb'||_n_);
    INSTTYPE = 'regrpt_crsec_irb';
_COSTVAR_ = &COSTVAR;
 RUN;     

/*---------------------------------------------------------------------------
* Step 4. Adjust portfolio to include inflow/outflow information through
*         the inclusion of two instrument types
* -------------------------------------------------------------------------*/   
    
/*-Separate the mitigants from the exposures and assign them an insttype -*/
/*
data work.only_crm work.only_exp;
length INSTTYPE $16.;
set _INTDS.CAPITAL_CRSEC_IRB;
if CRM_ID NE '' then
do;
	COUNTERPARTY_RK = CRM_COUNTERPARTY_RK;
	INSTID = compress('INSTCRM_'||_n_);
	INSTTYPE = 'regrpt_crsec_crm';

	EXP_VALUE=0;
	EAD=0;
	EAD_ADJ=0;
	EAD_PORTION=0;
	output only_crm;
end;
else
do; 
	INSTID = compress('INSTEXP_'||_n_);
	INSTTYPE = 'regrpt_crsec_irb';
	output only_exp;
end;

run;
*/
/*-Separate the mitigants from the exposures and assign them an insttype -*/
data work.only_crm work.only_exp;
length INSTTYPE $16.;
set _INTDS.CAPITAL_CRSEC_IRB;
INSTID = compress('INSTEXP_'||_n_);
INSTTYPE = 'regrpt_crsec_irb';
if crm_id ne '' and exp_id ne '' and upcase(insttype)eq "REGRPT_CRSEC_IRB" then
do;
	SEC_TOTAL_AMT_ORIGINATED =0;RETAINED_AMT=0;EXP_VALUE=0; SEC_DEDUCTION_AMT=0;SEC_INFRINGE_ADJUST_AMT=0;RWA_SEC_MEMO_AMT=0;;
end;

output only_exp;
 
if CRM_ID NE '' then
do;
COUNTERPARTY_RK = CRM_COUNTERPARTY_RK;
INSTID = compress('INSTCRM_'||_n_);
INSTTYPE = 'regrpt_crsec_crm';

EXP_VALUE=0;
EAD=0;
EAD_ADJ=0;
EAD_PORTION=0;
RWA_SEC_MAT_MIS_ADJ_AMT=0;
output only_crm;
end;
run;
/*-Merge the mitigants with all the exposures
* and assign an insttype to the exposure. -*/
data _intds.CAPITAL_CRSEC_IRB;
set work.only_crm
work.only_exp;     
run;

proc sort data=_intds.CAPITAL_CRSEC_IRB ; 
   by exp_id;run;

/*Add information on Credit Protection to the underlying*/
/*Get the synhetic POOL_RK*/
data work._synthetic_pool_(keep=securitization_pool_rk SEC_STRUCTURE_TYPE);
  length SEC_STRUCTURE_TYPE $12.;
  set rd_stage.Securitization_pool_mart;
  SEC_STRUCTURE_TYPE=put(compress(SECURITIZ_STRUC_TYPE_CD || SECURITIZ_STRUC_SUBTYPE_CD), $MAP_SEC_STRUCTURE_TYPE.);
  if SEC_STRUCTURE_TYPE='SYNTHETIC' then output;
run;

/*Identify the crms that cover exposures which belong in synthetic pools*/
proc sql; create table work.crm_synth_pool as
select t3.crm_id, t3.exp_id
from rd_pos.exposure_sec_underlying as t1, 
              work._synthetic_pool_ as t2, 
           rd_pos.exposure_crm_link as t3
where 
t1.securitization_pool_rk = t2.securitization_pool_rk AND
t1.instid = t3.exp_id;
quit;

 /*Get mitigants information (funded/unfunded amt)*/
 data work._funded;
   set _detail.Crm_allocation_&MITIGANTS_ALLOCATION_METHOD._detail;
   if crm_type="" then fund_flag=.; else
   if upcase(crm_type) in ('FINANCIAL_COLLATERAL','NETTING','IRB_COLLATERAL') or upcase(crm_subtype) in ('FUNDED') then 
	fund_flag=1;
   else fund_flag=0;
   where (upcase(SEC_STRUCTURE_TYPE) eq 'TRADITIONAL') or (upcase(SEC_STRUCTURE_TYPE) eq 'SYNTHETIC');
 run;

proc sort data=work._funded ; 
   by exp_id fund_flag;run;

proc summary data=work._funded noprint sum;
   by exp_id fund_flag;
   var crm_used_amt_eff fund_flag;
   output out=work._crm_by_instid  (keep=exp_id fund_amt fund_flag where=(fund_flag ne .)) sum=fund_amt;
run;

data work._crm_by_instid (keep=funded unfunded exp_id);
 set work._crm_by_instid;
 format FUNDED UNFUNDED nlnum18.5;
 length FUNDED UNFUNDED 8.;
  FUNDED=0;
  UNFUNDED=0;
 if fund_flag=1 then funded=fund_amt;else
 if fund_flag=0 then unfunded=fund_amt;
run;

/* Get the adjusted value for the financial collaterals*/
data work._fin_coll_;
set work._funded;
if upcase(crm_type) EQ 'FINANCIAL_COLLATERAL' then do;
IF MAT_MISMATCH_WEIGHT_CRM NE . then 
 FIN_COLL_ADJ_VAL_AMT=  CRM_VALUE*(1 - max(HAIRCUT_CRM/100,0) - max(HAIRCUT_FX/100,0) )*MAT_MISMATCH_WEIGHT_CRM;
 ELSE FIN_COLL_ADJ_VAL_AMT = CRM_VALUE*(1 - HAIRCUT_CRM/100 - HAIRCUT_FX/100 );
output;
end;
run;

%if %attrn(work._fin_coll_, NOBS) > 0 %then %do;
  proc summary data=work._fin_coll_ noprint sum;
    by exp_id;
    var FIN_COLL_ADJ_VAL_AMT; 
    output out=work._adjvalue_by_instid  (keep=exp_id FIN_COLL_ADJ_VAL_AMT) sum=FIN_COLL_ADJ_VAL_AMT;
  run;
%end;

data _all_exposures_(rename=(INSTID=EXP_ID));
set _detail.instvals(where=( 
    (POSITION_CATEGORY='EXPOSURE') AND 
    (INDEX(APPROACH, 'STD') EQ 0) AND 
    (upcase(IRB_PRODUCT_CLASS) IN ('SEC','SECURITIZATION'))
));
run;

/*Get the notional amount retained*/
proc sql; create table work.retained_exp(rename=(INSTID=EXP_ID)) as
select t1.instid, sum(t3.exp_value) as retained_amt
from rd_pos.Exposure_securitization as t1, 
              work._synthetic_pool_ as t2,
              work._all_exposures_  as t3
where 
t1.securitization_pool_rk = t2.securitization_pool_rk AND
t1.POSITION_CATEGORY = 'EXPOSURE' AND
upcase(t1.PRIMARY_BANK_ROLE) IN ('ORIGINATOR', 'INVESTOR') AND
t1.instid = t3.exp_id
group t1.instid
order by t1.instid;
quit;


/* Change for reg reports */
data _INTDS.CAPITAL_CRSEC_IRB(drop=internal_org_rk);
 merge _INTDS.CAPITAL_CRSEC_IRB 
         work._crm_by_instid work.retained_exp 
         %if %dsexist(work.crm_und_by_instid) %then %do;work.crm_und_by_instid (rename = (CRM_ID = EXP_ID)) %end;
         %if %dsexist(work._adjvalue_by_instid) %then %do;work._adjvalue_by_instid %end;;
 by exp_id;
 if EXPOSURE_TYPE='' then delete; /* The EXPOSURE_TYPE is missing only if an EXP_ID  */
                                  /* doesn't exist in _INTDS.CAPITAL_CRSEC_SA. These */
                                  /* records can be deleted                          */

 %if %attrn(work.crm_synth_pool, NOBS) = 0 %then %do;
  FUNDED_UNDERLYING = 0;
  UNFUNDED_UNDERLYING = 0;
 %end;
run;


/* Check to see if data was created */

%checkdata(_detail, &inputds , (APPROACH IN ('IRB_RBA','IRB_SFA','IRB_IAA')) AND 
                               ((upcase(IRB_PRODUCT_CLASS) EQ 'SEC') OR 
                                (upcase(IRB_PRODUCT_CLASS) EQ 'SECURITIZATION')));
data _intds.CAPITAL_CRSEC_IRB_CRD4;
	set _intds.CAPITAL_CRSEC_IRB;
run; 
proc sql; 
	drop table _intds.CAPITAL_CRSEC_IRB;
quit;	

%if &HAVEDATA = YES %then
%do;
%status(CAPITAL_CRSEC_IRB_CRD4,SUCCESS,Created portfolio,CAPITAL_CRSEC_IRB_CRD4);
%end;
%else
%do;
%print_msg (WARNING,3,62);
%status(CAPITAL_CRSEC_IRB_CRD4,FAILED,Exposures for securization under IRB approach,CAPITAL_CRSEC_IRB_CRD4);
%end;

options notes source;    
%mend b20_prep_regrpt_port_secirb_crd4;
