/*****************************************************************************
* Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
*
*    NAME: b25_prep_regrpt_port_crirb_crd4.sas
*
* PURPOSE: Create portoflio data for CR regulatory reports (IRBA Approach)
*
*   USAGE:
*
*   NOTES:
*
*****************************************************************************/
 
/*---------------------------------------------------------------------------
* Step 1. Check to see if the user has requested CR-IRBA data
* -------------------------------------------------------------------------*/
 
%macro b25_prep_regrpt_port_crirb_crd4;
%macro prepare_regrpt_port_cr_irb (inputds);
 
%let HAVEDATA=NO;
 
%if  
     (%UPCASE(&REGPROJECTNAME) EQ CAPITAL_CRIRBA_CRD4) OR
     (%UPCASE(&REGPROJECTNAME) EQ ALL) OR 
     (%UPCASE(&REGPROJECTNAME) EQ IRB) OR
     (%UPCASE(&REGPROJECTNAME) EQ CAPITAL_CRGB_IRBA_CRD4)

%then %do;

/* Define the library to the regulatory_calculations folder, in 
    order to consume Lgd_adjusted_crm_IRB data set in OPTIMAL and BY_RANK
    crm allocation.   */ 
    
libname _rg_calc "&REGPATH";


 
%if %UPCASE(&MITIGANTS_ALLOCATION_METHOD) EQ OPTIMAL
%then %do;
 
libname _incrlib  "&REGPATH";
%goto checkirba_opt;
 
%end;
 
%else %if %UPCASE(&MITIGANTS_ALLOCATION_METHOD) EQ BY_RANK          
%then %do;
 
libname _incrlib  "!CRISKMRES&PATHSEP.&PROJECT_SET&PATHSEP.&PROJECT_SET._rnk";
%goto checkirba_rnk;
 
%end;
 
%end;
    
%else %goto SKIP;
 
 
/*---------------------------------------------------------------------------
* Step 2. Check to see if we have data
* -------------------------------------------------------------------------*/
 
%SKIP:
/* User did not request CRIRB portfolio - skip */
%print_msg (NOTE,3,60);/*-------------------------->Add another message*/
%return;
 
 
%CHECKIRBA_OPT:
%checkdata (_incrlib, &INPUTDS , APPROACH in ('IRB', 'IRBA', 'IRBF', 'IRB_SLOTTING'));
 
%CHECKIRBA_RNK:
%checkdata (_incrlib, &INPUTDS , APPROACH in ('IRB', 'IRBA', 'IRBF', 'IRB_SLOTTING'));
 
 
/* If no data then return*/
%if   (&HAVEDATA = NO)  %then %do;
%print_msg (WARNING,3,1);/*------------------------>Change this message*/
%return;
%end;
 
/*---------------------------------------------------------------------------
* Step 3. Creating portfolio for IRBA approach
* -------------------------------------------------------------------------*/
 
%print_msg(note,3,26);
%if &APPLY_CCF_AFTER_CRM EQ NO %then %print_msg (warning,3,108);
 
/*Start by calculating the obligor_pd buckets (by counterparty) */
data work._inputs_;
set _incrlib.&INPUTDS(where=(APPROACH in ('IRB', 'IRBA', 'IRBF','IRB_SLOTTING')));

/*only Exposure PDs are to be reported (and not CRM provider PDs) */ 
/* if CRM_ID NE '' then _pd_val_ = PD_CRM_COUNTERPARTY;
else _pd_val_ = PD_EXP; */
_pd_val_ = PD_EXP;
run;
 
proc sort data=work._inputs_;
by counterparty_id;
run;
 
proc summary data=work._inputs_;
var _pd_val_;
by COUNTERPARTY_ID;
weight EAD_PORTION;
output out=_obligor_pd_ mean=obligor_pd_avg;
run;
 
data work._inputs_;
length OBLIGOR_GRADE $32.;
label obligor_pd_avg="AVERAGE_OBLIGOR_PD";
merge work._inputs_
_obligor_pd_(drop=_type_ _freq_);
by COUNTERPARTY_ID;
OBLIGOR_GRADE = put(obligor_pd_avg, MAP_PD_BUCKET.);
run;

/* for SL with IRB Slotting Obligor grade values are not required*/
data work._inputs_;
	set work._inputs_;
	if APPROACH = 'IRB_SLOTTING' then do ; 
		OBLIGOR_GRADE = '' ; 
		_pd_val_ = . ; 
	end;
	
/*Make sure that the SPECIFIC_PROVISIONS will be nullified for duplicate EXP_ID records*/
proc sort data=work._inputs_(where=(APPROACH in ('IRB', 'IRBA', 'IRBF', 'IRB_SLOTTING')));
by EXP_ID CRM_ID;
run;
 
data work._inputs_;
set work._inputs_;
if FIRST.EXP_ID then VALID_PROVISION = 1;
else VALID_PROVISION = 0;
by exp_id;
run;

/* In IRB and IRBA Case get CRM Values for LGD_CRM_ADJUSTED_FLG=1*/

data work._inputs_ (DROP=CRM_VALUE_B) ;
 merge work._inputs_(in=a) _rg_calc.Lgd_adjusted_crm_IRB (in=b rename= (CRM_VALUE= CRM_VALUE_B));
 by EXP_ID;
 if a;
 if a and b then  
 CRM_USED_AMT_EFF = CRM_VALUE_B ; 
run; 
 
/*Continue with the creation of other cross-class variables*/
 
data _intds.CAPITAL_CRIRBA;
set work._inputs_;
length  GUAR_FLAG SL_FLAG OWN_LGD_CCF_ESTIMATES $10.
EXPOSURE_CLASS_LEVEL_1 EXPOSURE_CLASS_LEVEL_2
EXPOSURE_TYPE OTHER_CR_CLASSES CRM_CLASS_LEVEL_1
CRM_CLASS_LEVEL_2 CRM_GROUP SL_TYPE SL_OF_WHICH_CAT1 $16.
CRM_PRODUCT $32.;

if not missing(COUNTERPARTY_RK) then COUNTERPARTYID = compress( 'CPTY_' || put( COUNTERPARTY_RK, 20. ) ); 
 
/* 3a. Define the top hierarchy of CR_IRBA */
    
/* The exposure classes are calculated using both EXP and CRM info */
/* That way the inflow/outflow specification can be defined        */   
 
/*First, get the implied CPTY and PRODUCT codes from the classes-subclasses*/
    /*IMPLIED_CPTY_CD    = put(compress(COUNTERPARTY_CLASS||'_'||COUNTERPARTY_SUBCLASS), $MAPPED_CPTY_CD.);*/
if COUNTERPARTY_SUBCLASS ne '' then
IMPLIED_CPTY_CD    = put(compress(COUNTERPARTY_CLASS||'_'||COUNTERPARTY_SUBCLASS), $MAPPED_CPTY_CD.);
else IMPLIED_CPTY_CD    = put(compress(COUNTERPARTY_CLASS), $MAPPED_CPTY_CD.);
    /*IMPLIED_PRODUCT_CD = put(compress(IRB_PRODUCT_CLASS||'_'||IRB_PRODUCT_SUBCLASS), $MAPPED_IRB_PRODUCT_CD.);*/
if IRB_PRODUCT_SUBCLASS ne '' then
IMPLIED_PRODUCT_CD = put(compress(IRB_PRODUCT_CLASS||'_'||IRB_PRODUCT_SUBCLASS), $MAPPED_IRB_PRODUCT_CD.);
else IMPLIED_PRODUCT_CD = put(compress(IRB_PRODUCT_CLASS), $MAPPED_IRB_PRODUCT_CD.);

EXPOSURE_CLASS_LEVEL_1 =
put(compress(IMPLIED_CPTY_CD || IMPLIED_PRODUCT_CD),$MAP_EXPOSURE_CLASS_1_REGRPT.);
 
EXPOSURE_CLASS_LEVEL_2 =
put(compress(IMPLIED_CPTY_CD|| IMPLIED_PRODUCT_CD),$MAP_EXPOSURE_CLASS_2_REGRPT.);

if CRM_ID NE '' then do;
 
	CRM_CLASS_LEVEL_1 =
	put(compress(CRM_REG_COUNTERPARTY_TYPE_CD || CRM_REG_PRODUCT_CD), $MAP_EXPOSURE_CLASS_1_REGRPT.);
	 
	CRM_CLASS_LEVEL_2 =
	put(compress(CRM_REG_COUNTERPARTY_TYPE_CD || CRM_REG_PRODUCT_CD), $MAP_EXPOSURE_CLASS_2_REGRPT.);
 
end;


/* SME supporting factor related change */

/* SME supporting factor cross class */
if SME_CAP_DEDUCTION_TRT_FLG  eq 1 then
	SME_SUPPORT_FACTOR="SME_SUPPORT";
else
	SME_SUPPORT_FACTOR="NOTAPP";
	
      
/*Checking whether Approach is IRBF or IRBA */ 
if APPROACH in ('IRBF') then do; 
	 OWN_LGD_CCF_ESTIMATES = "NO" ; 
end; 
else do ; 
	OWN_LGD_CCF_ESTIMATES = "YES" ; 
end; 
  
  
EXPOSURE_CLASS_IRB_LEVEL_1= put(compress(EXPOSURE_CLASS_LEVEL_1),$MAP_IRB_GB_CLASS.);        

/*CP 50 instructions : 
The exposure values for which the maturity is not an element in the calculation of risk weighted exposure amounts,
 they do not have to be reported. This means that this column (maturity) should not be filled in for retail portfolios.
*/
if upcase(EXPOSURE_CLASS_IRB_LEVEL_1) eq 'RETAIL' then MAT_EFF = . ; 

if PAST_DUE_CLAIM_FLG EQ 1 or IN_DEFAULT_FLG EQ 1 or PD_EXP=100 then
	do;
		EXPOSURE_SUBTYPE  = 'PAST_DUE';
		
		if (DEFAULT_DATE <= &RUNDATE AND DEFAULT_DATE > = DATEPART(&LAST_REPORTING_DATE)) THEN
			IN_DEFAULT_STATUS='NEW';
		else
			IN_DEFAULT_STATUS='OLD';
	end;
      
/* 3b. Breakdown of Exposures by EXPOSURE_TYPE */

/*--  Cross-product netting is not supported hence, exposures should route based on irb_product_class --*/  

/*IF NETTING_SET_RK NE '' THEN EXPOSURE_TYPE = 'NETTING'; */ 

IF IRB_PRODUCT_CLASS EQ 'REPO_STYLE' THEN EXPOSURE_TYPE = 'REPOS';
ELSE IF IRB_PRODUCT_CLASS EQ 'DERIVATIVE' THEN EXPOSURE_TYPE = 'DERIVATIVES';
ELSE IF OFF_BALANCE_SHEET_TYPE_CD NE '' THEN EXPOSURE_TYPE = 'OFF_BALANCE';
ELSE EXPOSURE_TYPE = 'ON_BALANCE';
 
    
IF APPROACH ='IRB_SLOTTING' AND IRB_PRODUCT_CLASS EQ 'SL' AND EXPOSURE_CLASS_LEVEL_1 EQ 'CORPORATE' then
DO;
            
		SL_TYPE = put(_COST_, MAP_IRB_RW_BUCKET_SL_CAREGRPT.);
		SL_TYPE = compress('SL'||'_'||SL_TYPE);
		        
		/*
		IF ("&IRB_SL_PREF_TREATMENT" = "YES" and RESIDUAL_MATURITY < &IRB_SL_SHORT_PREF_MAT_LIMIT)
		then SL_TYPE = 'SL_PREF_CAT_1'; 
		*/ 
		/*need to change this for CP50 */ 
		
		if IRB_RW_BUCKET = 'BUCKET1' then 
		SL_OF_WHICH_CAT1 = 'SL_CAT_1';
		
		/* The SL_FLAG is needed to aggregate over all SL slotting criteria */      
		SL_FLAG = '001';
        
END;    

IF INDEX(EXP_ID,'DILUTION') then OTHER_CR_CLASSES = 'DILUTION_RISK';
ELSE IF IRB_ALTER_TREAT_ELIGIB_TYPE_CD EQ '001' then OTHER_CR_CLASSES = 'ALT_TREATMENT';
/*For Row-170 CP:IRB report */ 
else if IRB_PRODUCT_SUBCLASS in ('OTHER_NON_CREDIT_OBLG', 'CASH_GOLD_BULLION_EXP')
         then OTHER_CR_CLASSES = 'OTHER_EXPOSURES';
    
    
/* 3e. Define the CRM groups and products */
 
IF CRM_ID NE '' then
DO;

if LGD_CRM_ADJUSTED_FLG ne 1 then do ;
	SPECIFIC_PROVISION = 0;
	SPECIFIC_WRITEOFF = 0;/*Nullify writeoff in the case of mitigants*/
end;

if put(put(cats(CRM_REG_COUNTERPARTY_TYPE_CD, CRM_REG_PRODUCT_CD), $MAP_APPROACH_CLASS.), $MAP_APPROACH.) in ('STD') then
do;
		CRM_USED_AMT=0;
		CRM_USED_AMT_EFF=0;
end;

 
CRM_GROUP = put(LGD_CRM_ADJUSTED_FLG, MAP_LGD_ADJUSTED_REGRPT.);
IF ELIGIBLE_DD_TREAT_CRM EQ 'Y' then CRM_GROUP = "DOUBLE_DEF";
    
/*- CRMs that appear in all CRM types -*/
IF CRM_SUBTYPE = 'UNFUNDED' THEN CRM_PRODUCT = 'DER_UNFUNDED';
ELSE IF CRM_SUBTYPE = 'FUNDED' THEN CRM_PRODUCT = 'DER_FUNDED';
ELSE IF CRM_TYPE = 'GUARANTEE' THEN     
DO;
/* GUAR_FLAG = put(CRM_ID,$MAP_GUARANTEE_FLAG_REGRPT.); */ /* commented as of changes in SA */ 
/*GUAR_FLAG = put(UNFUNDED_FLG,MAP_GUARANTEE_FLAG_REGRPT.);
CRM_PRODUCT = compress('GUAR_'||GUAR_FLAG);
*/ 
/* Guarantees are always unfunded */ 
CRM_PRODUCT = 'GUAR_UNFUNDED' ; 

END;
 
/*- CRMs needed only for the non-adjusted LGD case -*/
IF CRM_GROUP IN ('NOT_ADJ', 'UNDEFINED') then
DO;
	
	if CRM_PRODUCT IN ('DER_FUNDED', 'GUAR_FUNDED')  then CRM_PRODUCT = 'OTHER_FUNDED';
	/* To comply with CP 50 reports  */
	if CRM_TYPE = 'FINANCIAL_COLLATERAL' then CRM_PRODUCT = 'FIN_COLL';
	else if CRM_SUBTYPE = 'RECEIVABLES'  then CRM_PRODUCT = 'RECEIV';
  else if CRM_SUBTYPE IN('CRE', 'RRE', 'OTHER') then CRM_PRODUCT = CRM_SUBTYPE;

	
END;
    
/*- CRMs needed only for the LGD adjusted case -*/
IF CRM_GROUP EQ "LGD_ADJ" then
DO;
	if CRM_TYPE = 'FINANCIAL_COLLATERAL' then 
	do; 
		  if CRM_SUBTYPE IN('LIFE_INSURANCE', 'CASH_3RD_PARTY') then CRM_PRODUCT = CRM_SUBTYPE;
		  else 
			    CRM_PRODUCT = 'FIN_COLL';
	end; 		
	else if CRM_SUBTYPE = 'RECEIVABLES'  then CRM_PRODUCT = 'RECEIV';
	else if CRM_SUBTYPE IN('CRE', 'RRE', 'OTHER') then CRM_PRODUCT = CRM_SUBTYPE;
END;
        
END;
        
run;

/*Purchased Receivables Calculations */ 
/* CRR Aritcle 162 (6)
The exposure value for the calculation of risk weighted exposure amounts of purchased
receivables shall be the value according to paragraph 1 minus the own funds requirements
for dilution risk prior to credit risk mitigation.
*/
data _capital_crirba_dilution;
	set _intds.CAPITAL_CRIRBA;
if DILUTION_FLG ; 
run ;  

data _capital_crirba_dilution;
 set _capital_crirba_dilution;
 if LGD_EFF=. or PD_EFF=. then
    EL_AMT = EAD_PORTION * PD_PCT * LGD_PCT/10000;
else     
    EL_AMT = EAD_PORTION * PD_EFF * LGD_EFF/10000;
    
run ; 

proc sort data=_capital_crirba_dilution;
by issue_key;
run;
proc summary data=_capital_crirba_dilution;
var RWA EL_AMT ;
by issue_key;
output out=_dilution_rwa_ sum=RWA_SUM EL_AMT_SUM;
run;
 
data _capital_crirba_dilution;
merge _capital_crirba_dilution
_dilution_rwa_(drop=_type_ _freq_);
by issue_key;
run;
proc sort data=_intds.CAPITAL_CRIRBA;
by issue_key;
run;
data _intds.CAPITAL_CRIRBA ;
merge _intds.capital_crirba (in= a)
_capital_crirba_dilution (in =b);
by issue_key;
if a ; 
run;

data _intds.CAPITAL_CRIRBA ;
 set _intds.CAPITAL_CRIRBA ;
 if DILUTION_FLG then do ; 
	IF INDEX(EXP_ID,'DILUTION') then do;
		 EAD = EXP_VALUE ; 
		 EAD_PORTION = EXP_VALUE ; 
		 EL_AMT = EL_AMT_SUM ; 
		 RWA = RWA_SUM ; 
	end; 
	else do ; 
		EXP_VALUE = . ; 
		EAD_PORTION = . ; 
/*		EL_AMT = . ; */
		RWA = . ; 
	end; 
		/*For receivables obligor grade information is not required */ 
	OBLIGOR_GRADE = '' ; 
end;	
run; 

/* CRR Article 158 (5): For defaulted exposures (PD = 100 %) where institutions use own estimates of LGDs, 
   EL shall be EL BE , the institution's best estimate of expected loss for the defaulted exposure
   in accordance with Article 181(1)(h).*/ 
data _intds.CAPITAL_CRIRBA ;
 set _intds.CAPITAL_CRIRBA ;
if (IN_DEFAULT_FLG EQ 1 or PD_EXP=100) and APPROACH in ('IRB', 'IRBA') then 
    EL_AMT = (EL/100) * EAD_PORTION ; 
run ; 

/*remove the EXP_VALUE corresponding to CRM's */  
data _intds.CAPITAL_CRIRBA;
	set _intds.CAPITAL_CRIRBA;
	if CRM_ID NE '' and LGD_CRM_ADJUSTED_FLG ne 1 then 
	do;	
		  EXP_VALUE=0; 
	end; 
run; 
		
/*---------------------------------------------------------------------------
* Step 4. Adjust portfolio to include inflow/outflow information through
*         the inclusion of two instrument types
* -------------------------------------------------------------------------*/   
    
/*-Separate the mitigants from the exposures and assign them an insttype -*/
data work.only_crm work.only_exp;
length INSTTYPE $16. INSTID $32.;
set _intds.CAPITAL_CRIRBA;


INSTID = compress(EXP_ID||CRM_ID);
INSTTYPE = 'regrpt_crirb_exp';
output only_exp;

if CRM_ID NE '' then
do;
		INSTID = compress(CRM_ID||EXP_ID);
		INSTTYPE = 'regrpt_crirb_crm';
		
		/*As per CP 50 Instructions for INFLOWS: 
		Outflows correspond to the covered part of the Original Exposure pre conversion factors,
		that is deducted from the obligor's exposure class and, when relevant, risk weight or obligor
		grade or pool, and subsequently assigned to the protection provider's exposure class and, when 
		relevant, risk weight or obligor grade or pool. This amount will be considered as an Inflow 
		into the protection provider's exposure class and, when relevant, risk weights or obligor grades or pools.
		*/ 
		/*Separate sheet needs to be genereated when there is need to report Inflows amount in the 
		  protection provider's exposure class */ 
		IF CRM_GROUP IN ('NOT_ADJ', 'UNDEFINED') then
		DO;
				EXPOSURE_CLASS_LEVEL_1 = CRM_CLASS_LEVEL_1;
				EXPOSURE_CLASS_LEVEL_2 = CRM_CLASS_LEVEL_2;
    END;   
     	
		IF INDEX(EXP_ID,'DILUTION') then OBLIGOR_GRADE='UNDEFINED';
		EXP_VALUE=0;
		EAD=0;  
	/*	EAD_ADJ=0;*/ 
		EAD_PORTION=0;
		output only_crm;
end;
run;

/* For Correct calculations of Exposure weighted LGD and Exposure Weighted Maturity
   Extra information generated in column LGD_EFF and EAD due to above code ( which is required for
   other reporting columns) needs to be removed. 
 */ 
/* sort the data first */ 
proc sort data = Only_exp ; by EXP_ID ; run ;  
	
data Only_exp ; 
set Only_exp ; 
by EXP_ID ; 
if first.EXP_ID ne 1 then do ;
		EAD = 0 ; 
end; 
run ;

/*-Merge the mitigants with the exposures.
* Also, define the obligor flag, that is
* used for summing over all obligor grades  -*/
 
data _intds.CAPITAL_CRIRBA (drop = EXP_ID CRM_ID)
_intds.error_CAPITAL_CRIRBA;
length reason $64.;
set work.only_crm(rename=(INTERNAL_ORG_RK=INT_ORG_RK))
work.only_exp(rename=(INTERNAL_ORG_RK=INT_ORG_RK));
if EXPOSURE_CLASS_LEVEL_1 = '' or EXPOSURE_CLASS_LEVEL_2 = '' then
do;
reason = 'Exposure classes (level 1 and/or 2) not mapped';
output _intds.error_CAPITAL_CRIRBA;
end;
else if EXPOSURE_CLASS_LEVEL_1 = 'EQUITY' then
do;
reason = 'The equity exposure class does not apply to this template';
output _intds.error_CAPITAL_CRIRBA;
end;
else do;
if OBLIGOR_GRADE NOT IN ('', 'UNDEFINED') then OBLIGOR_FLAG = '001';
INTERNAL_ORG_RK = put(INT_ORG_RK, MAP_INTERNAL_ORG_RK_CARPT.);
output _intds.CAPITAL_CRIRBA;
end;
run;
 


/*---------------------------------------------------------------------------
* Step 5. Check to see if data was created
* -------------------------------------------------------------------------*/
 
%checkdata (_intds,CAPITAL_CRIRBA, APPROACH in ('IRB', 'IRBA', 'IRBF', 'IRB_SLOTTING'));


data _intds.CAPITAL_CRIRBA_CRD4;
	set _intds.CAPITAL_CRIRBA;
run; 

proc sql; 
	drop table _intds.CAPITAL_CRIRBA;
quit;	

%if &HAVEDATA = YES %then %do;
%status(CAPITAL_CRIRBA_CRD4,SUCCESS,Exposures for IRB approach,CAPITAL_CRIRBA_CRD4);
	/* Copy the same portfolio for CR-GB (IRB) REPORT */
	data _intds.CAPITAL_CRGB_IRBA_CRD4;
	set _intds.CAPITAL_CRIRBA_CRD4;
	run;
	/* Insert the status for dynamic portfolio creation */
	%status(CAPITAL_CRGB_IRBA_CRD4,SUCCESS,Exposures for GB-IRBA approach,CAPITAL_CRGB_IRBA_CRD4);
%end;	
%else
%do;
%print_msg (WARNING,3,62);
%status(CAPITAL_CRIRBA_CRD4,Problems creating input data for portfolio,CAPITAL_CRIRBA_CRD4);
%end;
 
 
%mend prepare_regrpt_port_cr_irb;
 
 
%prepare_regrpt_port_cr_irb (crm_allocation_&MITIGANTS_ALLOCATION_METHOD._detail);
options notes source;

/*deassign the library */ 
libname _rg_calc ;

%mend b25_prep_regrpt_port_crirb_crd4;
