/*****************************************************************************
* Copyright (c) 2014 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
*
*    NAME: b45_prepare_regrpt_sec_det_crd4.sas
*
* PURPOSE: Create portoflio data for SEC DETAILS regulatory report
*
*   USAGE:
*
*   NOTES:
*
*****************************************************************************/
%macro b45_prepare_regrpt_sec_det_crd4 ;

   %macro prepare_regrpt_port_sec_det (inputds) ; 

   /*---------------------------------------------------------------------------
   * Step 1. Check to see if the user has requested the report 
   * -------------------------------------------------------------------------*/
    
   %let HAVEDATA=NO;

   %if  
      (%UPCASE(&REGPROJECTNAME) EQ CAPITAL_CRSEC_DET_CRD4 OR  %UPCASE(&REGPROJECTNAME) EQ ALL )

      %then %do;
         %if %UPCASE(&MITIGANTS_ALLOCATION_METHOD) EQ OPTIMAL %then %do;
            libname _incrlib  "&REGPATH";
            %goto checkirba_opt;
         %end;
         %else %if %UPCASE(&MITIGANTS_ALLOCATION_METHOD) EQ BY_RANK %then %do;
            libname _incrlib  "!CRISKMRES&PATHSEP.&PROJECT_SET&PATHSEP.&PROJECT_SET._rnk";
            %goto checkirba_rnk;
         %end;
      %end;

   %else %goto SKIP;

   /*---------------------------------------------------------------------------
   * Step 2. Check to see if we have data
   * -------------------------------------------------------------------------*/

   %SKIP:
   %print_msg (NOTE,3,60);/*-------------------------->Add another message*/
   %return;

 
   %CHECKIRBA_OPT:
   %checkdata (_incrlib, &INPUTDS , );

   %CHECKIRBA_RNK:
   %checkdata (_incrlib, &INPUTDS , );
 
   /* If no data then return*/
   %if (&HAVEDATA = NO)  %then %do;
      %print_msg (WARNING,3,1);/*------------------------>Change this message*/
      %return;
   %end;

   /*---------------------------------------------------------------------------
   * Step 3a. Creating portfolio for SEC Details report
   * -------------------------------------------------------------------------*/

   /*- Perform some pre-processing to get values for the portfolio -*/
   proc sql ; 
      create table work.SEC_DETAILS_SUM As
         select SECURITIZATION_POOL_RK, sum(EXP_VALUE) as TRANCHE_VALUE_SUM, sum(SPECIFIC_PROVISION) as PROVISION_SUM
         from _incrlib.&INPUTDS
         where not missing(SECURITIZATION_POOL_RK) 
         group by SECURITIZATION_POOL_RK
         order by SECURITIZATION_POOL_RK ;
   quit ;

   /*- Need to sort the data set for the merge -*/
   proc sort data = _incrlib.&INPUTDS ;
   by SECURITIZATION_POOL_RK ; 
   run ;

   data _intds.CAPITAL_CRSEC_DET_CRD4 ;
      merge _incrlib.&INPUTDS work.SEC_DETAILS_SUM ;
      by SECURITIZATION_POOL_RK ;
      where not missing(SECURITIZATION_POOL_RK) ; 
      length INSTTYPE $ 16 INSTID ORIGINATOR_ID INTERNAL_CODE $ 32 ;
      
      INSTTYPE = "REGRPT_SEC_DET"  ; 
      INSTID = compress('SEC_DET_'||_N_) ;


      /*- Col. 10 -*/
      INTERNAL_CODE = SECURITIZATION_POOL_RK ;

      /*- Col. 20 -*/
      SECURITIZATION_ID = SECURITIZATION_POOL_ID ;

      /*- Col. 30 -*/
      if PRIMARY_BANK_ROLE = 'ORIGINATOR' then ORIGINATOR_ID = "&SYSTEM_ID" ;
      else if PRIMARY_BANK_ROLE in ('INVESTOR','SPONSOR') then ORIGINATOR_ID = COUNTERPARTY_ID ;

      /*- Col. 40 -*/
      if SEC_STRUCTURE_TYPE = 'TRADITIONAL' then SECURITIZATION_TYPE = 'T' ;
      else if SEC_STRUCTURE_TYPE = 'SYNTHETIC' then SECURITIZATION_TYPE = 'S' ; 

      /*- Col. 50 -*/
      ACCOUNTING_TREATMENT = SEC_ACCTING_TREATMENT ; 

      /*- Col. 60 -*/
      SOLVENCY_TREATMENT = SECURITIZATION_TREATMENT_TYPE ; 

      /*- Col. 70 -*/
      if RESECURITIZATION_FLG = 1 then SECURITIZATION_RESEC = 'R' ; 
      else SECURITIZATION_RESEC = 'S' ; 

      /*- Col. 80 -*/
      RETENTION_TYPE = SEC_RETENTION_TYPE ;

      /*- Col. 90 -*/
      RETENTION_PCT = SEC_RETENTION_PCT ;

      /*- Col. 100 -*/
      if RETENTION_TYPE not in ('E','N') then do ; 
         if SEC_RETENTION_COMPLIANCE_FLG = 1 then RETENTION_COMPLIANCE = 'Y' ; 
         else RETENTION_COMPLIANCE = 'N' ;
      end ;
      else call missing(RETENTION_COMPLIANCE) ; 

      /*- Col. 110 -*/
      if PRIMARY_BANK_ROLE = 'ORIGINATOR' then INSTITUTION_ROLE = 'O' ; 
      else if PRIMARY_BANK_ROLE = 'SPONSOR' then INSTITUTION_ROLE = 'S' ; 
      else if PRIMARY_BANK_ROLE = 'INVESTOR' then INSTITUTION_ROLE = 'I' ; 
      else if PRIMARY_BANK_ROLE = 'ORIGINAL_LENDER' then INSTITUTION_ROLE = 'L' ; 

      /*- Col. 120 -*/
      if SEC_STRUCTURE_SUBTYPE ne "ABCP" then NON_ABCP_ORIGINATION_DATE = INCEPTION_DATE ;
      else call missing(NON_ABCP_ORIGINATION_DATE) ; 

      /*- Col. 130 -*/
      if SEC_STRUCTURE_SUBTYPE ne "ABCP" then NON_ABCP_ORIGINATION_AMT = POOL_FACE_VALUE_AMT ;
      else call missing(NON_ABCP_ORIGINATION_AMT) ;

      /*- Col. 140 -*/
      TOTAL_AMOUNT = TRANCHE_VALUE_SUM ;

      /*- Col. 150 -*/
      /*- Misnamed. Should be a _PCT not an _AMT -*/
      if missing(INSTITUTION_SHARE_PCT) then INSTITUTION_SHARE = 100 ; 
      else INSTITUTION_SHARE = INSTITUTION_SHARE_PCT ; 

      /*- Col. 160 -*/
      ASSET_LIABILITY_TYPE = SEC_PORTFOLIO_TYPE ; 

      /*- Col. 170 -*/
      if SEC_PORTFOLIO_TYPE not in ('11','12') and INSTITUTION_ROLE ne 'S' then do ;
         if APPROACH = 'STD' then APPROACH_APPLIED = 'S' ; 
         else if index(APPROACH,'IRB') ne 0 then APPROACH_APPLIED = 'I' ; 
         else call missing(APPROACH_APPLIED) ; 
      end ; 
      else call missing(APPROACH_APPLIED) ; 

      /*- Col. 180 -*/
      if PRIMARY_BANK_ROLE ne 'INVESTOR' then 
         NUMBER_OF_EXPOSURES = EFFECTIVE_NUMBER_OF_EXPOSURES ; 
      else call missing(NUMBER_OF_EXPOSURES) ;

      /*- Col. 190 -*/
      COUNTRY = ORIGINATION_COUNTRY_CD ; 

      /*- Col. 200 -*/
      ELGD = WEIGHTED_AVG_LGD_PCT ; 

      /*- Col. 210 -*/
      VALUE_ADJUST_PROVISIONS = PROVISION_SUM ; 

      /*- Col. 220 -*/
      if SEC_PORTFOLIO_TYPE not in ('11','12') and INSTITUTION_ROLE ne 'S' then do ;
         OWN_FUND_REQ_PRE_SECURITIZATION = K_IRB ; 
      end ; 
      else call missing(OWN_FUND_REQ_PRE_SECURITIZATION) ;

      /*- Cols. 230, 240, 250 -*/
      if missing(OFF_BALANCE_SHEET_TYPE_CD) then do ; 
         call missing(ON_BS_SENIOR_TRANCHE_VALUE) ; 
         call missing(ON_BS_MEZZ_TRANCHE_VALUE) ; 
         call missing(ON_BS_FIRST_LOST_TRANCHE_VALUE) ; 

         if SENIORITY_CD = 'SEN' then ON_BS_SENIOR_TRANCHE_VALUE = TRANCHE_FACE_VALUE_AMT ; 
         else if SENIORITY_CD = 'MEZ' then ON_BS_MEZZ_TRANCHE_VALUE = TRANCHE_FACE_VALUE_AMT ;
         else if TRANCHE_LOSS_RANK = 1 then ON_BS_FIRST_LOST_TRANCHE_VALUE = TRANCHE_FACE_VALUE_AMT ; 
      end ;
         
      /*- Cols. 260, 270, 280 -*/
      if not missing(OFF_BALANCE_SHEET_TYPE_CD) then do ; 
         call missing(OFF_BS_SENIOR_TRANCHE_VALUE) ; 
         call missing(OFF_BS_MEZZ_TRANCHE_VALUE) ; 
         call missing(OFF_BS_FIRST_LOST_TRANCHE_VALUE) ; 

         if SENIORITY_CD = 'SEN' then OFF_BS_SENIOR_TRANCHE_VALUE = TRANCHE_FACE_VALUE_AMT ; 
         else if SENIORITY_CD = 'MEZ' then OFF_BS_MEZZ_TRANCHE_VALUE = TRANCHE_FACE_VALUE_AMT ;
         else if TRANCHE_LOSS_RANK = 1 then OFF_BS_FIRST_LOST_TRANCHE_VALUE = TRANCHE_FACE_VALUE_AMT ; 
      end ;

      /*- Col. 290 -*/
      FIRST_TERMINATION_DATE = FIRST_POSSIBLE_TERM_DT ;

      /*- Col. 300 -*/
      LEGAL_FINAL_DATE = LONGEST_MATURITY_DATE ; 

      /*- Cols. 310, 320, 330 -*/
      if missing(OFF_BALANCE_SHEET_TYPE_CD) then do ; 
         call missing(ON_BS_SENIOR_EXP_VALUE) ; 
         call missing(ON_BS_MEZZ_EXP_VALUE) ; 
         call missing(ON_BS_FIRST_LOST_EXP_VALUE) ; 

         if SENIORITY_CD = 'SEN' then ON_BS_SENIOR_EXP_VALUE = EXP_VALUE ; 
         else if SENIORITY_CD = 'MEZ' then ON_BS_MEZZ_EXP_VALUE = EXP_VALUE ;
         else if TRANCHE_LOSS_RANK = 1 then ON_BS_FIRST_LOST_EXP_VALUE = EXP_VALUE ; 
      end ;
         
      /*- Cols. 340, 350, 360 -*/
      call missing(OFF_BS_SENIOR_EXP_VALUE) ; 
      call missing(OFF_BS_MEZZ_EXP_VALUE) ; 
      call missing(OFF_BS_FIRST_LOST_EXP_VALUE) ; 

      if not missing(OFF_BALANCE_SHEET_TYPE_CD) then do ; 

         if SENIORITY_CD = 'SEN' then OFF_BS_SENIOR_EXP_VALUE = EXP_VALUE ; 
         else if SENIORITY_CD = 'MEZ' then OFF_BS_MEZZ_EXP_VALUE = EXP_VALUE ;
         else if TRANCHE_LOSS_RANK = 1 then OFF_BS_FIRST_LOST_EXP_VALUE = EXP_VALUE ; 
      end ;

      /*- Cols. 370, 380, 390, 400 -*/
      call missing(DCS_MEMO) ; 
      call missing(IRS_CRS_MEMO) ; 
      call missing(FAC_MEMO) ; 
      call missing(OTHER_MEMO) ; 

      if put(OFF_BALANCE_SHEET_TYPE_CD,$MAP_OBSI_SEC_DETAIL_REGRPT.) in ('DCS') then
         DCS_MEMO = RWA_SEC_MEMO_AMT ; 
      else if put(OFF_BALANCE_SHEET_TYPE_CD,$MAP_OBSI_SEC_DETAIL_REGRPT.) in ('IRS','CRS') then
         IRS_CRS_MEMO = RWA_SEC_MEMO_AMT ; 
      else if put(OFF_BALANCE_SHEET_TYPE_CD,$MAP_OBSI_SEC_DETAIL_REGRPT.) in ('FAC') then
         FAC_MEMO = RWA_SEC_MEMO_AMT ; 
      else OTHER_MEMO = RWA_SEC_MEMO_AMT ;   

      /*- Col. 410 -*/
      if not missing(EARLY_AMORTIZATION_TYPE) then CCF_APPLIED = CCF ; 

      /*- Col. 420 -*/
      OWN_FUNDS_DEDUCTION = SEC_DEDUCTION_AMT ; 

      /*- Col. 430 -*/
      PRE_CAP_EXPOSURE = RWA_BEFORE_CAP ;

      /*- Col. 440 -*/
      POST_CAP_EXPOSURE = RWA ; 

      /*- Col. 450 -*/
      if CORRELATION_TRADING_PORT_FLG = 1 then CTP_NON_CTP = 'C' ; 
      else CTP_NON_CTP = 'N' ; 

      /*- Cols. 460, 470 -*/
      if TRADING_BOOK_FLG = 1 then do ; 
         if SHORTPOSITION = 1 then LONG_POSITION_NET = EXP_VALUE_NET ; 
         else SHORT_POSITION_NET = EXP_VALUE_NET ;
      end ; 
      else do ; 
         call missing(LONG_POSITION_NET) ; 
         call missing(SHORT_POSITION_NET) ; 
      end ;


      /*- Col. 480 -*/
      SPECIFIC_RISK = 0.08*max(LONG_POSITION_NET,SHORT_POSITION_NET) ; 



  keep INSTID INSTTYPE INTERNAL_CODE SECURITIZATION_ID ORIGINATOR_ID SECURITIZATION_TYPE ACCOUNTING_TREATMENT SOLVENCY_TREATMENT 
  SECURITIZATION_RESEC RETENTION_TYPE RETENTION_PCT RETENTION_COMPLIANCE INSTITUTION_ROLE NON_ABCP_ORIGINATION_DATE 
  NON_ABCP_ORIGINATION_AMT TOTAL_AMOUNT INSTITUTION_SHARE ASSET_LIABILITY_TYPE APPROACH_APPLIED NUMBER_OF_EXPOSURES
  COUNTRY ELGD VALUE_ADJUST_PROVISIONS OWN_FUND_REQ_PRE_SECURITIZATION ON_BS_SENIOR_TRANCHE_VALUE 
  ON_BS_MEZZ_TRANCHE_VALUE ON_BS_FIRST_LOST_TRANCHE_VALUE OFF_BS_SENIOR_TRANCHE_VALUE OFF_BS_MEZZ_TRANCHE_VALUE 
  OFF_BS_FIRST_LOST_TRANCHE_VALUE ON_BS_SENIOR_EXP_VALUE ON_BS_MEZZ_EXP_VALUE ON_BS_FIRST_LOST_EXP_VALUE 
  OFF_BS_SENIOR_EXP_VALUE OFF_BS_MEZZ_EXP_VALUE OFF_BS_FIRST_LOST_EXP_VALUE DCS_MEMO IRS_CRS_MEMO FAC_MEMO
  OTHER_MEMO CCF_APPLIED OWN_FUNDS_DEDUCTION PRE_CAP_EXPOSURE POST_CAP_EXPOSURE CTP_NON_CTP LONG_POSITION_NET
  SHORT_POSITION_NET SPECIFIC_RISK FIRST_TERMINATION_DATE LEGAL_FINAL_DATE ; 

   run ;

   /*---------------------------------------------------------------------------
   * Step 4. Check to see if data was created
   * -------------------------------------------------------------------------*/

   %checkdata (_intds,CAPITAL_CRSEC_DET_CRD4, );

   %if &HAVEDATA = YES %then %do;
      %status(CAPITAL_CRSEC_DET_CRD4,SUCCESS,SEC Details,CAPITAL_CRSEC_DET_CRD4);
   %end;
   %else %do;
      %print_msg (WARNING,3,62);
      %status(CAPITAL_CRSEC_DET_CRD4,Problems creating input data for portfolio,CAPITAL_CRSEC_DET_CRD4);
   %end;

   %mend prepare_regrpt_port_sec_det ;

   %prepare_regrpt_port_sec_det (crm_allocation_&MITIGANTS_ALLOCATION_METHOD._detail);
   options notes source;

%mend b45_prepare_regrpt_sec_det_crd4 ;
