/*****************************************************************************
 * Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME: Batch_CRiskM_20_Prc_Data_crd4.sas
 *
 * PURPOSE: CRiskM batch run: process market and position data.
 *
 *   USAGE: 
 *
 *   NOTES: The numbers in filenames indicates run sequence groups.  In general, 
 *          programs within the same group can run in any order.  
 *          
 *
 *****************************************************************************/

 %macro batch_criskm_20_prc_data_crd4;

/****************************************************************************
 *         Recreate Global Macro Definitions from Previous Session
 ****************************************************************************/

%u00_recreate_macro_definitions;

%b00_process_data_initial;
/*****************************************************************************
 *                      Parameter Matrix Data Sets
 *****************************************************************************/

/*- create a ccf parameter matrix for each set -*/
%b05_process_ccf_sets ;

/*- create a haircut parameter matrix for each set -*/
%b05_process_haircut_sets ;


/*****************************************************************************
 *                              Market Data
 *****************************************************************************/

/*- market data for interest rates -*/
%b10_process_market_ir ;

/*- market data for foreign exchange rates -*/
%b10_process_market_fx ;

/*- market data for equity prices -*/
%b10_process_market_equities ;

/*- market data for CIU  -*/
%b10_process_mkt_ciu_crd4;

/*- market data for PD/LGD -*/
%b10_process_market_pd_lgd ;

/*- market data for collateralization levels -*/
%b10_process_mkt_colateralan_lvl;

/*- market data for RW -*/
%b10_process_market_rw ;

/*- concatenate all market data horizontally -*/
%b10_process_market_vector ;


/*****************************************************************************
 *         Provision Data Sets and Preparation for Position Data
 *****************************************************************************/

%b15_process_exposure_provisions ;

%b15_process_general_provisions ;

%b15_process_counterparty_crd4 ;   

%b15_process_pos_initial_crd4 ;


/*****************************************************************************
 *                       Position Data Sets
 *****************************************************************************/

/* process_exp_ and process_crms_ files are updated*/
%b20_process_exp_accounts_crd4 ; 

%b20_process_exp_insts_crd4 ;  

%b20_process_exp_fac_crd4 ;

%b20_process_exp_rec_crd4 ;

%b20_process_exp_sec_crd4 ;

/*%b20_process_exposures_segments ;*/ 

%b20_process_netting_sets ;

/*%b20_process_crms_segments ;*/ 

%b20_process_crms_acct_crd4 ;

%b20_process_crms_instr_crd4 ;

%b20_process_crms_guar_crd4 ;

%b20_process_crms_der_crd4 ;

%b20_process_crms_insur_crd4 ;

%b20_process_crms_rec_crd4 ;

%b20_process_crms_phys_crd4 ;

%b25_process_exp_sec_underlying ;

%b30_process_exposure_crm_links ;

%b35_process_facility_exp_links ;

%b36_process_trading_book ;

%b37_process_simulation_data ;

%b38_prc_fin_rpt_data_crd4 ;  


%b40_process_positions_end ;

/*- subsequent batch runs need to know which previous batches have been run -*/
%global RUN_STAGE;
%let RUN_STAGE = 20;

/*****************************************************************************
 *  Save Macro Definitions so this step doesnot have to be run multiple times.
 *****************************************************************************/

%u00_save_macro_definitions;
%mend batch_criskm_20_prc_data_crd4;
