/* $Id: c05_create_output_var_crd4.sas,v 1.1.4.1 2014/01/10 18:25:50 sasdwu Exp $ */
/*****************************************************************************
 * Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME: c05_create_output_var_crd4.sas
 *
 * PURPOSE: Create output variables registration data set for RiskDimensions for CRD-IV configuration
 *
 *   USAGE: 
 *
 *   NOTES: VALUETYPE indicates type of the variable value for output format purpose
 *          0 = numeric  ; 1 = value amount ; 2 = percentage   
 *          
 *
 *****************************************************************************/

%macro c05_create_output_var_crd4;

data _null_;
filename f1 temp;
file f1;
put "OUTV_GENERAL_PROVISION , General Provision Amount    , FX  , NOHOLDING, NOSHORTPOS,  REG,   1";
put "OUTV_EAD               , Exposure at Default         , FX  , HOLDING  , SHORTPOS,    REG,   1";
put "OUTV_EAD_ADJ           , Exposure at Default Adj for CRM, FX  , HOLDING  , SHORTPOS,    REG,   1";
put "OUTV_EAD_SEG           , Exposure at Default-SEGMENT , FX  , HOLDING  , SHORTPOS,    REG,   1";
put "OUTV_FACE_VALUE        , Face Value Amount           , FX  , HOLDING  , NOSHORTPOS,  REG,   1";
put "OUTV_MAT_EFF           , Effective Maturity          , NOFX, NOHOLDING, NOSHORTPOS,  VALWGT,0";
put "OUTV_CRM               , CRM Value                   , FX  , HOLDING  , SHORTPOS  ,  REG,   1";
put "OUTV_HAIRCUT           , Haircut Applied             , NOFX, NOHOLDING, NOSHORTPOS,  VALWGT,0";
put "OUTV_ADD_ON            , Regulatory Add-on           , NOFX, HOLDING  , SHORTPOS  ,  VALWGT,0";
put "OUTV_CCF               , CCF Applied                 , NOFX, NOHOLDING, NOSHORTPOS,  VALWGT,0";
put "OUTV_RESIDUAL_VALUE    , Residual Value for lease    , FX  , HOLDING  , SHORTPOS  ,  REG,   1";
put "OUTV_EXPOSURE_PROVISION, Exposure-Specific Provision , FX  , NOHOLDING, NOSHORTPOS,  REG,   1";
put "OUTV_HAIRCUT_SCALE     , Scale factor for haircut    , NOFX, NOHOLDING, NOSHORTPOS,  VALWGT,0";
put "OUTV_RISK_POSITION     , Risk Positions              , FX  , HOLDING  , SHORTPOS  ,  REG   ,1";
put "OUTV_RP_CCF            , Risk Positions adjusted by CCF, FX, HOLDING  , SHORTPOS  ,  REG   ,1";
put "OUTV_EAD_REG_Y         , Exposure at Default (Reg Y) , FX  , HOLDING  , SHORTPOS,    REG   ,1";
put "OUTV_CCF_REG_Y         , CCF Applied (Reg Y)         , NOFX, NOHOLDING, NOSHORTPOS,  VALWGT,0";
put "OUTV_DEDUCTION_AMT     , Deduction Amount from Capital, FX , HOLDING  , SHORTPOS,    REG,   1";
put "OUTV_EXPOSURE_WRITEOFF, Exposure-Specific WriteOff   , FX  , NOHOLDING, NOSHORTPOS,  REG,   1";
run;

data RD_TEMP.mtm_outvar;
infile f1 delimiter = ',';
length NAME KIND ROLE TYPE GROUP FORMAT COMPTYPE ROLLUPTYPE POSTTYPE FXTYPE HOLDTYPE SHORTTYPE $32.;
length LABEL $256.;
length VALUETYPE 8.;
KIND       = 'OUTPUT';
TYPE       = 'NUM';
ROLE       = 'COMPUTED';
GROUP      = 'MtM Output Variables';
LENGTH     = 8;
FORMAT     = 'NLNUM';
FORMATL    = 20;
FORMATD    = 4;
COMPTYPE   = 'PL(UNBOUNDED)';
POSTTYPE   = 'POSTREG';
input NAME $ LABEL $ FXTYPE $ HOLDTYPE $ SHORTTYPE $ ROLLUPTYPE $ VALUETYPE;
run;

/*- additional variable for the trading book calculation -*/
/*-  datalines statement replaced with file infile statements while moving to MVA code -*/

data _null_;
filename f1 temp;
file f1;
put "OUTV_HEDGING_SET          , Aggregated risk position per hedging set, 1";
run;

data RD_TEMP.ccr_outvar;
infile f1 delimiter = ',';
length NAME KIND ROLE TYPE GROUP FORMAT COMPTYPE ROLLUPTYPE POSTTYPE FXTYPE HOLDTYPE SHORTTYPE $32.;
length LABEL $256.;
length VALUETYPE 8.;
KIND       = 'OUTPUT';
TYPE       = 'NUM';
ROLE       = 'COMPUTED';
GROUP      = 'Postprice Output Variables';
LENGTH     = 8;
FORMAT     = 'NLNUM';
FORMATL    = 20;
FORMATD    = 4;
COMPTYPE   = 'PL(UNBOUNDED)';
FXTYPE     = 'NOFX';
HOLDTYPE   = 'NOHOLDING';
SHORTTYPE  = 'NOSHORTPOS';
ROLLUPTYPE = 'REG';
POSTTYPE   = 'POSTPRICE';
input NAME $ LABEL $ VALUETYPE;
;
run;


/*- datalines statement replaced with file infile statements while moving to MVA code -*/
data _null_;
filename f1 temp;
file f1;
put "OUTV_FIRM_SIZE           , Firm Size                            , VALWGT , POSTREG, 1";
put "OUTV_PD_COUNTERPARTY     , PD (Counterparty)                    , VALWGT , POSTREG, 0";
put "OUTV_PD_ISSUE            , PD (Issue)                           , VALWGT , POSTREG, 0 ";
put "OUTV_PD_SEG              , PD : Retail (SEGMENT)                , VALWGT , POSTREG, 0 ";
put "OUTV_LGD                 , LGD: IRBF/IRBA (Exposure)            , VALWGT , POSTREG, 0";
put "OUTV_LGD_OTHER           , LGD_OTHER: lgd unadjusted for CRM    , VALWGT , POSTREG, 0";
put "OUTV_LGD_SEG             , LGD: Retail (SEGMENT)                , VALWGT , POSTREG, 0";
put "OUTV_LGD_DILUTION        , LGD: IRBF/IRBA (Dilution)            , VALWGT , POSTREG, 0";
put "OUTV_LGD_CRM_SEN         , LGD: Senior Claims (CRM)             , VALWGT , POSTREG, 0";
put "OUTV_LGD_CRM_SUB         , LGD: Subordinated Claims (CRM)       , VALWGT , POSTREG, 0";
put "OUTV_LTV                 , LTV: SEGMENT                         , VALWGT , POSTREG, 0";
put "OUTV_RW_COUNTERPARTY     , RW: Counterparty                     , VALWGT , POSTREG, 0";
put "OUTV_RW_ISSUE            , RW: Issue                            , VALWGT , POSTREG, 0";
put "OUTV_RW_ISSUE_OTHER      , RW: Issue using LGD_OTHER            , VALWGT , POSTREG, 0";
put "OUTV_RW_SEG              , RW: SEGMENT                          , VALWGT , POSTREG, 0";
put "OUTV_RW_DILUTION         , Dilution RW                          , VALWGT , POSTREG, 0";
put "OUTV_EL                  , Expected Loss (Percent)              , VALWGT , POSTREG, 0";
put "OUTV_EL_OTHER            , Expected Loss using LGD_OTHER        , VALWGT , POSTREG, 0";
put "OUTV_EL_SEG              , Expected Loss (Percent)-SEGMENT      , VALWGT , POSTREG, 0";
put "OUTV_EL_DILUTION         , Dilution Risk Expected Loss (Percent), VALWGT , POSTREG, 0";
put "OUTV_C_STAR              , Minimum Collateralization Level      , VALWGT , POSTREG, 0";
put "OUTV_C_STAR_STAR         , Over-Collateralization Level         , VALWGT , POSTREG, 0";
put "OUTV_BALANCE_AMT_SEG     , Balance amount at segment Level      , VALWGT , POSTREG, 0";
put "OUTV_RW_REG_Y            , Reg Y Risk Weight                    , VALWGT , POSTREG, 0";
put "OUTV_VALUE_REG_Y         , Reg Y Value                          , VALWGT , POSTREG, 0";
put "OUTV_RW_FROM_CENTGOV_FLG , Flag: STD RW Derived from Cent Gov   , VALWGT , POSTREG, 0";
put "OUTV_CVA_STD_WGT         , CVA Std. Approach Weight             , VALWGT , POSTREG, 0"; 
put "OUTV_CVA_STD_WGT_CRM     , CVA Std. Approach Weight for CRM     , VALWGT , POSTREG, 0"; 
run;

data RD_TEMP.regulatory_outvar;
infile f1 delimiter = ',';
length NAME KIND ROLE TYPE GROUP FORMAT COMPTYPE ROLLUPTYPE POSTTYPE FXTYPE HOLDTYPE SHORTTYPE $32.;
length LABEL $256.;
length VALUETYPE 8.;
KIND       = 'OUTPUT';
TYPE       = 'NUM';
ROLE       = 'COMPUTED';
GROUP      = 'Regulatory Output Variables';
LENGTH     = 8;
FORMAT     = 'NLNUM';
FORMATL    = 20;
FORMATD    = 4;
COMPTYPE   = 'PL(UNBOUNDED)';
FXTYPE     = 'NOFX';
HOLDTYPE   = 'NOHOLDING';
SHORTTYPE  = 'NOSHORTPOS';
ROLLUPTYPE = 'VALWGT';
POSTTYPE   = 'POSTREG';
input NAME $ LABEL $ ROLLUPTYPE $ POSTTYPE $ VALUETYPE;
run;

/*-  datalines statement replaced with file infile statements while moving to MVA code-*/
data _null_;
filename f1 temp;
file f1;
put "OUTV_VALUE             , MtM Value                             , REG   , POSTREG, 0, 1";
put "OUTV_RW                , Risk Weight (%)                       , REG   , POSTVAR, 0, 0";
put "OUTV_RW_NO_CRM         , Risk Weight: No CRM Applied (%)       , REG   , POSTVAR, 0, 0";
put "OUTV_EL_AMT            , Expected Loss Amount                  , REG   , POSTREG, 0, 1";
put "OUTV_RWA               , Risk Weighted Assets                  , REG   , POSTREG, 0, 1";
put "OUTV_RWA_SECURED       , RWA: Secured Portion                  , REG   , POSTREG, 0, 1";
put "OUTV_RWA_PD_LGD_EFFECT , Effect of CD on RWA                   , REG   , POSTREG, 0, 1";
put "OUTV_RWA_DBL_DEF_EFFECT, RWA: Without Double Default           , REG   , POSTREG, 0, 1";
put "OUTV_RWA_UNSECURED     , RWA: Unsecured Portion                , REG   , POSTREG, 0, 1";
put "OUTV_RWA_NO_CRM        , RWA: No CRM Applied                   , REG   , POSTREG, 0, 1";
put "OUTV_CAPITAL           , Capital Requirement                   , REG   , POSTREG, 0, 1";
put "OUTV_CAPITAL_NO_CRM    , Capital Requirement: No CRM Applied   , REG   , POSTREG, 0, 1";
put "OUTV_CAPITAL_REG_Y     , Capital Requirement: Reg Y            , REG   , POSTREG, 0, 1";
put "OUTV_REG_Y_CRM_VALUE   , CRM value:Reg Y                       , REG   , POSTREG, 0, 1";
put "OUTV_PD                , Probability of Default (%)            , VALWGT, POSTREG, 0, 0";
put "OUTV_PD_EFF            , Effective Probability of Default (%)  , VALWGT, POSTREG, 0, 0";
put "OUTV_LGD_EFF           , Effective Loss Given Default (%)      , VALWGT, POSTREG, 0, 0";
put "OUTV_EL_EFF_AMT        , Effective Expected loss amount        , REG   , POSTREG, 0, 1";
put "OUTV_CRM_USED_AMT      , Used CRM Amount                       , REG   , POSTREG, 0, 1";
put "OUTV_CRM_USED_AMT_EFF  , Effective Used CRM Amount             , REG   , POSTREG, 0, 1";
put "OUTV_VALUE_CON         , Value Concentration                   , REG   , POSTVAR, 0, 2";
put "OUTV_EAD_CON           , Exposure Concentration                , REG   , POSTVAR, 0, 2";
put "OUTV_RWA_CON           , RWA Concentration                     , REG   , POSTVAR, 0, 2";
put "OUTV_RWA_NO_CRM_CON    , RWA Concentration: No CRM Applied     , REG   , POSTVAR, 0, 2";
put "OUTV_CAPITAL_CON       , Capital Concentration                 , REG   , POSTVAR, 0, 2";
put "OUTV_CAPITAL_NO_CRM_CON, Capital Concentration: No CRM Applied , REG   , POSTVAR, 0, 2";
put "OUTV_RWA_PV            , Risk Weighted Assets                  , REG   , POSTVAR, 0, 1";
put "OUTV_CAPITAL_PV        , Capital Requirement                   , REG   , POSTVAR, 0, 1";
put "OUTV_PD_EFF_PV         , Effective PD                          , REG   , POSTVAR, 0, 0";
put "OUTV_LGD_EFF_PV        , Effective LGD                         , REG   , POSTVAR, 0, 0";
put "OUTV_EL_EFF_PV         , Effective Expected Loss after CRM     , REG   , POSTVAR, 0, 0";
put "OUTV_EL_EFF_AMT_PV     , Effective Expected loss amount        , REG   , POSTVAR, 0, 1";
put "OUTV_MIT_RWA           , RWA reduced by mitigant               , REG   , POSTREG, 0, 1";
put "OUTV_MIT_RWA_DBL_DEF_EFFECT, RWA reduced by mitigant           , REG   , POSTREG, 0, 1"; 
put "OUTV_MIT_USED_AMT_EFF  , Effective used amount from the CRM    , REG   , POSTREG, 0, 1";
put "OUTV_MIT_USED_AMT      , Used amount from the CRM              , REG   , POSTREG, 0, 1";
put "OUTV_MIT_VALUE         , Value amount referenced in mitigation , REG   , POSTREG, 1, 1";
put "PD_WEIGHTED_SUM        , Weighted sum of the PD values         , REG   , POSTREG, 0, 0";
put "LGD_WEIGHTED_SUM       , Weighted sum of the LGD values        , REG   , POSTREG, 0, 0";
put "HAIRCUT_ADJ_FLG        , Flag: haircut adjusted exposure       , REG   , POSTREG, 1, 0";
put "OUTV_RWA_REG_Y         , Risk Weighted Assets Under Reg Y      , REG   , POSTREG, 0, 1";
put "OUTV_RWA_SEG           , RWA: SEGMENT                         ,  REG   , POSTREG, 0, 1";
put "OUTV_ECL_SEG           , ECL: SEGMENT                         ,  REG   , POSTREG, 0, 1";
put "OUTV_CAPITAL_SEG       , Capital: SEGMENT                     ,  REG   , POSTREG, 0, 1";

run;

data RD_TEMP.rollup_outvar;
infile f1 delimiter = ',';
length NAME KIND ROLE TYPE GROUP FORMAT COMPTYPE ROLLUPTYPE POSTTYPE FXTYPE HOLDTYPE SHORTTYPE $32.;
length LABEL $256.;
length VALUETYPE DROP 8.;
KIND      = 'OUTPUT';
TYPE      = 'NUM';
ROLE      = 'COMPUTED';
GROUP     = 'Rollup Output Variables';
LENGTH    = 8;
FORMAT    = 'NLNUM';
FORMATL   = 20;
FORMATD   = 4;
COMPTYPE  = 'PL(UNBOUNDED)';
FXTYPE    = 'NOFX';
HOLDTYPE  = 'NOHOLDING';
SHORTTYPE = 'NOSHORTPOS';
input NAME $ LABEL $ ROLLUPTYPE $ POSTTYPE $ DROP VALUETYPE;
run;

data RD_TEMP.var_output;
set RD_TEMP.mtm_outvar RD_TEMP.regulatory_outvar RD_TEMP.rollup_outvar RD_TEMP.ccr_outvar;
run;
%mend c05_create_output_var_crd4;
