 /*****************************************************************************
 * Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME: c05_create_rf_var_crd4.sas
 *
 * PURPOSE: Create risk factor variables registration data set for RiskDimensions
 *
 *   USAGE: 
 *
 *   NOTES:
 *          
 *
 *****************************************************************************/
 
%macro c05_create_rf_var_crd4;
/*- fx -*/
data RD_TEMP.var_rf_fx (keep=KIND NAME LABEL ROLE TYPE FROMCUR CURRENCY MATURITY MUNIT GROUP CURVE) ;

    length KIND     $8. ;
    length NAME     $32.;
    length LABEL    $40.;
    length ROLE     $8. ;
    length TYPE     $8. ;
    length FROMCUR  $8. ;
    length CURRENCY $8. ;
    length MATURITY  8. ;
    length MUNIT    $8. ;
    length GROUP    $32.;
    length CURVE    $32.;

    set RD_MKT.current_fx
        (rename = (_NAME_ = NAME TYPE = CURVE 
                   MATURITY_LENGTH = MATURITY MATURITY_UNIT = MUNIT
                   FROM_CUR = FROMCUR TO_CUR = CURRENCY 
                )
        );

    KIND     = 'FACTOR';
    TYPE     = 'NUM';

    if MATURITY = . or MATURITY = 0 then do;
        ROLE = 'FX_SPOT';
        GROUP = 'Spot FX Rates';
    end;
    else if CURVE NE '' then do; 
        ROLE  = 'FX';
        GROUP = compbl(compress(CURRENCY || '_' || FROMCUR) || ' : ' || CURVE);
    end;
    else do;
        ROLE  = 'FX';
        GROUP = compbl(compress(CURRENCY || '_' || FROMCUR) || ' : ' || 'FORWARD');
        CURVE = 'FORWARD';
    end;

    LABEL = NAME;

    NAME = upcase(NAME);

run;

/*- interest rates -*/
data RD_TEMP.var_rf_ir (keep=KIND NAME LABEL ROLE TYPE CURRENCY MATURITY MUNIT GROUP CURVE) ;

    length KIND     $8. ;
    length NAME     $32.;
    length LABEL    $40.;
    length ROLE     $8. ;
    length TYPE     $8. ;
    length CURRENCY $8. ;
    length MATURITY  8. ;
    length MUNIT    $8. ;
    length GROUP    $32.;
    length CURVE    $32.;

    set RD_MKT.current_ir
        (rename = (_NAME_ = NAME TYPE = CURVE 
                   MATURITY_LENGTH = MATURITY MATURITY_UNIT = MUNIT
                  )
        );
    
    KIND     = 'FACTOR';
    TYPE     = 'NUM';
    ROLE     = 'IR';

    if MATURITY = . or MATURITY = 0 then do;
        GROUP = 'Short Interest Rates';
    end;
    else if CURVE NE '' then do;
        GROUP = compbl(CURRENCY || ': ' || CURVE);    
    end;
    else do;
        GROUP = compbl(CURRENCY || ': ' || 'FORWARD');    
    end;

    LABEL = NAME;
    NAME = upcase(NAME);

run;

/*- equity prices -*/
data RD_TEMP.var_rf_equities(keep = KIND NAME LABEL ROLE TYPE GROUP);
    length KIND     $8. ;
    length NAME     $32.;
    length LABEL    $40.;
    length ROLE     $8. ;
    length TYPE     $8. ;
    length GROUP    $32.;

    set RD_MKT.current_equities(rename = (ISSUE_CODE = NAME));

    KIND     = 'FACTOR';
    TYPE     = 'NUM';
    ROLE     = 'VAR';
    LABEL    = ISSUE_DESC;
    GROUP    = 'Equity Prices';

run;

/*-CIU prices -*/
data RD_TEMP.var_rf_funds(keep = KIND NAME LABEL ROLE TYPE GROUP);
       length KIND     $8. ;
       length NAME     $32.;
       length LABEL    $40.;
       length ROLE     $8. ;
       length TYPE     $8. ;
       length GROUP    $32.;
   
       set RD_MKT.current_funds(rename = (ISSUE_CODE = NAME));
   
       KIND     = 'FACTOR';
       TYPE     = 'NUM';
       ROLE     = 'VAR';
       LABEL    = ISSUE_DESC;
       GROUP    = 'Fund Prices';
   
run;

/*- Regulatory Risk Weights -*/

data RD_TEMP.var_rf_rw (keep = KIND NAME LABEL ROLE TYPE GROUP MLEVEL);

    length KIND     $8. ;
    length NAME     $32.;
    length LABEL    $40.;
    length ROLE     $8. ;
    length TYPE     $8. ;
    length GROUP    $32.;
    length MLEVEL   $8.;

    set RD_MKT.current_rw;

    NAME = upcase(RW_NAME) ;
    LABEL= NAME;
    KIND = 'FACTOR';
    TYPE = 'NUM' ;
    ROLE = 'VAR';
    MLEVEL = 'INTERVAL';

    if index(NAME,'BASELI') > 0 then 
        GROUP = 'BASEL I Risk Weights';
    else
    if substr(RW_NAME, 1, 4) = 'STD_' then do;

       if index(NAME, 'CENTGOV') > 0 then 
           GROUP = 'STD RW: Central Gov/Bank Claims';
       else if index(NAME, 'REGGOV') > 0 then 
           GROUP = 'STD RW: Regional/Local Gov Claims';
       else if index(NAME, 'PSE') > 0 then 
           GROUP = 'STD RW: PSE Claims'; 
       else if index(NAME, 'MDB') > 0 then 
           GROUP = 'STD RW: MDB Claims';
       else if index(NAME, 'INT_ORG') > 0 then 
           GROUP = 'STD RW: International Organization Claims';     
       else if index(NAME, 'INST_') > 0 then 
           GROUP = 'STD RW: Institution Claims';
       else if index(NAME, 'CORPORATE') > 0 then 
           GROUP = 'STD RW: Corporate Claims';
       else if index(NAME, 'PASTDUE') > 0 then 
           GROUP = 'STD RW: Exp in Default Claims';
       else if index(NAME, 'HIGHRISK') > 0 then 
           GROUP = 'STD RW: High Risk Claims';
       else if index(NAME, 'EQUITY') > 0 then 
           GROUP = 'STD RW: Equity Claims';    
       else if index(NAME, 'RETAIL') > 0 then
           GROUP = 'STD RW: Retail Claims'; 
       else if index(NAME, 'CIU') > 0 then
           GROUP = 'STD RW: CIUs'; 
       else if index(NAME, 'COV_BOND') > 0 then
           GROUP = 'STD RW: COV_BOND';    
       else if index(NAME, 'RME') > 0 then
           GROUP = 'STD RW: Residential Mortgages';
       else if index(NAME, 'CME') > 0 then
           GROUP = 'STD RW: Commercial Mortgages';
       else if index(NAME, '_SEC') >0  then
           GROUP = 'STD RW: Sec. Exposures';
       else if index(NAME, '_RESEC') >0  then
           GROUP = 'STD RW: Re-Sec. Exposures';    
       else if index(NAME, 'SHORT') > 0 then
           GROUP = 'STD RW: Short-term Claims';        
       else if index(NAME, 'OTHERS') > 0 then
           GROUP = 'STD RW: Other Assets';
       else if index(NAME, 'LIFE_INS') > 0 then
           GROUP = 'STD RW: Life Insurance Policy';    
       else
           GROUP = 'STD RW: Others';
    end;
    
    else do;

    if index(NAME, 'EL_HVCRE') > 0 then
        GROUP = 'IRB RW: HVCRE(EL)';
    else if index(NAME, 'UL_HVCRE') > 0 then
        GROUP = 'IRB RW: HVCRE(UL)';
    if index(NAME, 'EL_SL') > 0 then
        GROUP = 'IRB RW: SL(EL)';
    else if index(NAME, 'UL_SL') > 0 then
        GROUP = 'IRB RW: SL(UL)';
    else if index(NAME, 'EQUITY') > 0 then
        GROUP = 'IRB RW: Equities';
    else if index(NAME, '_SEC') > 0 then
        GROUP = 'IRB RW: Sec. Exposures';
    else 
        GROUP = 'IRB RW: Others';

    end;

run;

/*- PD/ LGD -*/
data  RD_TEMP.var_rf_pd_lgd (keep = KIND NAME LABEL ROLE TYPE GROUP MLEVEL CURVE);

    length KIND     $8. ;
    length NAME     $40.;
    length LABEL    $40.;
    length ROLE     $8. ;
    length TYPE     $8. ;
    length GROUP    $32.;
    length MLEVEL   $8.;
    length CURVE    $32.;
    length SOURCE   $40.;
    set RD_MKT.current_pd(in =a drop = PD_VALUE rename = (PD_NAME = NAME))
        RD_MKT.current_lgd(drop = LGD_VALUE rename = (LGD_NAME = NAME)) ;

    LABEL = NAME;
    KIND = 'FACTOR';
    TYPE = 'NUM' ;
    ROLE = 'VAR';
    MLEVEL = 'INTERVAL';

    if a then GROUP = 'PDs';
    else GROUP = 'LGDs';

    loc=index(name,scan(name,-1,'_'));
    curve=substr(name,1,loc-2);

run;

/*- EL -*/
data RD_TEMP.var_rf_el (keep = KIND NAME LABEL ROLE TYPE GROUP MLEVEL CURVE) ;

    length KIND     $8. ;
    length NAME     $32.;
    length LABEL    $32.;
    length ROLE     $8. ;
    length TYPE     $8. ;
    length GROUP    $32.;
    length MLEVEL   $8.;
    length CURVE    $32.;

    set RD_MKT.current_el (rename = (EL_NAME = NAME)) ;

    LABEL = NAME;
    KIND = 'FACTOR';
    TYPE = 'NUM' ;
    ROLE = 'VAR';
    MLEVEL = 'INTERVAL';
    GROUP = 'ELs' ;

    LOC = index(NAME,scan(NAME,-1,'_')) ;
    CURVE = substr(NAME,1,LOC-2) ;
run ;

/*- collateralization levels for IRB collateral -*/
data RD_TEMP.var_rf_level_irb_collateral (keep = KIND NAME LABEL ROLE TYPE GROUP MLEVEL);

    length KIND     $8. ;
    length NAME     $32.;
    length LABEL    $40.;
    length ROLE     $8. ;
    length TYPE     $8. ;
    length GROUP    $32.;
    length MLEVEL   $8.;

    set RD_MKT.current_min_level_irb_coll(keep=LEVEL_NAME rename=(LEVEL_NAME=NAME))
        RD_MKT.current_over_level_irb_coll(keep=LEVEL_NAME rename=(LEVEL_NAME=NAME))
    ;
    LABEL = NAME;
    KIND  = 'FACTOR';
    TYPE  = 'NUM';
    ROLE  = 'VAR';
    MLEVEL = 'INTERVAL';
    GROUP = 'Coll. Levels: IRB Collateral';

run;

/*- RF Vars used in aggregation -*/
/*- datalines statement replaced with file infile statements while moving to MVA code -*/

data _null_;
filename f1 temp;
file f1;
put "VALUE_TOTAL          , Firmwide Exposure Value";
put "EAD_TOTAL            , Firmwide EAD ";
put "RWA_TOTAL            , Firmwide RWA";
put "RWA_NO_CRM_TOTAL     , Firmwide RWA: No CRM Applied";
put "CAPITAL_TOTAL        , Firmwide Capital";
put "CAPITAL_NO_CRM_TOTAL , Firmwide Capital: No CRM Applied";

run;
data RD_TEMP.var_rf_rollup;
    infile f1 delimiter = ',';
    length KIND     $8. ;
    length NAME     $32.;
    length LABEL    $40.;
    length ROLE     $8. ;
    length TYPE     $8. ;
    length GROUP    $32.;
    KIND  = 'FACTOR';
    TYPE  = 'NUM' ;
    ROLE  = 'VAR';
    GROUP = "RFs used in Aggregation";
    input NAME $ LABEL $ ;
run;

/*- Concatenating all risk factor definition data sets -*/

data RD_TEMP.var_rf_all;
    length NAME $40.;
    set RD_TEMP.var_rf_fx
        RD_TEMP.var_rf_ir
        RD_TEMP.var_rf_equities
        RD_TEMP.var_rf_funds
        RD_TEMP.var_rf_rw
        RD_TEMP.var_rf_pd_lgd
        RD_TEMP.var_rf_el
        RD_TEMP.var_rf_level_irb_collateral    
        RD_TEMP.var_rf_rollup  
    ;
run;

/* Sort first by name to remove duplicate risk factor names. */
proc sort data = RD_TEMP.var_rf_all nodup;
    by NAME;
run;
%mend c05_create_rf_var_crd4;
