/*****************************************************************************
 * Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME: c20_create_ref_var.sas
 *
 * PURPOSE: Create data set for reference variable for input to RiskDimensions
 *
 *   USAGE: 
 *
 *   NOTES:
 *          
 *
 *****************************************************************************/

%macro c20_create_ref_var;

/*- no need for FX_SPOT reference variable since it is a automatic RD reference -*/

/*- reference variables for fx curves -*/
/*- reference name convention:        -*/
/*- FX_CURVE_REF_TYPENAME             -*/
/*- reference key is CURRENCY         -*/
data RD_TEMP.ref_rf_fx(keep = NAME REFVAR REFKEY);

    length NAME     $32. ;
    length REFVAR   $32. ;
    length REFKEY   $32. ;

    set RD_TEMP.array_rf_all;
    where CONTENT in ('FX');

    NAME   = ARRAYNAM;
    REFVAR = compress('FX_CURVE_REF_' || scan(ARRAYNAM, 3, '_'));
    REFKEY = compress(scan(ARRAYNAM, 1, '_') || ':' || scan(ARRAYNAM, 2, '_'));

run;

/*- reference variable for ir short rates -*/
/*- reference key is CURRENCY             -*/
data RD_TEMP.ref_rf_ir_short(keep = NAME REFVAR REFKEY);

    length NAME     $32. ;
    length REFVAR   $32. ;
    length REFKEY   $32. ;

    set RD_TEMP.var_rf_ir;
    where MATURITY = . or MATURITY = 0;

    REFVAR = 'IR_SHORT';
    REFKEY = CURRENCY  ;

run;

/*- reference variables for ir curves -*/
/*- reference name convention:        -*/
/*- IR_CURVE_REF_TYPENAME             -*/
/*- reference key is CURRENCY         -*/
data RD_TEMP.ref_rf_ir(keep = NAME REFVAR REFKEY);

    length NAME     $32. ;
    length REFVAR   $32. ;
    length REFKEY   $32. ;

    set RD_TEMP.array_rf_all;
    where CONTENT in ('IR');

    NAME   = ARRAYNAM;
    REFVAR = compress('IR_CURVE_REF_' || scan(ARRAYNAM, 2, '_'));
    REFKEY = compress(scan(ARRAYNAM, 1, '_'));

run;

/*- Reference variable for equities -*/
/*- reference key is ISSUE_CODE     -*/
data RD_TEMP.ref_rf_equities(keep = NAME REFVAR REFKEY);

    length NAME     $32. ;
    length REFVAR   $32. ;
    length REFKEY   $32. ;

    set RD_TEMP.var_rf_equities;

    REFVAR = "EQUITY_REF";
    REFKEY = NAME ;

run;

/*- Reference variable PD_REF, LGD_REF for values from models -*/
data RD_TEMP.ref_rf_pd_lgd (keep = NAME REFVAR REFKEY);

    length NAME     $40. ;
    length REFVAR   $32. ;
    length REFKEY   $32. ;
    length SOURCE   $40.;	

    set  RD_TEMP.rf_pd_temp(in=pd where=(SOURCE='MODEL')) RD_TEMP.rf_lgd_temp(in=lgd where=(SOURCE='MODEL'));

    if pd then REFVAR='PD_REF';
        else REFVAR='LGD_REF';

    REFKEY = compress(MODEL_ID) || ':' || compress(RATING_GRADE);

run;

/*- Reference variable EL_REF, for values from models -*/
data RD_TEMP.ref_rf_el (keep = NAME REFVAR REFKEY) ;
    
    length NAME     $32. ;
    length REFVAR   $32. ;
    length REFKEY   $32. ; 
    
    set RD_TEMP.rf_el_temp ;
    
    REFVAR = 'EL_REF' ;
    
    REFKEY = compress(MODEL_ID)|| ':' || compress(RATING_GRADE) ;
    
run ;
    
/*- reference variable for PD  floors -*/
data RD_TEMP.ref_rf_pd_floor(keep = NAME REFVAR REFKEY);

    length NAME     $32. ;
    length REFVAR   $32. ;
    length REFKEY   $32. ;

    set RD_TEMP.rf_pd_temp(in=pd where=(SOURCE='REGULATORY' and scan(NAME, 3, '_')='FLOOR'));

    if index(NAME, 'EQUITY') > 0 then do;
        REFVAR = 'PD_FLOOR_EQUITY_PD_LGD_REF';
        REFKEY = scan(NAME, 5, '_');
    end;
    else do;
        REFVAR = 'PD_FLOOR_REF';
        REFKEY = scan(NAME, 4, '_');
    end;
run;

/*- reference variable for equity LGD under PD/LGD approach -*/
data RD_TEMP.ref_rf_lgd_equity (keep = NAME REFVAR REFKEY);

    length NAME     $40. ;
    length REFVAR   $32. ;
    length REFKEY   $32. ;

    set RD_TEMP.rf_lgd_temp;
    where index(NAME, 'EQUITY') > 0;

    REFKEY = scan(NAME, 4, '_');
    REFVAR = 'LGD_EQUITY_PD_LGD_REF';
run;

/*- Reference variable LGD_IRB_COLLATERAL_REF -*/
data RD_TEMP.ref_rf_lgd_irb_collateral (keep = NAME REFVAR REFKEY);

    length NAME     $40. ;
    length REFVAR   $32. ;
    length REFKEY   $32. ;

    set RD_TEMP.rf_lgd_temp;
    where SOURCE = 'REGULATORY' and index(NAME, 'IRB_COLLATERAL') > 0;

    REFKEY = scan(NAME, 2, '_');
    REFVAR = 'LGD_IRB_COLLATERAL_REF';
run;

/*- Reference variable LGD_IRBF_REF -*/
data RD_TEMP.ref_rf_lgd_irbf (keep = NAME REFVAR REFKEY);

    length NAME     $40. ;
    length REFVAR   $32. ;
    length REFKEY   $32. ;

    set RD_TEMP.rf_lgd_temp;
    where NAME in ('IRBF_LGD_SENIOR' ,'IRBF_LGD_SUBORDINATED');
    REFKEY = substr(scan(NAME, 3, '_'), 1, 3);
    REFVAR = 'LGD_IRBF_REF';
run;

/*- Reference variables for collateralization levels for IRB collateral -*/
data RD_TEMP.ref_rf_level_irb_collateral (keep = NAME REFVAR REFKEY);

    length NAME     $32. ;
    length REFVAR   $32. ;
    length REFKEY   $32. ;

    set RD_TEMP.var_rf_level_irb_collateral;

    REFKEY = scan(NAME, 2, '_');

    if index(NAME, 'OLEVEL') > 0 then do;
        REFVAR = 'OVER_COLL_LEVEL_REF';
    end;
    else do;
        REFVAR = 'MIN_COLL_LEVEL_REF';
    end;
run;

/*- Reference variables for STD risk weights -*/
data RD_TEMP.ref_rf_rw(keep = NAME REFVAR REFKEY);

    length NAME     $32. ;
    length REFVAR   $32. ;
    length REFKEY   $32. ;

    set  RD_TEMP.var_rf_rw ;
    where index(NAME, 'BUCKET') > 0 or index(NAME, 'BASELI')>0;

    REFKEY = scan(NAME, 3, '_');

    /*- Reference variables for Basel I risk weights -*/
    if index(NAME, 'BASELI') > 0 then do;
        REFVAR = 'BASELI_RW_REF' ;
        REFKEY = NAME;*substrn(NAME,8);
        output;    
    end;
    else
    if substr(NAME, 1, 6) = 'STD_RW' then do;

    if index(NAME, 'SOVEREIGN_PREF') > 0 then do;
        REFVAR = 'STD_RW_SOVEREIGN_PREF_REF' ;
        output;
    end;        
    else if index(NAME, 'SOVEREIGN') > 0 then do;
        REFVAR = 'STD_RW_SOVEREIGN_REF' ;
        output;    
    end;
    else if index(NAME, 'BANK_OPT1') > 0 then do;
        REFVAR = 'STD_RW_BANK_OPT1_REF' ;
        output;    
    end;
    else if index(NAME, 'BANK_OPT2_LONG') > 0 then do;
        REFVAR = 'STD_RW_BANK_OPT2_LONG_REF' ;
        output;
    end;
    else if index(NAME, 'BANK_OPT2_SHORT') > 0 then do;
        REFVAR = 'STD_RW_BANK_OPT2_SHORT_REF' ;
        output;    
    end;
    else if index(NAME, 'BANK_PREF') > 0 then do ;
        REFVAR = 'STD_RW_BANK_PREF_REF' ;
        output ;
    end ;
    else if index(NAME, 'CORPORATE') > 0 then do;
        REFVAR = 'STD_RW_CORPORATE_REF' ;
        output;    
    end;
    else if index(NAME, 'PASTDUE_RME_PREF') > 0 then do;
        REFVAR = 'STD_RW_PASTDUE_RME_PREF_REF';
        output;
    end;
    else if index(NAME, 'PASTDUE_RME') > 0 then do;
        REFVAR = 'STD_RW_PASTDUE_RME_REF';
        output;
    end;
    else if index(NAME, 'PASTDUE_PREF') > 0 then do;
        REFVAR = 'STD_RW_PASTDUE_PREF_REF' ;
        output;    
    end;
    else if index(NAME, 'PASTDUE') > 0 then do;
        REFVAR = 'STD_RW_PASTDUE_REF' ;
        output;    
    end;   
    else if index(NAME, 'RETAIL') > 0 then do;
        REFVAR = 'STD_RW_RETAIL_REF';
        output;    
    end;
    else if index(NAME, 'RME') > 0 then do;
        REFVAR = 'STD_RW_RME_REF';
        output;
    end;
    else if index(NAME, 'CME') > 0 then do;
        REFVAR = 'STD_RW_CME_REF';
        output;
    end;    
    else if index(NAME, 'OTHERS') > 0 then do;
        REFVAR = 'STD_RW_OTHERS_REF';
        output;
    end;
    else if index(NAME, 'SHORT_RATED') > 0 then do;
        REFVAR = 'STD_RW_SHORT_RATED_REF' ;
        output;    
    end;
    else if index(NAME, 'SHORT_UNRATED') > 0 then do;
        REFVAR = 'STD_RW_SHORT_UNRATED_REF' ;
        output;    
    end;    
    else if index(NAME, 'SEC_SHORT') > 0 then do;
        REFVAR = 'STD_RW_SEC_SHORT_REF';
        output;
    end;        
    else if index(NAME, 'SHORT') > 0 then do;
        REFVAR = 'STD_RW_SHORT_REF' ;
        output;    
    end;    
    else if index(NAME, 'SEC_INVESTOR') > 0 then do;
        REFVAR = 'STD_RW_SEC_INVESTOR_REF';
        output;
    end;
    else if index(NAME, 'SEC_ORIGINATOR') > 0 then do;
        REFVAR = 'STD_RW_SEC_ORIGINATOR_REF';
        output;
    end;    
  
    end;

    else if substr(NAME, 1, 6) = 'IRB_RW' then do;

    if index(NAME, 'UL_EQ_SIMPLE_RW') > 0 then do;
        REFVAR = 'IRB_RW_UL_EQUITY_SIMPLE_REF';
        output;
    end;
    else if index(NAME, 'EL_EQ_SIMPLE_RW') > 0 then do;
        REFVAR = 'IRB_RW_EL_EQUITY_SIMPLE_REF';
        output;
    end;    
    else if index(NAME, 'MIN_EQ_PD_LGD') > 0 then do;
        REFVAR = 'IRB_RW_FLOOR_EQ_PD_LGD_REF';
        output;
    end;
    else if index(NAME, 'MIN_EQ_INT_MODELS') > 0 then do;
        REFVAR = 'IRB_RW_FLOOR_EQ_INT_MODELS_REF';
        output;
    end;
    else if index(NAME, 'UL_SL_PREF') > 0 then do;
        REFVAR = 'IRB_RW_UL_SL_PREF_REF';
        output;
    end;
    else if index(NAME, 'UL_SL') > 0 then do;
        REFVAR = 'IRB_RW_UL_SL_REF';
        output;
    end;
    else if index(NAME, 'UL_HVCRE_PREF') > 0 then do;
        REFVAR = 'IRB_RW_UL_HVCRE_PREF_REF';
        output;
    end;
    else if index(NAME, 'UL_HVCRE') > 0 then do;
        REFVAR = 'IRB_RW_UL_HVCRE_REF';
        output;
    end;
    if index(NAME, 'EL_SL_PREF') > 0 then do;
        REFVAR = 'IRB_RW_EL_SL_PREF_REF';
        output;
    end;
    else if index(NAME, 'EL_SL') > 0 then do;
        REFVAR = 'IRB_RW_EL_SL_REF';
        output;
    end;
    else if index(NAME, 'EL_HVCRE_PREF') > 0 then do;
        REFVAR = 'IRB_RW_EL_HVCRE_PREF_REF';
        output;
    end;
    else if index(NAME, 'EL_HVCRE') > 0 then do;
        REFVAR = 'IRB_RW_EL_HVCRE_REF';
        output;
    end;
    else if index(NAME, 'SEC_SHT_BASE') > 0 then do;
        REFVAR = 'IRB_RW_SEC_SHORT_BASE_REF';
        output;
    end;
    else if index(NAME, 'SEC_SHT_NG') > 0 then do;
        REFVAR = 'IRB_RW_SEC_SHORT_NG_REF';
        output;
    end;
    else if index(NAME, 'SEC_SHT_SENIOR') > 0 then do;
        REFVAR = 'IRB_RW_SEC_SHORT_SENIOR_REF';
        output;
    end;   
    else if index(NAME, 'SEC_BASE') > 0 then do;
        REFVAR = 'IRB_RW_SEC_BASE_REF';
        output;
    end;
    else if index(NAME, 'SEC_NG') > 0 then do;
        REFVAR = 'IRB_RW_SEC_NG_REF';       
        output;
    end;
    else if index(NAME, 'SEC_SENIOR') > 0 then do;
        REFVAR = 'IRB_RW_SEC_SENIOR_REF';
        output;
    end;
    
    end;

run;

/*- Concatenating all ref.var. datasets -*/
data RD_TEMP.ref_rf_all;
    length NAME $40.;
    set RD_TEMP.ref_rf_fx
        RD_TEMP.ref_rf_ir_short
        RD_TEMP.ref_rf_ir
        RD_TEMP.ref_rf_equities
        RD_TEMP.ref_rf_pd_lgd
        RD_TEMP.ref_rf_el 
        RD_TEMP.ref_rf_pd_floor
        RD_TEMP.ref_rf_lgd_equity
        RD_TEMP.ref_rf_lgd_irb_collateral   
        RD_TEMP.ref_rf_lgd_irbf    
        RD_TEMP.ref_rf_level_irb_collateral    
        RD_TEMP.ref_rf_rw
    ;
run;

/*- Create a table to declare all the reference variables. -*/
proc sql ;
    create table RD_TEMP.ref_vars as
        select distinct REFVAR as NAME
        from RD_TEMP.ref_rf_all;
quit;

/*- add ref vars for parameter matrices -*/
data RD_TEMP.ref_vars;
    length NAME $32.;
    set RD_TEMP.ref_vars end=last;
    output;
    if last then do;
        NAME = "HAIRCUT_PARM_REF";
        output;
        NAME = "CCF_PARM_REF";
        output;
    end;
run;

data RD_TEMP.ref_vars(keep = KIND NAME ROLE TYPE) ;
    length ROLE $16.;
    length TYPE $16.;

    set RD_TEMP.ref_vars;

    KIND='REFERENCE';

    if index(NAME, "CURVE") > 0 then TYPE = 'ARRAY';
    else if index(NAME, "HAIRCUT_PARM") > 0 or index(NAME, "CCF_PARM") > 0 then TYPE = 'PARAMETER';
    else TYPE ='NUM';

    if index(NAME, "FX_") > 0 then ROLE = 'FX';
    else if index(NAME, "IR_") gt 0 then ROLE = 'IR';
    else ROLE = 'VAR';

run;
%mend c20_create_ref_var;
