/*****************************************************************************
 * Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME: calc_std_rw_centgov_crd4.sas
 *
 * PURPOSE: Code to get risk weight for exposures to central governments/banks
 *          under STD approach in CRD-IV.
 *                   
 *   USAGE: %calc_std_rw_centgov_crd4.sas
 *
 *           
 *   NOTES: 
 *   4/12/2013: Created for crd4    
 *          
 *****************************************************************************/
%macro calc_std_rw_centgov_crd4;

    /*- initialize outvars -*/
    %initialize_regulatory_outvars;

    /*- by default, get the RW associated with the counterparty -*/
    OUTV_RW_COUNTERPARTY = STD_RW_CPTY;
    
    /*- Allow for preferential RW for EEA member countries: CRR Article 114(4)-*/
    /*- if exposure is to an EEA member denominated in its domestic currency -*/
       if  EEA_MEMBER_FLG eq 'YES' and (index(trim(CPTY_COUNTRY_CURRENCY), trim(CCY))) > 0 then do ;                                        
           OUTV_RW_ISSUE = STD_RW_CENTGOV_EEA_DOM ;                
       end ;    
    

    /*- Get RW based on issue rating, if it exists. -*/
       else if  STD_RW_BUCKET not in ('_#_','') and EXT_ISSUE_MAP_RATING ne 'MISS' then do ;
           OUTV_RW_ISSUE = STD_RW_CENTGOV_REF.STD_RW_BUCKET;                      
           /*- if exposure is to an EEA member denominated in domestic currency of any other EEA members -*/
           if EEA_MEMBER_FLG eq 'YES' and (index("&eea_currency_list", trim(CCY))) >0 then do ;                  
               OUTV_RW_ISSUE = &SOV_EEA_NDOM_SCALING_FCTR * STD_RW_CENTGOV_REF.STD_RW_BUCKET;  
           end ;    
       end; 
       
     /*- If issue rating is not available, then RW is based on counterparty rating -*/
       else do ;
       
           OUTV_RW_ISSUE = STD_RW_CPTY ;           
           /*if exposure is to an EEA member denominated in domestic currency of any other EEA members*/
           if EEA_MEMBER_FLG eq 'YES' and (index("&eea_currency_list", trim(CCY))) >0 then do ;
               OUTV_RW_ISSUE = &SOV_EEA_NDOM_SCALING_FCTR * STD_RW_CPTY;
           end ;           
       end;
    
        
    _VALUE_ = EXP_VALUE ;

%mend calc_std_rw_centgov_crd4;
