/*****************************************************************************
 * Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME: calc_std_rw_inst_crd4.sas
 *
 * PURPOSE: Code to get risk weight for exposures to institutions
 *          under STD approach in CRD-IV.
 *                   
 *   USAGE: %calc_std_rw_inst_crd4.sas
 *
 *           
 *   NOTES: 
 *   4/8/2013: Created for crd4    
 *          
 *****************************************************************************/
%macro calc_std_rw_inst_crd4;

    /*- initialize outvars -*/
    %initialize_regulatory_outvars;

    /*- by default, get the RW associated with the counterparty -*/
    if SHORT_TERM_ORIG_FLG = 1 then 
        OUTV_RW_COUNTERPARTY = STD_RW_CPTY_SHORT;
        
    else if SHORT_TERM_RESIDUAL_FLG = 1 then
        OUTV_RW_COUNTERPARTY = STD_RW_CPTY_SHORT;
        
    else  OUTV_RW_COUNTERPARTY = STD_RW_CPTY;   
            
    
    /*- get RW if issue rating is available: CRR Article 120 -*/ 
    if STD_RW_BUCKET not in ('_#_','') and EXT_ISSUE_MAP_RATING ne 'MISS' then do;
    
            if SHORT_TERM_RESIDUAL_FLG ne 1 then            
               OUTV_RW_ISSUE = STD_RW_INST_LONG_REF.STD_RW_BUCKET;

            else if SHORT_TERM_RESIDUAL_FLG eq 1 then do ;           
                    OUTV_RW_ISSUE = STD_RW_INST_SHORT_REF.STD_RW_BUCKET; 

                    if SHORT_TERM_ASSESS_FLG = 1 then
                       OUTV_RW_ISSUE = STD_RW_SHORT_REF.STD_RW_BUCKET;
            end ;
    end ;    
    
    /*- get RW based on counterparty rating or central government rating -*/
    /*- if issue rating does not exist: CRR Article 121.                 -*/ 
    /*- note that short-term assessment would not exist here             -*/
    else if STD_RW_BUCKET in ('_#_','') or EXT_ISSUE_MAP_RATING eq 'MISS' then do ; 
    
            OUTV_RW_ISSUE = OUTV_RW_COUNTERPARTY ;
            if CPTY_RW_FROM_CENTGOV_FLG =1 then OUTV_RW_FROM_CENTGOV_FLG = 1 ;   
            
            /*- Article 121(4): adjust RW of trade finance exposure to unrated institution  -*/
            if STD_PRODUCT_CLASS = 'TRADE_FIN' and CPTY_UNRATED = 1 then do; 
                if SHORT_TERM_RESIDUAL_FLG = 1 then 
                    OUTV_RW_ISSUE = STD_RW_TRADEFIN_UR_INST_SHORT; 
                else
                    OUTV_RW_ISSUE = STD_RW_TRADEFIN_UR_INST;
            end;           
    end;   
    
    /*- get RW for minimum reserve for EEA members: Article 119(4) of CRR  -*/                
    if STD_PRODUCT_CLASS eq 'RESERVE' and EEA_MEMBER_FLG eq 'YES' then do ;
       if STD_RW_CPTY_RESERVE ne . then do ;
          OUTV_RW_ISSUE = STD_RW_CPTY_RESERVE ;
          OUTV_RW_FROM_CENTGOV_FLG = 1 ;
       end;
    end ; 
    
    /*-   Special cases: Article 119(2) and 119(3) of CRR*/
    /*- Check the currency of issues eligible for preferential treatment. -*/
    if EEA_MEMBER_FLG eq 'YES' and (index(trim(CPTY_COUNTRY_CURRENCY), trim(CCY))) > 0 and SHORT_TERM_RESIDUAL_FLG = 1 then do ;
        OUTV_RW_ISSUE = &STD_SHORT_INST_RW_FLOOR; 
    end ;
    
      
    _VALUE_ = EXP_VALUE ;

%mend calc_std_rw_inst_crd4;
