/*****************************************************************************
 * Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME: calc_std_rw_reggov_crd4.sas
 *
 * PURPOSE: Code to get risk weight for exposures to regional governments,
 *          local governments or religious organizations under STD approach 
 *          in CRD-IV. 
 *         
 *   USAGE: %calc_std_rw_reggov_crd4.sas
 *
 *           
 *   NOTES: 
 *   4/10/2013: Created for crd4    
 *          
 *****************************************************************************/

%macro calc_std_rw_reggov_crd4;
    /*- initialize outvars -*/
    %initialize_regulatory_outvars;

    /*- by default, get the RW associated with the counterparty -*/
    OUTV_RW_COUNTERPARTY = STD_RW_CPTY;
    

    /*- get RW for institution: CRR Article 115(1)&(3) */   
    %calc_std_rw_inst_crd4 ;
    /*short-term rw do not apply because the short_term_orig_flg and short_term_residual_flg would not turn on for this exposure class*/
           
         
    if  COUNTERPARTY_SUBCLASS ne 'RELIGIOUS_ORG'  then do ;          
    /*- get central government RW if the regional/local government has the same risk as its central government: CRR Article 115(2) */  
        if CENTGOV_TREAT_FLG eq 1 then  do;
           %calc_std_rw_centgov_crd4 ;
        end;
        
    /*get RW for regional/local government of EEA member States denominated in domestic currency: CRR Article 115(5)  */ 
        else if  CENTGOV_TREAT_FLG ne 1 and EEA_MEMBER_FLG eq 'YES' and (index(trim(CPTY_COUNTRY_CURRENCY), trim(CCY))) > 0 then 
                 OUTV_RW_ISSUE = STD_RW_REGGOV_EEA_DOM ; 
    end ;         
   
        
    _VALUE_ = EXP_VALUE ;

%mend calc_std_rw_reggov_crd4;
