/*****************************************************************************
 * Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME: check_asset_class_approach.sas
 *
 * PURPOSE: Check proper assignment of approaches to asset classes
 *
 *
 *   USAGE: %check_asset_class_approach
 *          
 *
 *   NOTES: This macro checks proper assignment of approaches to asset classes. 
 *          If improper assignment is found, the observation will be excluded
 *          for further calculation.  This macro should be updated if new approach
 *          types are added for an asset class
 *          
 *
 *****************************************************************************/
 
 %macro check_asset_class_approach;
    INVALID_APPROACH_FLG = 0;

 /*- two direction check -*/
 /*- certain product class has special approach -*/
    if IRB_PRODUCT_CLASS EQ 'EQUITY' then do;
       if APPROACH notin ('US_SRWA','IRB_SIMPLE_RW', 'IRB_INT_MODELS', 'IRB_PD_LGD', 'STD', 'BASEL_I') then 
          INVALID_APPROACH_FLG = 1;  
    end;
     /* Added by for investment funds under USfinal configuration */ 
    else if IRB_PRODUCT_CLASS EQ 'INV_FUNDS' then do;
        if APPROACH notin ('US_SIMPLE_LKTHRU','US_MMF')then 
              INVALID_APPROACH_FLG = 1;  
    end; 
    else if IRB_PRODUCT_CLASS EQ 'SL' and 
       APPROACH notin ('IRB_SLOTTING', 'IRBF', 'IRBA', 'STD', 'BASEL_I') then 
       INVALID_APPROACH_FLG = 1;  
    else if IRB_PRODUCT_CLASS in ('SEC', 'SECURITIZATION') and
       APPROACH not in ('US_IRB','IRB_RBA', 'STD', 'STD_IAA', 'IRB_IAA', 'BASEL_I') then
       INVALID_APPROACH_FLG = 1;  
    else if IRB_PRODUCT_CLASS in ('REVOLVING','QUALIFYING_REVOLVING', 'RESIDENTIAL_MORTGAGE','OTHER_RETAIL') and 
       APPROACH not in ('IRB','US_IRB','STD') then 
       INVALID_APPROACH_FLG = 1;  
            
       
 /*- make sure approaches are assigned properly -*/
    if INVALID_APPROACH_FLG EQ 0 then do;     
       if APPROACH in ('US_SRWA','IRB_SIMPLE_RW', 'IRB_INT_MODELS', 'IRB_PD_LGD') then do;
         if IRB_PRODUCT_CLASS NE 'EQUITY' then 
            INVALID_APPROACH_FLG = 1;
       end;
       /* Added for investment funds under USFINAL config : two directional check  */ 
       else if APPROACH IN ('US_SIMPLE_LKTHRU','US_MMF') then do;
         if IRB_PRODUCT_CLASS NE 'INV_FUNDS' then 
            INVALID_APPROACH_FLG = 1;
       end;
       else if APPROACH EQ 'IRB_SLOTTING' then do;
         if IRB_PRODUCT_CLASS NE 'SL' then 
            INVALID_APPROACH_FLG = 1;
       end;
       else if APPROACH EQ 'IRB_RBA' then do;
         if IRB_PRODUCT_CLASS notin ('SEC', 'SECURITIZATION') then 
            INVALID_APPROACH_FLG = 1;
       end;
       else if APPROACH in ('IRB_IAA', 'STD_IAA') then do; 
                if IRB_PRODUCT_CLASS notin ('SEC', 'SECURITIZATION') then 
                   INVALID_APPROACH_FLG = 1;
       end;
       else if APPROACH EQ 'IRB' then do;
         if COUNTERPARTY_CLASS NE 'RETAIL' and 
            (IRB_PRODUCT_CLASS NE 'PURCHASED_REC' and 
             IRB_PRODUCT_SUBCLASS NE 'RETAIL_OTHER') then 
         INVALID_APPROACH_FLG = 1;
       end;
       else if APPROACH EQ 'US_IRB' then do;
         if IRB_PRODUCT_CLASS NOT IN ('QUALIFYING_REVOLVING', 'RESIDENTIAL_MORTGAGE','OTHER_RETAIL', 'SOVEREIGN','BANK','CORPORATE','HVCRE', 'DERIVATIVE', 'REPO_STYLE', 'EML','SEC', 'SECURITIZATION', 'IPRE')
             then 
                INVALID_APPROACH_FLG = 1;
       end;
       else if APPROACH notin ('STD', 'IRBF', 'IRBA', 'BASEL_I') then
         INVALID_APPROACH_FLG = 1;
    end;
 %mend;
       
