/*****************************************************************************
 * Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME: create_issue_rating_crd4.sas
 *
 * PURPOSE: Stores code that transposes issue ratings from multi-row per
 *          issuer into single-row per issuer.
 *
 *   USAGE: %create_issue_rating;
 *          
 *
 *   NOTES: RD_STAGE.issue_ratings table needs to be pre-sorted on ISSUE_KEY
 *
 *
 *****************************************************************************/

%macro create_issue_rating_crd4(rating_time= );
        
  %if &RATING_TIME= INCEPTION %then %let rating_type = _INCEP; %else  %let rating_type =; ;  
        /*Sorting the data before enrichment*/
       proc sort data = RD_STAGE.issue_ratings;
        by ISSUE_KEY;
        run;
       /*- get eligible external agency -*/     
/*- get ratings for an issue on the same row -*/
/*- check for null eligible external rating agencies -*/
   %if &NUM_AGENCIES_ISSUE=0 or &NUM_ELIGIBLE_AGENCY=0 %then %do;
       data RD_POS.issue_ratings&rating_type.;
       length ISSUE_KEY $32.;
       run;
       
       data RD_POS.issue_int_ratings&rating_type.(drop=RATING_AGENCY PRINCIPAL_ONLY_FLG %if &RATING_TIME= INCEPTION %then RATING; %else RATING_INCEPTION;);
       set RD_STAGE.issue_ratings
       (where=(RATING_AGENCY='INT' and PRINCIPAL_ONLY_FLG NE 1 ) 
        
        %if &RATING_TIME= INCEPTION %then %do ;
        rename=(RATING_INCEPTION=INT_ISSUE_INCEP_RATING SHORTTERM_FLG=INT_SHORT_TERM_ASSESS_FLG 
                CRM_ADJUSTED_FLG=INT_RATING_CRM_ADJUSTED_FLG)
        %end ;
        %else %do;
            rename=(RATING=INT_ISSUE_RATING SHORTTERM_FLG=INT_SHORT_TERM_ASSESS_FLG 
                CRM_ADJUSTED_FLG=INT_RATING_CRM_ADJUSTED_FLG)
        %end;   

       );
       run;
                      
       
       
   %end;
   %else %do;
       %let AGENCY_FILTER=RATING_AGENCY in (%quote_list(list=&ELIGIBLE_AGENCY, case=));

       proc transpose data   = rd_stage.issue_ratings (where=(PRINCIPAL_ONLY_FLG NE 1 and RATING_AGENCY NE 'INT' 
                                             and &AGENCY_FILTER ) )
                      out    = issue_ratings(drop=_NAME_)
                      prefix = EXT_ISSUE&RATING_TYPE._RATING_ ;
       by  ISSUE_KEY;
       id  RATING_AGENCY;
       var %if &RATING_TIME= INCEPTION %then RATING_INCEPTION; %else RATING;;
       run;

/*- get CRM adjustment flag for an issue on the same row -*/
       proc transpose data   = rd_stage.issue_ratings (where=(PRINCIPAL_ONLY_FLG NE 1 and RATING_AGENCY NE 'INT' 
                                            and &AGENCY_FILTER)) 
                      out    = issue_ratings_crm_adjust_flg(drop=_NAME_)
                      prefix = CRM_ADJUSTED_FLG_ ;
       by  ISSUE_KEY;
       id  RATING_AGENCY;
       var CRM_ADJUSTED_FLG;
       run;
  
/*- short-term assessment flag for an issue on the same row -*/
       proc transpose data   = rd_stage.issue_ratings (where=(PRINCIPAL_ONLY_FLG NE 1 and RATING_AGENCY NE 'INT' 
                                            and &AGENCY_FILTER))
                      out    = issue_ratings_short_term_flg(drop=_NAME_)
                      prefix = SHORT_TERM_ASSESS_FLG_  ;
       by  ISSUE_KEY;
       id  RATING_AGENCY;
       var SHORTTERM_FLG;
       run;

/*- get all things for an issue on one row -*/
       data RD_POS.issue_ratings&RATING_TYPE.(drop=_LABEL_);
       merge issue_ratings issue_ratings_crm_adjust_flg issue_ratings_short_term_flg;
       by ISSUE_KEY;
       run;

/*- get internal ratings -*/
       data RD_POS.issue_int_ratings&RATING_TYPE.(drop=RATING_AGENCY PRINCIPAL_ONLY_FLG %if &RATING_TIME= INCEPTION %then RATING; %else RATING_INCEPTION;);
       set RD_STAGE.issue_ratings
       (where=(RATING_AGENCY='INT' and PRINCIPAL_ONLY_FLG NE 1) 
        %if &RATING_TIME= INCEPTION %then %do ; 
        rename=(RATING_INCEPTION=INT_ISSUE_INCEP_RATING SHORTTERM_FLG=INT_SHORT_TERM_ASSESS_FLG 
                CRM_ADJUSTED_FLG=INT_RATING_CRM_ADJUSTED_FLG)
        %end ;
        %else %do;
            rename=(RATING=INT_ISSUE_RATING SHORTTERM_FLG=INT_SHORT_TERM_ASSESS_FLG 
                CRM_ADJUSTED_FLG=INT_RATING_CRM_ADJUSTED_FLG)
        %end;   
                
       );
       run;
        
       proc sort data = RD_POS.issue_int_ratings&RATING_TYPE.;
        by ISSUE_KEY;
       run;  
%end;
/*- delete temporary data sets -*/
  *  %clean_lib;

%mend create_issue_rating_crd4;
