/*****************************************************************************
 * Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME: d00_pm_counterparty_crd4.sas
 *
 * PURPOSE: Create method for counterparty
 *
 *   USAGE: 
 *
 *   NOTES: 
 *          
 *
 *****************************************************************************/

%macro d00_pm_counterparty_crd4;

%macro irb_cpty;

   if COUNTERPARTY_PD_PCT ne . then
   PD_CPTY = COUNTERPARTY_PD_PCT;
   
   %if "&PD_MODEL_USED" NE "N" %then %do;
   /*- PD - derived from model and rating_grade -*/
   else if PD_CPTY =. and COUNTERPARTY_PD_MODEL_ID NE '_#_' and COUNTERPARTY_PD_RATING_GRADE NE '_#_' then
       PD_CPTY = PD_REF.COUNTERPARTY_PD_MODEL_ID.COUNTERPARTY_PD_RATING_GRADE ;
   %end;
   else PD_CPTY= .;
   /*- Floor for PD applies except for sovereign exposures Basel II 285:-*/
   if PD_CPTY NE . then 
       PD_CPTY = max(PD_CPTY, PD_FLOOR_REF.CPTY_CLASS);


%mend irb_cpty;


proc compile outlib  = RD_TEMP.&RD_TEMPLATE
             inlib   = RD_TEMP.&RD_TEMPLATE
             package = pricing
             label   = "Regulatory Initial Risk Weight Methods"
             env     = RD_TEMP.&RD_TEMPLATE ;


method PM_REGULATORY_CPTY desc="Get STD RW and PD for Counterparties" kind = score;

   /*****************************************************************************
    *         Determine Counterparty Risk Weight for STD Approach
    *****************************************************************************/

   /*- Set the risk weight under preferential treatment to missing -*/
   STD_RW_CPTY_PREF = . ;
   
   /*- set risk weight derived from central government flag as missing -*/
   CPTY_RW_FROM_CENTGOV_FLG  = . ;
   
   /*- set cpty unrated variable to missing -*/
   CPTY_UNRATED = .;
   
   /*- get the counterparty default risk weight -*/
   STD_RW_CPTY       = STD_RW_COUNTERPARTY_DEFAULT;
   STD_RW_CPTY_SHORT = STD_RW_COUNTERPARTY_DEFAULT;
   
   /*- get risk weight directly if already assigned -*/
   if RISK_WEIGHT_CPTY NE . then STD_RW_CPTY = RISK_WEIGHT_CPTY;
   
   /*  get risk weight for counterparty with zero risk weight*/
   else if STD_ZERO_RW_FLG EQ 1 then STD_RW_CPTY = STD_RW_ZERO ;
       
   /*-   get risk weight based on counterparty class and rating -*/
   else do;
   
         /*- risk weight for exposures to central governments/banks or to regional/local governments or pses that have the same risk as central governments -*/         
         if CPTY_SUBCLASS in('CENTRAL_GOV','CENTRAL_BANK') or CENTGOV_TREAT_FLG EQ 1 then do ;      
             if STD_RW_BUCKET_CPTY NE '_#_' then do ;
                
                STD_RW_CPTY = STD_RW_CENTGOV_REF.STD_RW_BUCKET_CPTY;
                STD_RW_CPTY_SHORT = STD_RW_CPTY ;
                
                if CPTY_SUBCLASS eq 'PSE' then 
                   STD_RW_CPTY_SHORT = STD_RW_INST_SHORT;
             
             end ;      
         end;
         
         /*- risk weight for exposures to institutions, or those sovereign exposures that do not have central government treatment -*/ 
         else if CPTY_CLASS eq 'INSTITUTION' or 
                 CPTY_SUBCLASS  in ('RELIGIOUS_ORG', 'MDB') or 
                 (CPTY_SUBCLASS in ('REGIONAL_GOV', 'LOCAL_GOV','PSE') and CENTGOV_TREAT_FLG ne 1) 

         then do ;                 
                  /*- get minimum reserve's risk weight based on central government's rating: CRR Article 119(4) -*/
                  if CPTY_SUBCLASS = 'INSTITUTION' and STD_RW_BUCKET_SOVEREIGN ne '_#_' then do;
                        STD_RW_CPTY_RESERVE = STD_RW_CENTGOV_REF.STD_RW_BUCKET_SOVEREIGN;                      
                  end ;
                  
                  if CPTY_EXT_MAP_RATING = 'MISS' then CPTY_UNRATED = 1;
                                    
                  /*- if counterparty rating is missing, get risk weight based on central government rating: CRR Article 121 -*/                  
                  if CPTY_EXT_MAP_RATING = 'MISS' and STD_RW_BUCKET_SOVEREIGN ne '_#_' then do ;
                 
                     CPTY_RW_FROM_CENTGOV_FLG  = 1;  
                     STD_RW_CPTY = STD_RW_INST_NORATE_REF.STD_RW_BUCKET_SOVEREIGN;                     
                     STD_RW_CPTY_SHORT = STD_RW_INST_SHORT;                     
                                        
                     /*- get risk weight of unrated PSE based on its central government rating: CRR Article 116(1) -*/
                     if CPTY_SUBCLASS eq 'PSE' then do ;
                        STD_RW_CPTY = STD_RW_PSE_NORATE_REF.STD_RW_BUCKET_SOVEREIGN;
                        STD_RW_CPTY_SHORT = STD_RW_INST_SHORT;
                     end ;   
                  end;  
                 
                  /*- get risk weight if counterparty rating is available  -*/
                  else if STD_RW_BUCKET_CPTY not in ('_#_','') or CPTY_EXT_MAP_RATING ne 'MISS' then do;
                  
                         STD_RW_CPTY   = STD_RW_INST_LONG_REF.STD_RW_BUCKET_CPTY;           
                         STD_RW_CPTY_SHORT = STD_RW_INST_SHORT_REF.STD_RW_BUCKET_CPTY;
                       
                         /*  no short-term treatment for the following sovereign counterparty subclasses */
                         if CPTY_SUBCLASS in ('LOCAL_GOV', 'REGIONAL_GOV','RELIGIOUS_ORG','MDB') and STD_RW_BUCKET_CPTY NE '_#_' then
                            STD_RW_CPTY_SHORT = STD_RW_CPTY;
                            
                         else if CPTY_SUBCLASS eq 'PSE' then 
                            STD_RW_CPTY_SHORT = STD_RW_INST_SHORT;   
                  end ;            

         end;

                 
         else if CPTY_SUBCLASS = 'INT_ORG' then do ;
                    STD_RW_CPTY = STD_RW_INT_ORG;
         end ;

         else if CPTY_CLASS in ('CORPORATE') then do;
               if CPTY_EXT_MAP_RATING ne 'MISS' and STD_RW_BUCKET_CPTY ne '_#_' then do;
                   STD_RW_CPTY = STD_RW_CORPORATE_REF.STD_RW_BUCKET_CPTY; 
                   STD_RW_CPTY_SHORT = STD_RW_CPTY;               
               end;

               /*  Exposures for which such a credit assessment is not available shall be assigned a 100 %        */
               /*  risk weight or the risk weight of exposures to the central government of the jurisdiction in   */ 
               /*  which the corporate is incorporated, whichever is the higher : CRR Article 122(2)               */
               else if CPTY_EXT_MAP_RATING = 'MISS' and STD_RW_BUCKET_SOVEREIGN ne '_#_' then do;
                STD_RW_CPTY       = max( STD_RW_COUNTERPARTY_DEFAULT,STD_RW_CENTGOV_REF.STD_RW_BUCKET_SOVEREIGN ); 
                STD_RW_CPTY_SHORT = max( STD_RW_COUNTERPARTY_DEFAULT, STD_RW_CENTGOV_REF.STD_RW_BUCKET_SOVEREIGN );
                CPTY_RW_FROM_CENTGOV_FLG  = 1;
               end;

         end;

         else if CPTY_CLASS in ('RETAIL') then do;
               STD_RW_CPTY = STD_RW_RETAIL;
               STD_RW_CPTY_SHORT = STD_RW_CPTY;               
         end;


   end;

   /*****************************************************************************
    *         Determine counterparty PD for IRB Approaches
    *****************************************************************************/

   %irb_cpty;

   /*- Get counterparty size in the numeraire currency for IRB RW calculation -*/
   COUNTERPARTY_SIZE = CPTY_SIZE * GET_FX_SPOT (REPORT_CURRENCY);

   /*****************************************************************************
    * Determine the weight to be applied for CVA Standardized calculations 
    *****************************************************************************/
    if not missing(CVA_STD_CPTY_RW_BUCKET) then do ;  
      CVA_STD_WGT = CVA_STD_WGT_REF.CVA_STD_CPTY_RW_BUCKET ;  
    end ;   

endmethod;

run; 
%mend d00_pm_counterparty_crd4;
