/*****************************************************************************
 * Copyright (c) 2014 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME: d00_pm_regrpt_crd4.sas
 *
 * PURPOSE: Define pricing methods for regulatory reporting
 *
 *   USAGE:
 *
 *   NOTES:
 *
 *
 *****************************************************************************/
%macro d00_pm_regrpt_crd4;

    proc compile inlib = RD_PROJ.REGRPT outlib = RD_PROJ.REGRPT env=RD_PROJ.REGRPT package=reg_rpts;
method pm_regrpt_crsec_irb kind=price;

			_VALUE_ = EAD;

            if HAIRCUT_EXP > 0 and CRM_PRODUCT eq 'FIN_COLL_COMPREH' then
                _EAD_PORTION_ = EAD_PORTION - CRM_USED_AMT_EFF ; 
            else 
			    	_EAD_PORTION_ = EAD_PORTION;
			    	
			if PRIMARY_BANK_ROLE = "ORIGINATOR" THEN
			do;
				OUTV_TRANCHE_NOMINAL_AMT = SEC_TOTAL_AMT_ORIGINATED * GET_FX_SPOT (CCY); /* Col.10 */
				if SEC_STRUCTURE_TYPE = "SYNTHETIC" then 
				do;
					IF CRM_PRODUCT EQ 'UNFUNDED' THEN
						OUTV_SEC_UNFUNDED_AMT = -CRM_USED_AMT_EFF/max(coalesce(CCF,100),1)*100; /*Col. 30*/
					ELSE IF CRM_PRODUCT EQ 'FIN_COLL_SIMPLE' THEN
						OUTV_SEC_FUNDED_AMT =- CRM_USED_AMT_EFF/max(coalesce(CCF,100),1)*100; /*Col 20*/
						OUTV_RETAINED_AMT = RETAINED_AMT;                                      /* Col.40 */
				end;
			end;
			
            OUTV_EXPOSURE_ORIG_AMT = EXP_VALUE;                                    /* Col.50 */
			      OUTV_VALUE_ADJ_AMT = -sum(0, SPECIFIC_PROVISION);                      /* Col.60 */
            OUTV_EXPOSURE_NET_AMT =  max(0, sum(OUTV_EXPOSURE_ORIG_AMT, OUTV_VALUE_ADJ_AMT));  /* Col.70 */
			
			IF CRM_PRODUCT EQ 'UNFUNDED' THEN
                OUTV_SEC_UNFUNDED_UND_AMT = - CRM_USED_AMT_EFF/max(coalesce(CCF,100),1)*100; /* 5th col.*/
			ELSE IF CRM_PRODUCT EQ 'FIN_COLL_SIMPLE' THEN
                OUTV_SEC_FUNDED_UND_AMT = - CRM_USED_AMT_EFF/max(coalesce(CCF,100),1)*100; /* 7th col. */
				
			if CRM_PRODUCT IN ('UNFUNDED','FIN_COLL_SIMPLE') then
			do;
				TOTAL_OUTFLOW_CRM_SUB_AMT = sum(OUTV_SEC_UNFUNDED_UND_AMT,OUTV_SEC_FUNDED_UND_AMT);	
			end;
			
			OUTV_PRE_CCF_AFTER_CRM = sum(OUTV_EXPOSURE_NET_AMT, TOTAL_OUTFLOW_CRM_SUB_AMT, TOTAL_INFLOW_CRM_SUB_AMT);			
			
            IF CRM_PRODUCT EQ 'FIN_COLL_COMPREH' THEN
                DO;
                    IF upcase(CRM_TYPE) EQ 'FINANCIAL_COLLATERAL' then
                        do;
                            IF MAT_MISMATCH_WEIGHT_CRM NE . then
                                OUTV_FIN_COLL_ADJ_VAL_AMT = -CRM_VALUE*(1 - max(HAIRCUT_CRM/100,0) - max(HAIRCUT_FX/100,0) )*MAT_MISMATCH_WEIGHT_CRM; /* 13th col.*/
                            ELSE OUTV_FIN_COLL_ADJ_VAL_AMT = -CRM_VALUE*(1 - HAIRCUT_CRM/100 - HAIRCUT_FX/100 );

                            IF OUTV_FIN_COLL_ADJ_VAL_AMT=. then
                                OUTV_FIN_COLL_ADJ_VAL_AMT=0;
								
						           	OUTV_EXPOSURE_ADJ_AMT = sum(OUTV_EXPOSURE_NET_AMT * sum(1, HAIRCUT_EXP/100), - CRM_USED_AMT_EFF);

                        END;
                END;
			ELSE if CRM_PRODUCT NE 'FIN_COLL_SIMPLE' and  CRM_COMP_FLG eq 1 then
			do;
						if HAIRCUT_EXP > 0 then
							OUTV_FIN_COLL_ADJ_VAL_AMT = max(0,HAIRCUT_EXP*OUTV_EXPOSURE_ORIG_AMT/100);
							
							OUTV_EXPOSURE_ADJ_AMT = sum(OUTV_EXPOSURE_NET_AMT * sum(1, HAIRCUT_EXP/100), - CRM_USED_AMT_EFF);

			end;
			
			ELSE do;
				OUTV_FIN_COLL_ADJ_VAL_AMT=0;
				OUTV_EXPOSURE_ADJ_AMT = OUTV_PRE_CCF_AFTER_CRM; /* Col.140 */

			end;
            
      if scan(REGRPT_CCF_BUCKET, 1,'=') = "CCF1" then
                OUTV_EXP_ADJ_CCF_0 = OUTV_EXPOSURE_ADJ_AMT;				/* Col.150 */
            else if scan(REGRPT_CCF_BUCKET, 1,'=') = "CCF2" then
                OUTV_EXP_ADJ_CCF_0_20 = OUTV_EXPOSURE_ADJ_AMT;			/* Col.160 */
            else if scan(REGRPT_CCF_BUCKET, 1,'=')= "CCF3" then
                OUTV_EXP_ADJ_CCF_20_50 = OUTV_EXPOSURE_ADJ_AMT;			/* Col.170 */
            else if scan(REGRPT_CCF_BUCKET, 1,'=')= "CCF4" then
                OUTV_EXP_ADJ_CCF_50_100 = OUTV_EXPOSURE_ADJ_AMT;		/* Col.180 */

			OUTV_EAD = _EAD_PORTION_; /* Col 190*/

			OUTV_DED_OWN_FUNDS = -SEC_DEDUCTION_AMT ; /* Col 200*/

			OUTV_SUB_RW = max(0 , sum(OUTV_EAD, OUTV_DED_OWN_FUNDS)) ;/* Col 210 */

     /* cols 22 to 29 */
       if RW_LOOK_THROUGH_UPDATE_FLG eq 1 then
                do;
                    OUTV_EAD_LOOKTHROUGH_AMT = OUTV_EAD;						/* Col.280 */
				           	EAD_LOOK_THRU_NUMERATOR_AMT = OUTV_EAD_LOOKTHROUGH_AMT * _COSTVAR_ ; 
					
                    if TRANCHE_LOSS_RANK >= 2 and SEC_STRUCTURE_SUBTYPE = "ABCP" then
                        OUTV_EAD_LOOK_THROUGH_2ND_LOSS = OUTV_EAD; 				/* Col.290 */
                end;
			else if APPROACH = "IRB_IAA" then /* Internal Assessment approach */
				do;
					EAD_SEC_IAA_AMT = OUTV_EAD;									/* Col.310 */
					EAD_IAA_NUMERATOR_AMT = EAD_SEC_IAA_AMT * _COSTVAR_ ; 
				end;  
      else if upcase(APPROACH) EQ 'IRB_RBA' then
              do;
              	    if REGRPT_RW_BUCKET = "CQS1" then
                         EAD_RW_7 = OUTV_EAD;								/* Col.220 */
                    else if REGRPT_RW_BUCKET = "CQS2" then
                         EAD_RW_8 = OUTV_EAD;								/* Col.230 */
                    else if REGRPT_RW_BUCKET = "CQS3" then
                        OUTV_EAD_RW_10 = OUTV_EAD;								/* Col.240 */
                    else if REGRPT_RW_BUCKET = "CQS4" then
                         EAD_RW_12 = OUTV_EAD;								/* Col.250 */
                    else if REGRPT_RW_BUCKET = "CQS5" then
                         EAD_RW_20 = OUTV_EAD;								
                    else if REGRPT_RW_BUCKET = "CQS6" then
                         OUTV_EAD_RW_35 = OUTV_EAD;								
                    else if REGRPT_RW_BUCKET = "CQS7" then
                         EAD_RW_60 = OUTV_EAD;								
                    else if REGRPT_RW_BUCKET = "CQS8" then
                        OUTV_EAD_RW_100 = OUTV_EAD;								
                    else if REGRPT_RW_BUCKET = "CQS9" then
                        OUTV_EAD_RW_250 = OUTV_EAD;								
                    else if REGRPT_RW_BUCKET = "CQS10" then
                        OUTV_EAD_RW_425 = OUTV_EAD;								
                    else if REGRPT_RW_BUCKET = "CQS11" then
                        OUTV_EAD_RW_650 = OUTV_EAD;								
                    else if REGRPT_RW_BUCKET = "OTHER" then
                        do;
                            if RATING_STATUS = "RATED" then
                                OUTV_EAD_RW_1250_RATED = OUTV_EAD;				/* Col.260 */
                            else OUTV_EAD_RW_1250_UNRATED = OUTV_EAD;			/* Col.270 */
                        end;              	
                        /*
                            if scan(REGRPT_RW_BUCKET_SEC,1,':') = "RW1" then
                                OUTV_EAD_RW_10 = OUTV_EAD;        
                            else if scan(REGRPT_RW_BUCKET_SEC,1,':') = "RW2" then
                                OUTV_EAD_RW_18 = OUTV_EAD;   
                            else if scan(REGRPT_RW_BUCKET_SEC,1,':') = "RW3" then
                                OUTV_EAD_RW_35 = OUTV_EAD;   
                            else if scan(REGRPT_RW_BUCKET_SEC,1,':') = "RW4" then
                                OUTV_EAD_RW_75 = OUTV_EAD;   
                            else if scan(REGRPT_RW_BUCKET_SEC,1,':') = "RW5" then
                                OUTV_EAD_RW_100 = OUTV_EAD;  
                            else if scan(REGRPT_RW_BUCKET_SEC,1,':') = "RW6" then
                                OUTV_EAD_RW_250 = OUTV_EAD;  
                            else if scan(REGRPT_RW_BUCKET_SEC,1,':') = "RW7" then
                                OUTV_EAD_RW_425 = OUTV_EAD;  
                            else if scan(REGRPT_RW_BUCKET_SEC,1,':') = "RW8" then
                                OUTV_EAD_RW_650 = OUTV_EAD;  
                            else if scan(REGRPT_RW_BUCKET_SEC,1,':') = "RW9" then
                                do;
                                    if RATING_STATUS = "RATED" then
                                        OUTV_EAD_RW_1250_RATED = OUTV_EAD; 
                                    else OUTV_EAD_RW_1250_UNRATED = OUTV_EAD;
                                end;
                       */         
              end;
                    else if upcase(APPROACH) EQ 'IRB_SFA' then
                        do;
							OUTV_EAD_SFA = OUTV_EAD;    /* Col 30 */
					/*		outv_rw_sfa=.; */
						end;
/*                    else if upcase(APPROACH) EQ 'IRB_IAA' then*/
/*                        OUTV_EAD_IAA = OUTV_EAD;   */
						/* Col 33 */
            else
                do;
                    /* look-through */
                    OUTV_EAD_LOOKTHROUGH_AMT = OUTV_EAD;                  /* Col 32 */
                end;
        

			OUTV_RWA = RWA; 													/* Col.330*/

			
			if SEC_STRUCTURE_TYPE = "SYNTHETIC" then
				RWA_SYNTHETIC_SEC_AMT = RWA;										/* Col.340*/
				
			RWA_ADJ_INFRINGEMENT_AMT = SEC_INFRINGE_ADJUST_AMT;					/* Col.350*/
				
			RWA_ADJ_MATURITY_MISMATCH_AMT = RWA_SEC_MAT_MIS_ADJ_AMT;						/* Col.360*/
			RWA_BEFORE_CAP_AMT = RWA_BEFORE_CAP;								/* Col.370*/
			RWA_AFTER_CAP_AMT = RWA;											/* Col.380*/

			RWA_SEC_OUTFLOW_OTHER_EXP_AMT = RWA_SEC_MEMO_AMT;								/* Col.390*/

            OUTV_CAPITAL = CAPITAL; /* Col.31 */
			OUTV_EAD_ROLLUP = sum(OUTV_EXPOSURE_ADJ_AMT, -OUTV_EXP_ADJ_CCF_0, -0.8*OUTV_EXP_ADJ_CCF_0_20, -0.5*OUTV_EXP_ADJ_CCF_20_50);

endmethod;


        method pm_regrpt_crsec_sa kind=price;
            _VALUE_ = EAD;

              if HAIRCUT_EXP > 0 and CRM_PRODUCT eq 'FIN_COLL_COMPREH' then
                _EAD_PORTION_ = EAD_PORTION - CRM_USED_AMT_EFF ; 
            else 
				_EAD_PORTION_ = EAD_PORTION;
				


			if PRIMARY_BANK_ROLE = "ORIGINATOR" THEN
			do;
				OUTV_TRANCHE_NOMINAL_AMT = SEC_TOTAL_AMT_ORIGINATED * GET_FX_SPOT (CCY); /* Col.10 */
				if SEC_STRUCTURE_TYPE = "SYNTHETIC" then 
				do;
					IF CRM_PRODUCT EQ 'UNFUNDED' THEN
						OUTV_SEC_UNFUNDED_AMT = -CRM_USED_AMT_EFF/max(coalesce(CCF,100),1)*100;
					ELSE IF CRM_PRODUCT EQ 'FIN_COLL_SIMPLE' THEN
						OUTV_SEC_FUNDED_AMT =- CRM_USED_AMT_EFF/max(coalesce(CCF,100),1)*100;
					
					OUTV_RETAINED_AMT = RETAINED_AMT;                                      /* Col.40 */
				end;
			end;
			
            OUTV_EXPOSURE_ORIG_AMT = EXP_VALUE;                                    /* Col.50 */
			
            OUTV_VALUE_ADJ_AMT = -sum(0, SPECIFIC_PROVISION);                      /* Col.60 */
            OUTV_EXPOSURE_NET_AMT =  max(0, sum(OUTV_EXPOSURE_ORIG_AMT, OUTV_VALUE_ADJ_AMT));  /* Col.70 */
			
			if SEC_STRUCTURE_TYPE NE "SYNTHETIC" THEN
			DO;
			IF CRM_PRODUCT EQ 'UNFUNDED' THEN
                OUTV_SEC_UNFUNDED_UND_AMT = - CRM_USED_AMT_EFF/max(coalesce(CCF,100),1)*100; /* 5th col.*/
			ELSE IF CRM_PRODUCT EQ 'FIN_COLL_SIMPLE' THEN
                OUTV_SEC_FUNDED_UND_AMT = - CRM_USED_AMT_EFF/max(coalesce(CCF,100),1)*100; /* 7th col. */
			
			if CRM_PRODUCT IN ('UNFUNDED','FIN_COLL_SIMPLE') then
			do;
				TOTAL_OUTFLOW_CRM_SUB_AMT = sum(OUTV_SEC_UNFUNDED_UND_AMT,OUTV_SEC_FUNDED_UND_AMT);	
			end;
			END;
			
			OUTV_PRE_CCF_AFTER_CRM = sum(OUTV_EXPOSURE_NET_AMT, TOTAL_OUTFLOW_CRM_SUB_AMT, TOTAL_INFLOW_CRM_SUB_AMT);			
			
            IF CRM_PRODUCT EQ 'FIN_COLL_COMPREH' THEN
                DO;
                    IF upcase(CRM_TYPE) EQ 'FINANCIAL_COLLATERAL' then
                        do;
                            IF MAT_MISMATCH_WEIGHT_CRM NE . then
                                OUTV_FIN_COLL_ADJ_VAL_AMT = -CRM_VALUE*(1 - max(HAIRCUT_CRM/100,0) - max(HAIRCUT_FX/100,0) )*MAT_MISMATCH_WEIGHT_CRM; /* 13th col.*/
                            ELSE OUTV_FIN_COLL_ADJ_VAL_AMT = -CRM_VALUE*(1 - HAIRCUT_CRM/100 - HAIRCUT_FX/100 );

                            IF OUTV_FIN_COLL_ADJ_VAL_AMT=. then
                                OUTV_FIN_COLL_ADJ_VAL_AMT=0;
								
							OUTV_EXPOSURE_ADJ_AMT = sum(OUTV_EXPOSURE_NET_AMT * sum(1, HAIRCUT_EXP/100), - CRM_USED_AMT_EFF);

                        END;
                END;
			ELSE if CRM_PRODUCT NE 'FIN_COLL_SIMPLE' and  CRM_COMP_FLG eq 1 then
			do;
						if HAIRCUT_EXP > 0 then
							OUTV_FIN_COLL_ADJ_VAL_AMT = max(0,HAIRCUT_EXP*OUTV_EXPOSURE_ORIG_AMT/100);
							
							OUTV_EXPOSURE_ADJ_AMT = sum(OUTV_EXPOSURE_NET_AMT * sum(1, HAIRCUT_EXP/100), - CRM_USED_AMT_EFF);

			end;
			
			ELSE do;
				OUTV_FIN_COLL_ADJ_VAL_AMT=0;
				OUTV_EXPOSURE_ADJ_AMT = OUTV_PRE_CCF_AFTER_CRM; /* Col.140 */

			end;
            
            if scan(REGRPT_CCF_BUCKET, 1,'=') = "CCF1" then
                OUTV_EXP_ADJ_CCF_0 = OUTV_EXPOSURE_ADJ_AMT;				/* Col.150 */
            else if scan(REGRPT_CCF_BUCKET, 1,'=') = "CCF2" then
                OUTV_EXP_ADJ_CCF_0_20 = OUTV_EXPOSURE_ADJ_AMT;			/* Col.160 */
            else if scan(REGRPT_CCF_BUCKET, 1,'=')= "CCF3" then
                OUTV_EXP_ADJ_CCF_20_50 = OUTV_EXPOSURE_ADJ_AMT;			/* Col.170 */
            else if scan(REGRPT_CCF_BUCKET, 1,'=')= "CCF4" then
                OUTV_EXP_ADJ_CCF_50_100 = OUTV_EXPOSURE_ADJ_AMT;		/* Col.180 */

			OUTV_EAD = _EAD_PORTION_; /* Col 190*/

			OUTV_DED_OWN_FUNDS = -SEC_DEDUCTION_AMT ; /* Col 200*/

			OUTV_SUB_RW = max(0 , sum(OUTV_EAD, OUTV_DED_OWN_FUNDS)) ;/* Col 210 */

            /* cols 22 to 29 */
            if RW_LOOK_THROUGH_UPDATE_FLG eq 1 then
                do;
                    OUTV_EAD_LOOKTHROUGH_AMT = OUTV_EAD;						/* Col.280 */
					EAD_LOOK_THRU_NUMERATOR_AMT = OUTV_EAD_LOOKTHROUGH_AMT * _COSTVAR_ ; 
					
                    if TRANCHE_LOSS_RANK >= 2 and SEC_STRUCTURE_SUBTYPE = "ABCP" then
                        OUTV_EAD_LOOK_THROUGH_2ND_LOSS = OUTV_EAD; 				/* Col.290 */
                end;
			else if APPROACH = "STD_IAA" then /* Internal Assessment approach */
				do;
					EAD_SEC_IAA_AMT = OUTV_EAD;									/* Col.310 */
					EAD_IAA_NUMERATOR_AMT = EAD_SEC_IAA_AMT * _COSTVAR_ ; 
				end;
			else 
                do;
                    if REGRPT_RW_BUCKET = "CQS1" then
                        OUTV_EAD_RW_20 = OUTV_EAD;								/* Col.220 */
                    else if REGRPT_RW_BUCKET = "CQS2" then
                        OUTV_EAD_RW_50 = OUTV_EAD;								/* Col.230 */
                    else if REGRPT_RW_BUCKET = "CQS3" then
                        OUTV_EAD_RW_100 = OUTV_EAD;								/* Col.240 */
                    else if REGRPT_RW_BUCKET = "CQS4" then
                        OUTV_EAD_RW_350 = OUTV_EAD;								/* Col.250 */
                    else if REGRPT_RW_BUCKET = "OTHER" then
                        do;
                            if RATING_STATUS = "RATED" then
                                OUTV_EAD_RW_1250_RATED = OUTV_EAD;				/* Col.260 */
                            else OUTV_EAD_RW_1250_UNRATED = OUTV_EAD;			/* Col.270 */
                        end;
                end;
        

			OUTV_RWA = RWA_SEC_ORIG; 													/* Col.330*/

			
			if SEC_STRUCTURE_TYPE = "SYNTHETIC" then
				RWA_SYNTHETIC_SEC_AMT = RWA;										/* Col.340*/
				
			RWA_ADJ_INFRINGEMENT_AMT = SEC_INFRINGE_ADJUST_AMT;					/* Col.350*/
				
			RWA_ADJ_MATURITY_MISMATCH_AMT = RWA_SEC_MAT_MIS_ADJ_AMT;						/* Col.360*/
			RWA_BEFORE_CAP_AMT = RWA_BEFORE_CAP;								/* Col.370*/
			RWA_AFTER_CAP_AMT = RWA;											/* Col.380*/

			RWA_SEC_OUTFLOW_OTHER_EXP_AMT = RWA_SEC_MEMO_AMT;								/* Col.390*/

            OUTV_CAPITAL = CAPITAL; /* Col.31 */
			OUTV_EAD_ROLLUP = sum(OUTV_EXPOSURE_ADJ_AMT, -OUTV_EXP_ADJ_CCF_0, -0.8*OUTV_EXP_ADJ_CCF_0_20, -0.5*OUTV_EXP_ADJ_CCF_20_50);
        endmethod;

		method pm_regrpt_crsec_crm kind=price;
		_VALUE_ = EAD;

		if upcase(CRM_PRODUCT) in ('FIN_COLL_SIMPLE') then
			do;
				TOTAL_INFLOW_CRM_SUB_AMT = CRM_USED_AMT_EFF/max(coalesce(CCF,100),1)*100; 

				/*11th col.*/
				OUTV_PRE_CCF_AFTER_CRM = sum(OUTV_EXPOSURE_NET_AMT, TOTAL_OUTFLOW_CRM_SUB_AMT, TOTAL_INFLOW_CRM_SUB_AMT);	
				/*15th col.*/
				OUTV_EXPOSURE_ADJ_AMT = OUTV_PRE_CCF_AFTER_CRM; /* Col.140 */
				OUTV_EAD_ROLLUP = OUTV_EXPOSURE_ADJ_AMT;
			end;
		else
			do;
				TOTAL_INFLOW_CRM_SUB_AMT = 0;
			end;

		endmethod;
			
        method pm_regrpt_crsa_exp kind=price;
            _VALUE_ = EAD;

            if HAIRCUT_EXP > 0 and CRM_PRODUCT NE '' then
                _EAD_PORTION_ = EAD_PORTION/(1+HAIRCUT_EXP/100);
            else _EAD_PORTION_ = EAD_PORTION;
            OUTV_EXP_PRE_CCF_PRE_CRM = EXP_VALUE;  /*1st col.*/

            if CCF ne 0 then
                do;
                    OUTV_EXP_PRE_CCF_PRE_CRM = sum(_EAD_PORTION_/coalesce(CCF,100)*100, min(coalesce(SPECIFIC_PROVISION,0), EAD) );
                end;

            if EXPOSURE_TYPE in ('REPOS', 'DERIVATIVES') then
                OUTV_EAD_CCR = _EAD_PORTION_ - coalesce(CRM_USED_AMT_EFF,0);
            OUTV_VALUE_ADJ_AMT = -sum(0, SPECIFIC_PROVISION);   /* 3rd col.*/
            OUTV_SPECIFIC_WRITEOFF_AMT = sum(0, SPECIFIC_WRITEOFF); /* cr-gb COLUMN 060 */

            IF COMPRESS(IN_DEFAULT_STATUS) EQ 'NEW' THEN
                do;
                    OUTV_NEW_DEFAULTS_AMT = OUTV_EXP_PRE_CCF_PRE_CRM; /* cr-gb COLUMN 040 */
                    OUTV_PROVISIONS_NEW_DFLT_AMT = sum(0, SPECIFIC_PROVISION); /* cr-gb COLUMN 070 */
                end;

            IF COMPRESS(IN_DEFAULT_STATUS) NE '' THEN
                OUTV_DEFAULTS_AMT=OUTV_EXP_PRE_CCF_PRE_CRM;
            OUTV_EXPOSURE_NET_AMT = sum(OUTV_EXP_PRE_CCF_PRE_CRM,OUTV_VALUE_ADJ_AMT); /* 4th col.*/

            IF CRM_PRODUCT EQ 'DER_UNFUNDED' THEN
                OUTV_CREDIT_DERIV_UNFUNDED_AMT = -CRM_USED_AMT_EFF/max(coalesce(CCF,100),1)*100; /* 5th col.*/
            ELSE IF CRM_PRODUCT EQ 'GUAR_UNFUNDED' THEN
                OUTV_GUARANTEE_UNFUNDED_AMT = -CRM_USED_AMT_EFF/max(coalesce(CCF,100),1)*100; /* 6th col. */
            ELSE IF CRM_PRODUCT EQ 'FIN_COLL_SIMPLE' THEN
                OUTV_ELIG_FIN_COLLATERAL_AMT = -CRM_USED_AMT_EFF/max(coalesce(CCF,100),1)*100; /* 7th col. */
            ELSE IF CRM_PRODUCT EQ 'OTHER_FUNDED' THEN
                OUTV_CREDIT_PROTECT_FUNDED_AMT = -CRM_USED_AMT_EFF/max(coalesce(CCF,100),1)*100; /* 8th col.*/
            ELSE IF CRM_PRODUCT EQ 'FIN_COLL_COMPREH' THEN
                DO;
                    OUTV_VOL_ADJ_EXP_AMT = max(0,HAIRCUT_EXP*OUTV_EXP_PRE_CCF_PRE_CRM/100);  /* 12th col. */

                    IF upcase(CRM_TYPE) EQ 'FINANCIAL_COLLATERAL' then
                        do;
                            IF MAT_MISMATCH_WEIGHT_CRM NE . then
                                OUTV_FIN_COLL_ADJ_VAL_AMT= -/*CRM_USED_AMT_EFF*/
                            CRM_USED_AMT*(1 - max(HAIRCUT_CRM/100,0) - max(HAIRCUT_FX/100,0) )*MAT_MISMATCH_WEIGHT_CRM; /* 13th col.*/
                            ELSE OUTV_FIN_COLL_ADJ_VAL_AMT = -/*CRM_USED_AMT_EFF*/
                            CRM_USED_AMT*(1 - HAIRCUT_CRM/100 - HAIRCUT_FX/100 );

                            IF OUTV_FIN_COLL_ADJ_VAL_AMT=. then
                                OUTV_FIN_COLL_ADJ_VAL_AMT=0;
                        END;

                    OUTV_VOL_MAT_ADJ_AMT = -OUTV_FIN_COLL_ADJ_VAL_AMT - CRM_USED_AMT;

                    IF OUTV_VOL_MAT_ADJ_AMT EQ . then
                        OUTV_VOL_MAT_ADJ_AMT = 0;
                END;

            if CRM_PRODUCT IN ('DER_UNFUNDED', 'GUAR_UNFUNDED', 'FIN_COLL_SIMPLE', 'OTHER_FUNDED') then
                do;
                    OUTV_OUTFLOW_WITHIN_SA_AMT = sum(OUTV_CREDIT_DERIV_UNFUNDED_AMT,OUTV_GUARANTEE_UNFUNDED_AMT,OUTV_ELIG_FIN_COLLATERAL_AMT,OUTV_CREDIT_PROTECT_FUNDED_AMT);
                end;

            /*11th col.*/
            OUTV_EXP_PRE_CCF_AFTER_CRM = sum(OUTV_EXPOSURE_NET_AMT, OUTV_OUTFLOW_WITHIN_SA_AMT);

            /*15th col.*/
            OUTV_FULLY_ADJ_EXP_AMT = sum(OUTV_EXP_PRE_CCF_AFTER_CRM, OUTV_VOL_ADJ_EXP_AMT, OUTV_FIN_COLL_ADJ_VAL_AMT);

            /*OUTV_RW = RW_EXP;*/
            OUTV_RWA = RWA;
            OUTV_EAD = _EAD_PORTION_*coalesce(CCF,100)/100;

            /* RWA before SME */
            RWA_PRE_SME_AMT = RWA_PRE_SME;
            
            if STD_RW_FROM_ECAI_FLG eq 1 then
                OUTV_RW_ECAI_AMT=RWA;

            if STD_RW_FROM_CENTGOV_FLG eq 1 then
                OUTV_RW_GOVT_AMT=RWA;
            OUTV_EAD_FUND_CCP_AMT=.;
            OUTV_CAPITAL = RWA * &CAPITAL_RATIO;

            /*Now, update the OUTV_CCF.. values*/
            if compress(REGRPT_CCF_BUCKET)= 'CCF1' then
                OUTV_CCF1 = outv_fully_adj_exp_amt;

            if compress(REGRPT_CCF_BUCKET)= 'CCF2' then
                OUTV_CCF2 = outv_fully_adj_exp_amt;

            if compress(REGRPT_CCF_BUCKET)= 'CCF3' then
                OUTV_CCF3 = outv_fully_adj_exp_amt;

            if compress(REGRPT_CCF_BUCKET)= 'CCF4' then
                OUTV_CCF4 = outv_fully_adj_exp_amt;

            if compress(REGRPT_CCF_BUCKET)= 'UNDEF' then
                OUTV_CCF5 = outv_fully_adj_exp_amt;
            OUTV_EAD_ROLLUP = sum(OUTV_FULLY_ADJ_EXP_AMT, -OUTV_CCF1, -0.8*OUTV_CCF2, -0.5*OUTV_CCF3);
            endmethod;

        method pm_regrpt_crsa_crm kind=price;
            _VALUE_ = EAD;

            if CRM_PRODUCT IN ('DER_UNFUNDED', 'GUAR_UNFUNDED', 'FIN_COLL_SIMPLE', 'OTHER_FUNDED') then
                do;
                    OUTV_INFLOW_WITHIN_SA_AMT = CRM_USED_AMT_EFF/max(coalesce(CCF,100),1)*100; /* 10th col. */

                    /*11th col.*/
                    OUTV_EXP_PRE_CCF_AFTER_CRM = sum(OUTV_EXPOSURE_NET_AMT, OUTV_INFLOW_WITHIN_SA_AMT);

                    /*15th col.*/
                    OUTV_FULLY_ADJ_EXP_AMT = sum(OUTV_EXP_PRE_CCF_AFTER_CRM, OUTV_VOL_ADJ_EXP_AMT, OUTV_FIN_COLL_ADJ_VAL_AMT);
                    OUTV_EAD_ROLLUP = OUTV_FULLY_ADJ_EXP_AMT;
                end;
            else
                do;
                    OUTV_INFLOW_WITHIN_SA_AMT = 0;
                end;

            endmethod;

        method pm_regrpt_crirb_exp kind=price;
            _VALUE_ = EAD;

            /* 
            if HAIRCUT_EXP > 0 and CRM_PRODUCT NE '' then _EAD_PORTION_ = EAD_PORTION /(1+HAIRCUT_EXP/100);
                else _EAD_PORTION_ = EAD_PORTION;
            */
            _EAD_PORTION_ = EAD_PORTION;
            OUTV_MAT_EFF = MAT_EFF*365.25;
            OUTV_VALUE_ADJ_AMT = - sum(0, SPECIFIC_PROVISION)*VALID_PROVISION;

            IF CRM_PRODUCT EQ 'DER_UNFUNDED' THEN
                DO;
                    OUTV_CREDIT_DERIV_UNFUNDED_AMT = CRM_USED_AMT_EFF/max(coalesce(CCF,100),1)*100;

                    /*  OUTV_CREDIT_PROTECT_UNFUND_AMT = CRM_USED_AMT_EFF/max(coalesce(CCF,100),1)*100;*/
                    /*The unfunded credit protection will only be used for the Double-Default group*/
                END;
            ELSE IF CRM_PRODUCT EQ 'GUAR_UNFUNDED' THEN
                DO;
                    OUTV_GUARANTEE_UNFUNDED_AMT = CRM_USED_AMT_EFF/max(coalesce(CCF,100),1)*100;

                    /* OUTV_CREDIT_PROTECT_UNFUND_AMT = CRM_USED_AMT_EFF/max(coalesce(CCF,100),1)*100; */
                    /*The unfunded credit protection will only be used for the Double-Default group*/
                END;
            ELSE IF CRM_PRODUCT IN ('DER_FUNDED', 'GUAR_FUNDED')  THEN
                OUTV_CREDIT_PROTECT_FUNDED_AMT = CRM_USED_AMT_EFF/max(coalesce(CCF,100),1)*100;
            ELSE IF CRM_PRODUCT IN ('LIFE_INSURANCE', 'CASH_3RD_PARTY')  THEN
                OUTV_CREDIT_PROTECT_FUNDED_AMT = CRM_USED_AMT_EFF/max(coalesce(CCF,100),1)*100;
            ELSE IF CRM_PRODUCT EQ 'FIN_COLL' THEN
                OUTV_ELIG_FIN_COLLATERAL_AMT = CRM_USED_AMT_EFF/max(coalesce(CCF,100),1)*100;
            ELSE IF CRM_PRODUCT EQ 'RECEIV' THEN
                OUTV_CLLTRL_RECEIVABLE_AMT = CRM_USED_AMT_EFF/max(coalesce(CCF,100),1)*100;
            ELSE IF CRM_PRODUCT IN ('RRE', 'CRE') THEN
                OUTV_CLLTRL_REAL_ESTATE_AMT = CRM_USED_AMT_EFF/max(coalesce(CCF,100),1)*100;
            ELSE IF CRM_PRODUCT EQ 'OTHER' THEN
                OUTV_CLLTRL_OTHER_PHYSICAL_AMT = CRM_USED_AMT_EFF/max(coalesce(CCF,100),1)*100;

            /*For Double Default case  */
            if CRM_GROUP EQ 'DOUBLE_DEF' then
                do;
                    OUTV_CREDIT_PROTECT_UNFUND_AMT = CRM_USED_AMT_EFF/max(coalesce(CCF,100),1)*100;
                end;

            /*    
            IF EL=. then OUTV_EL_AMT = _EAD_PORTION_*PD_PCT*LGD_PCT/10000;
                else  OUTV_EL_AMT = _EAD_PORTION_*EL/100;
            */
            IF EL_AMT = . then
                do;
                    if LGD_EFF=. or PD_EFF =.  then
                        OUTV_EL_AMT = _EAD_PORTION_*PD_PCT*LGD_PCT/10000;
                    else OUTV_EL_AMT = _EAD_PORTION_*PD_EFF*LGD_EFF/10000;
                end;
            else OUTV_EL_AMT = EL_AMT;

            /*OUTV_EAD = _EAD_PORTION_*coalesce(CCF,100)/100;  */
            OUTV_EAD = _EAD_PORTION_;
            OUTV_EXP_PRE_CCF_PRE_CRM = EXP_VALUE;

            if CCF NOT in (0,.) then
                do;
                    OUTV_EXP_PRE_CCF_PRE_CRM = sum(_EAD_PORTION_/coalesce(CCF,100)*100, min(coalesce(SPECIFIC_PROVISION,0), EAD) );
                end;

            if EXPOSURE_TYPE in ('REPOS', 'DERIVATIVES') then
                OUTV_EXP_OF_WHICH_CCR = _EAD_PORTION_ - coalesce(CRM_USED_AMT_EFF,0);

            if (CRM_GROUP NOT IN ('LGD_ADJ','DOUBLE_DEF')) AND
                (CRM_PRODUCT IN ('DER_UNFUNDED', 'GUAR_UNFUNDED', 'OTHER_FUNDED')) then
                do;
                    OUTV_OUTFLOW_IRB_AMT = -sum(OUTV_CREDIT_DERIV_UNFUNDED_AMT,OUTV_GUARANTEE_UNFUNDED_AMT,OUTV_CREDIT_PROTECT_FUNDED_AMT);
                end;

            if LGD_EFF=. then
                OUTV_LGD_EFF=LGD_PCT;
            else OUTV_LGD_EFF=LGD_EFF;

            /* OUTV_LGD_EFF = LGD_EFF;*/
            OUTV_PD_EFF=_pd_val_;
			/* RWA before SME */
			RWA_PRE_SME_AMT = RWA_PRE_SME;

            /*OUTV_RW = RW_EXP;*/
            OUTV_RWA = RWA;
            OUTV_CAPITAL = RWA * &CAPITAL_RATIO;

            /*Exposure value in case of Large FI  */
            if LARGE_FI_ENTITY_FLG then
                do;
                    OUTV_LARGE_FIN_ORG_EXP_AMT = EXP_VALUE;
                    OUTV_LARGE_FIN_EXPOSURE_VAL_AMT = _EAD_PORTION_*coalesce(CCF,100)/100;
                    OUTV_RWA_LARGE_FIN_ENTITY_AMT = RWA;
                    OUTV_WA_LGD_LARGE_FIN_AMT = LGD_EFF;
                end;

            /* cODE FOR crgb-irb OUTVARS */
            OUTV_SPECIFIC_WRITEOFF_AMT = sum(0, SPECIFIC_WRITEOFF); /* cr-gb COLUMN 060 */

            IF IN_DEFAULT_FLG EQ 1 THEN
                do;
                    OUTV_DEFAULTS_AMT=OUTV_EXP_PRE_CCF_PRE_CRM;
                    OUTV_RWA_DEFAULT_AMT=OUTV_RWA;
                    OUTV_LGD_EFF_DEFAULT_PCT = OUTV_LGD_EFF;  /* cr-gb COLUMN 100 */
                end;

            IF COMPRESS(IN_DEFAULT_STATUS) EQ 'NEW' THEN
                do;
                    OUTV_NEW_DEFAULTS_AMT = OUTV_EXP_PRE_CCF_PRE_CRM; /* cr-gb COLUMN 040 */
                    OUTV_PROVISIONS_NEW_DFLT_AMT = sum(0, SPECIFIC_PROVISION); /* cr-gb COLUMN 070 */
                end;

            /*New Code will replace the macro create_vars from regrpt_d0_capital_crirbf.sas since 
            this macro does not create the values at aggregate level */
            if CRM_GROUP EQ 'LGD_ADJ' then
                do;
                    OUTV_CRD_DERIV_UNFUND_LGD  =  outv_credit_deriv_unfunded_amt;
                    OUTV_FUND_CRED_PROTECT_LGD =  outv_credit_protect_funded_amt;
                    OUTV_GUAR_UNFUND_LGD       =  OUTV_GUARANTEE_UNFUNDED_AMT;
                end;
            else if CRM_GROUP IN ('NOT_ADJ', 'UNDEFINED') then
                do;
                    OUTV_GUAR_UNFUND_NLGD       = - OUTV_GUARANTEE_UNFUNDED_AMT;
                    OUTV_CRD_DERIV_UNFUND_NLGD  = - outv_credit_deriv_unfunded_amt;
                    OUTV_FUND_CRED_PROTECT_NLGD = - outv_credit_protect_funded_amt;
                end;
            else if CRM_GROUP EQ 'DOUBLE_DEF' then
                do;
                    OUTV_UNFUND_CRED_PROTECT_LGD_DD = OUTV_CREDIT_PROTECT_UNFUND_AMT;
                end;

            /*---------------------------------------------------------------------------
             * The exposure type is a flag that is set if the exp is off balance
         *--------------------------------------------------------------------------*/
            if EXPOSURE_TYPE in ('OFF_BALANCE') then
                do;
                    OUTV_OFF_BAL_EXP_PRE_CCF_CRM = outv_exp_pre_ccf_pre_crm;
                    OUTV_OFF_BAL_EAD             = outv_ead;
                end;

            OUTV_EXP_PRE_CCF_AFTER_CRM = sum(OUTV_EXP_PRE_CCF_PRE_CRM, OUTV_OUTFLOW_IRB_AMT);
            endmethod;

        method pm_regrpt_crirb_crm kind=price;
            _VALUE_ = EAD;
            OUTV_PD_EFF=_pd_val_;

            /* INFLOW AMT */
            if (CRM_GROUP NOT IN ('LGD_ADJ','DOUBLE_DEF')) AND
                (CRM_PRODUCT IN ('DER_UNFUNDED', 'GUAR_UNFUNDED', 'OTHER_FUNDED')) then
                do;
                    /*  OUTV_INFLOW_IRB_AMT = sum(OUTV_CREDIT_DERIV_UNFUNDED_AMT,OUTV_GUARANTEE_UNFUNDED_AMT,OUTV_CREDIT_PROTECT_FUNDED_AMT); */
                    OUTV_INFLOW_IRB_AMT = CRM_USED_AMT_EFF/max(coalesce(CCF,100),1)*100;
                    OUTV_EXP_PRE_CCF_AFTER_CRM = sum(OUTV_EXP_PRE_CCF_PRE_CRM,OUTV_INFLOW_IRB_AMT);
                end;
            else
                do;
                    OUTV_INFLOW_IRB_AMT = 0;
                end;

            endmethod;

        method pm_regrpt_cr_equ_exp kind=price;
            _VALUE_ = EAD;

            if HAIRCUT_EXP > 0 and CRM_PRODUCT NE '' then
                _EAD_PORTION_ = EAD_PORTION/(1+HAIRCUT_EXP/100);
            else _EAD_PORTION_ = EAD_PORTION;
            OUTV_PD_EFF=_pd_val_;
            OUTV_EXP_PRE_CCF_PRE_CRM = EXP_VALUE;

            if CCF ne 0 then
                do;
                    OUTV_EXP_PRE_CCF_PRE_CRM = sum(_EAD_PORTION_/coalesce(CCF,100)*100, min(coalesce(SPECIFIC_PROVISION,0), EAD) );
                end;

            if EXPOSURE_TYPE='OFF_BALANCE' then
                _EXP_PRE_CCF_PRE_CRM_OB_ = EXP_VALUE;

            IF CRM_PRODUCT EQ 'DER_UNFUNDED' THEN
                OUTV_CREDIT_DERIV_UNFUNDED_AMT = CRM_USED_AMT_EFF;
            ELSE IF CRM_PRODUCT EQ 'GUAR_UNFUNDED' THEN
                OUTV_GUARANTEE_UNFUNDED_AMT = CRM_USED_AMT_EFF;

            IF (CRM_GROUP EQ 'NOT_ADJ') AND
                (CRM_PRODUCT IN ('DER_UNFUNDED', 'GUAR_UNFUNDED')) then
                do;
                    OUTV_OUTFLOW_IRB_AMT = -sum(OUTV_CREDIT_DERIV_UNFUNDED_AMT,OUTV_GUARANTEE_UNFUNDED_AMT);

                    if EXPOSURE_TYPE = 'OFF_BALANCE' then
                        _OUTFLOW_IRB_AMT_OB_ = -sum(OUTV_CREDIT_DERIV_UNFUNDED_AMT,OUTV_GUARANTEE_UNFUNDED_AMT);
                end;

            OUTV_EAD = _EAD_PORTION_*coalesce(CCF,100)/100;

            If EXPOSURE_TYPE = 'OFF_BALANCE' then
                OUTV_EAD_OB = _EAD_PORTION_*coalesce(CCF,100)/100;
            OUTV_LGD_EFF = LGD_EXP;
            OUTV_RWA = RWA;
            OUTV_CAPITAL = RWA * &CAPITAL_RATIO;

            IF EL=. then
                OUTV_EL_AMT = _EAD_PORTION_*PD_PCT*LGD_PCT/10000;
            else  OUTV_EL_AMT = _EAD_PORTION_*EL/100;
            OUTV_VALUE_ADJ_AMT = sum(0, SPECIFIC_PROVISION);

            /* CR-GB IRB related changes */
            OUTV_SPECIFIC_WRITEOFF_AMT = sum(0, SPECIFIC_WRITEOFF); /* cr-gb COLUMN 060 */

            IF COMPRESS(IN_DEFAULT_STATUS) EQ 'NEW' THEN
                do;
                    OUTV_NEW_DEFAULTS_AMT = OUTV_EXP_PRE_CCF_PRE_CRM; /* cr-gb COLUMN 040 */
                    OUTV_PROVISIONS_NEW_DFLT_AMT = sum(0, SPECIFIC_PROVISION); /* cr-gb COLUMN 070 */
                end;

            IF COMPRESS(IN_DEFAULT_STATUS) NE '' THEN
                do;
                    OUTV_DEFAULTS_AMT = OUTV_EAD; /* cr-gb COLUMN 040 */
                    OUTV_RWA_DEFAULT_AMT=OUTV_RWA;
                    OUTV_LGD_EFF_DEFAULT_PCT = OUTV_LGD_EFF;  /* cr-gb COLUMN 100 */
                end;

            OUTV_EXP_PRE_CCF_AFTER_CRM = sum(OUTV_EXP_PRE_CCF_PRE_CRM, OUTV_OUTFLOW_IRB_AMT);
            endmethod;

        method pm_regrpt_cr_equ_crm kind=price;
            _VALUE_ = EAD;
            OUTV_PD_EFF=_pd_val_;

            if (CRM_GROUP EQ 'NOT_ADJ') AND
                (CRM_PRODUCT IN ('DER_UNFUNDED', 'GUAR_UNFUNDED')) then
                do;
                    OUTV_INFLOW_IRB_AMT = sum(OUTV_CREDIT_DERIV_UNFUNDED_AMT,OUTV_GUARANTEE_UNFUNDED_AMT);

                    if EXPOSURE_TYPE = 'OFF_BALANCE' then
                        _INFLOW_IRB_AMT_OB_ = sum(OUTV_CREDIT_DERIV_UNFUNDED_AMT,OUTV_GUARANTEE_UNFUNDED_AMT);
                    OUTV_EXP_PRE_CCF_AFTER_CRM = OUTV_INFLOW_IRB_AMT;
                end;
            else
                do;
                    OUTV_INFLOW_IRB_AMT = 0;
                    _INFLOW_IRB_AMT_OB_ = 0;
                    OUTV_EXP_PRE_CCF_AFTER_CRM = OUTV_INFLOW_IRB_AMT;
                end;

            endmethod;

        method pm_report_capital_1 kind=price;
            _VALUE_ = EXP_VALUE;
            OUTV_EXPOSURE_ORIG_AMT = EAD;
            OUTV_VALUE_ADJ_AMT = sum(0, SPECIFIC_PROVISION);
            OUTV_EXPOSURE_NET_AMT =  max(0, sum(OUTV_EXPOSURE_ORIG_AMT, - OUTV_VALUE_ADJ_AMT));
            OUTV_EXPOSURE_ADJ_AMT = sum(EAD * sum(1, HAIRCUT_EXP/100), - CRM_USED_AMT_EFF);

            if RW_EXP = 0 then
                OUTV_EAD = EAD;
            else OUTV_EAD = RWA / (RW_EXP/100);
            OUTV_RWA = RWA;
            OUTV_CAPITAL = CAPITAL;
            endmethod;

        method pm_report_capital_2 kind=price;
            _VALUE_ = EAD;
            OUTV_EXPOSURE_ORIG_AMT = EXP_VALUE;
            OUTV_VALUE_ADJ_AMT = sum(0, SPECIFIC_PROVISION);
            OUTV_EXPOSURE_NET_AMT =  max(0, sum(OUTV_EXPOSURE_ORIG_AMT, - OUTV_VALUE_ADJ_AMT));
            OUTV_EXPOSURE_ADJ_AMT = sum(EAD * sum(1, HAIRCUT_EXP/100), - CRM_USED_AMT_EFF);

            if RW_EXP = 0 then
                OUTV_EAD = EAD;
            else OUTV_EAD = RWA / (RW_EXP/100);
            OUTV_RWA = RWA;
            OUTV_CAPITAL = CAPITAL;
            OUTV_EAD   = EAD;
            OUTV_MAT_EFF = MAT_EFF/12;
            OUTV_EL_AMT = EL;
            OUTV_LGD_EFF = LGD_EFF;

            IF OUTV_LGD_EFF = .65 THEN
                OUTV_EAD_LGD65_AMT=OUTV_EAD;
            ELSE OUTV_EAD_LGD65_AMT=0;

            IF OUTV_LGD_EFF = .90 THEN
                OUTV_EAD_LGD90_AMT=OUTV_EAD;
            ELSE OUTV_EAD_LGD90_AMT=0;

            /*OUTV_RW = RW_EXP;*/
            endmethod;

      method pm_regrpt_le2 kind=price;
            _VALUE_ = EAD;
            OUTV_DIR_EXP_DEBT_AMT= DIR_EXP_DEBT;/*COl 90*/
            OUTV_DIR_EXP_EQUITY_AMT=DIR_EXP_EQU;/*COl 100*/
            OUTV_DIR_EXP_DERIVATIVE_AMT=DIR_EXP_DERIV;/*COl 110*/
            OUTV_DIR_EXP_OBSI_LOAN_AMT=DIR_EXP_OBSI_LOAN;/*COl 120*/
            OUTV_DIR_EXP_OBSI_GUAR_AMT=DIR_EXP_OBSI_GUAR;/*COl 130*/
            OUTV_DIR_EXP_OBSI_OTH_AMT=DIR_EXP_OBSI_OTHER;/*COl 140*/
            OUTV_INDIR_EXP_DEBT_AMT=IND_EXP_DEBT;/*COl 150*/
            OUTV_INDIR_EXP_EQUITY_AMT=IND_EXP_EQU;/*COl 155*/
            OUTV_INDIR_EXP_DERIVATIVE_AMT=IND_EXP_DERIV;/*COl 160*/
            OUTV_INDIR_EXP_OBSI_LOAN_AMT=IND_EXP_OBSI_LOAN;/*COl 170*/
            OUTV_INDIR_EXP_OBSI_GUAR_AMT=IND_EXP_OBSI_GUAR;/*COl 180*/
            OUTV_INDIR_EXP_OBSI_OTH_AMT=IND_EXP_OBSI_OTHER;/*COl 190*/
            OUTV_UNDERLYING_EXP_EAD_AMT=UNDERLYING_EXP_EAD;/*COl 200*/
            OUTV_TOT_ORIG_EXP_AMT= SUM_EAD_PORTION; /*COL 70*/
            OUTV_TOT_ORIG_EXP_DEFLT_AMT= TOT_ORIG_EXP_DEF;/*COL 80*/
            OUTV_VALUE_ADJ_AMT = -VALUE_ADJ_AMT ; /*COL 210 */

            /*COL 220- NOT TO BE IMPLEMENTED*/
            OUTV_EXP_PRE_CRM_AMT=SUM(SUM_EAD_PORTION,OUTV_VALUE_ADJ_AMT);/*COL 230*/

            IF TRADING_BOOK_FLG NE '1' THEN
                OUTV_EXP_PRE_CRM_TB_AMT=SUM(SUM_EAD_PORTION,OUTV_VALUE_ADJ_AMT);
            ELSE OUTV_EXP_PRE_CRM_TB_AMT=. ; /*COL 240*/
            OUTV_EXP_PRE_CRM_PCT=(OUTV_EXP_PRE_CRM_AMT/TOT_ELIG_CAP)*100;/*COL 250*/
            OUTV_CRM_EXP_DEBT_AMT= -CRM_EXP_DEBT;/*COL 260*/
            OUTV_CRM_EXP_EQUITY_AMT= -CRM_EXP_EQU;/*COL 265*/
            OUTV_CRM_EXP_DERIVATIVE_AMT= -CRM_EXP_DERIV;/*COL 270*/
            OUTV_CRM_EXP_OBSI_LOAN_AMT= -CRM_EXP_OBSI_LOAN;/*COL 280*/
            OUTV_CRM_EXP_OBSI_GUAR_AMT = -CRM_EXP_OBSI_GUAR;/*COL 290*/
            OUTV_CRM_EXP_OBSI_OTHER_AMT = -CRM_EXP_OBSI_OTHER;/*COL 300*/
            OUTV_CR_PRTCTN_NOT_SUB_EFF_AMT= -CREDIT_PROT_NOT_SUB_EFFECT;/*COL 310*/
            OUTV_ELIG_CRM_REAL_ESTATE_AMT= -ELIG_CRM_RE;/*COL 320*/
            OUTV_LE_EXEMPTED_AMT = -LE_EXEMPTED_AM ; /*COL 330*/
            OUTV_EXP_POST_CRM_AMT=sum(OUTV_EXP_PRE_CRM_AMT,OUTV_CRM_EXP_DEBT_AMT,OUTV_CRM_EXP_EQUITY_AMT,OUTV_CRM_EXP_DERIVATIVE_AMT,
                OUTV_CRM_EXP_OBSI_LOAN_AMT,OUTV_CRM_EXP_OBSI_GUAR_AMT,OUTV_CRM_EXP_OBSI_OTHER_AMT,OUTV_CR_PRTCTN_NOT_SUB_EFF_AMT,
                OUTV_ELIG_CRM_REAL_ESTATE_AMT,OUTV_LE_EXEMPTED_AMT);/*col 340*/

            IF TRADING_BOOK_FLG NE '1' THEN
                OUTV_EXP_POST_CRM_TB_AMT=sum(OUTV_EXP_PRE_CRM_AMT,OUTV_CRM_EXP_DEBT_AMT,OUTV_CRM_EXP_EQUITY_AMT,OUTV_CRM_EXP_DERIVATIVE_AMT,
                OUTV_CRM_EXP_OBSI_LOAN_AMT,OUTV_CRM_EXP_OBSI_GUAR_AMT,OUTV_CRM_EXP_OBSI_OTHER_AMT,OUTV_CR_PRTCTN_NOT_SUB_EFF_AMT,
                OUTV_ELIG_CRM_REAL_ESTATE_AMT,OUTV_LE_EXEMPTED_AMT);
            ELSE OUTV_EXP_POST_CRM_TB_AMT=. ; /*COL 350*/
            OUTV_EXP_POST_CRM_PCT=(OUTV_EXP_POST_CRM_AMT/TOT_ELIG_CAP)*100;/*COL 360*/
            OUTV_CAP_REQM_LRG_EXP_TB_AMT = LE_CAP_CHG;/*LE capital charge*/

            /*OUTV_CPTY_NAME=CPTY_NM;*/
            /*OUTV_CPTY_CODE=COUNTERPARTY_TYPE_CD;*/
            /*OUTV_LEI_CODE=LEI;*/
            /*OUTV_CPTY_RESI=CPTY_RES;*/
            /*OUTV_CPTY_SECTOR=CPTY_SECTOR;*/
            /*OUTV_NACE=NACE;*/
            /*OUTV_CPTY_TYPE=CPTY_TYPE;*/
            endmethod;


        method pm_regrpt_le3 kind=price;
            _VALUE_ = EAD;
            OUTV_DIR_EXP_DEBT_AMT= DIR_EXP_DEBT;/*COl 90*/
            OUTV_DIR_EXP_EQUITY_AMT=DIR_EXP_EQU;/*COl 100*/
            OUTV_DIR_EXP_DERIVATIVE_AMT=DIR_EXP_DERIV;/*COl 110*/
            OUTV_DIR_EXP_OBSI_LOAN_AMT=DIR_EXP_OBSI_LOAN;/*COl 120*/
            OUTV_DIR_EXP_OBSI_GUAR_AMT=DIR_EXP_OBSI_GUAR;/*COl 130*/
            OUTV_DIR_EXP_OBSI_OTH_AMT=DIR_EXP_OBSI_OTHER;/*COl 140*/
            OUTV_INDIR_EXP_DEBT_AMT=IND_EXP_DEBT;/*COl 150*/
            OUTV_INDIR_EXP_EQUITY_AMT=IND_EXP_EQU;/*COl 155*/
            OUTV_INDIR_EXP_DERIVATIVE_AMT=IND_EXP_DERIV;/*COl 160*/
            OUTV_INDIR_EXP_OBSI_LOAN_AMT=IND_EXP_OBSI_LOAN;/*COl 170*/
            OUTV_INDIR_EXP_OBSI_GUAR_AMT=IND_EXP_OBSI_GUAR;/*COl 180*/
            OUTV_INDIR_EXP_OBSI_OTH_AMT=IND_EXP_OBSI_OTHER;/*COl 190*/
            OUTV_UNDERLYING_EXP_EAD_AMT=UNDERLYING_EXP_EAD;/*COl 200*/
            OUTV_TOT_ORIG_EXP_AMT= SUM_EAD_PORTION; /*COL 70*/
            OUTV_TOT_ORIG_EXP_DEFLT_AMT= TOT_ORIG_EXP_DEF;/*COL 80*/
            OUTV_VALUE_ADJ_AMT = -VALUE_ADJ_AMT ; /*COL 210 */

            /*COL 220- NOT TO BE IMPLEMENTED*/
            OUTV_EXP_PRE_CRM_AMT=SUM(SUM_EAD_PORTION,OUTV_VALUE_ADJ_AMT);/*COL 230*/

            IF TRADING_BOOK_FLG NE '1' THEN
                OUTV_EXP_PRE_CRM_TB_AMT=SUM(SUM_EAD_PORTION,OUTV_VALUE_ADJ_AMT);
            ELSE OUTV_EXP_PRE_CRM_TB_AMT=. ; /*COL 240*/
            OUTV_EXP_PRE_CRM_PCT=(OUTV_EXP_PRE_CRM_AMT/TOT_ELIG_CAP)*100;/*COL 250*/
            OUTV_CRM_EXP_DEBT_AMT= -CRM_EXP_DEBT;/*COL 260*/
            OUTV_CRM_EXP_EQUITY_AMT= -CRM_EXP_EQU;/*COL 265*/
            OUTV_CRM_EXP_DERIVATIVE_AMT= -CRM_EXP_DERIV;/*COL 270*/
            OUTV_CRM_EXP_OBSI_LOAN_AMT= -CRM_EXP_OBSI_LOAN;/*COL 280*/
            OUTV_CRM_EXP_OBSI_GUAR_AMT = -CRM_EXP_OBSI_GUAR;/*COL 290*/
            OUTV_CRM_EXP_OBSI_OTHER_AMT = -CRM_EXP_OBSI_OTHER;/*COL 300*/
            OUTV_CR_PRTCTN_NOT_SUB_EFF_AMT= -CREDIT_PROT_NOT_SUB_EFFECT;/*COL 310*/
            OUTV_ELIG_CRM_REAL_ESTATE_AMT= -ELIG_CRM_RE;/*COL 320*/
            OUTV_LE_EXEMPTED_AMT = -LE_EXEMPTED_AM ; /*COL 330*/
            OUTV_EXP_POST_CRM_AMT=sum(OUTV_EXP_PRE_CRM_AMT,OUTV_CRM_EXP_DEBT_AMT,OUTV_CRM_EXP_EQUITY_AMT,OUTV_CRM_EXP_DERIVATIVE_AMT,OUTV_CRM_EXP_OBSI_LOAN_AMT,
                OUTV_CRM_EXP_OBSI_GUAR_AMT,OUTV_CRM_EXP_OBSI_OTHER_AMT,OUTV_CR_PRTCTN_NOT_SUB_EFF_AMT,OUTV_ELIG_CRM_REAL_ESTATE_AMT,OUTV_LE_EXEMPTED_AMT);/*col 340*/

            IF TRADING_BOOK_FLG NE '1' THEN
                OUTV_EXP_POST_CRM_TB_AMT=sum(OUTV_EXP_PRE_CRM_AMT,OUTV_CRM_EXP_DEBT_AMT,OUTV_CRM_EXP_EQUITY_AMT,
                OUTV_CRM_EXP_DERIVATIVE_AMT,OUTV_CRM_EXP_OBSI_LOAN_AMT,OUTV_CRM_EXP_OBSI_GUAR_AMT,OUTV_CRM_EXP_OBSI_OTHER_AMT,OUTV_CR_PRTCTN_NOT_SUB_EFF_AMT,
                OUTV_ELIG_CRM_REAL_ESTATE_AMT,OUTV_LE_EXEMPTED_AMT);
            ELSE OUTV_EXP_POST_CRM_TB_AMT=. ; /*COL 350*/
            OUTV_EXP_POST_CRM_PCT=(OUTV_EXP_POST_CRM_AMT/TOT_ELIG_CAP)*100;/*COL 360*/
            OUTV_CAP_REQM_LRG_EXP_TB_AMT = LE_CAP_CHG;/*LE capital charge*/

            /*OUTV_CPTY_NAME=CPTY_NM;*/
            /*OUTV_CPTY_CODE=COUNTERPARTY_TYPE_CD;*/
            /*OUTV_LEI_CODE=LEI;*/
            /*OUTV_CPTY_RESI=CPTY_RES;*/
            /*OUTV_CPTY_SECTOR=CPTY_SECTOR;*/
            /*OUTV_NACE=NACE;*/
            /*OUTV_CPTY_TYPE=CPTY_TYPE;*/
            endmethod;

			method pm_regrpt_le4 kind=price;
	 			_VALUE_=1;
	 			MATURITY_EXP=sum(CASHFLOW_AMT,-VALUE_ADJ_AMT);
	 		endmethod;

			method pm_regrpt_le5 kind=price;
	 			_VALUE_=1;
	 			MATURITY_EXP=sum(CASHFLOW_AMT,-VALUE_ADJ_AMT);
	 		endmethod;

        method pm_regrpt_cva kind=price;
            _VALUE_ = 1;
            OUTV_CVA_EAD_AMT = EAD_ADJ;
            OUTV_CVA_DERIVATIVES_AMT = CVA_EAD_ADJ_OTC;
            OUTV_CVA_SFT_AMT = CVA_EAD_ADJ_SFT;
            OUTV_CVA_CHARGE_AMT = CVA_CHARGE_AMT;
            OUTV_CVA_TOTAL_RISK_EXP_AMT = 12.5 * CVA_CHARGE_AMT;
            OUTV_CVA_CPTY_NO =CVA_COUNTERPARTY_COUNT;
            OUTV_NAME_CDS_AMT = CVA_CDS_NOTIONAL_AMT;
            OUTV_INDEX_CDS_AMT =CVA_INDEX_NOTIONAL_AMT;
            endmethod;

        method pm_regrpt_lr2 kind=price;
            _VALUE_ = EAD;

            if HAIRCUT_EXP > 0 and CRM_TYPE NE '' then
                _EAD_PORTION_ = EAD_PORTION/(1+HAIRCUT_EXP/100);
            else _EAD_PORTION_ = EAD_PORTION;

            if index(APPROACH, 'STD') > 0 then
                OUTV_EAD_STD_AMT = _EAD_PORTION_; /* column 1 */
            else if index(APPROACH, 'IRB') > 0 then 
                OUTV_EAD_IRB_AMT = _EAD_PORTION_; /* column 2 */

            /*Column 3: nominal amounts */
            OUTV_EXPOSURE_ORIG_AMT = EXP_VALUE;  /*1st col.*/

            if CCF ne 0 then
                do;
                    OUTV_EXPOSURE_ORIG_AMT  = sum(_EAD_PORTION_/coalesce(CCF,100)*100, min(coalesce(SPECIFIC_PROVISION,0), EAD) );
                end;

            endmethod;

        method pm_regrpt_lr4 kind=price;
            _VALUE_ = EAD;

            if HAIRCUT_EXP > 0 and CRM_TYPE NE '' then
                _EAD_PORTION_ = EAD_PORTION/(1+HAIRCUT_EXP/100);
            else _EAD_PORTION_ = EAD_PORTION;

            /* first part of report */
            OUTV_RWA = RWA;
            OUTV_EAD = _EAD_PORTION_;

            /* for second part of report, need to break out IRB and SA approach */
            if index(APPROACH, 'STD') > 0 then
                do;
                    OUTV_EAD_STD_AMT = _EAD_PORTION_;  /*Column 1: post-ccf amounts for STD approach */
                    OUTV_RWA_STD_AMT = RWA;           /*Column 3: RWA amounts for STD approach */
                end;
            else if index(APPROACH, 'IRB') > 0 then
                do;
                    OUTV_EAD_IRB_AMT = _EAD_PORTION_;  /*Column 2: post-ccf amounts for IRB approach */
                    OUTV_RWA_IRB_AMT = RWA;           /*Column 4: RWA amounts for IRB approach */
                end;

            endmethod;
        method pm_regrpt_gb3 kind=price;
            _VALUE_ = EAD;

			OUTV_CAPITAL = CAPITAL;
			
        endmethod;

      method pm_regrpt_sec_det kind=price;
         /*- Value is set to 0. -*/

         _VALUE_ = 0 ;

        /*- Set all of the output variable values. Each one has a distinct instrument -*/
        /*- variable which provieds it a value -*/
        SEC_RETENTION_PCT = RETENTION_PCT ;
        NON_ABCP_ORIGINATION_DT = NON_ABCP_ORIGINATION_DATE ;
        NON_ABCP_ORIG_AMT = NON_ABCP_ORIGINATION_AMT ;
        TOTAL_AMT = TOTAL_AMOUNT ;
        INSTITUTION_SHARE_PCT = INSTITUTION_SHARE ;
        EFFECTIVE_EXPOSURE_NO = NUMBER_OF_EXPOSURES ;
        ELGD_PCT = ELGD ;
        VALUE_ADJUST_PROVISIONS_AMT = VALUE_ADJUST_PROVISIONS ;
        OWN_FUND_REQ_PRE_SEC_AMT = OWN_FUND_REQ_PRE_SECURITIZATION ;
        ON_BS_SEN_TRANCHE_VALUE_AMT = ON_BS_SENIOR_TRANCHE_VALUE ;
        ON_BS_MEZZ_TRANCHE_VALUE_AMT = ON_BS_MEZZ_TRANCHE_VALUE ;
        ON_BS_FL_TRANCHE_VALUE_AMT = ON_BS_FIRST_LOST_TRANCHE_VALUE ;
        OFF_BS_SEN_TRANCHE_VALUE_AMT = OFF_BS_SENIOR_TRANCHE_VALUE ;
        OFF_BS_MEZZ_TRANCHE_VALUE_AMT = OFF_BS_MEZZ_TRANCHE_VALUE ;
        OFF_BS_FL_TRANCHE_VALUE_AMT = OFF_BS_FIRST_LOST_TRANCHE_VALUE ;
        FIRST_TERM_DT = FIRST_TERMINATION_DATE ; 
        LEGAL_FINAL_DT = LEGAL_FINAL_DATE ; 
        ON_BS_SEN_EXP_VALUE_AMT = ON_BS_SENIOR_EXP_VALUE ;
        ON_BS_MEZZ_EXP_VALUE_AMT = ON_BS_MEZZ_EXP_VALUE ;
        ON_BS_FL_EXP_VALUE_AMT = ON_BS_FIRST_LOST_EXP_VALUE ;
        OFF_BS_SEN_EXP_VALUE_AMT = OFF_BS_SENIOR_EXP_VALUE ;
        OFF_BS_MEZZ_EXP_VALUE_AMT = OFF_BS_MEZZ_EXP_VALUE ;
        OFF_BS_FL_EXP_VALUE_AMT = OFF_BS_FIRST_LOST_EXP_VALUE ;
        DCS_MEMO_AMT = DCS_MEMO ;
        IRS_CRS_MEMO_AMT = IRS_CRS_MEMO ;
        FAC_MEMO_AMT = FAC_MEMO ;
        OTHER_MEMO_AMT = OTHER_MEMO ;
        CCF_APPLIED_PCT = CCF_APPLIED ;
        OWN_FUNDS_DEDUCTION_AMT = OWN_FUNDS_DEDUCTION ;
        PRE_CAP_EXPOSURE_AMT = PRE_CAP_EXPOSURE ;
        POST_CAP_EXPOSURE_AMT = POST_CAP_EXPOSURE ;
        /*- OUTV_CTP_NON_CTP = CTP_NON_CTP ; -*/
        LONG_POSITION_NET_AMT = LONG_POSITION_NET ;
        SHORT_POSITION_NET_AMT = SHORT_POSITION_NET ;
        SPECIFIC_RISK_AMT = SPECIFIC_RISK ;
      endmethod;

    run;

    /* Define the CA pricing methods, using the information in the RD_ROOT.CAPMETHODS_FINFACT table */
    filename ca_pm catalog 'work.temp.ca.source' LRECL=32760;

    data work.out_dummy_pm;
        length pmethod $32.;
        set work.out_dummy (keep = name);
        pmethod = compress(tranwrd(name,'__','') , '');
    run;

    data work._inst_out;
        set rd_root.capmethods_finfact (keep = name pmethod)
        work.out_dummy_pm;
    run;

    data _null_;
        set work._inst_out nobs=maxobs; /*set work.define_ca_output nobs=maxobs;*/
        file ca_pm;

        if _n_ = 1 then
            do;
                put "proc compile inlib = RD_PROJ.REGRPT outlib = RD_PROJ.REGRPT env=RD_PROJ.REGRPT package=reg_rpts;";
                put;
                put "method pm_regrpt_ca kind=price;";
                put " _VALUE_ = 1;";
            end;

        line = "    " || trim(left(name)) || "=" || trim(left(pmethod)) || ";";
        put line;
        put;

        if _n_=maxobs then
            do;
                put "endmethod;";
                put "run;";
            end;
    run;

    %include ca_pm;
    filename le_pm catalog 'work.temp.le.source' LRECL=32760;

    data _null_;
        set work._inst_out nobs=maxobs; /*set work.define_ca_output nobs=maxobs;*/
        file le_pm;

        if _n_ = 1 then
            do;
                put "proc compile inlib = RD_PROJ.REGRPT outlib = RD_PROJ.REGRPT env=RD_PROJ.REGRPT package=reg_rpts;";
                put;
                put "method pm_regrpt_le_limits kind=price;";
                put " _VALUE_ = 1;";
            end;

        line = "    " || trim(left(name)) || "=" || trim(left(pmethod)) || ";";
        put line;
        put;

        if _n_=maxobs then
            do;
                put "endmethod;";
                put "run;";
            end;
    run;

    %include le_pm;
%mend d00_pm_regrpt_crd4;
