/*****************************************************************************
* Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
*
*    NAME: e10_proj_regrpt_cap_crsec_sa.sas
*
* PURPOSE: Run CR regulatory reports for securitization exposures subject to 
*          standardized approach
*
*   USAGE:
*
*   NOTES:
*
*
*****************************************************************************/
%macro e10_proj_regrpt_cap_sec_sa_crd4; 

%macro run_regrpt_crsec_sa;
 
libname _plib_ "&RPTPATH";
 
%local NOBS HAVEDATA PROJECT_SET_ORIG;
 
%let PROJECT_SET_ORIG = %lowcase(&PROJECT_SET); 
 
%let NOBS = %attrn(_plib_.CAPITAL_CRSEC_SA_CRD4, NOBS);
%checkdata (_plib_,CAPITAL_CRSEC_SA_CRD4, );
 
%if &HAVEDATA = NO %then %do;
%print_msg(note,3,1);
%goto EXIT;
%end;
 

%global REPORTS_PROJECT_TYPE;
%let REPORTS_PROJECT_TYPE = CAPITAL_CRSEC_SA_CRD4;
 
%let PROJECT_NAME = &PROJECT_SET._&REPORTS_PROJECT_TYPE;
 
/* Check for OLAP and configure is necessary */
%olapreport (&REPORTS_PROJECT_TYPE);
 
proc risk noseqcheck ;
 
setpath "&RPTPATH" <;
 
environment open = RD_PROJ.REGRPT;
 
setoptions keeplib;
 
/* Include olap options based on user options */
%inc OLAP;
 
project &PROJECT_NAME
portfolio  = &REPORTS_PROJECT_TYPE
currency   = &REPORT_CCY
crossclass = regrpt_crsec_sa
out        = &PROJECT_NAME
OUTPATH    = "&RPTPATH"
;
 
runproject &PROJECT_NAME
options = (outall noallscore nomddbs)
report
date    = &RUNDATE;
 
environment save noupdatemetadata;
 
run;
%r0_post_regrpt_01;
%r03_reportmartload_regrpts;
 
/* Create information map for cube if present */
%if %upcase(&cube_output) eq YES %then %do;
 
%get_regrpt_nls_strings;

%LET cname=%SYSFUNC(CAT(Summary,_,&PROJECT_NAME)); 
%let mapname = &report &for &username &in &usertype &mode : &cname;
 
%if %length(&mapname)<60 %then
%let namelength=%length(&mapname);
%else   %let namelength=60;
%infomap (&cname,%substr(&mapname,1,&namelength));
%end;
 
%EXIT:
 
libname _plib_ clear;
%let PROJECT_SET=&PROJECT_SET_ORIG;

%mend run_regrpt_crsec_sa;;
 
%run_regrpt_crsec_sa;
%mend e10_proj_regrpt_cap_sec_sa_crd4;
