/*****************************************************************************
 * Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME: get_le_capital_charge_crd4.sas
 *
 * PURPOSE: Gets the excess capital charge for all exposures in a dataset
 *
 *   USAGE: 
 *
 *   NOTES: assumes input data set has the same format as crm_allocation_*_detail table;
 *
 *          
 *
 *****************************************************************************/

%macro get_le_capital_charge_crd4 (dsname=);

    /*- filter out non-trading book exposures  -*/
    data all_exposures_for_prep;
        set &dsname;
        if  TRADING_BOOK_FLG = 1;
        if LE_COUNTERPARTY_RK NE .;
        KEEP COUNTERPARTY_GROUP LE_COUNTERPARTY_RK 
             EXP_ID CRM_ID DIRECT_EXP_FLG CRM_USED_AMT_EFF RW_EXP RW_CRM
             SPECIFIC_PROVISION UNDERLYING_EXP_EAD 
             MKT_RISK_CHG_AMT SETT_RISK_CHG_AMT CRM_TYPE 
             ELIGIBLE_CRM_TYPE EAD EXP_VALUE LE_ORIG_EXPOSURE_AMT CCF TRADE_EXP_FLG COUNTERPARTY_SUBCLASS BANKRUPTCY_REMOTE_FLG
             CRM_SUBTYPE MAT_MISMATCH_WEIGHT_CRM CRM_VALUE HAIRCUT_CRM HAIRCUT_FX;
    run;
    
    /*- get the eligible capital amount-*/
     data fin_rep_data;
        length elig_capital 8.;
        set rd_stage.financial_reporting_data;
        elig_capital=ELIGC_TIER1_AMT+ max(1/3*(ELIGC_TIER1_AMT),ELIGC_TIER2_AMT);
     run;
        
     data _null_;
        set fin_rep_data;
        call symput("TOT_ELIG_CAP",elig_capital);
        where internal_org_rk=&SYSTEM_ORG_RK;
     run;

    %prep_data_for_le_cap_chrg_crd4(dsname=all_exposures_for_prep, cpty_grp_flg = Y, TOT_ELIG_CAP = &TOT_ELIG_CAP)
    %prep_data_for_le_cap_chrg_crd4(dsname=all_exposures_for_prep, cpty_grp_flg = N, TOT_ELIG_CAP = &TOT_ELIG_CAP);
    
    /*- concatenate results from %prep_data_for_le_cap_chrg_crd4 for counterparty groups and individual counterparties -*/
    data all_exp_after_prep;
        set prepped_data_cpty_grp_n prepped_data_cpty_grp_y;
    run;
     

    /* Apply the format to get the factor and multiply the total charge by the factor for each Excposure */
    /* Note that formats were built so that percent eligible capital < 25%, 0% factor is applied*/
    data all_exp_with_le_cap_chrg;
        set all_exp_after_prep;
        if LE_EXCESS_DAYS_NUM <= 10 then 
            LE_FACTOR=put(PCT_OF_ELIGC,MAP_LE_CAP_CHARGE_LEQ_TEN.);
        else 
            LE_FACTOR=put(PCT_OF_ELIGC,MAP_LE_CAP_CHARGE_G_TEN.);

        LE_CAP_CHG = TOT_RISK_CHG * LE_FACTOR;
        
        LE_ID = compress(EXP_ID || CRM_ID);
        keep EXP_ID LE_COUNTERPARTY_RK COUNTERPARTY_GROUP TOT_RISK_CHG LE_FACTOR LE_CAP_CHG LE_EXCESS_DAYS_NUM LE_ID;
    run; 


    proc sort data = all_exp_with_le_cap_chrg;
        by LE_ID;
    run;
%mend get_le_capital_charge_crd4;
