/*****************************************************************************
 * Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME: get_obligor_no.sas
 *
 * PURPOSE: Get number of distinct counterparties in each crossclass cell
 *
 *   USAGE: %get_obligor_no(INSTDS, SUMMARYDS, OUTDS)
 *          INSTDS   : (pos) instvals data set name
 *          SUMMARYDS: (pos) summary data set name
 *          OUTDS    : (pos) output data set name
 *
 *   NOTES: requires predefined CCVARS and CCNVARS.
 *          
 *
 *****************************************************************************/
 

%macro get_obligor_no (INSTDS, SUMMARYDS, OUTDS);

    /*- some local variables -*/
    %local ICCVAR WCLAUSE RENOPT;
    %let WCLAUSE = ;
    %let RENOPT = ;

    %print_msg(note,2,122);

    /*- loop over crossclass vars: generate condition clause -*/
    %do ICCVAR = 1 %to &CCNVAR;

        /*- get current crossclass var -*/
        %local CCVAR&ICCVAR;
        %let CCVAR&ICCVAR = %scan(&CCVARS, &ICCVAR);

        /*- need delimiter -*/
        %if &ICCVAR NE 1 %then %do;
            %let WCLAUSE = &WCLAUSE &;
        %end;
 
        %let RENOPT = &RENOPT &&CCVAR&ICCVAR %str(=) b_&&CCVAR&ICCVAR;

        /*- totals for char and num are different -*/
        %if %attrv(&SUMMARYDS, &&CCVAR&ICCVAR, VARTYPE) = C %then
            %let WCLAUSE = &WCLAUSE (&&CCVAR&ICCVAR=b_&&CCVAR&ICCVAR | &&CCVAR&ICCVAR = '+');
        %else
            %let WCLAUSE = &WCLAUSE (&&CCVAR&ICCVAR=b_&&CCVAR&ICCVAR | &&CCVAR&ICCVAR = ._);   

    %end;

    /*- subset the data for performance -*/
    data _all_cpty_;
    set &INSTDS(keep=&CCVARS COUNTERPARTY_RK);
    run;

    data _all_ccs_;
    set &SUMMARYDS(keep=&CCVARS);
    run;

   /* from _all_ccs_ dataset remove the redundunt rows which will not be required in reporting */
    %do delCCVAR = 1 %to &CCNVAR;
         %local CCVAR&delCCVAR;
        %let CCVAR&delCCVAR = %scan(&CCVARS, &delCCVAR);
        %put &&CCVAR&delCCVAR ;
	  %end;
    data _all_ccs_;
    set _all_ccs_;
       %do del_class = 1 %to &CCNVAR;
		 			if missing(&&CCVAR&del_class) then delete;;
			 %end;
	  run;
	
    proc sort data=_all_cpty_ nodupkey threads ; by COUNTERPARTY_RK &ccvars ;run;
    proc sort data=_all_ccs_ threads        ; by &CCVARS  ;run;

    /*- get distinct COUNTERPARTY_RK per crossclass cell -*/
    data obligornum(drop=b_:);
    set _all_ccs_;

    do obsnum=1 to last;

        set _all_cpty_ (rename=(&RENOPT)) 
        point=obsnum nobs=last;

        if  &WCLAUSE then output;
  
    end;
    run; 
    
    /*- get number of distinct COUNTERPARTY_RK per cross-class cell -*/
    proc sort data=obligornum threads nodup; by &CCVARS COUNTERPARTY_RK; run;

    proc summary data=obligornum missing n nmiss;
    var COUNTERPARTY_RK;
    by &CCVARS;
    output out=work.sum(keep=&CCVARS NOBLIGOR NMISS) N=NOBLIGOR NMISS=NMISS;
    run;

    proc sort data=&summaryds threads;
     by &CCVARS;
    run;


    data &outds;
     merge &summaryds work.sum (rename=(nobligor=outv_obligor_nbr));
    by &CCVARS;
    run;
 
    %print_msg(note,2,123);

%mend get_obligor_no;    
