/*****************************************************************************
 * Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME: get_std_rw_buckets_crd4.sas
 *
 * PURPOSE: Get RW buckets under standardized approach in CRD-IV.
 *
 *   USAGE: %get_std_rw_buckets_crd4;
 * 
 *
 *   NOTES: 
 *
 *
 *****************************************************************************/

%macro get_std_rw_buckets_crd4;

    /*- securitization exposures -*/
    if STD_PRODUCT_CLASS in ('SEC', 'SECURITIZATION') then do;

        if SHORT_TERM_ASSESS_FLG = 1 then
            STD_RW_BUCKET = put(EXT_ISSUE_MAP_RATING, $MAP_STD_RW_BUCKET_SEC_SHORT.);
        else
            STD_RW_BUCKET = put(EXT_ISSUE_MAP_RATING, $MAP_STD_RW_BUCKET_SEC.);

    end;
  
    
    /*- ECAI rated CIUs   -*/
    else if STD_PRODUCT_CLASS = 'CIU' and STD_PRODUCT_SUBCLASS = 'ECAI_RATED' then do;

            STD_RW_BUCKET = put(EXT_ISSUE_MAP_RATING, $MAP_STD_RW_BUCKET_CIU.);
            
    end;

/*-  covered bonds  -*/
    else if STD_PRODUCT_CLASS = 'COVERED_BOND'  then do;

            STD_RW_BUCKET = put(EXT_ISSUE_MAP_RATING, $MAP_STD_RW_BUCKET_COV_BOND.);
            
    end;

    /*- exposures secured by residential property/commercial real estate -*/
    /*- remove this product_class based mapping for mortgage exp, rw based on cpty rw */ 
/*    else if STD_PRODUCT_CLASS in ('MORTGAGE','LEASE_IMM_PROPERTY') then do;

        if STD_PRODUCT_SUBCLASS = 'RESIDENTIAL' then
            STD_RW_BUCKET = put(REGULATORY_PRODUCT_CD, $MAP_STD_RW_BUCKET_RME.);
        else if STD_PRODUCT_SUBCLASS = 'COMMERCIAL' then
            STD_RW_BUCKET = put(REGULATORY_PRODUCT_CD, $MAP_STD_RW_BUCKET_CME.);

    end;
*/    
        
    else if STD_PRODUCT_CLASS = 'OTHER_ASSETS' then do;
           
            STD_RW_BUCKET = put(STD_PRODUCT_SUBCLASS, $MAP_STD_RW_BUCKET_OTHERS_ASSETS.);
    end;
                                                                      
   
    else do;
    
        if SHORT_TERM_ASSESS_FLG = 1 then do;
            STD_RW_BUCKET = put(EXT_ISSUE_MAP_RATING, $MAP_STD_RW_BUCKET_SHORT.);
        end;   
        else do;
            select (COUNTERPARTY_CLASS);
                when ('SOVEREIGN')
                    STD_RW_BUCKET = put(EXT_ISSUE_MAP_RATING, $MAP_STD_RW_BUCKET_SOVEREIGN.);
                
                when ('INSTITUTION')
                    STD_RW_BUCKET = put(EXT_ISSUE_MAP_RATING, $MAP_STD_RW_BUCKET_INSTITUTION.);    
                
                when ('CORPORATE')
                    STD_RW_BUCKET = put(EXT_ISSUE_MAP_RATING, $MAP_STD_RW_BUCKET_CORPORATE.);
                
                otherwise
                  
            end;
        end ;

    end;
    
%mend get_std_rw_buckets_crd4;
