/*****************************************************************************
 * Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME: pm_crm_financial_crd4.sas
 *
 * PURPOSE: Method program code for financial collateral.
 *          
 *
 *   USAGE: %pm_crm_financial_crd4;
 *
 *   NOTES: 
 *          
 *
 *****************************************************************************/

%macro pm_crm_financial_crd4;

    %initialize_regulatory_outvars;
                                 
    OUTV_RW_ISSUE = 0;
    
    OUTV_LGD_CRM_SEN = 0;
    OUTV_LGD_CRM_SUB = 0;
    /*- CRR Article 232(2b) -*/ 
    if CRM_TYPE= 'FINANCIAL_COLLATERAL' and CRM_SUBTYPE = 'LIFE_INSURANCE' and LGD_PCT eq .  then do ;
       OUTV_LGD_CRM_SEN = 40;
       OUTV_LGD_CRM_SUB = 40;
    end ;
    

/*- for financial collateral eligible for simple approach, need RW based on issue RW bucket -*/
/*   RW of CRM based on CRR Article 222(3) */
    if "&STD_CRM_APPROACH" = "SIMPLE" and ELIGIBLE_CRM_TYPE = 'FINANCIAL_SIMPLE' then do;  
       /*if EXT_ISSUE_MAP_RATING NE 'MISS' and STD_RW_BUCKET NE '_#_' then do;*/
       if STD_PRODUCT_SUBCLASS in ('CASH','GOLD') then do ;
          %pm_exp_other_assets_std;
       end ; 
       
       else if STD_PRODUCT_CLASS eq 'CIU' then do ;
          %pm_exp_ciu_std_crd4;
       end ;
       
       else if STD_PRODUCT_CLASS eq 'COVERED_BOND' then do ;
               %pm_exp_cov_bond_std_crd4;
       end ;
       
       /*- risk weight for life insurance policy pledged: Article 232(3) of CRR -*/
       else if CRM_TYPE = 'FINANCIAL_COLLATERAL' and CRM_SUBTYPE = 'LIFE_INSURANCE' then do ;
               %calc_std_rw_life_ins_crd4;
       end ;
       
       
       else do;

        /*- General cases of CRM rw calculations. Special cases of CRM RWs are done in prepare_crm_allocation_crd4.sas file -*/
            select (COUNTERPARTY_CLASS);
                
                when ('INSTITUTION') do;
                   %calc_std_rw_inst_crd4;                
                end;
     
                when ('CORPORATE') do;
                   %pm_exp_corporate_std_crd4;
                end;
    
                when ('SOVEREIGN') do;
                  if COUNTERPARTY_SUBCLASS in ('CENTRAL_GOV','CENTRAL_BANK') then do ;
                     %calc_std_rw_centgov_crd4;
                  end ;
                  
                  if COUNTERPARTY_SUBCLASS in ('REGIONAL_GOV','LOCAL_GOV','RELIGIOUS_ORG') then do ;
                     %calc_std_rw_reggov_crd4;   
                  end;
                  
                  if COUNTERPARTY_SUBCLASS in ('PSE') then do ;
                     %pm_exp_pse_std_crd4;
                  end;
                  
                  if COUNTERPARTY_SUBCLASS in ('MDB') then do ;
                     %pm_exp_mdb_std_crd4;
                  end ;
                  
                  if COUNTERPARTY_SUBCLASS in ('INT_ORG') then do ;
                     %pm_exp_int_org_std_crd4;
                  end ;                                  
                end ;
                
                otherwise;    
                
            end;    
        end;
    end ;   
       
    else do ;
        OUTV_RW_ISSUE = .;
    end ;
   
    _VALUE_ = CRM_VALUE ;
    
%mend pm_crm_financial_crd4;
