/*****************************************************************************
 * Copyright (c) 2013 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME: pm_exp_ccr_ccp_crd4.sas
 *
 * PURPOSE: Method code to get risk weight for trade exposures to CCPs
 *          
 *
 *   USAGE: %pm_exp_ccr_ccp_crd4;
 *
 *   NOTES: Created 7/11/2013 for CRD-IV.  
 *          Modified 12/20/2013 to include both QCCP and NQCCP treatments.          
 *
 *****************************************************************************/

%macro pm_exp_ccr_ccp_crd4;

/*- initialize outvars -*/
    %initialize_regulatory_outvars;
    
/*- by default, get the RW associated with the counterparty -*/
    OUTV_RW_COUNTERPARTY = STD_RW_CPTY;    

/*- Clients' risk weight treatment for CCP related exposures:                       -*/
/*- CRR article 305(2) and (3) apply to risk weight treatment for qualifying CCP    -*/
/*- only.  Risk weight treatment for non-qualifying CCP would not be triggered.     -*/
/*- If conditions in CRR article 305(2) and (3) are not satisfied, then risk weight -*/
/*- of trade exposures of a client are treated as exposures to its clearing member. -*/
    
    if  NO_LOSS_FROM_CM_BANKRUPTCY_FLG = 1 then 
 
        OUTV_RW_ISSUE = &CCR_QCCP_RW_DEFAULT;            
        
    else if NO_LOSS_FROM_CM_BANKRUPTCY_FLG ne 1 then 

        OUTV_RW_ISSUE = &CCR_QCCP_RW_CLIENT;
        
    if STD_PRODUCT_CLASS = 'REPO_STYLE' and APPROACH = 'STD' then 
        OUTV_RW_COUNTERPARTY =  OUTV_RW_ISSUE ;
    
    _VALUE_ = EXP_VALUE ;
    
%mend pm_exp_ccr_ccp_crd4;
