/*****************************************************************************
 * Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME: pm_exp_pse_std_crd4.sas
 *
 * PURPOSE: Method program code for exposures to PSEs under STD approach. 
 *          
 *
 *   USAGE: %pm_exp_pse_std_crd4;
 *
 *  
 *          
 *   NOTES: 
 *   4/11/2013: Created for crd4    
 *          
 *****************************************************************************/
/*- RW for PSEs under STD approach: CRR Article 116   -*/
%macro pm_exp_pse_std_crd4;

    /*- initialize outvars -*/
    %initialize_regulatory_outvars;

    /*- by default, get the RW associated with the counterparty -*/
    OUTV_RW_COUNTERPARTY = STD_RW_CPTY;
    
    /*Get RW for short-term exposures */    
     if SHORT_TERM_ORIG_FLG = 1 then do ;

            OUTV_RW_COUNTERPARTY = STD_RW_INST_SHORT ;
            OUTV_RW_ISSUE = STD_RW_INST_SHORT ;  
     end;
     
    /*- Get RW based on issue rating, if it exists. */
     else if   STD_RW_BUCKET not in('_#_','') and EXT_ISSUE_MAP_RATING NE 'MISS' then do;

        if CENTGOV_TREAT_FLG eq 1 then do;
           %calc_std_rw_centgov_crd4;
        end;
        
        else if STD_REGGOV_TREAT_FLG eq 1 then do;
           %calc_std_rw_reggov_crd4;
        end;

        else do;
           %calc_std_rw_inst_crd4; 
           /*- Short-term treatment of risk weight occurs when the short_term_residual_flg is turned on.  -*/
           /*- This flag only applies to institutional exposures. Thus short-term risk weights based on   -*/
           /*- CRR Article 120(2) and (3) would not be applied to pse.                                           -*/ 
              
        end; 
     end ;  
    
   /*- Get RW based on counterparty rating if issue rating does not exist:                                          -*/
   /*- If issue rating does not exist, but counterparty rating exists, use couterparty rating for rw.               -*/
   /*- If counterparty rating is also missing,use the couterparty's central gov's rating for rw: CRR Article 116(1) -*/
     else if  STD_RW_BUCKET in ('_#_','') or EXT_ISSUE_MAP_RATING eq 'MISS' then do ;                  
              OUTV_RW_ISSUE = OUTV_RW_COUNTERPARTY ;
              
              if CPTY_RW_FROM_CENTGOV_FLG = 1 then OUTV_RW_FROM_CENTGOV_FLG = 1 ;

              if  STD_REGGOV_TREAT_FLG = 1 and EEA_MEMBER_FLG eq 'YES' and (index(trim(CPTY_COUNTRY_CURRENCY), trim(CCY))) > 0 then 
                 OUTV_RW_ISSUE = STD_RW_REGGOV_EEA_DOM ; 
                  
     end ;     
    
    
    _VALUE_ = EXP_VALUE ;

%mend pm_exp_pse_std_crd4;
