
 /* Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME: r00_post_mitigation_0_crd4.sas
 *
 * PURPOSE: Postprocessing results from mitigantion by rank and the 
 *          aggregated results 
 *
 *
 *   USAGE: 
 *
 *   NOTES:  
 *
 * UPDATES: 
 *      1)   Under BY_RANK method, create empty 'ALLMITIGATION' dataset when this dataset is not present. 
 * 2)   Under BY_RANK method, update tables as per actual haircut exposures 
 *                                stored in 'exposure_crm' link table
 *          
 *****************************************************************************/
 option notes;

%macro r00_post_mitigation_0_crd4;

    %if %dsexist(&RESLIB1..allmitigation) = 0  %then %do;

    /** Create &RESLIB1..allmitigation **/
        data &RESLIB1..allmitigation;
         attrib ADJEXPOSURE length = 8;
         attrib OUTV_EAD_ADJ LENTH = 8 ; 
         attrib EXPOSURE length = 8;
         attrib EXPOSUREID length = $15.;
         attrib LGD_WEIGHTED_SUM length = 8;
         attrib MITIGANTID length = $15.;
         attrib MITIGANT_ADJVAL length = 8;
         attrib MITIGANT_VAL length = 8;
         attrib OUTV_CAPITAL_NO_CRM length = 8;
         attrib OUTV_CRM_USED_AMT length = 8;
         attrib OUTV_CRM_USED_AMT_EFF length = 8;
         attrib OUTV_EAD length = 8;
         attrib OUTV_EL_AMT length = 8;
         attrib OUTV_EXPOSURE_PROVISION length = 8;
         attrib OUTV_LGD length = 8;
         attrib OUTV_MIT_RWA length = 8;
         attrib OUTV_MIT_USED_AMT length = 8;
         attrib OUTV_MIT_USED_AMT_EFF length = 8;
         attrib OUTV_PD length = 8;
         attrib OUTV_RWA_NO_CRM length = 8;
         attrib OUTV_RWA_SECURED length = 8;
         attrib OUTV_RWA_UNSECURED length = 8;
         attrib OUTV_VALUE length = 8;
         attrib PD_WEIGHTED_SUM length = 8;
         stop;
      run;
   %end;
/*******************************************/
/*- 1: post-process CRM_ALLOCATION -*/
    data allmitigation
         (index=(EXPCRM=(EXP_ID CRM_ID) EXPCRMUSED=(EXP_ID OUTV_CRM_USED_AMT_EFF)));
    length EXP_ID CRM_ID $32.;
    set &RESLIB1..allmitigation(rename=(EXPOSUREID=EXP_ID MITIGANTID=CRM_ID));
    run;
    
    proc sql;
    create table covered as 
    select a.OUTV_MIT_USED_AMT as CRM_USED_AMT,
           a.OUTV_MIT_USED_AMT_EFF as CRM_USED_AMT_EFF,
           a.OUTV_MIT_RWA as RWA,
           a.OUTV_MIT_USED_AMT_EFF as EAD_PORTION,
           b.*
    from allmitigation as a
    inner join "&REGPATH&PATHSEP.exposure_crm" as b
    on (a.EXP_ID=b.EXP_ID and a.CRM_ID=b.CRM_ID);
    quit;

    data after_crm(rename=(OUTV_RWA_NO_CRM=RWA_NO_CRM OUTV_RWA_SECURED=RWA_SECURED
                           OUTV_RWA_UNSECURED=RWA_UNSECURED OUTV_CRM_USED_AMT=CRM_USED_AMT
                           OUTV_CRM_USED_AMT_EFF=CRM_USED_AMT_EFF OUTV_EXPOSURE_PROVISION=EXPOSURE_PROVISION
                           PD_WEIGHTED_SUM=PD_WEIGHTED_SUM LGD_WEIGHTED_SUM=LGD_WEIGHTED_SUM
                           OUTV_EAD_ADJ=EAD_PORTION)); 
    set allmitigation;
    by EXP_ID OUTV_CRM_USED_AMT_EFF;
    if last.EXP_ID then output;
    run;
  
/* add uncovered or uncovered portions of exposure */
    data allpricebase (keep=INSTID VALUE OUTV_EAD OUTV_RWA_NO_CRM OUTV_RWA_SECURED OUTV_RWA_UNSECURED
                            OUTV_CRM_USED_AMT OUTV_CRM_USED_AMT_EFF PD_WEIGHTED_SUM LGD_WEIGHTED_SUM
                            EAD_PORTION
                       rename=(INSTID=EXP_ID OUTV_RWA_NO_CRM=RWA_NO_CRM
                               OUTV_RWA_SECURED=RWA_SECURED OUTV_RWA_UNSECURED=RWA_UNSECURED
                               OUTV_CRM_USED_AMT=CRM_USED_AMT OUTV_CRM_USED_AMT_EFF=CRM_USED_AMT_EFF
                              )
                       index=(EXP_ID)
                      );
    length INSTID $32.;
    merge &RESLIB1..allprice_v(where=(STATENUMBER=0)) &RESLIB1..allprice_p;
    by INSTNUMBER;
    EAD_PORTION=VALUE;
    run;


    /* allexposures will contain exposure level results after mitigation */
    data allexposures;
    merge allpricebase (in = a)
          after_crm ;
    by EXP_ID;
    if a;
    run;  
    
    data notcovered;
    merge allexposures(in=a keep=EXP_ID RWA_UNSECURED EAD_PORTION rename=(RWA_UNSECURED=RWA))  
          "&REGPATH&PATHSEP.all_exp_incl_sec_underly"(in=b) 
          "&REGPATH&PATHSEP.exposure_crm_uniq_exp"(in=c keep=EXP_ID MAT_MISMATCH_WEIGHT_SEC MAT_MISMATCH_WEIGHT_SEC_UNDERLY CRM_COMP_FLG) ;
                                               
    by EXP_ID;
    if a and b;
    
    CRM_USED_AMT = 0;
    CRM_USED_AMT_EFF = 0;
    run;
    
/*- create dataset that contains results for crm allocation by rank details:  -*/
/*- exposures include underlying exposures for a securitization pool          -*/  
/*- and securitization tranches not owned by the reporting institution        -*/ 
    data &RESLIB1..crm_allocation_by_rank_detail;              
       set covered notcovered ;
       by EXP_ID;
       UNDERLYING_EXP_EAD = 0;
     
/*- adjustment to RWA for SME exposures subject to SME supporting factor: CRR Article 501 -*/ 
       RWA_PRE_SME = RWA ;
       if not (IN_DEFAULT_FLG =1 or PAST_DUE_CLAIM_FLG =1) and not (HIGH_RISK_CPTY_FLG=1 or STD_PRODUCT_CLASS ='HIGH_RISK') 
            and COUNTERPARTY_CLASS in ('RETAIL','CORPORATE') and COUNTERPARTY_SUBCLASS ='SME'
            and SME_CAP_DEDUCTION_TRT_FLG = 1 then do ;                    
            RWA = &SME_SUPPORTING_FACTOR * RWA ;
       end ; 
    
   /*- calculate effect of infringement adjustment for securitization positions-*/ 
   /*- RWA variable already contains the effect of infringement at this point, so 
    only calculate the pre-infringement adjustment -*/
       if SEC_INFRINGEMENT_FLG = 1 then do;     
           RWA_SEC_ORIG = RW_EXP_BEFORE_INFRINGEMENT/100 * EAD_PORTION;
       end;
       else do;   
           RWA_SEC_ORIG = RWA;
       end;

       SEC_INFRINGE_ADJUST_AMT = sum(RWA, -RWA_SEC_ORIG);      
    run;

/*- get total RWA for all underlying exposures linked to a SECURITIZATION_POOL_RK -*/

  /*- create dataset for underlying exposures in a securitization pool -*/   
    data &RESLIB1..sec_underlying_by_rank_detail;
    set &RESLIB1..crm_allocation_by_rank_detail ;
        if IN_DEFAULT_FLG = 1 or PAST_DUE_CLAIM_FLG =1 then 
            RWA_UND_FOR_CAP_CALC = EAD_PORTION * 1.5; 
        else
            RWA_UND_FOR_CAP_CALC = RWA;
        if SEC_UNDERLYING_EXP_FLG = 1; 
    run;

    proc sort data= &RESLIB1..sec_underlying_by_rank_detail;
       by SECURITIZATION_POOL_RK ;
    run;

  /*- get total EAD and RWA for all underlying expousures in a a securitization pool -*/
    proc summary data=&RESLIB1..sec_underlying_by_rank_detail;
       by SECURITIZATION_POOL_RK;
       var EAD RWA RWA_UND_FOR_CAP_CALC;
       output out= &RESLIB1..rwa_sec_underlying(keep=SECURITIZATION_POOL_RK EAD_SEC_UNDERLYING_SUM RWA_SEC_UNDERLYING_SUM RWA_SEC_UNDERLYING_SUM_FOR_CAP)  
              sum = EAD_SEC_UNDERLYING_SUM RWA_SEC_UNDERLYING_SUM RWA_SEC_UNDERLYING_SUM_FOR_CAP;          
    run;  
    
  /*- exclude sec underlying exposures -*/
   proc sql ;
         delete from &RESLIB1..crm_allocation_by_rank_detail 
         where SEC_UNDERLYING_EXP_FLG = 1 ;
   quit ;
   
    proc sort data= &RESLIB1..crm_allocation_by_rank_detail ;
       by SECURITIZATION_POOL_RK ;
    run;

/*- add total EAD and RWA for sec underlying exposures to crm_allocation_by_rank_detail table -*/
    data &RESLIB1..crm_allocation_by_rank_detail ;     
       merge &RESLIB1..crm_allocation_by_rank_detail &RESLIB1..rwa_sec_underlying;
       by SECURITIZATION_POOL_RK;
    run ;   
  
    data all_sec_tranches 
         all_sec_facility 
         all_sec_deriv;
      set &RESLIB1..crm_allocation_by_rank_detail  
          (keep = EXP_ID SECURITIZATION_POOL_RK TRANCHE_SENIORITY_RANK SECURITIZATION_EXPOSURE_FLG
                  FACILITY_FLG STD_PRODUCT_CLASS IRB_PRODUCT_CLASS
                  TRANCHE_FACE_VALUE_AMT FACE_VALUE_AMT EXP_VALUE RWA ) ;      
      if SECURITIZATION_EXPOSURE_FLG =1 and SECURITIZATION_POOL_RK ne . and TRANCHE_SENIORITY_RANK ne . then output all_sec_tranches ;
      else if SECURITIZATION_EXPOSURE_FLG =1 and SECURITIZATION_POOL_RK ne . and FACILITY_FLG =1 then output all_sec_facility ;
      else if SECURITIZATION_EXPOSURE_FLG =1 and SECURITIZATION_POOL_RK ne . and 
              (STD_PRODUCT_CLASS = 'DERIVATIVE' or IRB_PRODUCT_CLASS = 'DERIVATIVE') then output all_sec_deriv ;
    run;
 
 /*- get RWA for all securitization tranche exposures linked to a securitization_pool_rk, -*/
 /*- regardless if they are owned by the reporting institution.                           -*/
 /*- RWA_ALL_TRANCHES is used for cap calculation for securitizations with EAP.           -*/  
    proc summary data = all_sec_tranches;
           by SECURITIZATION_POOL_RK;
           var RWA ;
           output out= rwa_sec_all_tranches(keep=SECURITIZATION_POOL_RK RWA_ALL_TRANCHES )  
                 sum = RWA_ALL_TRANCHES;  
    run;
   
/*- get SEC_TOTAL_AMT_ORIGINATED: first column of CRSEC SA and CRSEC IRB report templates -*/
    %calc_sec_tot_amt_orig_crd4 ;
      
/*- exclude securitization exposures that are not owned by the reporting institution -*/
   proc sql ;
      delete from &RESLIB1..crm_allocation_by_rank_detail 
      where EXP_NOT_OWNED_FLG = 1 ;
   quit ;
    
/*- get total RWAs for securitization exposures owned by the institution.                                                -*/
/*- for each SECURITIZATION_POOL_RK, RWA_SEC_SUM is the total RWA of securitization exposures owned by the institution,  -*/
/*- and RWA_TRANCHE_SUM is the the total RWA of securitization tranche exposures owned by the institution.               -*/
    data sec_exposures;
        set &RESLIB1..crm_allocation_by_rank_detail;
        if SECURITIZATION_POOL_RK ne . and SECURITIZATION_EXPOSURE_FLG =1 and STD_PRODUCT_SUBCLASS not in ('EAP_INVESTORS_INT', 'DEDUCTION', 'EAP_ORIGINATOR_INT') and
          IRB_PRODUCT_SUBCLASS not in ('EAP_INVESTORS_INT', 'DEDUCTION', 'EAP_ORIGINATOR_INT') ;
        
        if not (TRANCHE_SENIORITY_RANK = . and TRANCHE_LOSS_RANK = . ) then RWA_TRANCHE = RWA;
        else RWA_TRANCHE = 0;  
    run;
    
    proc summary data = sec_exposures;
        by SECURITIZATION_POOL_RK;
        var RWA RWA_TRANCHE;
        output out= sec_tranche_sum(keep=SECURITIZATION_POOL_RK RWA_SEC_SUM RWA_TRANCHE_SUM )  
              sum = RWA_SEC_SUM RWA_TRANCHE_SUM;  
    run;
     
    data &RESLIB1..crm_allocation_by_rank_detail ;     
       merge &RESLIB1..crm_allocation_by_rank_detail 
             sec_tranche_sum 
             rwa_sec_all_tranches 
             sec_tot_amt_orig ; 
       by SECURITIZATION_POOL_RK;
    run;
    
 /*- sort dataset by EXP_ID again */   
    proc sort data= &RESLIB1..crm_allocation_by_rank_detail ;
       by EXP_ID ;
    run ;

/*- get sum of EAD_PORTION for each EXP_ID  -*/  
    proc sql ;
         create table tot_ead_portion as
         select EXP_ID,  sum(EAD_PORTION) as EAD_PORTION_SUM
         from &RESLIB1..crm_allocation_by_rank_detail
         where SECURITIZATION_EXPOSURE_FLG = 1 
         group by EXP_ID ;
    quit ;
    
/*- process RWA adjustments for securitization exposures  -*/    
    data &RESLIB1..crm_allocation_by_rank_detail
         "&OUTPATH.&PATHSEP.crm_allocation_by_rank"
            (label="CRM Allocation by Rank Information"
             keep = /*- brief exposure information -*/
                    EXP_ID COUNTERPARTY_CLASS COUNTERPARTY_SUBCLASS STD_PRODUCT_: IRB_PRODUCT_: APPROACH CCY 
                    REGULATORY_COUNTERPARTY_TYPE_CD REGULATORY_PRODUCT_CD OFF_BALANCE_SHEET_TYPE_CD 
                    TRADING_BOOK_FLG TRADE_EXP_FLG BANKRUPTCY_REMOTE_FLG ASSET_TRANSFERRABLE_FLG NO_LOSS_FROM_CM_BANKRUPTCY_FLG CCP_CPTY_SUBCLASS
                    INCEPTION_DATE MATURITY_DATE EXP_VALUE EAD HAIRCUT_EXP PD_EXP LGD_EXP RW_EXP RW_EXP_BEFORE_INFRINGEMENT RESMAT_EXP 
                    ORIGINAL_MATURITY RESIDUAL_MATURITY EXT_MAP_RATING EXT_ISSUE_MAP_RATING EXT_ISSUE_INCEP_MAP_RATING PAST_DUE_CLAIM_FLG IN_DEFAULT_FLG 
                    CCF HAIRCUT_FX STD_RW_FROM_ECAI_FLG STD_RW_FROM_CENTGOV_FLG CENTGOV_TRT_FLG
                    SME_SUPPORTING_FACTOR_FLG SME_CAP_DEDUCTION_TRT_FLG FREE_DELIVERY_FLG
                    LE_PRODUCT_CLASS LE_OBSI_TYPE COUNTERPARTY_RK 
                    COUNTERPARTY_NAME COUNTERPARTY_TYPE_CD COUNTERPARTY_GROUP
                    COUNTERPARTY_GROUP_PARENT_FLG COUNTERPARTY_SECTOR 
                    COUNTERPARTY_COUNTRY NACE LEGAL_ENTITY_ID CONNECTION_TYPE_CD FINANCIAL_ENTITY_TYPE_CD COUNTERPARTY_CD
                    SEC_INFRINGE_ADJUST_AMT SEC_INFRINGEMENT_FLG SEC_DEDUCTION_AMT SEC_TOTAL_AMT_ORIGINATED BUSINESS_TYPE_CD
                    /*- brief crm information -*/
                    CRM_ID CRM_COUNTERPARTY_CLASS CRM_COUNTERPARTY_SUBCLASS CRM_TYPE CRM_SUBTYPE ELIGIBLE_CRM_TYPE CRM_CCY
                    CRM_EFFECTIVE_DATE CRM_EXPIRATION_DATE CRM_INCEPTION_DATE CRM_MATURITY_DATE CRM_VALUE_DISCOUNT_FLG
                    CRM_VALUE HAIRCUT_CRM PD_CRM LGD_CRM RW_CRM RW_CRM_COUNTERPARTY RESMAT_CRM 
                    CRM_ORIGINAL_MATURITY CRM_RESIDUAL_MATURITY LINK_RESIDUAL_MATURITY 
                    CRM_COUNTERPARTY_RK CRM_COUNTERPARTY_NAME CRM_COUNTERPARTY_TYPE_CD CRM_COUNTERPARTY_GROUP
                    CRM_CPTY_GROUP_PARENT_FLG CRM_COUNTERPARTY_SECTOR CRM_COUNTERPARTY_COUNTRY CRM_NACE CRM_LEGAL_ENTITY_ID
                    CRM_CONNECTION_TYPE_CD CRM_FINANCIAL_ENTITY_TYPE_CD CRM_COUNTERPARTY_CD
                    /*- brief crm allocation information -*/
                    MAT_MISMATCH_WEIGHT_CRM _WEIGHT_ _MULT_ CRM_USED_AMT CRM_USED_AMT_EFF 
                    RWA RWA_PRE_SME RWA_SEC_ORIG RWA_SEC_MAT_MIS_ADJ_AMT RWA_BEFORE_CAP RWA_SEC_MEMO_AMT
                    
                    /* exposure to underlyings for LE report */
                    UNDERLYING_EXP_EAD

                 CORRELATION_TRADING_PORT_FLG  
              );
        merge  &RESLIB1..crm_allocation_by_rank_detail 
               tot_ead_portion ;
        by EXP_ID ;  ;  
 
 /*- Calculate RWA adjustments for securitization exposures: CRR articles 249, 250, 252, 256-*/
      %calc_sec_rwa_adj_amt_crd4(calc_option=CRM_ALLOCATION) ;
   
    run;
 
 /*- for CRSA report, adjuments to exposures secured by imm. properties: EXP_VALUE_IMP_ADJ, RW_EXP_IMP_ADJ            -*/       
 /*- SPECIFIC_PROVISION_IMP_ADJ and SPECIFIC_WRITEOFF_IMP_ADJ are created to get CRSA report template columns 010-040 -*/ 
%get_rw_adj_immprpty_crd4(crmalloc=by_rank) ;

/**************************************************
   update crm_allocation_by_rank table with columns
   needed for Large Exposure report
**************************************************/
    
    data "&OUTPATH.&PATHSEP.crm_allocation_by_rank";
    set "&OUTPATH.&PATHSEP.crm_allocation_by_rank";
        /*- add variables for LE report  -*/
          if LE_OBSI_TYPE NE '' THEN LE_PRODUCT_CLASS = ''; 
          
          if CRM_ID = '' then do;
            LE_COUNTERPARTY_RK = COUNTERPARTY_RK;
            DIRECT_EXP_FLG = 'Y';  
            if LE_PRODUCT_CLASS = 'DERIVATIVE' then do;
                LE_ORIG_EXPOSURE_AMT = EAD;   
            end;
            else do;
                LE_ORIG_EXPOSURE_AMT = EXP_VALUE;              
            end;   
        end;
        else do;
            LE_COUNTERPARTY_RK = CRM_COUNTERPARTY_RK;
            COUNTERPARTY_NAME = CRM_COUNTERPARTY_NAME;
            COUNTERPARTY_COUNTRY = CRM_COUNTERPARTY_COUNTRY;
            COUNTERPARTY_TYPE_CD = CRM_COUNTERPARTY_TYPE_CD;
            COUNTERPARTY_GROUP = CRM_COUNTERPARTY_GROUP;
            COUNTERPARTY_GROUP_PARENT_FLG = CRM_CPTY_GROUP_PARENT_FLG;
            COUNTERPARTY_SECTOR = CRM_COUNTERPARTY_SECTOR; 
            NACE = CRM_NACE;
            LEGAL_ENTITY_ID = CRM_LEGAL_ENTITY_ID;
            
            CONNECTION_TYPE_CD = CRM_CONNECTION_TYPE_CD; 
            FINANCIAL_ENTITY_TYPE_CD = CRM_FINANCIAL_ENTITY_TYPE_CD; 
            COUNTERPARTY_CD = CRM_COUNTERPARTY_CD; 
            
            DIRECT_EXP_FLG = 'N';
            LE_ORIG_EXPOSURE_AMT = CRM_USED_AMT_EFF;

        end;
        if COUNTERPARTY_GROUP_PARENT_FLG = . then COUNTERPARTY_GROUP_PARENT_FLG = 0; 
        
        drop COUNTERPARTY_RK CRM_COUNTERPARTY_RK CRM_COUNTERPARTY_RK CRM_COUNTERPARTY_NAME 
        CRM_COUNTERPARTY_TYPE_CD CRM_COUNTERPARTY_GROUP
                CRM_CPTY_GROUP_PARENT_FLG CRM_COUNTERPARTY_SECTOR CRM_COUNTERPARTY_COUNTRY CRM_NACE CRM_LEGAL_ENTITY_ID; 
    run;    

    data &RESLIB1..crm_allocation_by_rank_detail;
    set &RESLIB1..crm_allocation_by_rank_detail;
        /*- add variables for LE report  -*/
          if LE_OBSI_TYPE NE '' THEN LE_PRODUCT_CLASS = ''; 

        if CRM_ID = '' then do; /*direct exposure */
            LE_COUNTERPARTY_RK = COUNTERPARTY_RK;
            DIRECT_EXP_FLG = 'Y';  
            if LE_PRODUCT_CLASS = 'DERIVATIVE' then do;
                LE_ORIG_EXPOSURE_AMT = EAD;   
            end;
            else do;
                LE_ORIG_EXPOSURE_AMT = EXP_VALUE;              
            end;   
        end;
        else do; /* indirect exposure */
            LE_COUNTERPARTY_RK = CRM_COUNTERPARTY_RK;
            COUNTERPARTY_NAME = CRM_COUNTERPARTY_NAME;
            COUNTERPARTY_COUNTRY = CRM_COUNTERPARTY_COUNTRY;
            COUNTERPARTY_TYPE_CD = CRM_COUNTERPARTY_TYPE_CD;
            COUNTERPARTY_GROUP = CRM_COUNTERPARTY_GROUP;
            COUNTERPARTY_GROUP_PARENT_FLG = CRM_CPTY_GROUP_PARENT_FLG;
            COUNTERPARTY_SECTOR = CRM_COUNTERPARTY_SECTOR; 
            NACE = CRM_NACE;
            LEGAL_ENTITY_ID = CRM_LEGAL_ENTITY_ID;
            CONNECTION_TYPE_CD = CRM_CONNECTION_TYPE_CD; 
            FINANCIAL_ENTITY_TYPE_CD = CRM_FINANCIAL_ENTITY_TYPE_CD; 
            COUNTERPARTY_CD = CRM_COUNTERPARTY_CD; 
            
            DIRECT_EXP_FLG = 'N';
            LE_ORIG_EXPOSURE_AMT = CRM_USED_AMT_EFF;

        end;
        if COUNTERPARTY_GROUP_PARENT_FLG = . then COUNTERPARTY_GROUP_PARENT_FLG = 0; 
    run; 
/**************************************************   
 **************************************************/ 
 
/*- Add total RWA of underlying securitization pool for securitization positions to "&REGPATH&PATHSEP.all_exposures" table -*/
/*- Add total RWAs of securitization exposures owned by the reporting institution to "&REGPATH&PATHSEP.all_exposures" table -*/
    proc sort data ="&REGPATH&PATHSEP.all_exposures";
       by SECURITIZATION_POOL_RK;
    run;
  
    data "&REGPATH&PATHSEP.all_exposures";
       merge "&REGPATH&PATHSEP.all_exposures"
              &RESLIB1..rwa_sec_underlying
              rwa_sec_all_tranches
              sec_tranche_sum
              sec_tot_amt_orig
              ;
       by SECURITIZATION_POOL_RK;
    run;
 
    proc sort data = "&REGPATH&PATHSEP.all_exposures";
       by EXP_ID;
    run;
    
 /*- create capital detail_by_rank table to contain capital requirement results on exposure level                          -*/
 /*- underlying exposures for sec pool and securitization tranches not owned  have been excluded from all_exposures table  -*/
    data "&OUTPATH.&PATHSEP.capital_detail_by_rank" (label="Capital Requirement for all Exposures (by Rank)"
          drop=VALUE PD_WEIGHTED_SUM LGD_WEIGHTED_SUM MAT_MISMATCH_WEIGHT_SEC MAT_MISMATCH_WEIGHT_SEC_UNDERLY
               EAD_SEC_UNDERLYING_SUM RWA_SEC_UNDERLYING_SUM PRO_RATA TOTAL_REVOLVING INVESTORS_INTEREST_PCT
               AVG_RISK_WEIGHT RWA_SEC_UNDERLYING_SUM_FOR_CAP RWA_ALL_TRANCHES RWA_SEC_SUM RWA_TRANCHE_SUM
               );
       merge allexposures 
          (in=a 
           keep=EXP_ID VALUE PD_WEIGHTED_SUM LGD_WEIGHTED_SUM
                RWA_NO_CRM RWA_SECURED RWA_UNSECURED CRM_USED_AMT CRM_USED_AMT_EFF EAD_PORTION
          )           
          "&REGPATH&PATHSEP.all_exposures" 
          (in=b 
           keep=EXP_ID COUNTERPARTY_CLASS COUNTERPARTY_SUBCLASS APPROACH EXP_VALUE
                EAD HAIRCUT_EXP ADD_ON CCF LGD_EXP PD_EXP SPECIFIC_PROVISION
                EL EXPECTED_LOSS_PERCENT RW_EXP CCY COUNTERPARTY_COUNTRY COUNTERPARTY_RK CPTY_PD_MODEL_ID
                CPTY_PD_RATING_GRADE EARLY_AMORTIZATION_TYPE EXPECTED_LOSS_PERCENT EXT_ISSUE_MAP_RATING EXT_ISSUE_INCEP_MAP_RATING
                EXT_MAP_RATING INCEPTION_DATE IRB_PRODUCT_CLASS IRB_PRODUCT_SUBCLASS MATURITY_DATE
                MAT_EFF ORIGINAL_MATURITY OFF_BALANCE_SHEET_TYPE_CD 
                TRADING_BOOK_FLG TRADE_EXP_FLG BANKRUPTCY_REMOTE_FLG ASSET_TRANSFERRABLE_FLG NO_LOSS_FROM_CM_BANKRUPTCY_FLG CCP_CPTY_SUBCLASS
                PAST_DUE_CLAIM_FLG IN_DEFAULT_FLG 
                REGULATORY_COUNTERPARTY_TYPE_CD REGULATORY_PRODUCT_CD RESIDUAL_MATURITY SECTOR
                STD_PRODUCT_CLASS STD_PRODUCT_SUBCLASS STD_RW_FROM_ECAI_FLG STD_RW_FROM_CENTGOV_FLG
                TRANCHE_FACE_VALUE_AMT TRANCHE_LOSS_RANK TRANCHE_SENIORITY_RANK SEC_STRUCTURE_TYPE SEC_STRUCTURE_SUBTYPE
                SME_SUPPORTING_FACTOR_FLG SME_CAP_DEDUCTION_TRT_FLG FREE_DELIVERY_FLG 
                EAD_SEC_UNDERLYING_SUM RWA_SEC_UNDERLYING_SUM RWA_SEC_UNDERLYING_SUM_FOR_CAP
                RWA_ALL_TRANCHES RWA_SEC_SUM RWA_TRANCHE_SUM SEC_TOTAL_AMT_ORIGINATED RW_EXP_BEFORE_INFRINGEMENT
                POOL_FACE_VALUE_AMT TOTAL_REVOLVING INVESTORS_INTEREST_PCT AVG_RISK_WEIGHT
                SECURITIZATION_EXPOSURE_FLG SEC_UNDERLYING_EXP_FLG
                SECURITIZATION_POOL_ID SECURITIZATION_POOL_RK 
                RESECURITIZATION_FLG PRIMARY_BANK_ROLE 
                EFFECTIVE_NUMBER_OF_EXPOSURES WEIGHTED_AVG_LGD_PCT K_IRB
                SENIORITY_CD SHORTPOSITION
                SEC_ACCTING_TREATMENT SECURITIZATION_TREATMENT_TYPE SEC_RETENTION_TYPE 
                SEC_PORTFOLIO_TYPE SEC_RETENTION_COMPLIANCE_FLG INSTITUTION_SHARE_PCT
                SEC_RETENTION_PCT CORRELATION_TRADING_PORT_FLG SEC_DEDUCTION_AMT
                ORIGINATION_COUNTRY_CD FIRST_POSSIBLE_TERM_DT LONGEST_MATURITY_DATE COUNTERPARTY_ID
          )
          "&REGPATH&PATHSEP.exposure_crm_uniq_exp" 
          (in=c
           keep=EXP_ID CCF EAD MAT_MISMATCH_WEIGHT_SEC MAT_MISMATCH_WEIGHT_SEC_UNDERLY
          ) 
          ;
    by EXP_ID;
    if a and b ;
    
   
    RW_NO_CRM = RW_EXP;       
    RWA = sum(RWA_SECURED, RWA_UNSECURED);
 
 /*- Adjustment to RWA for SME exposures subject to SME supporting factor: CRR Article 501 -*/ 
     RWA_PRE_SME = RWA ;
     if not (IN_DEFAULT_FLG =1 or PAST_DUE_CLAIM_FLG =1) and not (HIGH_RISK_CPTY_FLG=1 or STD_PRODUCT_CLASS ='HIGH_RISK') 
            and COUNTERPARTY_CLASS in ('RETAIL','CORPORATE') and COUNTERPARTY_SUBCLASS ='SME'
            and SME_CAP_DEDUCTION_TRT_FLG = 1 then do ;                    
                RWA = &SME_SUPPORTING_FACTOR * RWA ;
                RWA_SECURED = &SME_SUPPORTING_FACTOR * RWA_SECURED ;
                RWA_UNSECURED = &SME_SUPPORTING_FACTOR * RWA_UNSECURED ; 
                RWA_NO_CRM = &SME_SUPPORTING_FACTOR * RWA_NO_CRM ;
                
    end ;
    
 /*- Calculate RWA adjustments for securitization exposures: CRR Articles 249, 250, 252, 256 -*/    
    %calc_sec_rwa_adj_amt_crd4(calc_option=CAPITAL) ;    
    
    CAPITAL = RWA * &CAPITAL_RATIO;
    CAPITAL_NO_CRM = RWA_NO_CRM * &CAPITAL_RATIO;
   
    if VALUE = 0 then do;
       PD_EFF = PD_EXP;
       LGD_EFF = LGD_EXP;
       RW = RW_EXP;
    end;
    else do;
       PD_EFF = PD_WEIGHTED_SUM / VALUE ;
       LGD_EFF = LGD_WEIGHTED_SUM / VALUE;
       RW = RWA / VALUE * 100;
    end;
    EL_EFF = PD_EFF * LGD_EFF /100;
   
    if APPROACH =: 'IRB' and SECURITIZATION_EXPOSURE_FLG = 1 and SEC_STRUCTURE_TYPE = 'SYNTHETIC' and PRIMARY_BANK_ROLE = 'ORIGINATOR' then 
       EL_EFF = 0 ;
   
   
    run;            
 
/**************************************************
   update tables as per actual haircut exposures 
         stored in 'exposure_crm' link table 
**************************************************/
   data exp_haircut_adj;
     set "&REGPATH&PATHSEP.exposure_crm" (keep=EXP_ID HAIRCUT_EXP) ;
   run;

   proc sort data=exp_haircut_adj  nodup;
     by exp_id;
   run;

   proc sql;
     update &RESLIB1..crm_allocation_by_rank_detail a
     set haircut_exp=(select haircut_exp from exp_haircut_adj b where a.exp_id= b.exp_id);

   update "&OUTPATH.&PATHSEP.crm_allocation_by_rank" a
     set haircut_exp=(select haircut_exp from exp_haircut_adj b where a.exp_id= b.exp_id);

   update "&OUTPATH.&PATHSEP.capital_detail_by_rank" a
     set haircut_exp=(select haircut_exp from exp_haircut_adj b where a.exp_id= b.exp_id);
   quit;

/***********************************************/

/* If the exposures with zero EAD are to be included in the reporting, then combine their information */
/* into a data set and append that data set to capital_detail_by_rank */
    %if "&REPORT_ZERO_EAD" = "YES" %then %do ;

        data "&OUTPATH.&PATHSEP.capital_detail_by_rank";
          set "&OUTPATH.&PATHSEP.capital_detail_by_rank"
              "&VALPATH.&PATHSEP.exposures_with_zero_ead"(drop=NOTE INSTSOURCE) 
              "&VALPATH.&PATHSEP.equity_exp_deducted_from_capital"(drop=NOTE INSTSOURCE) ;
        run ;
        
        data &RESLIB1..crm_allocation_by_rank_detail;
                            set &RESLIB1..crm_allocation_by_rank_detail
                                "&VALPATH&pathsep.exposures_with_zero_ead"(keep=EXP_ID EAD CCF RWA RW_EXP)
                                "&VALPATH&pathsep.equity_exp_deducted_from_capital"(keep=EXP_ID EAD DEDUCTION_AMT RWA RW_EXP);
        run; 
    %end ;


    /*- 3: post-process SUMMARY data -*/
    /*** %SUMMARY : ***/
    /* get number of exposures */
    %local NEXP; 
    proc sql noprint;
    select count(*) into :NEXP
    from "&REGPATH&PATHSEP.all_exposures"(keep=EXP_ID);
    quit;

    /*- get all crossclass variables from the summary data set -*/
    data _ccvars_;
    do i = 1 to &CCNVAR;
        ccvars = compress(scan("&ccvars", i, " ") || '=' || "'+'");
        output;
    end;
    run;

    %local TOPCELL;
    proc sql noprint;
    select ccvars into : TOPCELL separated by " and "
    from _ccvars_;
    run;

/*- get the total firm wide risk measures -*/
    data _total_;
    set &RESLIB1..summary;
    where &topcell;
    run;

    %local TOTAL_EAD TOTAL_RWA TOTAL_CAPITAL TOTAL_RWA_NO_CRM TOTAL_CAP_NO_CRM TOTAL_VALUE;    
    data _null_;
    set _total_;
  
    call symput("TOTAL_EAD", OUTV_EAD);
    call symput("TOTAL_RWA", OUTV_RWA_PV);
    call symput("TOTAL_CAPITAL", OUTV_CAPITAL_PV);
    call symput("TOTAL_RWA_NO_CRM", OUTV_RWA_NO_CRM);
    call symput("TOTAL_CAP_NO_CRM", OUTV_CAPITAL_NO_CRM);
    call symput("TOTAL_VALUE", OUTV_VALUE);
    run;

    /*- compute concentration measures -*/
    data &RESLIB1..summary;
    set &RESLIB1..summary;
  
    OUTV_VALUE_CON          = OUTV_VALUE/&TOTAL_VALUE;
    OUTV_EAD_CON            = OUTV_EAD/&TOTAL_EAD;
    OUTV_RWA_CON            = OUTV_RWA_PV/&TOTAL_RWA;
    OUTV_RWA_NO_CRM_CON     = OUTV_RWA_NO_CRM / &TOTAL_RWA_NO_CRM;
    OUTV_CAPITAL_CON        = OUTV_CAPITAL_PV/&TOTAL_CAPITAL;
    OUTV_CAPITAL_NO_CRM_CON = OUTV_CAPITAL_NO_CRM / &TOTAL_CAP_NO_CRM;
  
    run;


/*- For Large Exposure report:
    get EAD of underlying exposures in securitization and 
    add to crm_allocation_by_rank and crm_allocation_by_rank_detail -*/
    data sec_underlying;
   set &RESLIB1..sec_underlying_by_rank_detail;
   if LE_PRODUCT_CLASS = 'DERIVATIVE' then do;
      UNDERLYING_EXP_EAD = EAD;   
   end;
   else do;
      UNDERLYING_EXP_EAD = EXP_VALUE;              
   end;  
        LE_COUNTERPARTY_RK = COUNTERPARTY_RK;
        EXP_ID = INSTID;
        if COUNTERPARTY_GROUP_PARENT_FLG = . then COUNTERPARTY_GROUP_PARENT_FLG = 0; 

    run;

    proc append BASE = "&OUTPATH.&PATHSEP.crm_allocation_by_rank" 
                data = sec_underlying(keep = UNDERLYING_EXP_EAD LE_COUNTERPARTY_RK EXP_ID TRADING_BOOK_FLG COUNTERPARTY_GROUP_PARENT_FLG) 
                FORCE NOWARN;
    run;


    proc append BASE = &RESLIB1..crm_allocation_by_rank_detail 
                data = sec_underlying(keep = UNDERLYING_EXP_EAD LE_COUNTERPARTY_RK EXP_ID TRADING_BOOK_FLG COUNTERPARTY_GROUP_PARENT_FLG)
                FORCE NOWARN;
    run;
    
    
    /*- For CA report:calculate Large exposure capital charge -*/    
    /*- 1: calculate LE multiplier for counterparty groups and individual counterparties -*/
    %get_le_capital_charge_crd4(dsname=&RESLIB1..crm_allocation_by_rank_detail);
    
    /*- 2: merge results with crm_allocation_by_rank_detail -*/  
    proc sort data = &RESLIB1..crm_allocation_by_rank_detail;
        by exp_id;
    run;
        
    data &RESLIB1..crm_allocation_by_rank_detail;
       merge &RESLIB1..crm_allocation_by_rank_detail (in=a) all_exp_with_le_cap_chrg;
       by EXP_ID;
    run;
    
/*- Calculations for CVA standardized approach -*/
%get_cva_risk_amts_crd4(CRMAPP=BY_RANK,ALTCALC=&CALCULATE_CVA_ALT_VALUES) ;

/*- Append the data set to the capital detail table -*/
%append_cva_risk_amts_crd4(CRMAPP=BY_RANK) ;      
    
/*- 4: clean work library -*/
    %clean_lib;   
    
%mend r00_post_mitigation_0_crd4;

 
