/*****************************************************************************
 * Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME: r00_post_mtm_0_crd4.sas
 *
 * PURPOSE: Separate positions into exposures, crms, and provisions.
 *
 *   USAGE: 
 *
 *   NOTES:  
 *   UPDATES:
 * 1) 18 Aug2008 : Condition added for considering of zero EAD
 *
 *****************************************************************************/



%macro r00_post_mtm_0_crd4;
options notes;

/*- 1: check for errors -*/
    %local NBR_ERRORS;
    %let NBR_ERRORS=0;
    %if (%dsexist(&RESLIB1..errors) EQ 1) %then %do;
        %let NBR_ERRORS = %attrn(&RESLIB1..errors, NOBS);
    %end;


    %if &NBR_ERRORS > 0 %then %do;
        %put ;
        %print_msg(warning,2,24);
        %print_msg(warning,2,25);
        %put ;        
    %end;        

    %if (%dsexist(&RESLIB1..instvals) = 0) or (%dsexist(&RESLIB1..allprice_v) = 0) %then %do;
        %put ;
        %print_msg(error,2,27); 
        %put ;
        %goto EXIT;
    %end;

/*- 2: get MtM results for the stress scenario -*/
/*- and separate into different groups: exposures, crms, and provisions for different processing -*/
    data &RESLIB1..all_exposures
         (drop = CRM: ELIGIBLE_CRM_: OUTV_CRM: OUTV_GENERAL_PROVISION PROVISION: OUTV_EXPOSURE_PROVISION 
                 NOTE OUTV_HAIRCUT_SCALE ELIGIBLE_DD_TREAT_CRM ELIGIBLE_DD_TREAT_GUARANTOR
                 COLL_LEVEL_BUCKET LGD_BUCKET_: PROTECTION_VALUE_AMT 
                 UNFUNDED_FLG USED_AMOUNT  %if %attrn(rd_stage.crm_derivative,NOBS)>0 %then %do; FIRST_TO_DEFAULT_PROT_FLG %end;
          rename = (INSTID = EXP_ID
                    VALUE = EXP_VALUE OUTV_EAD = EAD OUTV_ADD_ON = ADD_ON OUTV_HAIRCUT = HAIRCUT OUTV_CCF = CCF
                    OUTV_MAT_EFF = MAT_EFF OUTV_RESIDUAL_VALUE = RESIDUAL_VALUE CURRENCY=CCY
                   )
          %if &N_TRADING_BOOK_EXP EQ 0 %then %do; index = (EXP_ID) %end;
         )

         &RESLIB1..crms_netting

         &RESLIB1..equity_exp_deducted_from_capital         
         %if "&REPORT_ZERO_EAD" eq "YES" %then %do ;
              (keep = OUTV_DEDUCTION_AMT CAPITAL CAPITAL_NO_CRM INSTID INSTSOURCE INSTNUMBER OUTV_EAD NOTE
                      RW RWA RW_NO_CRM RWA_NO_CRM RWA_SECURED RWA_UNSECURED RW_EXP 
               rename = (INSTID=EXP_ID OUTV_EAD=EAD OUTV_DEDUCTION_AMT=DEDUCTION_AMT))
         %end ;

         %else %do ;
              (keep = INSTID INSTSOURCE INSTNUMBER OUTV_DEDUCTION_AMT OUTV_CCF OUTV_EAD NOTE 
               rename = (INSTID=EXP_ID OUTV_EAD=EAD OUTV_DEDUCTION_AMT=DEDUCTION_AMT))
         %end ;
         
         &RESLIB1..exposures_with_zero_ead 
         %if "&REPORT_ZERO_EAD" eq "YES" %then %do ;
              (keep = CAPITAL CAPITAL_NO_CRM INSTID INSTSOURCE INSTNUMBER OUTV_CCF OUTV_EAD NOTE
                      RW RWA RW_NO_CRM RWA_NO_CRM RWA_SECURED RWA_UNSECURED RW_EXP 
               rename = (INSTID=EXP_ID OUTV_EAD=EAD OUTV_CCF=CCF))
         %end ;

         %else %do ;
              (keep = INSTID INSTSOURCE INSTNUMBER OUTV_CCF OUTV_EAD NOTE 
               rename = (INSTID=EXP_ID OUTV_EAD=EAD OUTV_CCF=CCF))
         %end ;


         &RESLIB1..all_crms
         (drop = APPROACH: EXP: ADDON: CCF: SPECIFIC_PROVISION NOTE OUTV_FACE_VALUE
                 OUTV_MAT_EFF OUTV_EAD OUTV_RESIDUAL_VALUE VALUE OUTV_ADD_ON OUTV_CCF
                 OUTV_GENERAL_PROVISION OUTV_EXPOSURE_PROVISION INSTSOURCE INSTNUMBER 
          rename = (INSTID = CRM_ID OUTV_CRM = CRM_VALUE OUTV_HAIRCUT = HAIRCUT CURRENCY=CCY OUTV_HAIRCUT_SCALE=HAIRCUT_SCALE
                    HOLDING_PERIOD_DAYS=HAIRCUT_HOLDING_DAYS)                 
         )

         &RESLIB1..crms_with_invalid_value
         (keep = INSTID INSTSOURCE INSTNUMBER CRM_TYPE CRM_SUBTYPE OUTV_CRM
          rename = (INSTID = CRM_ID OUTV_CRM = CRM_VALUE)                          
         )

         &RESLIB1..general_provision
         (keep = INTERNAL_ORG_RK COUNTRY BUSINESS_UNIT BUSINESS_LINE_TYPE_CD BUSINESS_TYPE_CD 
                 MANAGER APPROACH_TYPE_CD OUTV_GENERAL_PROVISION
          rename = (OUTV_GENERAL_PROVISION = GENERAL_PROVISION)
         )
         
         &RESLIB1..exposure_provision
         (keep = INSTID PROVISION_TYPE CURRENCY OUTV_EXPOSURE_PROVISION OUTV_EXPOSURE_WRITEOFF
          rename = (INSTID = EXP_ID OUTV_EXPOSURE_PROVISION = EXPOSURE_PROVISION OUTV_EXPOSURE_WRITEOFF=EXPOSURE_WRITEOFF)
          index=(EXP_ID)
         )

         &RESLIB1..facility_group
         (keep=FACILITY_GROUP_RK VALUE rename=(VALUE=GROUP_LIMIT_AMT)) 
         
         &RESLIB1..securitization_positions_no_cap
         (keep=INSTID INSTSOURCE INSTNUMBER OUTV_CCF OUTV_EAD PRIMARY_BANK_ROLE SEC_STRUCTURE_TYPE SEC_STRUCTURE_SUBTYPE
          rename=(INSTID=EXP_ID OUTV_EAD=EAD))     
         ;

    /*- COUNTERPARTYID is needed for counterparty object for the next project -*/
    length INSTID COUNTERPARTYID NOTE PRIMARY_BANK_ROLE SEC_STRUCTURE_TYPE $32. ELIGIBLE_SECURITIZATION $1.;

    merge &RESLIB1..instvals(drop=BASEDATE INSTTYPE COLLATERAL HOLDING )
          &RESLIB1..allprice_v
          ( where=(STATENUMBER=1) keep=STATENUMBER INSTNUMBER OUTV_: VALUE)
          ;
    by INSTNUMBER ;

    /*- redundant variables -*/
    drop  STATENUMBER  ;

    if POSITION_CATEGORY = 'GENERAL_PROVISION' then do;
        output &RESLIB1..general_provision;
    end;
    
    else if POSITION_CATEGORY = 'EXPOSURE_PROVISION' then do;
        INSTID = scan(INSTID, 2, '*');
        output &RESLIB1..exposure_provision;
    end;
    
    else if POSITION_CATEGORY in ('EXPOSURE' ,'SEC_UNDERLYING', 'SEC_POOL')  then do;  
        OUTV_EAD = max(0, OUTV_EAD);        
        FACE_VALUE_AMT = OUTV_FACE_VALUE;
       
        /*- exposures with negative values that can serve as netting instruments -*/
        /*- Only loans and deposits can be on-balance sheet netting items: see Basel II 139 & 188 and CRR Articles 196 & 219  -*/
        if VALUE NE . and VALUE < 0 and NETTING_SET_RK NE . and PRODUCT_CD in ('CASH','LOA') then do;
            POSITION_CATEGORY = 'CRM';
            CRM_TYPE_CD ='NET';
            CRM_SUBTYPE_CD = 'NET';
            ELIGIBLE_CRM_TYPE_CD = 'NET';
            CRM_TYPE = 'NETTING';
            CRM_SUBTYPE = 'NETTING';
            ELIGIBLE_CRM_TYPE = 'NETTING';
            CRM_EFFECTIVE_DATE = INCEPTION_DATE;
            CRM_EXPIRATION_DATE = MATURITY_DATE;
            OUTV_CRM = - VALUE;
            output &RESLIB1..crms_netting;
        end; 

        /*- exposures that are deducted and removed from the risk weight treatment -*/
       else if OUTV_DEDUCTION_AMT > 0 and OUTV_EAD = 0 then do ;
            NOTE = 'Equity Exposures deducted from Capital';
                    %if "&REPORT_ZERO_EAD" eq "YES" %then %do ;
                    CAPITAL = 0 ;
                    CAPITAL_NO_CRM = 0 ;
                    RW = 0 ;
                    RWA = 0 ;
                    RW_NO_CRM = 0 ;
                    RWA_NO_CRM = 0 ;
                    RWA_SECURED = 0 ;
                    RWA_UNSECURED = 0 ;
                    RW_EXP = 0 ;
                    %end ;
        
                    output &RESLIB1..equity_exp_deducted_from_capital;
        end;
      
        /*- exposures without valid EADs -*/
        /* else if VALUE = . or OUTV_EAD = 0 then do; */
        else if VALUE = . or (OUTV_EAD = 0 and OUTV_CCF <> 0) then do; 
            NOTE = 'Zero or missing value';
            %if "&REPORT_ZERO_EAD" eq "YES" %then %do ;
            CAPITAL = 0 ;
            CAPITAL_NO_CRM = 0 ;
            RW = 0 ;
            RWA = 0 ;
            RW_NO_CRM = 0 ;
            RWA_NO_CRM = 0 ;
            RWA_SECURED = 0 ;
            RWA_UNSECURED = 0 ;
            RW_EXP = 0 ;
            %end ;

            output &RESLIB1..exposures_with_zero_ead;
        end;
        /*- other exposures -*/
        else do;
            SPECIFIC_PROVISION = 0;
            output &RESLIB1..all_exposures;    
            /*- for leases, divide into two exposures: -*/
            /*- one for the lease itself and the other for the residual value -*/
            /*- see Basel II: 523-524.  CRR Articles 134(7) & 156(b)        -*/
            if (APPROACH in ('STD','IRB', 'IRBA', 'IRBF') and IRB_PRODUCT_CLASS = 'LEASE') and OUTV_RESIDUAL_VALUE NE . then do;
                INSTID = compress(INSTID || '*RESIDUAL');
                STD_PRODUCT_SUBCLASS = 'LEASE_RESIDUAL';
                IRB_PRODUCT_SUBCLASS = 'LEASE_RESIDUAL';
                VALUE = OUTV_RESIDUAL_VALUE;
                OUTV_EAD = OUTV_RESIDUAL_VALUE;
                output &RESLIB1..all_exposures;
            end;
        end;
    end;

    else if POSITION_CATEGORY = "SECURITIZATION_POSITION" then do;
        OUTV_EAD = max(0, OUTV_EAD);        
        FACE_VALUE_AMT = OUTV_FACE_VALUE;  
        
        if PRIMARY_BANK_ROLE IN('ORIGINATOR', 'SPONSOR', 'INVESTOR') then do; 
               
          /* if upcase(ELIGIBLE_SECURITIZATION) ~= 'Y' or SEC_STRUCTURE_TYPE = 'SYNTHETIC' then do;   */         
              *if VALUE = . or OUTV_EAD = 0 then do; 
           if VALUE = . or (OUTV_EAD = 0 and OUTV_CCF <> 0) then do; 
                 NOTE = 'Zero or missing value';
                 output &RESLIB1..exposures_with_zero_ead;
           end;
              
           else
                 output &RESLIB1..all_exposures;
     
        end ;  
          /* else do;
              output &RESLIB1..securitization_positions_no_cap;
           end;  
        end; 
        /*- no capital charge for a securitized position but the bank is an investor -*/
        else 
           output &RESLIB1..securitization_positions_no_cap;
    end;
    
    else if POSITION_CATEGORY = 'CRM' then do;
        if  OUTV_CRM = . or OUTV_CRM <= 0 then output &RESLIB1..crms_with_invalid_value;
        else output &RESLIB1..all_crms;
    end;

    else if POSITION_CATEGORY = 'FACILITY_GROUP' then do;
        output &RESLIB1..facility_group;
    end;

    run;
    
/*- get all exposure records -*/
    %if %dsexist(RD_POS.exposure_trading_book_zero_ead) %then %do;
    proc append base=&RESLIB1..exposures_with_zero_ead 
                data=RD_POS.exposure_trading_book_zero_ead (rename=(INSTID=EXP_ID)) force;
    run;
    %end;
    
    %if &N_TRADING_BOOK_EXP GT 0 %then %do;
        
        data &RESLIB1..all_exposures(index = (EXP_ID));
             set &RESLIB1..all_exposures
             %if &CCR_STD_DONE=Y %then %do;
                "&CCRSTDPATH.&pathsep.all_tb_std_exposures"
             %end;
             %if &CCR_IMM_DONE=Y %then %do;
                "&CCRIMMPATH.&pathsep.all_tb_imm_exposures"
             %end;
             ;
        run;
        
        %if &CCR_STD_DONE=Y %then %do;
            proc append base=&RESLIB1..exposures_with_zero_ead 
                        data="&CCRSTDPATH.&pathsep.all_tb_std_zero_ead";
        %end;
        %if &CCR_IMM_DONE=Y %then %do;
            proc append base=&RESLIB1..exposures_with_zero_ead 
                        data="&CCRIMMPATH.&pathsep.all_tb_imm_zero_ead";
        run;
        %end;
        
    %end;
    
/*- get all zero ead records -*/
    
/*- 3: add exposure-specific provisions to each exposure -*/

/*- get all types of exposure-specific provisions into one observation per exposure -*/
    proc summary data=&RESLIB1..exposure_provision;
    var EXPOSURE_PROVISION EXPOSURE_WRITEOFF;
    by EXP_ID;
    output out=&RESLIB1..exposure_provisions(keep=EXP_ID SPECIFIC_PROVISION SPECIFIC_WRITEOFF)
           sum = SPECIFIC_PROVISION SPECIFIC_WRITEOFF
    ;
    run;
   
    data &RESLIB1..all_exposures;   
    merge &RESLIB1..all_exposures(in=exp) &RESLIB1..exposure_provisions(in=prov);
    length SECURITIZATION_EXPOSURE_FLG RECEIVABLE_EXPOSURE_FLG 8.;
    by EXP_ID;
    if exp;
   
   /*- Basel II - 563: specific provisions against securitization exposures are not to be included     -*/
   /*- The following line of code was commented out because of exposure values defined in              -*/
   /*- CRR Article 246: exposure value of a securitization position should be: its accounting value    -*/
   /*- remaining after specific credit risk adjustment for STD approach, and its accounting value      -*/
   /*- measured without taking into account of any credit risk adjustment for IRB approach.            -*/
   
   /* if SECURITIZATION_EXPOSURE_FLG = 1 then SPECIFIC_PROVISION = 0; */
    run;
       
/*- 4. update crm data set */
    data &RESLIB1..crms_netting;
    set  &RESLIB1..crms_netting(rename = (INSTID = CRM_ID OUTV_CRM = CRM_VALUE OUTV_HAIRCUT = HAIRCUT CURRENCY=CCY 
                                          OUTV_HAIRCUT_SCALE=HAIRCUT_SCALE HOLDING_PERIOD_DAYS=HAIRCUT_HOLDING_DAYS));   
    proc append base=&RESLIB1..all_crms data=&RESLIB1..crms_netting force nowarn;run; 

/*- reporting -*/
    %local NNET;
    %let NNET = %attrn(&RESLIB1..crms_netting, NOBS);
    %if &NNET >0 %then %do;
        %put ;
        %print_msg(note,2,29);
        %print_msg(note,2,30);
        %print_msg(note,2,31);
        %put ;
    %end;

    %local NINVALID;
    %let NINVALID = %attrn(&RESLIB1..crms_with_invalid_value, NOBS);
    %if &ninvalid > 0 %then %do;
        %put ;    
        %print_msg(warning,2,32);
        %print_msg(warning,2,33);        
        %print_msg(warning,2,34);
        %put ;
    %end;

    %EXIT:

%mend r00_post_mtm_0_crd4;
