/*****************************************************************************
 * Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME: r00_post_regulatory_0_crd4.sas
 *
 * PURPOSE: Prepare data after regulatory calculations. 
 *
 *
 *   USAGE: 
 *
 *   NOTES:  
 *
 *
 *****************************************************************************/


%macro r00_post_regulatory_0_crd4;

options notes ; 

/* creating format for retrieving HIGH_RISK_PREF RW value below */
    data fmt;
      set RD_MKT.current_rw end=lastobs;
      where index(RW_NAME, 'HIGHRISK') > 0;
      FMTNAME          = 'MAP_STD_RW_HIGH_RISK' ;
      START            = RW_NAME ;
      END              = START          ;
      LABEL            = RW_VALUE ;
      TYPE             = 'C' ;
      output ;
      if lastobs then do;
         START            ='**OTHER**' ;
         END              = START;
         HLO              ='O' ;
         LABEL            =.;
         output ;
      end;
    run;

proc format cntlin=fmt lib=RD_ENV; run;

/*- 1: check for errors -*/
    %local NBR_ERRORS;
    %let NBR_ERRORS=0;
    %if (%dsexist(&RESLIB1..errors) EQ 1) %then %do;
        %let NBR_ERRORS = %attrn(&RESLIB1..errors, NOBS);
    %end;

    %if &NBR_ERRORS GT 0 %then %do;
        %put ;
        %print_msg(warning,2,58);
        %print_msg(warning,2,25);
        %put ;        
    %end;        

    %if (%dsexist(&RESLIB1..instvals) NE 1) or (%dsexist(&RESLIB1..allprice_v) NE 1) %then %do;
        %put ;
        %print_msg(error,2,26);
        %print_msg(error,2,27); 
        %print_msg(error,2,59);
        %put ;
        %goto EXIT;
    %end;

/*- 2: get regulatory results for the stress scenario and separate exposures and crms -*/
    data &RESLIB1..all_exposures
         (drop   = CRM: ELIGIBLE_CRM: LGD_BUCKET_: 
                   OUTV_LGD_CRM: OUTV_C_STAR: 
                   OUTV_EL_DILUTION OUTV_LGD_DILUTION ELIGIBLE_DD_TREAT_CRM
                   ELIGIBLE_DD_TREAT_GUARANTOR HAIRCUT_HOLDING_DAYS HAIRCUT_SCALE UNFUNDED_FLG OUTV_RW_FROM_CENTGOV_FLG
                 /*STD_RW_BUCKET_HRISK_PREF  %if &STD_HRISK_CPTY_PASTDUE_TREATMENT = YES %then %do; BUCKET_HRISK ADJUSTMENT_PCT %end; */
                    
                   
          rename = (INSTID = EXP_ID OUTV_PD_COUNTERPARTY = PD_EXP_COUNTERPARTY OUTV_PD_ISSUE = PD_EXP 
                    OUTV_LGD = LGD_EXP HAIRCUT = HAIRCUT_EXP 
                    OUTV_RW_ISSUE = RW_EXP OUTV_RW_COUNTERPARTY = RW_EXP_COUNTERPARTY OUTV_EL = EL  
                    OUTV_FIRM_SIZE = FIRM_SIZE 
                   )         
          index = (EXP_ID)
         )
         
/*- keep only needed variables for CRMs -*/          
         &RESLIB1..all_crms
         (keep   = INSTID COUNTERPARTY_RK NETTING_SET_RK COUNTERPARTY_GROUP
                   REGULATORY_COUNTERPARTY_TYPE_CD REGULATORY_PRODUCT_CD CRM_TYPE_CD CRM_SUBTYPE_CD
                   COUNTERPARTY_CLASS COUNTERPARTY_SUBCLASS 
                   STD_PRODUCT_CLASS STD_PRODUCT_SUBCLASS IRB_PRODUCT_CLASS IRB_PRODUCT_SUBCLASS
                   CRM_TYPE CRM_SUBTYPE ELIGIBLE_CRM_TYPE CCY   
                   CRM_EFFECTIVE_DATE CRM_EXPIRATION_DATE INCEPTION_DATE MATURITY_DATE ORIGINAL_MATURITY RESIDUAL_MATURITY
                   CRM_VALUE HAIRCUT OUTV_PD_COUNTERPARTY OUTV_PD_ISSUE OUTV_LGD_CRM_SEN OUTV_LGD_CRM_SUB 
                   OUTV_RW_COUNTERPARTY OUTV_RW_ISSUE OUTV_C_STAR OUTV_C_STAR_STAR OUTV_FIRM_SIZE
                   PD_MODEL_ID PD_MODEL_RATING_GRADE LGD_MODEL_ID LGD_MODEL_RATING_GRADE
                   ELIGIBLE_DD_TREAT_CRM ELIGIBLE_DD_TREAT_GUARANTOR HAIRCUT_HOLDING_DAYS HAIRCUT_SCALE UNFUNDED_FLG
                   COUNTERPARTY_NAME COUNTERPARTY_COUNTRY COUNTERPARTY_GROUP_PARENT_FLG COUNTERPARTY_SECTOR NACE LEGAL_ENTITY_ID
                   TRADING_BOOK_FLG TRADE_EXP_FLG BANKRUPTCY_REMOTE_FLG COUNTERPARTY_TYPE_CD
                   SME_SUPPORTING_FACTOR_FLG SME_CAP_DEDUCTION_TRT_FLG CONNECTION_TYPE_CD COUNTERPARTY_CD FINANCIAL_ENTITY_TYPE_CD
                   EXT_MAP_RATING CENTGOV_TRT_FLG
          rename =(INSTID = CRM_ID COUNTERPARTY_RK = CRM_COUNTERPARTY_RK NETTING_SET_RK = CRM_NETTING_SET_RK
                   REGULATORY_COUNTERPARTY_TYPE_CD = CRM_REG_COUNTERPARTY_TYPE_CD REGULATORY_PRODUCT_CD = CRM_REG_PRODUCT_CD
                   COUNTERPARTY_CLASS = CRM_COUNTERPARTY_CLASS COUNTERPARTY_SUBCLASS = CRM_COUNTERPARTY_SUBCLASS
                   STD_PRODUCT_CLASS = CRM_STD_PRODUCT_CLASS STD_PRODUCT_SUBCLASS = CRM_STD_PRODUCT_SUBCLASS
                   IRB_PRODUCT_CLASS = CRM_IRB_PRODUCT_CLASS IRB_PRODUCT_SUBCLASS = CRM_IRB_PRODUCT_SUBCLASS
                   INCEPTION_DATE = CRM_INCEPTION_DATE MATURITY_DATE = CRM_MATURITY_DATE
                   ORIGINAL_MATURITY = CRM_ORIGINAL_MATURITY RESIDUAL_MATURITY = CRM_RESIDUAL_MATURITY
                   OUTV_PD_COUNTERPARTY = PD_CRM_COUNTERPARTY OUTV_PD_ISSUE = PD_CRM
                   OUTV_LGD_CRM_SEN = LGD_CRM_SEN OUTV_LGD_CRM_SUB = LGD_CRM_SUB  
                   OUTV_RW_COUNTERPARTY = RW_CRM_COUNTERPARTY OUTV_RW_ISSUE = RW_CRM 
                   PD_MODEL_ID = CRM_PD_MODEL_ID PD_MODEL_RATING_GRADE = CRM_PD_MODEL_RATING_GRADE
                   LGD_MODEL_ID = CRM_LGD_MODEL_ID LGD_MODEL_RATING_GRADE = CRM_LGD_MODEL_RATING_GRADE
                   OUTV_C_STAR = C_STAR OUTV_C_STAR_STAR = C_STAR_STAR
                   HAIRCUT = HAIRCUT_CRM CCY = CRM_CCY OUTV_FIRM_SIZE = CRM_FIRM_SIZE
                   COUNTERPARTY_GROUP = CRM_COUNTERPARTY_GROUP
                   COUNTERPARTY_NAME = CRM_COUNTERPARTY_NAME COUNTERPARTY_COUNTRY = CRM_COUNTERPARTY_COUNTRY 
                   COUNTERPARTY_GROUP_PARENT_FLG = CRM_CPTY_GROUP_PARENT_FLG COUNTERPARTY_SECTOR = CRM_COUNTERPARTY_SECTOR 
                   NACE = CRM_NACE LEGAL_ENTITY_ID = CRM_LEGAL_ENTITY_ID COUNTERPARTY_TYPE_CD = CRM_COUNTERPARTY_TYPE_CD
                   CONNECTION_TYPE_CD = CRM_CONNECTION_TYPE_CD FINANCIAL_ENTITY_TYPE_CD = CRM_FINANCIAL_ENTITY_TYPE_CD 
                   COUNTERPARTY_CD = CRM_COUNTERPARTY_CD EXT_MAP_RATING = CRM_EXT_MAP_RATING 
                   CENTGOV_TRT_FLG = CRM_CENTGOV_TRT_FLG
                  ) 
         );

    length INSTID $32. RW_BUCKET PD_BUCKET LGD_BUCKET $16.;
    RW_LOOK_THROUGH_UPDATE_FLG=0; 

    merge &RESLIB1..instvals(drop=BASEDATE INSTTYPE INSTSOURCE COUNTERPARTYID PROVISION:)
          &RESLIB1..allprice_v
          ( where=(STATENUMBER=1) keep=STATENUMBER INSTNUMBER OUTV_: VALUE)
          ;
    by INSTNUMBER ;

    /*- unnecessary variables -*/
    drop  STATENUMBER INSTNUMBER;
    length STD_RW_BUCKET_HRISK_PREF $18.;
    /*- correcting issue risk weight -*/
    if RISK_WEIGHT NE . then OUTV_RW_ISSUE = RISK_WEIGHT;
    else if OUTV_RW_COUNTERPARTY NE . and OUTV_RW_ISSUE EQ . then OUTV_RW_ISSUE = OUTV_RW_COUNTERPARTY;
   
   /*- create flags identifying risk weights derived from central government or from ECAI rating: used in CRSA report template -*/
    if OUTV_RW_FROM_CENTGOV_FLG eq 1 then STD_RW_FROM_CENTGOV_FLG = 1 ;
    if OUTV_RW_FROM_CENTGOV_FLG ne 1 and (EXT_MAP_RATING ne 'MISS' or EXT_ISSUE_MAP_RATING ne 'MISS') then 
       STD_RW_FROM_ECAI_FLG = 1 ;
    
    if POSITION_CATEGORY = 'CRM' then do;
        output &RESLIB1..all_crms ;
    end;
    else do;
   
   /*-  the following high-risk treatment is removed from CRD-IV  -*/   
   /*- apply preferential treatment to exposures with high risk RW : Basel II para 75 footnote 30 -*/
   /***************************************************************************************************************
      %if "&STD_HRISK_CPTY_PASTDUE_TREATMENT" = "YES" %then %do;
    
        if ( APPROACH = "STD" and OUTV_RW_ISSUE LT &RW_DEDUCT and OUTV_RW_ISSUE GE &STD_HRISK_CPTY_PASTDUE_TREAT_RW 
             and PAST_DUE_CLAIM_FLG NE 1 ) then do;
                   
            if EAD > 0 then ADJUSTMENT_PCT = sum(0, SPECIFIC_PROVISION) / EAD * 100;
            STD_RW_BUCKET_HRISK_PREF = put(ADJUSTMENT_PCT, MAP_STD_RW_BUCKET_HIGHRISK.);
            BUCKET_HRISK = compress("STD_RW_"||STD_RW_BUCKET_HRISK_PREF||"_HIGHRISK_PREF");

            OUTV_RW_ISSUE = put(BUCKET_HRISK, $MAP_STD_RW_HIGH_RISK.) ;
                
        end;
        %end;
   /******************************************************************************************************************/

   /*- risk weight treatment for free delivery exposures: CRR Article 379 -*/
   /*- same risk weight as credit risk exposures unless in the following cases: -*/
        if FREE_DELIVERY_FLG = 1 then do ;
           if &RUNDATE<= FIRST_DUE_SETT_DT then  OUTV_RW_ISSUE = &FREE_DELIVERY_RW_FLOOR ;
           else if &RUNDATE > SECOND_DUE_SETT_DT+4 then  OUTV_RW_ISSUE = &FREE_DELIVERY_RW_CEILING ;
              
           if %upcase("&FREE_DELIVERY_AMT_IMMATERIAL") = "YES" then do ;
              if FIRST_DUE_SETT_DT < &RUNDATE <= SECOND_DUE_SETT_DT+4 then OUTV_RW_ISSUE = &FREE_DELIVERY_RW_ALTERNATIVE ;
           end ;           
        end ;
        
   /*- repo-style exposure is w.r.t. the counterparty not the issue -*/
        if STD_PRODUCT_CLASS = 'REPO_STYLE' and APPROACH = 'STD' then
           OUTV_RW_ISSUE = OUTV_RW_COUNTERPARTY;
        RW_BUCKET  = put(OUTV_RW_ISSUE,  MAP_RW_BUCKET. );
        PD_BUCKET  = put(OUTV_PD_ISSUE,  MAP_PD_BUCKET. );
        LGD_BUCKET = put(OUTV_LGD, MAP_LGD_BUCKET.);     
        /*- update the flag for off_balance_sheet items if CCF is to be applied after CRM allocation */
        %if "&APPLY_CCF_AFTER_CRM" = "YES" %then %do;
           if OFF_BALANCE_SHEET_FLG=1 and not missing(CCF) then
              OFF_BALANCE_SHEET_FLG=1;
           else
              OFF_BALANCE_SHEET_FLG=0;
        %end;
   
   /*- adjust EXP_VALUE of derivatives so that they are the same as the EAD of these exposures -*/
       if PE_APPROACH in ('CE','OE') or CCR_APPROACH = 'CEM' then do ;
           EXP_VALUE = EAD ;
       end ;   
       
        /*- 3: create a separate observation for dilution risk for purchased receivables -*/    
        if RECEIVABLE_EXPOSURE_FLG = 1 and APPROACH in ('IRB', 'IRBF', 'IRBA') then do;
             /*- default risk -*/            
             EAD = EAD * sum(1, - OUTV_RW_DILUTION * &CAPITAL_RATIO / 100);
             EXP_VALUE = EXP_VALUE * sum(1, - OUTV_RW_DILUTION * &CAPITAL_RATIO / 100);
             DILUTION_FLG = 1 ; 
             output &RESLIB1..all_exposures;
             
             /*- dilution risk -*/
             INSTID = compress(INSTID || '*DILUTION');
             EAD = EAD / sum(1, - OUTV_RW_DILUTION * &CAPITAL_RATIO / 100);
             OUTV_PD_ISSUE  = OUTV_EL_DILUTION;             
             OUTV_LGD = OUTV_LGD_DILUTION;
             OUTV_EL = OUTV_EL_DILUTION;
             OUTV_RW_ISSUE = OUTV_RW_DILUTION;
             MAT_EFF = &IRB_M_REC_DILUTION;
             RW_BUCKET  = put(OUTV_RW_ISSUE,  MAP_RW_BUCKET. );
             PD_BUCKET  = put(OUTV_PD_ISSUE,  MAP_PD_BUCKET. );
             LGD_BUCKET = put(OUTV_LGD, MAP_LGD_BUCKET.);        
             DILUTION_FLG = 1 ; 
             output &RESLIB1..all_exposures;
        end;
        else 
             output &RESLIB1..all_exposures;   
    end;
    run;

/*- report -*/
    %local NO_EXP NO_CRM;

    %let NO_EXP = %attrn(&RESLIB1..all_exposures, NOBS);
    %let NO_CRM = %attrn(&RESLIB1..all_crms, NOBS);

    %put ;
    %print_msg(note,2,60);
    %print_msg(note,2,55);
    %print_msg(note,2,61);
    %put ;

    %EXIT:

/*- clean work library -*/
    %clean_lib;    

%mend r00_post_regulatory_0_crd4;
