/*****************************************************************************
 * Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME: r00_post_regulatory_1_crd4.sas
 *
 * PURPOSE: Process risk weights for short-term claims under STD approach. 
 *
 *
 *   USAGE: 
 *
 *   NOTES:  
 *          
 *
 *****************************************************************************/


%macro r00_post_regulatory_1_crd4;

/*- Short-term assessment only applies to institution and corporate exposures:  CRR Articles 131,140 & 120 -*/

/*- need RW values -*/
    data _null_;
    set RD_MKT.current_rw;
    where index(RW_NAME, 'SHORT') > 0 ;
    call symput(RW_NAME, RW_VALUE);
    run;

       /*- all non-securitization exposures to institutions and corporates subject to STD: CRR Article 140(2)(a) -*/
    data exposures_std(drop=APPROACH PAST_DUE_CLAIM_FLG IN_DEFAULT_FLG SECURITIZATION_EXPOSURE_FLG index=(COUNTERPARTY_RK))
       /*- all short-term non-securitization exposures to institutions and corporates under STD approach: CRR Articles 131,140(2)(b)&120 -*/    
         exposures_std_short(drop=APPROACH PAST_DUE_CLAIM_FLG IN_DEFAULT_FLG SECURITIZATION_EXPOSURE_FLG 
                             where=(SHORT_TERM_CLAIM_FLG = 1) index=(COUNTERPARTY_RK)
                            );
    set &RESLIB1..all_exposures
        (keep=COUNTERPARTY_RK COUNTERPARTY_CLASS COUNTERPARTY_SUBCLASS EXP_ID RW_EXP /*RW_EXP_OTHER*/ RW_EXP_COUNTERPARTY
              EXT_ISSUE_MAP_RATING EXT_MAP_RATING SHORT_TERM_ASSESS_FLG SHORT_TERM_CLAIM_FLG APPROACH 
              PAST_DUE_CLAIM_FLG IN_DEFAULT_FLG SECURITIZATION_EXPOSURE_FLG
        );
    where APPROACH = 'STD' and not (PAST_DUE_CLAIM_FLG = 1 or IN_DEFAULT_FLG = 1) and 
          COUNTERPARTY_CLASS in ('INSTITUTION', 'CORPORATE') and SECURITIZATION_EXPOSURE_FLG NE 1;          
    output exposures_std;
    if SHORT_TERM_CLAIM_FLG = 1 then output exposures_std_short;
    run;

    /*- risk weights for unrated short-term exposures to counterparties that have a rated short-term claim of  -*/  
    /*- 50% risk weight should be no less than 100%: CRR Article 140(2)(b) -*/    
    /*- get all such counterparties -*/
    data counterparty_update_1(keep=COUNTERPARTY_RK);
    set exposures_std_short(keep=COUNTERPARTY_RK RW_EXP SHORT_TERM_ASSESS_FLG
                            where=(RW_EXP = &STD_RW_BUCKET2_SHORT and SHORT_TERM_ASSESS_FLG = 1)
                           );
    by COUNTERPARTY_RK;
    if first.COUNTERPARTY_RK then output;
    run;
    
    /*- update Risk weights of unrated short-term exposures -*/
    data exposures_std_short_update_1(keep=EXP_ID RW_EXP RW_EXP_COUNTERPARTY RW_EXP_UPDATED index=(EXP_ID));
    merge exposures_std_short(in=short where=(EXT_ISSUE_MAP_RATING = 'MISS' and  RW_EXP < &STD_RW_BUCKET3_SHORT)) 
          counterparty_update_1(in=cpty);
    by COUNTERPARTY_RK;
    if short and cpty;
    RW_EXP_UPDATED = max(RW_EXP, &STD_RW_BUCKET3_SHORT);
    run;
                                
    /*- risk weights for all unrated long- or short-term exposures to counterparties that have a rated short-term -*/
    /*- claim of 150% risk weight should be 150%: CRR Article 140(2)(a) -*/    
    /*- get all such counterparties -*/
    data counterparty_update_2(keep=COUNTERPARTY_RK);
    set exposures_std_short(keep=COUNTERPARTY_RK RW_EXP SHORT_TERM_ASSESS_FLG 
                            where=(RW_EXP = &STD_RW_BUCKET4_SHORT and SHORT_TERM_ASSESS_FLG = 1)
                           );
    by COUNTERPARTY_RK;
    if first.COUNTERPARTY_RK then output;
    run;

    /*- update risk weights of unrated exposures-*/
    data exposures_std_short_update_2(keep=EXP_ID RW_EXP RW_EXP_COUNTERPARTY RW_EXP_UPDATED index=(EXP_ID));
    merge exposures_std(in=exp where=(EXT_ISSUE_MAP_RATING = 'MISS'))
          counterparty_update_2(in=cpty);
    by COUNTERPARTY_RK;
    if exp and cpty;
    RW_EXP_UPDATED = &STD_RW_BUCKET4_SHORT;
    run;      

    /*- the latter Risk Weight always overwrite previous ones -*/
    data &RESLIB1..exposures_std_short_update;
    merge exposures_std_short_update_1 exposures_std_short_update_2;
    by EXP_ID;
    run;     

    /*- by default, issue rating-based Risk Weight already applies.                                   -*/
    /*- for an unrated short-term exposure to a rated institution, risk weight should be              -*/
    /*- the greater of the risk weight based on preferential treatmentng and the highest risk weight  -*/ 
    /*- of all rated short-term exposures based on short-term assessments : CRR Article 120(3)(b)&(c) -*/
    
        /*- worst issue-specific Risk Weight for short-term exposures per counterparty -*/    
        data counterparty_update_3(keep=COUNTERPARTY_RK RW_EXP_SHORT_WORST)
             exposures_std_short_inst(drop=RW_EXP_SHORT_WORST);
        set exposures_std_short;
        where COUNTERPARTY_CLASS = 'INSTITUTION' and EXT_MAP_RATING ne 'MISS' and RW_EXP_COUNTERPARTY <= RW_EXP  ;                      
        by COUNTERPARTY_RK;
        retain RW_EXP_SHORT_WORST;
        if first.COUNTERPARTY_RK then do;
            RW_EXP_SHORT_WORST = 0;
        end;
        RW_EXP_SHORT_WORST = max(RW_EXP_SHORT_WORST, RW_EXP);
        output exposures_std_short_inst;
        if last.COUNTERPARTY_RK then output counterparty_update_3;
        run;
        
        /*- update Risk Weight -*/
        data exposures_std_short_update_3(keep=EXP_ID RW_EXP RW_EXP_COUNTERPARTY RW_EXP_SHORT_WORST index=(EXP_ID));
        merge exposures_std_short_inst(in=exp where=(EXT_ISSUE_MAP_RATING = 'MISS')) 
              counterparty_update_3(in=cpty );
        by COUNTERPARTY_RK;
        if exp and cpty;
        run;

        data &RESLIB1..exposures_std_short_update;
        merge &RESLIB1..exposures_std_short_update  exposures_std_short_update_3;
        by EXP_ID;
        RW_EXP_UPDATED = max(RW_EXP_UPDATED,RW_EXP_SHORT_WORST) ;
        run;


    
    /*- update Risk Weight and report -*/   
    %local NUPDATE;
    %let NUPDATE = %attrn(&RESLIB1..exposures_std_short_update, NOBS);
    %if &NUPDATE > 0 %then %do;
        data &RESLIB1..all_exposures(drop=RW_EXP_UPDATED);
        merge &RESLIB1..all_exposures(in=exp)
              &RESLIB1..exposures_std_short_update(in=short drop=RW_EXP_SHORT_WORST)
              ;
        by EXP_ID;
        if short then RW_EXP = RW_EXP_UPDATED;
        run;    

        %put ;
        %print_msg(note,2,62);
        %print_msg(note,2,63);
        %print_msg(note,2,64);
        %put ;
    %end;

/*- clean work library -*/
    %clean_lib;

%mend r00_post_regulatory_1_crd4;
