/*****************************************************************************
 * Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME: r00_post_regulatory_4_crd4.sas
 *
 * PURPOSE: Handles securitization exposures subject to supervisory formula
 *          approach: prepare risk components.
 *
 *   USAGE: 
 *
 *   NOTES:  
 *          
 *
 *****************************************************************************/

%macro r00_post_regulatory_4_crd4;
/*- 0: get underlying exposures in securitization pools and securitization exposures -*/
    data /*- all unrated securitization exposures under STD -*/
         &RESLIB1..all_exp_ur_sec_std(index=(SECURITIZATION_POOL_RK) drop=SF_INPUT_UPDATE_FLG) 
         /*- all unrated securitization exposures potentially subject to SFA -*/
         &RESLIB1..all_exp_ur_sec_irb(index=(SECURITIZATION_POOL_RK))
         /*- all securitized exposures -*/
         &RESLIB1..all_exp_sec_underlying(index=(SECURITIZATION_POOL_RK) drop=SF_INPUT_UPDATE_FLG) 
         /*- securitization pool with eap capital charge -*/
         all_exp_pool_std(index=(SECURITIZATION_POOL_RK) drop=SF_INPUT_UPDATE_FLG) 
         all_exp_pool_irb(index=(SECURITIZATION_POOL_RK) drop=SF_INPUT_UPDATE_FLG) 
         first_loss_abcp (index=(SECURITIZATION_POOL_RK) keep=SECURITIZATION_POOL_RK)
         /*- remaining exposures -*/
         &RESLIB1..all_exposures(drop=SF_INPUT_UPDATE_FLG)  
         ;
    set &RESLIB1..all_exposures;
    
    SF_INPUT_UPDATE_FLG = 0;
    if SECURITIZATION_EXPOSURE_FLG = 1 then do;
        if index(APPROACH, 'IAA') then
            output &RESLIB1..all_exposures;
        else if APPROACH ='STD' then do;
           if STD_PRODUCT_SUBCLASS in ('EAP_ORIGINATOR_INT','EAP_INVESTORS_INT') then
              output all_exp_pool_std;
           else if EXT_ISSUE_MAP_RATING = 'MISS' then do;
              if STD_PRODUCT_SUBCLASS in ('ELQD_FACILITY','FACILITY','ECA_FACILITY') or STD_PRODUCT_CLASS = 'DERIVATIVE' then
                 output all_exp_pool_std;
              else 
                 output &RESLIB1..all_exp_ur_sec_std;
           end;
           else
              output &RESLIB1..all_exposures;
        end;
        else if index(APPROACH, 'IRB') then do; 
           if IRB_PRODUCT_SUBCLASS in ('EAP_ORIGINATOR_INT','EAP_INVESTORS_INT') then
              output all_exp_pool_irb;   
           else if EXT_ISSUE_MAP_RATING = 'MISS' then do; 
              if IRB_PRODUCT_SUBCLASS in ('ELQD_FACILITY','FACILITY','ECA_FACILITY') or IRB_PRODUCT_CLASS = 'DERIVATIVE' then
                 output all_exp_pool_irb;
              else if SEC_STRUCTURE_SUBTYPE NE 'ABCP' or INT_ISSUE_MAP_RATING = 'MISS' then
                 output &RESLIB1..all_exp_ur_sec_irb;                                                  
           end; 
           else 
              output &RESLIB1..all_exposures;
        end;
        
        if SEC_STRUCTURE_SUBTYPE = 'ABCP' and TRANCHE_LOSS_RANK = 1 then
           output first_loss_abcp;
    end;
    else if SEC_UNDERLYING_EXP_FLG = 1 then
        output &RESLIB1..all_exp_sec_underlying;
    
    else 
        output &RESLIB1..all_exposures;

    run;

/*- 1: exposures underlying unrated securitization exposures under IRB -*/
    data  &RESLIB1..all_exp_sec_underlying_irb(index=(POOL_CPTY=(SECURITIZATION_POOL_RK COUNTERPARTY_RK)));
    merge &RESLIB1..all_exp_sec_underlying(in=underlying) &RESLIB1..all_exp_ur_sec_irb(in=ur_irb keep=SECURITIZATION_POOL_RK);
    by SECURITIZATION_POOL_RK;
    if underlying and ur_irb;
    run;    
    
/*- 2: if neither underlying nor unrated available, update unnecessary -*/
    %local N_SEC_UNDERLYING_IRB N_UR_SEC_IRB N_UR_SEC_IRB_SF_UPDATE;
    %let N_SEC_UNDERLYING_IRB = %attrn(&RESLIB1..all_exp_sec_underlying_irb, NOBS);
    %let N_UR_SEC_IRB         = %attrn(&RESLIB1..all_exp_ur_sec_irb, NOBS);    
    %let N_UR_SEC_IRB_SF_UPDATE = 0;
    
/*- 3: if no underlying available, update unnecessary -*/
    %if &N_SEC_UNDERLYING_IRB = 0 or &N_UR_SEC_IRB = 0 %then %goto NO_UPDATE_UR_SEC;

/*- 4: find weighted average LGD for securitization pools under IRB -*/
    proc summary data = &RESLIB1..all_exp_sec_underlying_irb;
    by SECURITIZATION_POOL_RK;
    weight EAD;
    var LGD_EXP;
    by SECURITIZATION_POOL_RK;
    output out  = lgd_sec_underlying_ur_irb(keep = SECURITIZATION_POOL_RK WA_LGD)
           mean = WA_LGD
           ;
    run;

/*- 5: find effective number of exposures for securitization pools under IRB -*/
/*-    actually, effective number of obligors: Basel II - 633                -*/    
    data n_sec_underlying_ur_irb(keep = SECURITIZATION_POOL_RK N_EFFECTIVE);
    set &RESLIB1..all_exp_sec_underlying_irb;
    by SECURITIZATION_POOL_RK COUNTERPARTY_RK;
    retain EAD_CPTY EAD_SUM EADSQ_SUM 0;

    if first.SECURITIZATION_POOL_RK then do;
       EAD_SUM = 0;
       EADSQ_SUM = 0;
    end;
    
    if first.COUNTERPARTY_RK then EAD_CPTY = 0;
       EAD_CPTY + EAD;

    if last.COUNTERPARTY_RK then do;
       EAD_SUM + EAD_CPTY;
       EADSQ_SUM + (EAD_CPTY * EAD_CPTY);
    end;

    if last.SECURITIZATION_POOL_RK and EADSQ_SUM not in (., 0) then do;
        N_EFFECTIVE = EAD_SUM * EAD_SUM / EADSQ_SUM;
        output;
    end;
    run;

/*- 6: update LGD and N for ur securitization exposures: subject to SF -*/
/*-    update only where underlying exposures are available and when   -*/
/*-    there are no user-supplied values                               -*/
    data &RESLIB1..sf_input_sec_underlying_ur_irb;
    merge lgd_sec_underlying_ur_irb n_sec_underlying_ur_irb;
    by SECURITIZATION_POOL_RK;
    run;
    
    data &RESLIB1..all_exp_ur_sec_irb(drop=WA_LGD N_EFFECTIVE index=(EXP_ID));
    merge &RESLIB1..all_exp_ur_sec_irb(in=ur_irb) &RESLIB1..sf_input_sec_underlying_ur_irb(in=sf_input);
    by SECURITIZATION_POOL_RK;

    if WEIGHTED_AVG_LGD_PCT = . and WA_LGD NE . then do;
        WEIGHTED_AVG_LGD_PCT = WA_LGD;
        SF_INPUT_UPDATE_FLG = 1;
    end;
    if EFFECTIVE_NUMBER_OF_EXPOSURES = . and N_EFFECTIVE NE . then do;
        EFFECTIVE_NUMBER_OF_EXPOSURES = N_EFFECTIVE;
        SF_INPUT_UPDATE_FLG = 1;
    end;

    if WEIGHTED_AVG_LGD_PCT NE . then LGD_EXP = WEIGHTED_AVG_LGD_PCT;
    
    run;

    proc sql noprint;
    select count(*) into :N_UR_SEC_IRB_SF_UPDATE
    from &RESLIB1..all_exp_ur_sec_irb(keep=SF_INPUT_UPDATE_FLG)
    where SF_INPUT_UPDATE_FLG = 1;
    quit;

    %if &N_UR_SEC_IRB_SF_UPDATE > 0 %then %do;
        %put ;
        %print_msg(note,2,70);
        %print_msg(note,2,71);
        %print_msg(note,2,72);
        %put ;
    %end;
    
%NO_UPDATE_UR_SEC :

/*- 7: get these updated securitization exposures under IRB back    -*/
/*-    underlying exposures are still needed for K_IRB calculation  -*/
/*-    but for now, these underlying exposures remain separate   -*/
    proc append base=&RESLIB1..all_exposures data=&RESLIB1..all_exp_ur_sec_irb (drop=SF_INPUT_UPDATE_FLG)force;
    run;    

/*- update exposure-crm links only when necessary -*/
    /*- if no update done to unrated, no need to update -*/
    %if &N_UR_SEC_IRB_SF_UPDATE = 0 %then %do;
        %goto EXIT;
    %end;
    
    %if &N_UR_SEC_IRB_SF_UPDATE > 0 %then %do;
        data &RESLIB1..exposure_crm(drop=SF_INPUT_UPDATE_FLG);
        merge &RESLIB1..exposure_crm(in=exp_crm)
              &RESLIB1..all_exp_ur_sec_irb
              (in=exp_update where=(SF_INPUT_UPDATE_FLG=1)
               keep=EXP_ID LGD_EXP WEIGHTED_AVG_LGD_PCT EFFECTIVE_NUMBER_OF_EXPOSURES SF_INPUT_UPDATE_FLG
              );
        by EXP_ID;
        if exp_crm;
        run;
    %end;
    
    %EXIT :

%mend r00_post_regulatory_4_crd4;
