/*****************************************************************************
 * Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME: r00_post_regulatory_8_crd4.sas
 *
 * PURPOSE: Prepare for crm allocation through BY_RANK. 
 *
 *
 *   USAGE: 
 *
 *   NOTES:  
 *          
 *
 *****************************************************************************/

%macro r00_post_regulatory_8_crd4;

/*- Only when CRM allocation is by rank -*/
    %if %upcase(&MITIGANTS_ALLOCATION_METHOD) NE BY_RANK %then %goto EXIT;

/*- prepare data for crm allocation by rank -*/
    %prepare_crm_allocation_crd4(EXPCRMDS = &RESLIB1..exposure_crm, 
                            EXPDS    = &RESLIB1..all_exp_incl_sec_underly,
                            CRMDS    = &RESLIB1..all_crms, 
                            NODEDS   = &RESLIB1..node, 
                            ARCDS    = &RESLIB1..arc, 
                            EXPNOCRM = &RESLIB1..exp_wo_crm, 
                            EXP1CRM1 = &RESLIB1..unique_exp_crm,
                            METHOD   = BY_RANK 
                            );

/*- create mitigation data set -*/
    data &RESLIB1..exp_crm_link;
    set &RESLIB1..exposure_crm(keep=EXP_ID CRM_ID _MULT_ _WEIGHT_ _WEIGHT_DBL_DEF_EFFECT_ RW_EXP CRM_TYPE APPROACH HAIRCUT_EXP
                                       PD_EXP LGD_EXP PD_CRM PD_CRM_COUNTERPARTY LGD_CRM CRM_SUBTYPE LGD_CRM_ADJUSTED_FLG
                                       EXPOSURE_RANK CRM_RANK CRM_COMP_FLG 
                                       /*LGD_EXP_OTHER RW_EXP_OTHER*/
                                       %if "&APPLY_CCF_AFTER_CRM" = "YES" %then %do;
                                       OFF_BALANCE_SHEET_FLG 
                                       %end;
                                       CCF
                               rename=(APPROACH=EXP_APPROACH HAIRCUT_EXP=MIT_HAIRCUT_EXP
                                        CRM_TYPE=CRMTYPE PD_EXP=MIT_PD_EXP 
                                        PD_CRM_COUNTERPARTY=MIT_PD_CRM_CPTY PD_CRM=MIT_PD_CRM
                                        LGD_EXP=MIT_LGD_EXP LGD_CRM=MIT_LGD_CRM RW_EXP=MIT_RW_EXP
                                        /*RW_EXP_OTHER=MIT_RW_EXP_OTHER*/ EXP_ID=EXPOSUREID CRM_ID=MITIGANTID 
                                       )
                              );
    %if "&APPLY_CCF_AFTER_CRM" = "YES" %then %do;
    length MIT_CCF_FLG 8.;
    %end;
    
    MITIGATIONTYPE="REGULATORY_MITIGATION";
       
/*- add variable NOT_NETTING_FIN_COLLATERAL -*/
    NOT_NETTING_FIN_COLLATERAL = 1;
    if CRMTYPE in ("FINANCIAL_COLLATERAL", "NETTING") then NOT_NETTING_FIN_COLLATERAL = 0;
    %if "&APPLY_CCF_AFTER_CRM" = "YES" %then %do;
    if OFF_BALANCE_SHEET_FLG = 1 and CCF = 0 then MIT_CCF_FLG=1;
    else MIT_CCF_FLG=0;
    %end;
    
/*- assigning lower priority to missing ranks -*/
    if missing(EXPOSURE_RANK) then EXPOSURE_RANK=1000;
    if missing(CRM_RANK) then CRM_RANK=1000;
    run;   
    
/*- sort exposure_crm link by exposure rank and crm rank -*/
/*- netting and financial collateral are always used first */
    proc sort data = &RESLIB1..exp_crm_link;
    by EXPOSURE_RANK CRM_RANK NOT_NETTING_FIN_COLLATERAL;
    run;   
    
/*- make crm data, only those crm that appear in the link data are selected -*/
    proc sql;
       create table &RESLIB1..all_crm_input 
       as select CRM_VALUE as CRM_VALUE,
                 CRM_ID as INSTID,
                 "CRM" as POSITION_CATEGORY
       from &RESLIB1..all_crms
       where CRM_ID in (select MITIGANTID from &RESLIB1..exp_crm_link );
    quit;
    
/*- create dummy cross class variables for a clean run 
    data &RESLIB1..all_crm_input;
    length &ALL_CC_VARS $32.;
    set &RESLIB1..all_crm_input;
    run;
-*/    
    %EXIT :

%mend r00_post_regulatory_8_crd4;
