
/*****************************************************************************
 * Copyright (c) 2013 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME: r00_post_regulatory_9_crd4.sas
 *
 * PURPOSE: Allocate CRMs through PROC NETFLOW and post-process the results. 
 *
 *
 *   USAGE: 
 *
 *   NOTES:  
 *          
 *   MODIFIED: 05/04/05
 *****************************************************************************/

%macro r00_post_regulatory_9_crd4;

/*- Only when optimal CRM allocation is required -*/
    %if %upcase(&MITIGANTS_ALLOCATION_METHOD) NE OPTIMAL %then %goto EXIT;

/*- 1: allocate crm optimally -*/    
    %allocate_crm_optimal_crd4(EXPCRMDS = &RESLIB1..exposure_crm,
                          EXPDS    = &RESLIB1..all_exp_incl_sec_underly, 
                          NODEDS   = %if &N_NETWORK > 0 %then %do; &RESLIB1..node %end;, 
                          ARCDS    = %if &N_NETWORK > 0 %then %do; &RESLIB1..arc %end;, 
                          EXPNOCRM = &RESLIB1..exp_wo_crm, 
                          EXP1CRM1 = %if &N_EXP_CRM > 0 %then %do; &RESLIB1..unique_exp_crm %end;, 
                          CONDS    = &RESLIB1..condata, 
                          CONOUTDS = intpoint_out2, 
                          OUTDS    = arcout_full
                         );
    %if &SYSTEM_FATAL_ERROR=Y %then %goto EXIT;
    
/*- 2: crm calculation -*/
    data &RESLIB1..crm_allocation_optimal_detail
         (label="Detailed Optimal CRM Allocation Information"
         drop = _SUPPLY_ _DEMAND_ _VALUE_ _VALUE_0 _FCOST_) /*- detailed information -*/
         ;      
    set arcout_full;
    
    UNDERLYING_EXP_EAD = 0;
    
    label EAD_ADJ = "Adjusted EAD in RWA calculation";
    
    EAD_ADJ = _DEMAND_;
    EAD_PORTION=_VALUE_;

    RWA = _FCOST_ / 100;  

    if CRM_TYPE = '' then CRM_TYPE = 'NOT_COVERED';

    if CRM_ID NE 'NOT_COVERED' then do;
        CRM_USED_AMT     = _VALUE_0;
        CRM_USED_AMT_EFF = _VALUE_;
    end;
    else do;
        CRM_USED_AMT     = 0;
        CRM_USED_AMT_EFF = 0;
    end;

    if CRM_ID = 'NOT_COVERED' then do;
        RWA_SECURED   = 0;
        RWA_UNSECURED = RWA;
    end;
    else do;
        RWA_SECURED   = RWA;
        RWA_UNSECURED = 0;
    end;

/*- Adjustment to RWA for SME exposures subject to SME supporting factor: CRR Article 501 -*/ 
    RWA_PRE_SME = RWA;
    if not (IN_DEFAULT_FLG =1 or PAST_DUE_CLAIM_FLG =1) and not (HIGH_RISK_CPTY_FLG=1 or STD_PRODUCT_CLASS ='HIGH_RISK') 
       and COUNTERPARTY_CLASS in ('RETAIL','CORPORATE') and COUNTERPARTY_SUBCLASS ='SME'
       and SME_CAP_DEDUCTION_TRT_FLG = 1 then do ;
       RWA = &SME_SUPPORTING_FACTOR * RWA ;
       RWA_SECURED = &SME_SUPPORTING_FACTOR * RWA_SECURED ;
       RWA_UNSECURED = &SME_SUPPORTING_FACTOR * RWA_UNSECURED ;
    end ;  
    
/*- calculate effect of infringement adjustment -*/ 
/*- RWA variable already contains the effect of infringement at this point, so 
    only calculate the pre-infringement adjustment -*/
    if SEC_INFRINGEMENT_FLG = 1 then do;     
        RWA_SEC_ORIG = RW_EXP_BEFORE_INFRINGEMENT/100 * EAD_PORTION;
    end;
    else do;   
        RWA_SEC_ORIG = RWA;
    end;
    SEC_INFRINGE_ADJUST_AMT = sum(RWA, -RWA_SEC_ORIG);
     
    PD_LGD_WEIGHT = .;
    PD_EFF  = .;
    LGD_EFF = .;
       
    if APPROACH in ('IRB', 'IRBF', 'IRBA', 'IRB_PD_LGD', 'IRB_SLOTTING') then do;
    
        PD_LGD_WEIGHT = _VALUE_;
        PD_EFF  = PD_EXP;
        LGD_EFF  = LGD_EXP;
  
        if CRM_TYPE NE 'NOT_COVERED' then do;
            if CRM_TYPE in ('GUARANTEE', 'CREDIT_DERIVATIVE', 'INSURANCE') then do;
                PD_EFF = PD_CRM_COUNTERPARTY;
                if "&IRB_USE_GUARANTEE_LGD" = "YES" and LGD_CRM NE . then LGD_EFF = LGD_CRM;            
            end;
            else do;
                LGD_EFF = LGD_CRM;
            end;
        end;

    end;
  
 /*   if CRM_TYPE = 'NOT_COVERED' then do;
        CRM_TYPE = " ";
        CRM_ID   = " ";
    end;*/

    run;

/***********************************************************************************/
/* get total RWA for all underlying exposures linked to a SECURITIZATION_POOL_RK   */
/***********************************************************************************/
/*- create dataset for underlying exposures in a securitization pool -*/
   data &RESLIB1..sec_underlying_optimal_detail;
   set &RESLIB1..crm_allocation_optimal_detail ;
    if SEC_UNDERLYING_EXP_FLG = 1;
    
    if IN_DEFAULT_FLG = 1 or PAST_DUE_CLAIM_FLG = 1 then 
        RWA_UND_FOR_CAP_CALC = EAD_PORTION * 1.5; 
    else
        RWA_UND_FOR_CAP_CALC = RWA;
    
   run;

   proc sort data= &RESLIB1..sec_underlying_optimal_detail;
   by SECURITIZATION_POOL_RK ;
   run;
/*- get total EAD and RWA for all underlying expousures in a securitization pool -*/
   proc summary data=&RESLIB1..sec_underlying_optimal_detail;
      by SECURITIZATION_POOL_RK;
      var EAD RWA RWA_UND_FOR_CAP_CALC ;
      output out= &RESLIB1..rwa_sec_underlying(keep=SECURITIZATION_POOL_RK EAD_SEC_UNDERLYING_SUM RWA_SEC_UNDERLYING_SUM  RWA_SEC_UNDERLYING_SUM_FOR_CAP )  
             sum=EAD_SEC_UNDERLYING_SUM RWA_SEC_UNDERLYING_SUM RWA_SEC_UNDERLYING_SUM_FOR_CAP;          
   run;  

/*- exclude sec underlying exposures -*/
   proc sql ;
         delete from &RESLIB1..crm_allocation_optimal_detail 
         where SEC_UNDERLYING_EXP_FLG = 1 ;
   quit ;
    
   proc sort data= &RESLIB1..crm_allocation_optimal_detail ;
      by SECURITIZATION_POOL_RK ;
   run;

/*- add total EAD and RWA from sec underlying pool to crm_allocation_optimal_detail table -*/
   data &RESLIB1..crm_allocation_optimal_detail ;     
      merge &RESLIB1..crm_allocation_optimal_detail &RESLIB1..rwa_sec_underlying;
      by SECURITIZATION_POOL_RK;
   run ;  
  
    data all_sec_tranches 
         all_sec_facility 
         all_sec_deriv;
      set &RESLIB1..crm_allocation_optimal_detail  
          (keep = EXP_ID SECURITIZATION_POOL_RK TRANCHE_SENIORITY_RANK SECURITIZATION_EXPOSURE_FLG
                  FACILITY_FLG STD_PRODUCT_CLASS IRB_PRODUCT_CLASS
                  TRANCHE_FACE_VALUE_AMT FACE_VALUE_AMT EXP_VALUE RWA ) ;      
      if SECURITIZATION_EXPOSURE_FLG =1 and SECURITIZATION_POOL_RK ne . and TRANCHE_SENIORITY_RANK ne . then output all_sec_tranches ;
      else if SECURITIZATION_EXPOSURE_FLG =1 and SECURITIZATION_POOL_RK ne . and FACILITY_FLG =1 then output all_sec_facility ;
      else if SECURITIZATION_EXPOSURE_FLG =1 and SECURITIZATION_POOL_RK ne . and 
              (STD_PRODUCT_CLASS = 'DERIVATIVE' or IRB_PRODUCT_CLASS = 'DERIVATIVE') then output all_sec_deriv ;
    run;
 
 /*- get RWA for all securitization tranche exposures linked to a securitization_pool_rk, -*/
 /*- regardless if they are owned by the reporting institution.                           -*/
 /*- RWA_ALL_TRANCHES is used for cap calculation for securitizations with EAP.           -*/  
    proc summary data = all_sec_tranches;
           by SECURITIZATION_POOL_RK;
           var RWA ;
           output out= rwa_sec_all_tranches(keep=SECURITIZATION_POOL_RK RWA_ALL_TRANCHES )  
                 sum = RWA_ALL_TRANCHES;  
    run;
    
/*- get SEC_TOTAL_AMT_ORIGINATED: first column of CRSEC SA and CRSEC IRB report templates -*/
   %calc_sec_tot_amt_orig_crd4 ; 
                 
/*- exclude securitization tranche exposures that are not owned by the reporting institution -*/ 
   proc sql ;
         delete from &RESLIB1..crm_allocation_optimal_detail 
         where EXP_NOT_OWNED_FLG = 1 ;
   quit ;
    
    
/*- get total RWAs within a SECURITIZATION_POOL_RK:                                                                      -*/
/*- for each SECURITIZATION_POOL_RK, RWA_SEC_SUM is the total RWA of securitization exposures owned by the institution,  -*/
/*- and RWA_TRANCHE_SUM is the the total RWA of securitization tranche exposures owned by the institution                -*/
    data sec_exposures;
        set &RESLIB1..crm_allocation_optimal_detail;        
        if SECURITIZATION_POOL_RK ne . and SECURITIZATION_EXPOSURE_FLG =1 and STD_PRODUCT_SUBCLASS not in ('EAP_INVESTORS_INT', 'DEDUCTION', 'EAP_ORIGINATOR_INT') and
          IRB_PRODUCT_SUBCLASS not in ('EAP_INVESTORS_INT', 'DEDUCTION', 'EAP_ORIGINATOR_INT') ;
        
        if not (TRANCHE_SENIORITY_RANK = . and TRANCHE_LOSS_RANK = . ) then RWA_TRANCHE = RWA;
        else RWA_TRANCHE = 0;
    run;
    
    proc summary data = sec_exposures;
        by SECURITIZATION_POOL_RK;
        var RWA RWA_TRANCHE;
        output out= sec_tranche_sum(keep=SECURITIZATION_POOL_RK RWA_SEC_SUM RWA_TRANCHE_SUM )  
              sum = RWA_SEC_SUM RWA_TRANCHE_SUM;  
    run;
    
    data &RESLIB1..crm_allocation_optimal_detail ;       
       merge &RESLIB1..crm_allocation_optimal_detail
             sec_tranche_sum 
             rwa_sec_all_tranches
             sec_tot_amt_orig ;
       by SECURITIZATION_POOL_RK;
    run;
    
 /*- sort dataset by EXP_ID again */         
   proc sort data= &RESLIB1..crm_allocation_optimal_detail ;
      by EXP_ID ;
   run ;

 /*- get sum of EAD_PORTION for each EXP_ID  -*/  
   proc sql ;
      create table tot_ead_portion as
      select EXP_ID,  sum(EAD_PORTION) as EAD_PORTION_SUM
      from &RESLIB1..crm_allocation_optimal_detail
      where SECURITIZATION_EXPOSURE_FLG = 1 
      group by EXP_ID ;
   quit ;
      
   data &RESLIB1..crm_allocation_optimal_detail
        "&OUTPATH&PATHSEP.crm_allocation_optimal"  /*- brief information -*/
              (label="Optimal CRM Allocation Information"
               keep = /*- brief exposure information -*/
                      EXP_ID COUNTERPARTY_CLASS COUNTERPARTY_SUBCLASS STD_PRODUCT_: IRB_PRODUCT_: APPROACH CCY 
                      REGULATORY_COUNTERPARTY_TYPE_CD REGULATORY_PRODUCT_CD OFF_BALANCE_SHEET_TYPE_CD
                      INCEPTION_DATE MATURITY_DATE EXP_VALUE EAD HAIRCUT_EXP PD_EXP LGD_EXP RW_EXP RESMAT_EXP 
                      ORIGINAL_MATURITY RESIDUAL_MATURITY EXT_MAP_RATING EXT_ISSUE_MAP_RATING EXT_ISSUE_INCEP_MAP_RATING PAST_DUE_CLAIM_FLG IN_DEFAULT_FLG 
                      CCF HAIRCUT_FX PRIMARY_BANK_ROLE SEC_STRUCTURE_TYPE STD_RW_FROM_ECAI_FLG STD_RW_FROM_CENTGOV_FLG CENTGOV_TRT_FLG 
                      LE_PRODUCT_CLASS LE_OBSI_TYPE TRADING_BOOK_FLG TRADE_EXP_FLG BANKRUPTCY_REMOTE_FLG 
                      ASSET_TRANSFERRABLE_FLG NO_LOSS_FROM_CM_BANKRUPTCY_FLG CCP_CPTY_SUBCLASS
                      COUNTERPARTY_RK COUNTERPARTY_NAME COUNTERPARTY_TYPE_CD COUNTERPARTY_GROUP
                      COUNTERPARTY_GROUP_PARENT_FLG SECTOR COUNTERPARTY_COUNTRY NACE LEGAL_ENTITY_ID SME_SUPPORTING_FACTOR_FLG
                      FREE_DELIVERY_FLG CONNECTION_TYPE_CD FINANCIAL_ENTITY_TYPE_CD COUNTERPARTY_CD 
                      RW_EXP_BEFORE_INFRINGEMENT SEC_INFRINGE_ADJUST_AMT SEC_INFRINGEMENT_FLG SEC_DEDUCTION_AMT SEC_TOTAL_AMT_ORIGINATED
                      ORIGINATION_COUNTRY_CD BUSINESS_TYPE_CD SME_CAP_DEDUCTION_TRT_FLG
                      /*- brief crm information -*/
                      CRM_ID CRM_COUNTERPARTY_CLASS CRM_COUNTERPARTY_SUBCLASS CRM_TYPE CRM_SUBTYPE ELIGIBLE_CRM_TYPE CRM_CCY
                      CRM_EFFECTIVE_DATE CRM_EXPIRATION_DATE CRM_INCEPTION_DATE CRM_MATURITY_DATE CRM_VALUE_DISCOUNT_FLG
                      CRM_VALUE HAIRCUT_CRM PD_CRM LGD_CRM RW_CRM RW_CRM_COUNTERPARTY RESMAT_CRM 
                      CRM_ORIGINAL_MATURITY CRM_RESIDUAL_MATURITY LINK_RESIDUAL_MATURITY
                      CRM_COUNTERPARTY_RK CRM_COUNTERPARTY_NAME CRM_COUNTERPARTY_TYPE_CD CRM_COUNTERPARTY_GROUP
                      CRM_CPTY_GROUP_PARENT_FLG CRM_COUNTERPARTY_SECTOR CRM_COUNTERPARTY_COUNTRY CRM_NACE CRM_LEGAL_ENTITY_ID
                      EAD_ADJ CRM_CONNECTION_TYPE_CD CRM_FINANCIAL_ENTITY_TYPE_CD CRM_COUNTERPARTY_CD 
                      /*- brief crm allocation information -*/
                      MAT_MISMATCH_WEIGHT_CRM _COST_ _MULT_ CRM_USED_AMT CRM_USED_AMT_EFF RWA RWA_PRE_SME RWA_SEC_MAT_MIS_ADJ_AMT 
                      RWA_SEC_ORIG RWA_BEFORE_CAP RWA_SEC_MEMO_AMT 
                      /* exposure to underlyings for LE report */
                       UNDERLYING_EXP_EAD
              )
         ;
         
     merge &RESLIB1..crm_allocation_optimal_detail 
           tot_ead_portion ;
     by EXP_ID ;

 /*- Calculate RWA adjustments for securitization exposures: CRR Articles 249,250,252 and 256 -*/ 
  %calc_sec_rwa_adj_amt_crd4(calc_option=CRM_ALLOCATION) ;
   if CRM_ID = 'NOT_COVERED' then do;
                RWA_SECURED   = 0;
                RWA_UNSECURED = RWA;
         end;
         else do;
                RWA_SECURED   = RWA;
                RWA_UNSECURED = 0;
         end;         
      
         if CRM_TYPE = 'NOT_COVERED' then do;
              CRM_TYPE = " ";
              CRM_ID   = " ";
         end;
   run;
   
/*- for CRSA report, adjuments to exposures secured by imm. properties: EXP_VALUE_IMP_ADJ, RW_EXP_IMP_ADJ            -*/       
 /*- SPECIFIC_PROVISION_IMP_ADJ and SPECIFIC_WRITEOFF_IMP_ADJ are created to get CRSA report template columns 010-040 -*/ 
%get_rw_adj_immprpty_crd4(crmalloc=optimal) ; 
  
/**************************************************
   update crm_allocation_optimal and
   crm_allocation_optimal_detail tables with columns
   needed for Large Exposure report
**************************************************/
    
    data "&OUTPATH&PATHSEP.crm_allocation_optimal";
    set "&OUTPATH&PATHSEP.crm_allocation_optimal"; 
        /*- add variables for LE report  -*/
          if LE_OBSI_TYPE NE '' THEN LE_PRODUCT_CLASS = ''; 
          if CRM_ID = '' then do;
            LE_COUNTERPARTY_RK = COUNTERPARTY_RK;
            DIRECT_EXP_FLG = 'Y';  
            if LE_PRODUCT_CLASS = 'DERIVATIVE' then do;
                LE_ORIG_EXPOSURE_AMT = EAD;   
            end;
            else do;
                LE_ORIG_EXPOSURE_AMT = EXP_VALUE;              
            end;   
        end;
        else do;
            LE_COUNTERPARTY_RK = CRM_COUNTERPARTY_RK;
            COUNTERPARTY_NAME = CRM_COUNTERPARTY_NAME;
            COUNTERPARTY_COUNTRY = CRM_COUNTERPARTY_COUNTRY;
            COUNTERPARTY_TYPE_CD = CRM_COUNTERPARTY_TYPE_CD;
            COUNTERPARTY_GROUP = CRM_COUNTERPARTY_GROUP;
            COUNTERPARTY_GROUP_PARENT_FLG = CRM_CPTY_GROUP_PARENT_FLG;
            COUNTERPARTY_SECTOR = CRM_COUNTERPARTY_SECTOR; 
            NACE = CRM_NACE;
            LEGAL_ENTITY_ID = CRM_LEGAL_ENTITY_ID;
             
            CONNECTION_TYPE_CD = CRM_CONNECTION_TYPE_CD; 
            FINANCIAL_ENTITY_TYPE_CD = CRM_FINANCIAL_ENTITY_TYPE_CD; 
            COUNTERPARTY_CD = CRM_COUNTERPARTY_CD; 
    
            DIRECT_EXP_FLG = 'N';
            LE_ORIG_EXPOSURE_AMT = CRM_USED_AMT_EFF;

        end;
        if COUNTERPARTY_GROUP_PARENT_FLG = . then COUNTERPARTY_GROUP_PARENT_FLG = 0; 
        drop COUNTERPARTY_RK CRM_COUNTERPARTY_RK CRM_COUNTERPARTY_RK CRM_COUNTERPARTY_NAME CRM_COUNTERPARTY_COUNTRY
                COUNTERPARTY_TYPE_CD CRM_COUNTERPARTY_GROUP
                CRM_CPTY_GROUP_PARENT_FLG CRM_COUNTERPARTY_SECTOR CRM_COUNTERPARTY_COUNTRY CRM_NACE CRM_LEGAL_ENTITY_ID; 
    run;    
    
    /*- add variables for LE report -*/  
    data &RESLIB1..crm_allocation_optimal_detail;
        set &RESLIB1..crm_allocation_optimal_detail; 
        
        /*- add variables for LE report  -*/
          if LE_OBSI_TYPE NE '' THEN LE_PRODUCT_CLASS = ''; 

          if CRM_ID = '' then do;
            LE_COUNTERPARTY_RK = COUNTERPARTY_RK;
            DIRECT_EXP_FLG = 'Y';  
            if LE_PRODUCT_CLASS = 'DERIVATIVE' then do;
                LE_ORIG_EXPOSURE_AMT = EAD;   
            end;
            else do;
                LE_ORIG_EXPOSURE_AMT = EXP_VALUE;              
            end;   
        end;
        else do;
            LE_COUNTERPARTY_RK = CRM_COUNTERPARTY_RK;
            COUNTERPARTY_NAME = CRM_COUNTERPARTY_NAME;
            COUNTERPARTY_COUNTRY = CRM_COUNTERPARTY_COUNTRY;
            COUNTERPARTY_TYPE_CD = CRM_COUNTERPARTY_TYPE_CD;
            COUNTERPARTY_GROUP = CRM_COUNTERPARTY_GROUP;
            COUNTERPARTY_GROUP_PARENT_FLG = CRM_CPTY_GROUP_PARENT_FLG;
            COUNTERPARTY_SECTOR = CRM_COUNTERPARTY_SECTOR; 
            NACE = CRM_NACE;
            LEGAL_ENTITY_ID = CRM_LEGAL_ENTITY_ID;
            
            CONNECTION_TYPE_CD = CRM_CONNECTION_TYPE_CD; 
            FINANCIAL_ENTITY_TYPE_CD = CRM_FINANCIAL_ENTITY_TYPE_CD; 
            COUNTERPARTY_CD = CRM_COUNTERPARTY_CD;             

            DIRECT_EXP_FLG = 'N';
            LE_ORIG_EXPOSURE_AMT = CRM_USED_AMT_EFF;

        end;
        if COUNTERPARTY_GROUP_PARENT_FLG = . then COUNTERPARTY_GROUP_PARENT_FLG = 0; 
    run;    
    
/**************************************************   
 **************************************************/  
 
/*- aggregate over each exposure -*/
/*- get weighted effective PD and LGD for each exposure -*/
    proc summary data = &RESLIB1..crm_allocation_optimal_detail (where = (PD_LGD_WEIGHT NE . )) ;
    by EXP_ID;
    var PD_EFF LGD_EFF;
    weight PD_LGD_WEIGHT;
    output out  = pd_lgd_by_exp(keep = EXP_ID PD_EFF LGD_EFF PD_LGD_WEIGHT)
           mean = PD_EFF LGD_EFF sumwgt=PD_LGD_WEIGHT;
    run;

/*- get totals for each exposure -*/
    proc summary data = &RESLIB1..crm_allocation_optimal_detail;
    by EXP_ID;
    var RWA RWA_PRE_SME RWA_SECURED RWA_UNSECURED CRM_USED_AMT CRM_USED_AMT_EFF 
        RWA_SEC_ORIG RWA_SEC_MAT_MIS_ADJ_AMT RWA_BEFORE_CAP RWA_SEC_MEMO_AMT; 
    output out  = total_by_exp(keep = EXP_ID RWA RWA_PRE_SME RWA_SECURED RWA_UNSECURED
                                      CRM_USED_AMT CRM_USED_AMT_EFF 
                                      RWA_SEC_ORIG RWA_SEC_MAT_MIS_ADJ_AMT RWA_BEFORE_CAP RWA_SEC_MEMO_AMT)
           sum  = RWA RWA_PRE_SME RWA_SECURED RWA_UNSECURED CRM_USED_AMT CRM_USED_AMT_EFF 
                  RWA_SEC_ORIG RWA_SEC_MAT_MIS_ADJ_AMT RWA_BEFORE_CAP RWA_SEC_MEMO_AMT; 
    run;

/*- update to get necessary flags for post- processing -*/

data total_by_exp ;
  merge total_by_exp (in =a)
        "&REGPATH&PATHSEP.all_exp_incl_sec_underly" (keep= EXP_ID TRADING_BOOK_FLG TRADE_EXP_FLG BANKRUPTCY_REMOTE_FLG
                                                           ASSET_TRANSFERRABLE_FLG NO_LOSS_FROM_CM_BANKRUPTCY_FLG CCP_CPTY_SUBCLASS
                                                           SME_CAP_DEDUCTION_TRT_FLG in=b) ;
  by EXP_ID ;
  if a ;
run ;  

/*- contains one observation per EXP_ID -*/
/*- crm info dropped since meaningless  -*/
/*- only keep necessary information -*/
    
    /*- get crm-related variable list -*/
    %local CRM_VARLIST;
    %let CRM_VARLIST = %dsvarlist(&RESLIB1..all_crms);    
            
data  "&OUTPATH&PATHSEP.capital_detail_optimal"
(label="Capital Requirement for all Exposures (Optimal)" 
keep = EXP_ID COUNTERPARTY_CLASS COUNTERPARTY_SUBCLASS APPROACH STD_PRODUCT_: IRB_PRODUCT_: CCY
REGULATORY_COUNTERPARTY_TYPE_CD REGULATORY_PRODUCT_CD OFF_BALANCE_SHEET_TYPE_CD 
TRADING_BOOK_FLG TRADE_EXP_FLG BANKRUPTCY_REMOTE_FLG ASSET_TRANSFERRABLE_FLG NO_LOSS_FROM_CM_BANKRUPTCY_FLG CCP_CPTY_SUBCLASS
INCEPTION_DATE MATURITY_DATE EXP_VALUE EAD HAIRCUT_EXP ADD_ON CCF SECTOR COUNTERPARTY_COUNTRY COUNTERPARTY_CLASS
PD_EXP PD_EFF LGD_EXP LGD_EFF ORIGINAL_MATURITY RESIDUAL_MATURITY EXT_MAP_RATING EXT_ISSUE_MAP_RATING EXT_ISSUE_INCEP_MAP_RATING PAST_DUE_CLAIM_FLG IN_DEFAULT_FLG
RW RW_EXP RW_NO_CRM RWA RWA_NO_CRM RWA_SECURED RWA_UNSECURED CAPITAL CAPITAL_NO_CRM CRM_USED_AMT CRM_USED_AMT_EFF 
EL EL_EFF SPECIFIC_PROVISION CPTY_PD_MODEL_ID CPTY_PD_RATING_GRADE MAT_EFF PRIMARY_BANK_ROLE SEC_STRUCTURE_TYPE SEC_STRUCTURE_SUBTYPE TRANCHE_SENIORITY_RANK
TRANCHE_LOSS_RANK COUNTERPARTY_RK TRANCHE_FACE_VALUE_AMT EARLY_AMORTIZATION_TYPE 
STD_RW_FROM_ECAI_FLG STD_RW_FROM_CENTGOV_FLG SME_SUPPORTING_FACTOR_FLG SME_CAP_DEDUCTION_TRT_FLG RWA_PRE_SME FREE_DELIVERY_FLG
RWA_SEC_ORIG RWA_SEC_MAT_MIS_ADJ_AMT RWA_BEFORE_CAP SEC_TOTAL_AMT_ORIGINATED RWA_SEC_MEMO_AMT
SECURITIZATION_POOL_ID SECURITIZATION_POOL_RK RESECURITIZATION_FLG POOL_FACE_VALUE_AMT 
EFFECTIVE_NUMBER_OF_EXPOSURES WEIGHTED_AVG_LGD_PCT K_IRB SENIORITY_CD SHORTPOSITION
SECURITIZATION_TREATMENT_TYPE SEC_RETENTION_TYPE SEC_PORTFOLIO_TYPE SEC_RETENTION_COMPLIANCE_FLG 
INSTITUTION_SHARE_PCT SEC_RETENTION_PCT SEC_ACCTING_TREATMENT CORRELATION_TRADING_PORT_FLG SEC_DEDUCTION_AMT
ORIGINATION_COUNTRY_CD FIRST_POSSIBLE_TERM_DT LONGEST_MATURITY_DATE COUNTERPARTY_ID)
  
          &RESLIB1..all_exposures_before_rollup;
        
    merge 

        &RESLIB1..crm_allocation_optimal_detail
          (in = detail 
           drop = &CRM_VARLIST /*- crm information -*/
                  RWA RWA_SECURED RWA_UNSECURED CRM_USED_AMT CRM_USED_AMT_EFF RWA_SEC_MAT_MIS_ADJ_AMT RWA_BEFORE_CAP RWA_SEC_MEMO_AMT
          )          
          pd_lgd_by_exp(in = pdlgd)
          %if N_EXP_CRM > 0 %then %do;
          total_by_exp (in = total)
          %end;
          exp_haircut_adjust (in=adjust keep=EXP_ID);

    by EXP_ID;
    
    label EL_EFF='Effective expect loss after CRM (%)';
   
    CAPITAL = RWA * &CAPITAL_RATIO;
    if not missing(COUNTERPARTY_RK) then COUNTERPARTYID = compress( 'CPTY_' || put( COUNTERPARTY_RK, 20. ) ); 


    if APPROACH = 'STD' then do;
        %if "&APPLY_CCF_AFTER_CRM" = "YES" %then %do;
          if OFF_BALANCE_SHEET_FLG=1 then 
             RWA_NO_CRM = max(0, sum(EAD, -SPECIFIC_PROVISION*CCF/100)) * RW_EXP / 100;
          else
             RWA_NO_CRM = max(0, sum(EAD, -SPECIFIC_PROVISION)) * RW_EXP / 100;
        %end;
        %else %do;
          RWA_NO_CRM = max(0, sum(EAD, -SPECIFIC_PROVISION)) * RW_EXP / 100;

        %end;
    end;
    else 
        RWA_NO_CRM = EAD * RW_EXP / 100; 
        
   
     
    %if N_EXP_CRM > 0 %then %do;    
    if pdlgd and adjust and EAD_ADJ > 0 then do;
       LGD_EFF = LGD_EFF * PD_LGD_WEIGHT / EAD_ADJ;
    end;
    %end;
    
    EL_EFF = PD_EFF * LGD_EFF / 100;
       
    /*- Maturity mismatch adjustment to EL of originators' synthetic securitization exposures: CRR Article 250 -*/  
    if SECURITIZATON_EXPOSURE_FLG = 1 and SEC_STRUCTURE_TYPE = 'SYNTHETIC' and PRIMARY_BANK_ROLE = 'ORIGINATOR' and index(APPROACH, 'IRB')   
    then  EL_EFF = 0 ;
    
    
    CAPITAL_NO_CRM = RWA_NO_CRM * &CAPITAL_RATIO;
    
    /*- no crm should have been used -*/
    if EAD_ADJ = 0 then RW = RW_EXP;
    else RW = RWA / EAD_ADJ * 100;

    RW_NO_CRM = RW_EXP;
    
    /*- Adjustment to RWA_NO_CRM and Capital_NO_CRM for SME exposures subject to SME supporting factor: CRR Article 501 -*/ 
    if not (IN_DEFAULT_FLG =1 or PAST_DUE_CLAIM_FLG =1) and not (HIGH_RISK_CPTY_FLG=1 or STD_PRODUCT_CLASS ='HIGH_RISK') 
       and COUNTERPARTY_CLASS in ('RETAIL','CORPORATE') and COUNTERPARTY_SUBCLASS ='SME'
       and SME_CAP_DEDUCTION_TRT_FLG = 1 then do ;

        RWA_NO_CRM = &SME_SUPPORTING_FACTOR * RWA_NO_CRM ;
        CAPITAL_NO_CRM = &SME_SUPPORTING_FACTOR * CAPITAL_NO_CRM;       
         
    end ;    
    
    if first.EXP_ID then output;

    run;
    
    /*update LGD_EFF value in crm_allocation_optimal_detail, this is required in CP50 reports  */
    data &RESLIB1..crm_allocation_optimal_detail(drop=LGD_EFF_capital);
         merge &RESLIB1..crm_allocation_optimal_detail(in=detail) 
                   "&OUTPATH&PATHSEP.capital_detail_optimal"(in=capital keep=EXP_ID LGD_EFF
                                                                                                     rename=(LGD_EFF=LGD_EFF_capital));
         by EXP_ID;
         if DETAIL and not missing(LGD_EFF_capital) then lgd_eff=LGD_EFF_capital;
         
    run;    
    

    /*- Append exposures with zero EAD if requested -*/
    %if "&REPORT_ZERO_EAD" eq "YES" %then %do ;
        data "&OUTPATH&PATHSEP.capital_detail_optimal" ;
            set "&OUTPATH&PATHSEP.capital_detail_optimal" 
                "&VALPATH&pathsep.exposures_with_zero_ead"(drop=NOTE INSTSOURCE INSTNUMBER)
                "&VALPATH&pathsep.equity_exp_deducted_from_capital"(drop=NOTE INSTSOURCE INSTNUMBER);
        run; 
        
        data &RESLIB1..crm_allocation_optimal_detail;
                    set &RESLIB1..crm_allocation_optimal_detail
                        "&VALPATH&pathsep.exposures_with_zero_ead"(keep=EXP_ID EAD CCF RWA RW_EXP)
                        "&VALPATH&pathsep.equity_exp_deducted_from_capital"(keep=EXP_ID EAD DEDUCTION_AMT RWA RW_EXP);
        run; 
        
    %end ;  

   /*- get EAD of underlying exposures in securitization and add to crm_allocation_optimal
        for Large Exposure report-*/
    data sec_underlying;
        set &RESLIB1..sec_underlying_optimal_detail;
        if LE_PRODUCT_CLASS = 'DERIVATIVE' then do;
         UNDERLYING_EXP_EAD = EAD;   
      end;
      else do;
         UNDERLYING_EXP_EAD = EXP_VALUE;              
      end;  
        LE_COUNTERPARTY_RK = COUNTERPARTY_RK;
        EXP_ID = INSTID;
        if COUNTERPARTY_GROUP_PARENT_FLG = . then COUNTERPARTY_GROUP_PARENT_FLG = 0; 

    run;
    
    proc append BASE = "&OUTPATH&PATHSEP.crm_allocation_optimal" 
                data = sec_underlying(keep = UNDERLYING_EXP_EAD LE_COUNTERPARTY_RK EXP_ID TRADING_BOOK_FLG COUNTERPARTY_GROUP_PARENT_FLG)
                FORCE NOWARN;
    run;
        
    proc append BASE = &RESLIB1..crm_allocation_optimal_detail
                data = sec_underlying(keep = UNDERLYING_EXP_EAD LE_COUNTERPARTY_RK EXP_ID TRADING_BOOK_FLG COUNTERPARTY_GROUP_PARENT_FLG)
                FORCE NOWARN;
    run; 
    
    /*- For CA report:calculate Large exposure capital charge -*/    
    /*- 1: calculate LE multiplier for counterparty groups and individual counterparties -*/
    %get_le_capital_charge_crd4(dsname=&RESLIB1..crm_allocation_optimal_detail);
        
    /*- 2: merge results with crm_allocation_optimal_detail -*/  
    proc sort data = &RESLIB1..crm_allocation_optimal_detail;
        by exp_id;
    run;
            
    data &RESLIB1..crm_allocation_optimal_detail;
        merge &RESLIB1..crm_allocation_optimal_detail (in=a) all_exp_with_le_cap_chrg;
        by EXP_ID;
    run;
    
    /*- Calculations for CVA standardized approach -*/
    %get_cva_risk_amts_crd4(CRMAPP=OPTIMAL,ALTCALC=&CALCULATE_CVA_ALT_VALUES) ;
    
    /*- Append the data set to the capital detail table -*/
   %append_cva_risk_amts_crd4(CRMAPP=OPTIMAL) ;  
    
    %EXIT :
    




%mend r00_post_regulatory_9_crd4;
