/***********************************************************************
 * Copyright (c) 2010-2013 by SAS Institute Inc., Cary, NC, USA.
 *
 * NAME: rdcube_generate_cube_code.sas
 *
 * PURPOSE: called by rdcube_main to build cube using PROC OLAP
 *
 * PARAMETERS:
 *
 ***********************************************************************/

%macro rdcube_generate_cube_code;
   /* delete old cube if it exists */
   %rdcube_delete_cube( rdcube_name=&results_name,
                        olap_schema=&olap_schema );

   %rdcube_find_dimension_attributes;

   /* start OLAP Procedure step */
   data _NULL_;
      file MyFile mod;
      put " ";
      put "/* build cube */";
      put "PROC OLAP CUBE='&out_folder./&results_name' EMPTY_CHAR=' '";
      put "      DESCRIPTION='&description_used'";
      put '      PATH="&metaref_path" ';
      %if &write_detail_data %then %do;
         put '      DRILLTHROUGH_TABLE=&metaref' "..&results_name._d";
         %end;
      put '      ;';
      put ' ';
      put "   METASVR OLAP_SCHEMA = '&olap_schema';";
      run;
   %rdcube_check_syserr;
   %if &syserr ne 0 %then %return;

   %rdcube_write_analysis_dimensions( &analysis_type,
                                      &analysis_number,
                                      &results_libref );
   %rdcube_check_syserr;
   %if &syserr ne 0 %then %return;

   %rdcube_write_portfolio_dimension( &results_libref );
   %rdcube_check_syserr;
   %if &syserr ne 0 %then %return;

   %rdcube_write_aggregations( &results_libref,
                               &results_name,
                               &analysis_number );
   %rdcube_check_syserr;
   %if &syserr ne 0 %then %return;

   %rdcube_write_measures( &measure_table );
   %rdcube_check_syserr;
   %if &syserr ne 0 %then %return;

   /* finish OLAP Procedure step */
   data _NULL_;
      file MyFile mod;
      put '   RUN;';
      %RDCUBE_SET_RSKERR;
      %RDCUBE_CHECK_RSKERR( 'rdcube_1' );
      run;
   %rdcube_check_syserr;
   %if &syserr ne 0 %then %return;
%mend rdcube_generate_cube_code;

%macro rdcube_delete_cube( rdcube_name=, olap_schema= );
   data _NULL_;
      file MyFile mod;
      put " ";
      put "/* check if cube with this name exists in the olap_schema */";
      put "DATA _NULL_;";
      put "   LENGTH uri asn_uri schema_name $ 500;";
      put "   uri = ' ';";
      put "   asn_uri = ' ';";
      put "   schema_name = ' ';";
      put "   n = 1;";
      put '   nobj = METADATA_GETNOBJ("omsobj:Cube?@Name=' "'&rdcube_name'" '", n, uri);';
      put '   num_schema = METADATA_GETNASN(uri, "AssociatedOLAPSchema", 1, asn_uri);';
      put '   rc = METADATA_GETATTR(asn_uri, "Name", schema_name);';
      put "   verified = (schema_name = '&olap_schema');";
      put '   CALL SYMPUT("out", verified);';
      put "   RUN;";

      put " ";
      put "/* delete cube if it does exist */";
      put '%if &out = 1 %then %do;';
      put "PROC OLAP CUBE=&rdcube_name DELETE;";
      put "METASVR OLAP_SCHEMA = '&olap_schema';";
      put "RUN;";
      %RDCUBE_SET_RSKERR;
      %RDCUBE_CHECK_RSKERR( 'rdcube_2' );
      put '%end;';
      run;
%mend rdcube_delete_cube;

/***************************/
/* dimension helper macros */
/***************************/
%macro rdcube_write_analysis_dimensions( analysis_type, analysis_number, libref );
   %if %upcase(&analysis_type) eq SIMULATION %then %do;
      %let ovname = SimulationPart;
      %end;
   %else %do;
      %let ovname = OutputVariable;
      %end;

   data _analysis_hierarchy_information;
      merge &libref..Dimension_Information(where=(Analysis_Number = &analysis_number))
            _analysis_information;
      run;

   data _NULL_;
      file MyFile mod;
      set _analysis_hierarchy_information;
      length sysvarlist $ 100 wherelist $ 200;

      wherelist = ' ';
      sysvarlist = ' ';

      /* handle riskfactor dimension (for sensitivities) */
      %if %upcase(&analysis_type) eq SUMMARY %then %do;
         %end;
      %else %if %upcase(&analysis_type) eq SCENARIO %then %do;
         %rdcube_include_outvars;
         %end;
      %else %if %upcase(&analysis_type) eq SIMULATION %then %do;
         %rdcube_include_horizons;
         %rdcube_include_alphas;
         %rdcube_include_categories;
         %rdcube_include_outvars;
         %end;
      %else %if %upcase(&analysis_type) eq SENSITIVITY %then %do;
         %rdcube_include_riskfactors;
         %rdcube_include_outvars;
         %end;

      call symput( "sysvarlist", strip(sysvarlist) );
      call symput( "wherelist", strip(wherelist) );
   run;
%mend rdcube_write_analysis_dimensions;

%macro rdcube_write_portfolio_dimension( libref );
   data _NULL_;
      file MyFile mod;
      set &libref..ccpaths end=last;
   if _N_ = 1 then do;
      put ' ';
      put '   /* list the paths due to the crossclassification */';
      end;
   put '   HIERARCHY h_' _N_;
   put '             DESCRIPTION = "' path '"';
   put '             LEVELS=( ' path ' )';
   put '             ALL_MEMBER="Portfolio Level Results";' ;
   if last then do;
      put '   HIERARCHY Top_ ';
      put '             LEVELS=( top )';
      put '             ALL_MEMBER="Portfolio Level Results";' ;
      end;
   run;
   %rdcube_check_syserr;
   %if &syserr ne 0 %then %return;

   data _NULL_;
      file MyFile mod;
      set &libref..ccpaths end=last;
   if _N_ = 1 then do;
      put ' ';
      put '   /* the Portfolio dimension */';
      put '   DIMENSION Portfolio ';
      put '             CAPTION="Portfolio" ';
      put '             HIERARCHIES=( Top_';
   end;
   put '                           h_' _N_;
   if last then do;
      put '                           ) SORT_ORDER=DSORDER;';
   end;
   run;
   %rdcube_check_syserr;
   %if &syserr ne 0 %then %return;
%mend rdcube_write_portfolio_dimension;

%macro rdcube_write_aggregations( reslibref, resname, analysis_number );
   /* merge analysis variables (like Simulation Part) with
            page list and
            dimension information (like outvars_used_flag).
      there will be one aggregation for each row in this table. */

   %if &analysis_number ne 0 %then %do;
      %rdcube_create_aggregation_mult;
      proc sql;
         create table work._aggregations as
         select t1.*, t2.*, t3.*
            from work._rdcube_aggregation_multiplier
               %if %sysfunc(LENGTH("&wherelist")) NE 2 %then %do;
                  (WHERE=(&wherelist))
                  %end; as t1
            cross join &reslibref..ccpages as t2
            cross join _analysis_hierarchy_information as t3;
         quit;
      %end;
   %else %do;
      data work._aggregations;
         set &reslibref..ccpages;
         run;
      %end;

   /* write regular aggregations and
      determine whether super-aggregation is necessary */
   data _NULL_;
      file MyFile mod;
      set work._aggregations;
      length wc $ 200 var_insert $ 32;
   if _N_ = 1 then do;
      put " ";
      put "   /* the aggregations */";
      CALL SYMPUT( 'allVarsInOneAggregation', 0);
   end;

   put "   AGGREGATION top " keeplist;
   wc = " ";
   kl = " ";

   /* for SimStat data set */
   %if %upcase(&analysis_type) eq SIMULATION %then %do;
      %rdcube_handle_outvars;
      %rdcube_handle_alphas;
      %rdcube_handle_horizons;
      %rdcube_handle_categories;
      %end;

   /* for Sens data set */
   %if %upcase(&analysis_type) eq SENSITIVITY %then %do;
      %rdcube_handle_outvars;
      %rdcube_handle_sens_type;
      %end;

   /* for Scen data set */
   %if %upcase(&analysis_type) eq SCENARIO %then %do;
      %rdcube_handle_outvars;
      %end;

   if length(wc) NE 1 then do;
      wc = '(WHERE=(' || strip(wc) || '))';
      end;
   put '             / TABLE = &metaref' "..&results_name._" pagenumber wc ';';
   if countw(keeplist) = &ccvarcount then
      CALL SYMPUT( 'allVarsInOneAggregation', 1);
   run;
   %rdcube_check_syserr;
   %if &syserr ne 0 %then %return;

   /* add super-aggregation if necessary */
   %if &allVarsInOneAggregation eq 0 %then %do;
   data _NULL_;
      file MyFile mod;
      set &reslibref..ccvars end=last;
   if _N_ = 1 then do;
      put '   AGGREGATION top ' "&sysvarlist ";
   end;
   put ' ' class_var;
   if last then
      /* insert any table... just reusing portfolio-level table */
      put '   / TABLE = &metaref' "..&resname._0;";
   run;
   %end;
   %rdcube_check_syserr;
   %if &syserr ne 0 %then %return;
%mend rdcube_write_aggregations;

%macro rdcube_write_measures( measure_table );
   %local _measure_table;

   %if "&measure_table" ne "%str()" %then %do;
      %let _measure_table = &measure_table;
      %end;
   %else %do;
      %rdcube_create_measure_table;
      %end;

   data _formats_for_measures;
      set _contents;
      length fmt $ 32;

      fmt = strip(format);
      if length(fmt) > 0 then do;
         if formatl > 0 then
            fmt = strip(fmt) || strip(formatl) || '.' || strip(formatd);
         else
            fmt = strip(fmt) || '.';
         end;
      run;

      %if %upcase(&analysis_type) eq SUMMARY %then %do;
             data &_measure_table;
                 set &results_libref.._rd_bc_outvars(rename=(OutputVariableName=name)) &_measure_table;
                 run;
         %end;

   proc sql;
      create table work._measures as
             select t1.name, t2.label, t2.fmt from
             &_measure_table as t1
             join work._formats_for_measures as t2
             on upcase(t1.name)=upcase(t2.name);
      quit;

   data _NULL_;
      file MyFile mod;
      set _measures end=last;
   if _N_ = 1 then do;
      put ' ';
      put '   /* the measures */';
   end;

   put '   MEASURE ' name ' AGGR_COLUMN=' name
       ' STAT=SUM CAPTION="' label '" FORMAT=' fmt ';';
   run;

   /* add risk factors as measures for sensitivity analysis */
   %if %upcase(&analysis_type) eq SENSITIVITY %then %do;
      data _NULL_;
         file MyFile mod;
      set &results_libref.._rd_a_riskfactors(where=(&analysis_number = AnalysisNumber));
      put '   MEASURE ' RiskFactorName ' AGGR_COLUMN=' RiskFactorName
          ' STAT=SUM FORMAT=' RiskFactorFormat;
      if length(RiskFactorLabel) ne 1 then
         put ' CAPTION="' RiskFactorLabel '";';
      else
         put ';';
      run;
   %end;
%mend rdcube_write_measures;

%macro rdcube_handle_alphas;
   /* for SimStat data set */
   if alpha_flag then do;
      if ~ need_alphas then do;
         put '               Alpha';
         kl = strip(kl) || ' Alpha';
         end;
      else do;
         if length(wc) NE 1 then
            wc = strip(wc) || ' AND';
         wc = strip(wc) || ' Alpha EQ ' || Alpha;
         end;
      end;
%mend rdcube_handle_alphas;

%macro rdcube_handle_horizons;
      /* for SimStat data set */
      if horizon_flag then do;
         if ~ need_date then
            put '               SimulationHorizon1';
         else do;
            if length(wc) NE 1 then
               wc = strip(wc) || ' AND';
            wc = strip(wc) || " SimulationHorizon1 EQ '" || SimulationHorizon || "'";
            end;
         end;
%mend rdcube_handle_horizons;

%macro rdcube_handle_categories;
      if category_flag then do;
         if ~ need_cats then
            put '               SimulationCategory1';
         else do;
            if length(wc) NE 1 then
               wc = strip(wc) || ' AND';
            wc = strip(wc) || " SimulationCategory1 EQ 'Unconditional'";
            end;
         end;
%mend rdcube_handle_categories;

%macro rdcube_handle_outvars;
   if outvar_flag then do;
      if ~ need_outvars then
         put "               &ovname";
      else do;
         if length(wc) NE 1 then
            wc = strip(wc) || ' AND';
         wc = strip(wc) || " &ovname EQ '" || &ovname || "'";
         end;
      end;
%mend rdcube_handle_outvars;

%macro rdcube_handle_sens_type;
   if sens_flag then do;
   *   if analysis_type = 'SENS' then do;
      if need_rfs = 1 then do;
         var_insert = ' ';
/* need a where _type_="delta"? */
         wc_insert = ' ';
         end;
      else if need_rfs = 2 then do;
         var_insert = '_TYPE1_';
         wc_insert = ' ';
         end;
      end;
   else do;
      if sens_flag = 1 then do;
         var_insert = 'Name ';
         wc_insert = 'Name = Name2 ';
         end;
      else do;
         var_insert = 'Name Name2';
         wc_insert = ' ';
         end;
      end;
   put '               ' var_insert;
%mend rdcube_handle_sens_type;

%macro rdcube_include_riskfactors;
   put ' ';
   put '   /* RiskFactors dimension and hierarchy */';
   if LENGTH(wherelist) NE 1 then
      wherelist = STRIP(wherelist) || ' AND';
   wherelist = STRIP(wherelist) || 'need_rfs < 3';
   put '   HIERARCHY RiskFactors LEVELS=( _TYPE1_ ) ALL_MEMBER="_Type_ = ?";';
   sysvarlist = STRIP(sysvarlist) || ' _TYPE1_';
   put '   DIMENSION RiskFactors CAPTION="' TY_label
       '" HIERARCHIES=( RiskFactors ) SORT_ORDER=DSORDER;';
%mend rdcube_include_riskfactors;

%macro rdcube_include_horizons;
   if ( horizon_flag eq 0 ) then do;
      if LENGTH(wherelist) NE 1 then
         wherelist = STRIP(wherelist) || ' AND';
      wherelist = STRIP(wherelist) || ' need_date=0';
      end;
   else do;
      put ' ';
      put '   HIERARCHY Horizons LEVELS=( SimulationHorizon1 ) ALL_MEMBER="SimulationHorizon1 = '
          SimulationHorizon1 '";';
      put '   DIMENSION Horizons CAPTION="' SH_label
          '" HIERARCHIES=( Horizons ) SORT_ORDER=DSORDER;';
      sysvarlist = STRIP(sysvarlist) || ' SimulationHorizon1';
      end;
%mend rdcube_include_horizons;

%macro rdcube_include_alphas;
   /* handle alpha dimension (for simulations) */
   if ( alpha_flag eq 0 ) then do;
      if LENGTH(wherelist) NE 1 then
         wherelist = STRIP(wherelist) || ' AND';
      wherelist = STRIP(wherelist) || ' need_alphas=0';
      end;
   else do;
      put ' ';
      put '   HIERARCHY Alphas LEVELS=( Alpha ) ALL_MEMBER="Alpha =' Alpha '";';
      put '   DIMENSION Alphas CAPTION="' AL_label
          '" HIERARCHIES=( Alphas ) SORT_ORDER=DSORDER;';
      sysvarlist = STRIP(sysvarlist) || ' Alpha';
      end;
%mend rdcube_include_alphas;

%macro rdcube_include_categories;
   /* handle category dimension (for scenarios? and simulations) */
   if ( category_flag eq 0 ) then do;
      if LENGTH(wherelist) NE 1 then
         wherelist = STRIP(wherelist) || ' AND';
      wherelist = STRIP(wherelist) || ' need_cats=0';
      end;
   else do;
      put ' ';
      put '   HIERARCHY Categories LEVELS=( SimulationCategory1 ) ALL_MEMBER="SimulationCategory1 ='
          "'Unconditional'" '";';
      put '   DIMENSION Categories CAPTION="' SM_Label
          '" HIERARCHIES=( Categories ) SORT_ORDER=DSORDER;';
      sysvarlist = STRIP(sysvarlist) || ' SimulationCategory1';
      end;
%mend rdcube_include_categories;

%macro rdcube_include_outvars;
   if ( outvar_flag eq 0 ) then do;
      if LENGTH(wherelist) NE 1 then
         wherelist = STRIP(wherelist) || ' AND';
      wherelist = STRIP(wherelist) || ' need_outvars=0';
      end;
   else do;
      put ' ';
      put "   HIERARCHY OutputVariables LEVELS=( &ovname ) ALL_MEMBER=" '"'
          "&ovname ='" &ovname "'" '";';
      put '   DIMENSION OutputVariables CAPTION="' SP_label
          '" HIERARCHIES=( OutputVariables ) SORT_ORDER=DSORDER;';
      sysvarlist = STRIP(sysvarlist) || " &ovname";
      end;
%mend rdcube_include_outvars;

%macro rdcube_find_dimension_attributes;
/* the presence of these variables indicates the need for corresponding dimensions */
   proc contents data=&data_table out=_contents noprint short;
      run;
   data _labels_and_formats(keep = SH_label DA_format SP_label SM_label AL_label AL_format TY_label);
      set _contents end=last;
      length fmt $ 32;
      retain SH_label DA_format SP_label SM_label AL_label AL_format TY_label;

      /* if simulation */
      fmt = strip(format);
      if length(fmt) > 0 then do;
         if formatl > 0 then
            fmt = strip(fmt) || strip(formatl) || '.' || strip(formatd);
         else
            fmt = strip(fmt) || '.';
         end;

      if upcase(name) = 'SIMULATIONHORIZON' then do;
         SH_label = label;
         end;
      if upcase(name) = '_DATE_' then do;
         DA_format = fmt;
         end;
      if upcase(name) = 'SIMULATIONPART' then do;
         SP_label = label;
         end;
      if upcase(name) = 'OUTPUTVARIABLE' then do;
         SP_label = label;
         end;
      if upcase(name) = 'SIMULATIONMODE' then do;
         SM_label = label;
         end;
      if upcase(name) = 'ALPHA' then do;
         AL_label = label;
         AL_format = fmt;
         end;

      /* if sensitivity */
      if upcase(name) = '_TYPE_' then do;
         TY_label = label;
         end;

      if last then
         output;
      run;

   data _first_obs_in_results_data_set;
      set &data_table(obs=1
         %if &analysis_number NE 0 %then %do;
            where=(AnalysisNumber = &analysis_number)
            %end;
         );
      run;

   data _analysis_information;
      merge _labels_and_formats
            _first_obs_in_results_data_set;
      run;
%mend rdcube_find_dimension_attributes;

%macro rdcube_create_aggregation_mult;
   %if %upcase(&analysis_type) eq SIMULATION %then %do;
      data work._rdcube_aggregation_multiplier;
         need_outvars=0; need_date=0; need_cats=0; need_alphas=0; output;
         need_outvars=0; need_date=0; need_cats=0; need_alphas=1; output;
         need_outvars=0; need_date=0; need_cats=1; need_alphas=0; output;
         need_outvars=0; need_date=0; need_cats=1; need_alphas=1; output;
         need_outvars=0; need_date=1; need_cats=0; need_alphas=0; output;
         need_outvars=0; need_date=1; need_cats=0; need_alphas=1; output;
         need_outvars=0; need_date=1; need_cats=1; need_alphas=0; output;
         need_outvars=0; need_date=1; need_cats=1; need_alphas=1; output;
         need_outvars=1; need_date=0; need_cats=0; need_alphas=0; output;
         need_outvars=1; need_date=0; need_cats=0; need_alphas=1; output;
         need_outvars=1; need_date=0; need_cats=1; need_alphas=0; output;
         need_outvars=1; need_date=0; need_cats=1; need_alphas=1; output;
         need_outvars=1; need_date=1; need_cats=0; need_alphas=0; output;
         need_outvars=1; need_date=1; need_cats=0; need_alphas=1; output;
         need_outvars=1; need_date=1; need_cats=1; need_alphas=0; output;
         need_outvars=1; need_date=1; need_cats=1; need_alphas=1; output;
         run;
      %end;
   %else %if %upcase(&analysis_type) eq SCENARIO %then %do;
      data work._rdcube_aggregation_multiplier;
         need_outvars=0; output;
         need_outvars=1; output;
         run;
      %end;
   %else %do;
      data work._rdcube_aggregation_multiplier;
         need_outvars=0; need_rfs=1; output;
         need_outvars=0; need_rfs=2; output;
         need_outvars=1; need_rfs=1; output;
         need_outvars=1; need_rfs=2; output;
         run;
      %end;
%mend rdcube_create_aggregation_mult;

%macro rdcube_create_measure_table;
   %if %upcase(&analysis_type) eq SCENARIO %then %do;
      %let _measure_table = work._rdcube_scen_measures;
      data work._rdcube_scen_measures;
         length name $ 32;
         name="BaseCaseValue"; output;
         name="PL"; output;
         name="PLPct"; output;
         name="Return"; output;
         name="Value"; output;
         run;
      %end;
   %else %if %upcase(&analysis_type) eq SENSITIVITY %then %do;
      %let _measure_table = work._rdcube_sens_measures;
      data work._rdcube_sens_measures;
         length name $ 32;
         name="Value"; output;
         name="Sensitivity"; output;
         name="Gamma"; output;
         run;
      %end;
   %else %if %upcase(&analysis_type) eq SIMULATION %then %do;
      data work._rdcube_simstat_measures;
         length name $ 32;
         name="CondExpectedLoss"; output;
         name="ES"; output;
         name="Max"; output;
         name="Median"; output;
         name="Mean"; output;
         name="Min"; output;
         name="VaR"; output;
         name="VaREVT"; output;
         name="VaR_L"; output;
         name="VaR_U"; output;
         name="Kurtosis"; output;
         name="Skewness"; output;
         name="TailIndex"; output;
         name="VaRPct"; output;
         name="VaRPct_L"; output;
         name="VaRPct_U"; output;
         run;
      %let _measure_table = work._rdcube_simstat_measures;
      %end;
   %else %if %upcase(&analysis_type) eq SUMMARY %then %do;
      %let _measure_table = work._rdcube_summary_measures;
      data work._rdcube_summary_measures;
         length name $ 32;
         name="ExpNoNet"; output;
         name="Exposure"; output;
         name="InstMax"; output;
         name="InstMean"; output;
         name="InstMin"; output;
         name="InstStD"; output;
         name="MtM"; output;
         name="InstN"; output;
         name="NInst"; output;
         name="NMissing"; output;
         run;
      %end;
%mend rdcube_create_measure_table;
