 /*--------------------------------------------------------------
  * Copyright (C), 2010-2012
  * SAS Institute Inc., Cary, NC, USA.  All Rights Reserved
  * version date: 19 October 2010
  *
  * NAME:      rdcube_get_object_in_tree.sas
  * PURPOSE:   finds object in tree
  *
  * USAGE:     %rdcube_get_object_in_tree( treeuri=, objname=, 
  *                                        attrname=, attrval=,
  *                                        rdcube_outvar=objuri);
  *
  * PARAMETERS:
  *     treeuri=      - uri of tree in which to find object
  *     objname=      - name of object to find
  *     attrname=     - name of attribute/identifier of object to find in tree
  *     attrval=      - value of attribute/identifier of object to find in tree
  *     rdcube_outvar=objuri - macro variable to set, holding the uri of found object
  *
  *-------------------------------------------------------------*/

%macro rdcube_get_object_in_tree(
   treeuri=,
   objname=, 
   attrname=, 
   attrval=, 
   rdcube_outvar=objuri);
data _null_;
   length uri $256 objName attrVal objUri $256;
   
   numObjs = metadata_getnasn("&treeuri", "Members", 1, uri);
   objectFound = 0;
   n = 1;
    do until(n > numObjs | objectFound) ;
       rc = metadata_getattr(uri, "Name", objName);
      rc = metadata_getattr(uri, "&attrname", attrVal);
      if (objName = "&objname" and attrVal="&attrval") then do;
        objectFound = 1;
       objUri = uri;
      end; 
      else do;
        n = n+1;
        rc = metadata_getnasn("&treeUri", "Members", n, uri);
      end;
   end;
   call symput("&rdcube_outvar", objUri);
   run;
%mend rdcube_get_object_in_tree;
