/*****************************************************************************
* Copyright (c) 2013 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
*
*    NAME:regrpt_capital_crgb_sa_crd4.sas
*
* PURPOSE: Creates report for the CRGB SA report
*
*
*   USAGE: This is a draft
*
*   Macro Options:
*****************************************************************************/
 
%macro regrpt_capital_crgb_sa_crd4;

/* Create Data for Report */
%regrpt_d0_cap_crgb_sa_crd4;
 
proc format;
value $exp_type (default=256)
	"CEN_GOV_BNK"='Central governments or central banks'
	"REG_LOC_GOV"='Regional governments or local authorities '
	"PSE"='Public sector entities'
	"MDB"='Multilateral Development Banks '
	"INT_ORG"='International Organisations'
	"INSTITUTIONS"='Institutions'
	"CORPORATES"='Corporates'
	"CORPORATES_SME"='of which: SME'
	"RETAIL"='Retail'
	"RETAIL_SME"='of which: SME'
	"RETAIL_SEC_IMOV"='Secured by mortgages on immovable property'
	"RETAIL_SEC_IMOV_SME"='of which: SME'
	"PAST_DUE"='Exposures in default'
	"HIGH_RISK"='Items associated with particularly high risk'
	"COV_BOND"='Covered bonds'
	"SHORT_CLAIM"='Short-term claims on institutions and corporate'
	"CIU"='Collective investments undertakings (CIU)'
	"EQUITY"='Equity exposures'
	"OTHER_ASSETS"='Other exposures'
	"TOTAL_EXP"='Total exposures'
	;
RUN;

proc format;
	value $Aggregate
				"+"="Aggregate Total"
				;
run;	
	
**********************************************************;
* Format exclusively for CRGB-SA Reporting               *;
**********************************************************;

proc sort data=RD_MAP.MAP_NATIONAL_DISCRETION nodupkey out=fmt(keep=COUNTRY_CD COUNTRY_NM);
by COUNTRY_CD;
run;
data fmt (keep=FMTNAME START END LABEL TYPE HLO SEXCL EEXCL);
length FMTNAME  START END $32. LABEL $60. HLO $8. TYPE SEXCL EEXCL $1.;
if _n_ =1 then do;
START   = "+";
END     = "+";
LABEL   = "Aggregate Total";
TYPE    = 'C' ;
FMTNAME = 'ccvar';
output;
end;
set fmt end = lastobs ;
FMTNAME = 'ccvar';
      START            = compress(COUNTRY_CD);
      END              = START          ;
      LABEL            = COUNTRY_NM ;
      TYPE             = 'C' ;
output ;
/*
if lastobs then do;
     START            ='**OTHER**' ;
     END              = START;
	 HLO = 'O';
	 LABEL = "OTHER";
	 output;
end;
*/
run;
 
proc format cntlin=fmt  ; run;
**********************************************************;
* Create Local macros for CRGB-SA Reporting                 *;
**********************************************************;
/*%let style_type=%str(style=Data[Tagattr='format:#,##0' fontweight=bold background=#CED3D6]);  */
%let style_type=%str(style=Data[Tagattr='format:#,##0.00' ]);  


/* Creates basic  template report */
%macro report_page (dsn);
 
 
proc report data=&DSN (where=(rank ne .)) nowd missing LS=160 PS=50 SPLIT="*" contents=""
/*
style(column)={ bordercolor=#FAF8ED cellspacing=0}
style(header)={cellheight=0  cellspacing=0 };
*/
style(column)={ /*bordercolor=#FAF8ED*/ cellspacing=0}
style(header)={background=#CED3D6 cellheight=0  cellspacing=0 fontweight=bold};

 
column  CLASS_CRGB_SA  
		OUTV_EXP_PRE_CCF_PRE_CRM   /* Col 010 */
		OUTV_DEFAULTS_AMT              /* Col 020 */
		OUTV_NEW_DEFAULTS_AMT          /* Col 040 */
		OUTV_GEN_CR_ADJ            /* Col 050 */
		OUTV_VALUE_ADJ_AMT         /* Col 055 */
		OUTV_SPECIFIC_WRITEOFF_AMT      /* Col 060 */
		OUTV_PROVISIONS_NEW_DFLT_AMT   /* Col 070 */
		OUTV_EAD_ROLLUP            /* Col 030 */
		RWA_PRE_SME_AMT
		OUTV_RWA                   /* Col 080 */
		;
        
    define CLASS_CRGB_SA                /display format=$exp_type. "";
    define OUTV_EXP_PRE_CCF_PRE_CRM      /display &style_type.    ""  "&_outv_exp_pre_ccf_pre_crm"      ;
    define OUTV_DEFAULTS_AMT                 /display &style_type.    ""  "&_OUTV_DEFAULTS"      ;
    define OUTV_NEW_DEFAULTS_AMT             /display &style_type.    ""  "&_OUTV_NEW_DEFAULTS"      ;
    define OUTV_GEN_CR_ADJ               /display &style_type.    ""  "&_OUTV_GEN_CR_ADJ"      ;
    define OUTV_VALUE_ADJ_AMT            /display &style_type.    ""  "&_OUTV_VALUE_ADJ_AMT"      ;
    define OUTV_SPECIFIC_WRITEOFF_AMT         /display &style_type.    ""  "&_OUTV_OFWHICH_WRITEOFF"      ;
    define OUTV_PROVISIONS_NEW_DFLT_AMT      /display &style_type.    ""  "&_OUTV_PROVISIONS_NEW_DFLT"      ;
    define OUTV_EAD_ROLLUP               /display &style_type.    ""  "&_OUTV_EAD_ROLLUP"      ;
    define RWA_PRE_SME_AMT                      /display &style_type.    ""  "&CRSA_RWA_PRE_SME_AMT"      ;
    define OUTV_RWA                      /display &style_type.    ""  "&CRSA_RWA_AFT_SME_AMT"      ;
 
    compute CLASS_CRGB_SA;
       count+1;
       if mod(count,2) then do;
         call define(_row_,"Style", "Style=[background=#E6EDFF]");
       end;
    endcomp;
 
run;
 
%mend report_page;
 
 
%macro generate_report;
 
%if NOT %sysfunc(exist(work.current_regulatory)) or NOT %sysfunc(exist(work.&regprojectname._1))
or %upcase(&SYSTEM_FATAL_ERROR) = %upcase (Y) %then %do;
%print_msg(warning,3,10);
%print_msg(warning,3,15);
%regulatory_reportnopage();
%return;
%goto FINAL;
%end;
 
/* Get number of report pages */
%let pages=%attrn(report_pages,NOBS);
 
%do this_page=1 %to &PAGES ;
 
/*Change to &pages */
/*If data is not available for the report page then do no run report content */
%if NOT %sysfunc(exist(work.&regprojectname._&this_page)) %then %do;
%print_msg(warning,3,19);
%print_msg(note,3,20);
%regulatory_reportnopage();
%goto NOPAGE;
%end;

  %if &APPLY_CCF_AFTER_CRM EQ NO %then %do;
     %let ccf_crm_msg=%print_msg(,3,110,1); 
     
     footnote "&ccf_crm_msg";
  %end;
 
/* Displays the titles for the cross-classification variables */
%if %upcase(&REPORT_TYPE)=%upcase(XLS) %then %do;
	data _null_;
		ID = open("report_pages");
		Var_name = upcase(varname(ID,1));
		RC = close(ID);
		call symputx("class_gb_lev1",var_name);
	run;
   data _null_;
    set report_pages(firstobs=&this_page obs=&this_page);
	call symputx("sheet_name",put(&class_gb_lev1,$ccvar.));
   run;
%put sheet_name=&sheet_name;

   ods tagsets.ExcelXP_Mod 
 		options(
		sheet_name="&sheet_name."
		sheet_interval='none' autofit_height="yes");
		%_Report_Title(REPORT_TITLE_CD=rpt_cd2,REPORT_TITLE=rpt_title1);
   ods tagsets.ExcelXP_Mod 
 		options(
		autofit_height="NO");

%end;
 
%regulatory_reportheaders(work.&regprojectname._&this_page);
 
%report_page (work.&regprojectname._&this_page);

/* subroutine for no data available for report page */
%NOPAGE:
 
%end;
 
%FINAL:
footnote ;
 
%mend generate_report; /* end reportbody macro */
 
%generate_report;
 
 
 
 
 
 
 
 
 
%mend regrpt_capital_crgb_sa_crd4;
