/*****************************************************************************
 * Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 * NAME: regrpt_capital_crsec_det_crd4.sas
 *
 * PURPOSE: Runs regulatory report for securitization reports - DETAILS
 * 
 * NOTES: 
 * Created: 30/01/2014
 *****************************************************************************/
%macro regrpt_capital_crsec_det_crd4;

proc format lib=work;
 value NUM_EFF_EXP
   low  -< 6    ="a"
   6    -< 34   ="b"
   34   -  100  ="c"
   100  -  1000 ="d"
   1000 -  high ="e"
;
run;

/* Create Data for Report */
%regrpt_d0_cap_sec_det_crd4;

%macro regulatory_reportcontents (dsn);         

%let style_type=%str(style=Data[Tagattr='format:#,##0.00' ]);  
 proc report data=work.&dsn nowd missing LS=160 PS=50 /*SPLIT="*" */ contents=''
    style(column)={ bordercolor=#FAF8ED cellspacing=0}
    style(header)={ cellheight=0  cellspacing=0 };
column
	INTERNAL_CODE              /*	010   */
	SECURITIZATION_ID          /*	020   */
	ORIGINATOR_ID              /*	030   */
	SECURITIZATION_TYPE        /*	040   */
	ACCOUNTING_TREATMENT       /*	050   */
	SOLVENCY_TREATMENT         /*	060   */
	SECURITIZATION_RESEC       /*	070   */

	( "RETENTION"   
	RETENTION_TYPE             /*	080   */
	SEC_RETENTION_PCT          /*	090   */
	RETENTION_COMPLIANCE       /*	100   */
	)

	INSTITUTION_ROLE           /*	110   */

	("NON ABCP PROGRAMMES"
	NON_ABCP_ORIGINATION_DT    /*	120   */
	NON_ABCP_ORIG_AMT          /*	130   */
	)

	( "SECURITISED EXPOSURES"
	TOTAL_AMT                  /*	140   */
	INSTITUTION_SHARE_PCT      /*	150   */
	ASSET_LIABILITY_TYPE       /*	160   */
	APPROACH_APPLIED           /*	170   */
	EFFECTIVE_EXPOSURE_NO      /*	180   */
	COUNTRY                    /*	190   */
	ELGD_PCT                   /*	200   */
	VALUE_ADJUST_PROVISIONS_AMT          /*	210   */
	OWN_FUND_REQ_PRE_SEC_AMT             /*	220   */
	)

	("SECURITISATION STRUCTURE"

		("ON-BALANCE SHEET ITEMS"
		ON_BS_SEN_TRANCHE_VALUE_AMT            /*	230   */
		ON_BS_MEZZ_TRANCHE_VALUE_AMT           /*	240   */
		ON_BS_FL_TRANCHE_VALUE_AMT             /*	250   */
		)

		("OFF-BALANCE SHEET ITEMS AND DERIVATIVES"
		OFF_BS_SEN_TRANCHE_VALUE_AMT             /*	260   */
		OFF_BS_MEZZ_TRANCHE_VALUE_AMT            /*	270   */
		OFF_BS_FL_TRANCHE_VALUE_AMT              /*	280   */
		)

		("MATURITY"
		FIRST_TERM_DT             /*	290   */
		LEGAL_FINAL_DT            /*	300   */
		)
	)

	("SECURITISATION POSITION"
		("ORIGINAL EXPOSURE PRE-CONVERSION FACTORS"
			("ON-BALANCE SHEET ITEMS"
				ON_BS_SEN_EXP_VALUE_AMT            /*	310   */
				ON_BS_MEZZ_EXP_VALUE_AMT           /*	320   */
				ON_BS_FL_EXP_VALUE_AMT             /*	330   */
			)
			("OFF-BALANCE SHEET ITEMS AND DERIVATIVES"
				OFF_BS_SEN_EXP_VALUE_AMT            /*	340   */
				OFF_BS_MEZZ_EXP_VALUE_AMT           /*	350   */
				OFF_BS_FL_EXP_VALUE_AMT             /*	360   */
			)
		)

		("MEMORANDUM ITEMS: OFF-BALANCE SHEET ITEMS AND DERIVATIVES"
			DCS_MEMO_AMT                /*	370   */
			IRS_CRS_MEMO_AMT            /*	380   */
			FAC_MEMO_AMT                /*	390   */
			OTHER_MEMO_AMT              /*	400   */
		)

		("EARLY AMORTISATION"
			CCF_APPLIED_PCT             /*	410   */
		)
	)

	OWN_FUNDS_DEDUCTION_AMT             /*	420   */
	("TOTAL RISK-WEIGHTED EXPOSURE AMOUNT"
		PRE_CAP_EXPOSURE_AMT             /*	430   */
		POST_CAP_EXPOSURE_AMT            /*	440   */
	)

	("SECURITISATION POSITIONS - TRADING BOOK "
		CTP_NON_CTP                      /*	450   */
			("NET POSITIONS"
				LONG_POSITION_NET_AMT    /*	460   */
				SHORT_POSITION_NET_AMT   /* 470   */
			)
			("TOTAL OWN FUNDS REQUIREMENTS (SA)"
				SPECIFIC_RISK_AMT            /*	480   */
			)
	)
;

Define  INTERNAL_CODE                   / display                                       "&secdet_int_cd";                     /*   010    */     
Define  SECURITIZATION_ID               / display                                       "&secdet_id_of_sec";                  /*   020    */     
Define  ORIGINATOR_ID                   / display                                       "&secdet_of_orig";                    /*   030    */     
Define  SECURITIZATION_TYPE             / display                                       "&secdet_sec_type";                   /*   040    */     
Define  ACCOUNTING_TREATMENT            / display                                       "&secdet_accounting_type";            /*   050    */     
Define  SOLVENCY_TREATMENT              / display                                       "&secdet_solvency_type";              /*   060    */     
Define  SECURITIZATION_RESEC            / display                                       "&secdet_sec_or_resec";               /*   070    */     
Define  RETENTION_TYPE                  / display                                       "&secdet_typ_of_retn";                /*   080    */     
Define  SEC_RETENTION_PCT               / display       format=&FORMAT_NUMERIC          "&secdet_pct_of_retn";                /*   090    */     
Define  RETENTION_COMPLIANCE            / display                                       "&secdet_retn_complince";             /*   100    */     
Define  INSTITUTION_ROLE                / display                                       "&secdet_role_of_inst";               /*   110    */     
Define  NON_ABCP_ORIGINATION_DT         / display      /* format=&FORMAT_NUMERIC  */    "&secdet_orign_date";             /*   120    */     
Define  NON_ABCP_ORIG_AMT               / display       format=&FORMAT_NUMERIC          "&secdet_tot_amt_sec_exp";            /*   130    */     
Define  TOTAL_AMT                       / display       format=&FORMAT_NUMERIC          "&secdet_tot_amt";                    /*   140    */     
Define  INSTITUTION_SHARE_PCT           / display       format=&FORMAT_NUMERIC          "&secdet_inst_share_pct";             /*   150    */     
Define  ASSET_LIABILITY_TYPE            / display                                       "&secdet_type";                       /*   160    */     
Define  APPROACH_APPLIED                / display                                       "&secdet_approach_applied";           /*   170    */     
Define  EFFECTIVE_EXPOSURE_NO           / display    /* format=&FORMAT_NUMERIC */       "&secdet_no_of_exp";                  /*   180    */     
Define  COUNTRY                         / display                                       "&secdet_cntry";                      /*   190    */     
Define  ELGD_PCT                        / display       format=&FORMAT_NUMERIC          "&secdet_elgd_pct";                   /*   200    */     
Define  VALUE_ADJUST_PROVISIONS_AMT     / display       format=&FORMAT_NUMERIC          "&secdet_val_adj_prov";               /*   210    */     
Define  OWN_FUND_REQ_PRE_SEC_AMT        / display       format=percent32.2          "&secdet_own_fnd_bfre_sec";           /*   220    */     
Define  ON_BS_SEN_TRANCHE_VALUE_AMT     / display       format=&FORMAT_NUMERIC          "&secdet_obsi_senior";                /*   230    */     
Define  ON_BS_MEZZ_TRANCHE_VALUE_AMT    / display       format=&FORMAT_NUMERIC          "&secdet_obsi_mezz";                  /*   240    */     
Define  ON_BS_FL_TRANCHE_VALUE_AMT      / display       format=&FORMAT_NUMERIC          "&secdet_obsi_1st_loss";              /*   250    */     
Define  OFF_BS_SEN_TRANCHE_VALUE_AMT    / display       format=&FORMAT_NUMERIC          "&secdet_off_bal_senior";             /*   260    */     
Define  OFF_BS_MEZZ_TRANCHE_VALUE_AMT   / display       format=&FORMAT_NUMERIC          "&secdet_off_bal_mezz";               /*   270    */     
Define  OFF_BS_FL_TRANCHE_VALUE_AMT     / display       format=&FORMAT_NUMERIC          "&secdet_off_bal_1st_loss";           /*   280    */     
Define  FIRST_TERM_DT                   / display    /* format=&FORMAT_NUMERIC */       "&secdet_mat_1st_forseen_term_st";    /*   290    */     
Define  LEGAL_FINAL_DT                  / display    /* format=&FORMAT_NUMERIC */       "&secdet_mat_lgl_fnl_mat_dt";         /*   300    */     
Define  ON_BS_SEN_EXP_VALUE_AMT         / display       format=&FORMAT_NUMERIC          "&secdet_oepc_obsi_senior";           /*   310    */     
Define  ON_BS_MEZZ_EXP_VALUE_AMT        / display       format=&FORMAT_NUMERIC          "&secdet_oepc_obsi_mezz";             /*   320    */     
Define  ON_BS_FL_EXP_VALUE_AMT          / display       format=&FORMAT_NUMERIC          "&secdet_oepc_obsi_1st_loss";         /*   330    */     
Define  OFF_BS_SEN_EXP_VALUE_AMT        / display       format=&FORMAT_NUMERIC          "&secdet_oepc_off_bal_senior";        /*   340    */     
Define  OFF_BS_MEZZ_EXP_VALUE_AMT       / display       format=&FORMAT_NUMERIC          "&secdet_oepc_off_bal_mezz";          /*   350    */     
Define  OFF_BS_FL_EXP_VALUE_AMT         / display       format=&FORMAT_NUMERIC          "&secdet_oepc_off_bal_1st_loss";      /*   360    */     
Define  DCS_MEMO_AMT                    / display       format=&FORMAT_NUMERIC          "&secdet_mem_dcs";                    /*   370    */     
Define  IRS_CRS_MEMO_AMT                / display       format=&FORMAT_NUMERIC          "&secdet_mem_irs";                    /*   380    */     
Define  FAC_MEMO_AMT                    / display       format=&FORMAT_NUMERIC          "&secdet_mem_elg_liq_faclt";          /*   390    */     
Define  OTHER_MEMO_AMT                  / display       format=&FORMAT_NUMERIC          "&secdet_mem_oth";                    /*   400    */     
Define  CCF_APPLIED_PCT                 / display       format=&FORMAT_NUMERIC          "&secdet_EA_con_factor";              /*   410    */     
Define  OWN_FUNDS_DEDUCTION_AMT         / display       format=&FORMAT_NUMERIC          "&secdet_exp_dedc_own_fund";          /*   420    */     
Define  PRE_CAP_EXPOSURE_AMT            / display       format=&FORMAT_NUMERIC          "&secdet_tot_rw_exp_amt_bf_cap";      /*   430    */     
Define  POST_CAP_EXPOSURE_AMT           / display       format=&FORMAT_NUMERIC          "&secdet_tot_rw_exp_amt_aft_cap";     /*   440    */     
Define  CTP_NON_CTP                     / display                                       "&secdet_tb_sec_ctp";                 /*   450    */     
Define  LONG_POSITION_NET_AMT           / display       format=&FORMAT_NUMERIC          "&secdet_tb_netpos_lng";              /*   460    */     
Define  SHORT_POSITION_NET_AMT          / display       format=&FORMAT_NUMERIC          "&secdet_tb_netpos_short";            /*   470    */     
Define  SPECIFIC_RISK_AMT               / display       format=&FORMAT_NUMERIC          "&secdet_tb_own_fnd_req";             /*   480    */     

run;

%mend regulatory_reportcontents; /* end reportcontents */

%macro regulatory_reportbody ;

/* Test for data before producing report */
%if NOT %sysfunc(exist(work.current_regulatory)) or NOT %sysfunc(exist(work.page_1))
  or %upcase(&SYSTEM_FATAL_ERROR) = %upcase (Y) %then %do;
        %print_msg(warning,3,10);
  %print_msg(warning,3,15);
  %return;
    %goto FINAL;
%end;

/* Iterate thought the number of sec types and produce report pages */
%let numberofsec=1;
%do currpage=1 %to &numberofsec;

/* If data is not available for the report page then do no run report content */
  %if NOT %sysfunc(exist(work.page_&currpage)) %then %do;
      %print_msg(warning,3,19);
      %print_msg(note,3,20);
      %goto NOPAGE;
  %end; 
  
  %if &APPLY_CCF_AFTER_CRM EQ NO %then %do;
     %let ccf_crm_msg=%print_msg(,3,111,1); 
     
     footnote "&ccf_crm_msg";
  %end;

  /* Produce the report */
/* Displays the titles for the cross-classification variables */
%if %upcase(&REPORT_TYPE)=%upcase(XLS) %then %do;
 
   ods tagsets.ExcelXP_Mod 
 		options(
		sheet_name="CRSEC-DET"
		sheet_interval='none' autofit_height="yes");
		%_Report_Title(REPORT_TITLE_CD=rpt_cd2,REPORT_TITLE=rpt_title1);
   ods tagsets.ExcelXP_Mod 
 		options(
		autofit_height="NO");

%end;  
  %regulatory_reportheaders (page_&currpage);
  %regulatory_reportcontents (page_&currpage);
  /* subroutine for no data available for report page */
  %NOPAGE:      

%end; /* end report page generation from cross classes */

%FINAL: 
footnote ;

%mend regulatory_reportbody; /* end reportbody macro */                            

/* Invoke the report */
%regulatory_reportbody;





%mend regrpt_capital_crsec_det_crd4;
