/*****************************************************************************
 * Copyright (c) 2013 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 * NAME: regrpt_capital_crsec_sa_crd4.sas
 *
 * PURPOSE: Runs regulatory report for CRD4 securitization reports - SA
 * 
 * NOTES: 
 * Created: 12/12/2013  
 *****************************************************************************/

%macro regrpt_capital_crsec_sa_crd4;

/* Create Data for Report */
%regrpt_d0_capital_crsec_sa_crd4;
%get_classdepth;
/* Creates basic CAPITAL_CRSEC_SA template report */  
%macro regulatory_reportcontents (dsn);         

%let style_type=%str(style=Data[Tagattr='format:#,##0.00' ]);  


proc report data=work.&dsn nowd missing LS=160 PS=50  SPLIT="@"  contents=''
/*    style(column)={ cellspacing=0}
    style(header)={ cellheight=0  cellspacing=0 };*/
style(column)={ /*bordercolor=#FAF8ED*/ cellspacing=0}
style(header)={background=#CED3D6 cellheight=0  cellspacing=0 fontweight=bold};

column
(       label
        outv_tranche_nominal_amt
        ("&syn_sec"

        (outv_sec_funded_amt
        ("&SEC_SA_OUTFLOW_IRB_AMT" outv_sec_unfunded_amt)
        outv_retained_amt)
        )
        ("&SEC_SA_POS" outv_exposure_orig_amt)

        /*Unique to SA*/
        outv_value_adj_amt
        outv_exposure_net_amt
        /*Unique to SA*/

        ("&credit_risk_mit_tech"
        (outv_sec_unfunded_und_amt
        outv_sec_funded_und_amt)
		 ("SUBSTITUTION OF THE EXPOSURE DUE TO CRM"
		 TOTAL_OUTFLOW_CRM_SUB_AMT
		 TOTAL_INFLOW_CRM_SUB_AMT
		)
        )
        
        outv_pre_ccf_after_crm
        outv_fin_coll_adj_val_amt
        outv_exposure_adj_amt
        ("&SEC_SA_BREAKDOWN_FULL_EXP_VAL"
        (outv_exp_adj_ccf_0
        outv_exp_adj_ccf_0_20
        outv_exp_adj_ccf_20_50
        outv_exp_adj_ccf_50_100))

        ( ""
        (outv_ead
        (outv_ded_own_funds
        outv_sub_rw)))

        /*Unique to SA*/
        ("&SEC_SA_BRKDWN_BY_EXP_VAL_ST_RW"
        ("&SEC_SA_CQS_RATED_LBL"
         (outv_ead_rw_20        
        outv_ead_rw_50
        outv_ead_rw_100
        outv_ead_rw_350
		outv_ead_rw_1250_rated))
        ("&OUTV_EAD_RW_1250" (    
        outv_ead_rw_1250_unrated))
        ("&SEC_SA_LOOK_THRU" (outv_ead_lookthrough_amt
        outv_ead_look_through_2nd_loss
		EAD_LOOK_THRU_AVG_RW_PCT))
		(" &SEC_SA_INT_ASSES_APPCH" EAD_SEC_IAA_AMT
		 (EAD_IAA_AVG_RW_PCT))
        )
        /*Unique to SA*/

        (" &SEC_SA_RW_EXP_AMT" outv_rwa
		RWA_SYNTHETIC_SEC_AMT)
		RWA_ADJ_INFRINGEMENT_AMT
		RWA_ADJ_MATURITY_MISMATCH_AMT
		("TOTAL RISK-WEIGHTED EXPOSURE AMOUNT "
		RWA_BEFORE_CAP_AMT
	    RWA_AFTER_CAP_AMT)

        RWA_SEC_OUTFLOW_OTHER_EXP_AMT

        /*"MEMORANDUM ITEM:..."
        "TOTAL CAPITAL REQURIEMENTS AFTER CAP"*/

);

        define label                                    / display         width=150     style=[font_weight=bold  ]                   " ";
        define outv_tranche_nominal_amt                 / display         &style_type.          "&SEC_SA_TOT_SEC_EXP_AMT";
        define outv_sec_funded_amt                      / display         &style_type          "&SEC_SA_SYNT_SEC_FUND_CRD_PROT	";
        define outv_sec_unfunded_amt                    / display         &style_type          "&SEC_SA_SYNT_SEC_UNFND_CRD_PROT";
        define outv_retained_amt                        / display         &style_type          "&SEC_SA_NOTIONAL_AMT";
        define outv_exposure_orig_amt                   / display         &style_type          "&SEC_SA_ORIG_EXP_PRE_CCF";

        /*unique to SA*/
        define outv_value_adj_amt                       / display         &style_type           "&SEC_SA_VAL_ADJ_PROV";
        define outv_exposure_net_amt                    / display         &style_type           "&SEC_SA_EXP_NET_VAL_ADJ_PRO";
        /*Unique to SA*/

        define outv_sec_unfunded_und_amt                / display         &style_type          "&SEC_SA_UNFUND_CRD_PROT_ADJ_VAL ";
        define outv_sec_funded_und_amt                  / display         &style_type          "&SEC_SA_FND_CRD_PROT";  
		define TOTAL_OUTFLOW_CRM_SUB_AMT                / display         &style_type          "&SEC_SA_TOT_OUTFLOW";	
		define TOTAL_INFLOW_CRM_SUB_AMT                 / display         &style_type          "&SEC_SA_TOT_INFLOW"	;
        define outv_pre_ccf_after_crm                   / display         &style_type          "&SEC_SA_NET_EXP_MIT";

        define outv_fin_coll_adj_val_amt                / display         &style_type          "&SEC_SA_CRD_RSK_MIT";
        define outv_exposure_adj_amt                    / display         &style_type          "&SEC_SA_FULLY_ADJ_EXP";
        define outv_exp_adj_ccf_0                       / display         &style_type          "&SEC_SA_ADJ_EXP_0";  
        define outv_exp_adj_ccf_0_20                    / display         &style_type          "&SEC_SA_ADJ_EXP_0_20";
        define outv_exp_adj_ccf_20_50                   / display         &style_type          "&SEC_SA_ADJ_EXP_20_50";
        define outv_exp_adj_ccf_50_100                  / display         &style_type          "&SEC_SA_ADJ_EXP_50_100";

        define outv_ead                                 / display         &style_type         "&SEC_SA_EXP_VALUE " ;
        define outv_ded_own_funds                       / display         &style_type          "&SEC_SA_DEDUC_OWN_FNDS";
        define outv_sub_rw                              / display         &style_type          "&SEC_SA_SUBJ_RW ";

/***For SA***/
        define outv_ead_rw_20                           / display         &style_type          "&SEC_SA_CQS1";
        define outv_ead_rw_50                           / display         &style_type          "&SEC_SA_CQS2";
        define outv_ead_rw_100                          / display         &style_type          "&SEC_SA_CQS3";
        define outv_ead_rw_350                          / display         &style_type          "&SEC_SA_CQS4";

        define outv_ead_rw_1250_rated                   / display         &style_type          "&SEC_SA_OTHER_CQS";
        define outv_ead_rw_1250_unrated                 / display         &style_type          "&SEC_SA_UNRATED";
        define outv_ead_lookthrough_amt                 / display         &style_type          /*"&SEC_SA_LOOK_THRU"*/ "";
        define outv_ead_look_through_2nd_loss           / display         &style_type          "&SEC_SA_LOOK_THRU_SEC_LOSS";

        define EAD_LOOK_THRU_AVG_RW_PCT	                / display         &style_type          "&SEC_SA_LOOK_THRU_AVG_RW";
        define EAD_SEC_IAA_AMT                          / display         &style_type         /* "&SEC_SA_INT_ASSES_APPCH" */ "";
        DEFINE EAD_IAA_AVG_RW_PCT                       / display         &style_type          "&SEC_SA_INT_ASSES_AVG_RW";
		/************/

        define outv_rwa                                 / display         &style_type         /* "&SEC_SA_RW_EXP_AMT" */ "";
/*        define outv_capital                             / display         &style_type          "&outv_capital_sec";*/
        define RWA_SYNTHETIC_SEC_AMT                    / display        &style_type          "&SEC_SA_RW_EXP_AMT_SYN_SEC";
        define RWA_ADJ_INFRINGEMENT_AMT                 / display        &style_type          "&SEC_SA_EFF_DUE_DELIG";
        define  RWA_ADJ_MATURITY_MISMATCH_AMT           / display        &style_type          "&SEC_SA_ADJ_RW_AMT_MATR_MISMTCH";
        define RWA_BEFORE_CAP_AMT                       / display        &style_type          "&SEC_SA_RW_BEF_CAP";
        define RWA_AFTER_CAP_AMT                        / display        &style_type          "&SEC_SA_RW_AFT_CAP";
/* Memorandum Items */
        define RWA_SEC_OUTFLOW_OTHER_EXP_AMT            / display        &style_type          "&SEC_SA_MEMO_OUTFLOWS";

     
  run;

%mend regulatory_reportcontents; /* end reportcontents */

%macro regulatory_reportbody ;

/* Test for data before producing report */
%if NOT %sysfunc(exist(work.current_regulatory)) or NOT %sysfunc(exist(work.page1))
  or %upcase(&SYSTEM_FATAL_ERROR) = %upcase (Y) %then %do;
        %print_msg(warning,3,10);
  %print_msg(warning,3,15);
  %return;
    %goto FINAL;
%end;

/* Iterate thought the number of sec types and produce report pages */

%do currpage=1 %to &numberofsec;

/* If data is not available for the report page then do no run report content */
  %if NOT %sysfunc(exist(work.page&currpage)) %then %do;
      %print_msg(warning,3,19);
      %print_msg(note,3,20);
      %goto NOPAGE;
  %end; 

  %if &APPLY_CCF_AFTER_CRM EQ NO %then %do;
  
     %let ccf_crm_msg=%print_msg(,3,112,1); 
     
     footnote "&ccf_crm_msg";
  %end;
  
  /* Produce the report */
  %if %upcase(&REPORT_TYPE)=%upcase(XLS) %then %do;
/*	data _null_;
		ID = open("report_pages");
		Var_name = upcase(varname(ID,2));
		RC = close(ID);
		call symputx("class_sa_lev1",var_name);
	run;
   data _null_;
    set report_pages(firstobs=&this_page obs=&this_page);
	call symputx("sheet_nm",put(&class_sa_lev1,$aggregate.));
   run;
*/
%let sheet_nm= SEC_SA;
   ods tagsets.ExcelXP_Mod 
 		options(
		sheet_name="&sheet_nm"
		sheet_interval='none' autofit_height="yes");

		%_Report_Title(REPORT_TITLE_CD=rpt_cd2,REPORT_TITLE=rpt_title1);
   ods tagsets.ExcelXP_Mod 
 		options(
		autofit_height="NO");

%end;

  %regulatory_reportheaders (page&currpage);

  %regulatory_reportcontents (page&currpage);
  
  /* subroutine for no data available for report page */
  %NOPAGE:      

%end; /* end report page generation from cross classes */

%FINAL: 
footnote ;

%mend regulatory_reportbody; /* end reportbody macro */                            

/* Invoke the report */
%regulatory_reportbody;





%mend regrpt_capital_crsec_sa_crd4;
