/*****************************************************************************
* Copyright (c) 2013 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
*
*    NAME:regrpt_capital_le2_crd4.sas
*
* PURPOSE: Creates report for the Large Exposures report
*
*
*   USAGE: 
*
*   NOTES: Created for v4.8
*   Macro Options:
*****************************************************************************/
 
%macro regrpt_capital_le2_crd4;

%regrpt_d0_capital_le2_crd4;
 
/* Creates basic  template report */
%macro report_page (dsn);

%let style_type=%str(style=Data[Tagattr='format:#,##0.00' ]);  

proc report data=&dsn nowd missing LS=160 PS=50 /*SPLIT="*"*/ contents=""
style(column)={ /*bordercolor=#FAF8ED*/ cellspacing=0}
style(header)={background=#CED3D6 cellheight=0  cellspacing=0 fontweight=bold};


column  
 ("COUNTERPARTY IDENTIFICATION"           /*B1 Start*/
			CPTY_CD                               /* COL 010  */
			CPTY_TYPE_LE2                         /* COL 020  */
			UNDERLYING_FLG                        /* COL 030  */
  )                                        /*B1 Close*/
 ("ORIGINAL EXPOSURES"                     /*B2 Start*/
			OUTV_TOT_ORIG_EXP_AMT                 /* COL 040  */
			OUTV_TOT_ORIG_EXP_DEFLT_AMT           /* COL 050  */
		("Direct exposures"                /*B2.1 Start*/
			OUTV_DIR_EXP_DEBT_AMT                 /* COL 060  */
			OUTV_DIR_EXP_EQUITY_AMT               /* COL 070  */
			OUTV_DIR_EXP_DERIVATIVE_AMT           /* COL 080  */
			("Off balance sheet items"      /*B2.1.1 Start*/
				OUTV_DIR_EXP_OBSI_LOAN_AMT        /* COL 090  */
				OUTV_DIR_EXP_OBSI_GUAR_AMT        /* COL 100  */
				OUTV_DIR_EXP_OBSI_OTH_AMT         /* COL 110  */
			)                               /*B2.1.1 Close*/
		)                                   /*B2.1 Close*/
		("Indirect exposures"               /*B2.2 Start*/
			OUTV_INDIR_EXP_DEBT_AMT                /* COL 120  */
			OUTV_INDIR_EXP_EQUITY_AMT              /* COL 130  */
			OUTV_INDIR_EXP_DERIVATIVE_AMT          /* COL 140  */
			("Off balance sheet items"       /*B2.2.1 Start*/
				OUTV_INDIR_EXP_OBSI_LOAN_AMT       /* COL 150  */
				OUTV_INDIR_EXP_OBSI_GUAR_AMT       /* COL 160  */
				OUTV_INDIR_EXP_OBSI_OTH_AMT        /* COL 170  */
			)                                /*B2.2.1 Close*/
		)                                    /*B2.2.1 Close*/
		OUTV_UNDERLYING_EXP_EAD_AMT                /* COL 180  */
  			
  )                                          /*B2 END*/
		OUTV_VALUE_ADJ_AMT                         /* COL 190  */
		OUTV_NOT_POPULATED                         /* COL 200  */
 ("Exposure value before application of exemptions and CRM "           /*B3 Start*/
			OUTV_EXP_PRE_CRM_AMT                   /* COL 210  */
			OUTV_EXP_PRE_CRM_TB_AMT                /* COL 220  */
			OUTV_EXP_PRE_CRM_PCT                   /* COL 230  */
  )                                                                     /*B3 Close*/
 ("ELIGIBLE CREDIT RISK MITIGATION (CRM) TECHNIQUES"                    /*B4 Start*/
		("(-) Substitution effect of eligible credit risk mitigation techniques" /*B4.1 Start*/
			OUTV_CRM_EXP_DEBT_AMT                  /* COL 240  */
			OUTV_CRM_EXP_EQUITY_AMT                /* COL 250  */
			OUTV_CRM_EXP_DERIVATIVE_AMT            /* COL 260  */
			("(-) Off balance sheet items"       /*B4.1.2 Start*/
				OUTV_CRM_EXP_OBSI_LOAN_AMT         /* COL 270  */
				OUTV_CRM_EXP_OBSI_GUAR_AMT         /* COL 280  */
				OUTV_CRM_EXP_OBSI_OTHER_AMT        /* COL 290  */
			)                                /*B4.1.2 Close*/
		)                                    /*B4.1 Close*/
		OUTV_CR_PRTCTN_NOT_SUB_EFF_AMT             /* COL 300  */
		OUTV_ELIG_CRM_REAL_ESTATE_AMT              /* COL 310  */
  )
  OUTV_LE_EXEMPTED_AMT                             /* COL 320  */
 ("Exposure value after application of exemptions and CRM "
   OUTV_EXP_POST_CRM_AMT                           /* COL 330  */
   OUTV_EXP_POST_CRM_TB_AMT                        /* COL 340  */
   OUTV_EXP_POST_CRM_PCT                           /* COL 350  */
  )
;    
    
 
/*define       NAME           /display     " "              "Name";*/
define       CPTY_CD        /display      " "              "Code";
define       CPTY_TYPE_LE2         /display      " "              "Group or individual";
/*define       LEI        /display     " "              "LEI code";*/
define       UNDERLYING_FLG        /display     " "              "Transactions where there is an exposure to underlying assets";
/*define       CPTY_RES        /display      " "              "Residence of the counterparty";*/
/*define       CPTY_SECTOR        /display   style(column)={tagattr='000'}  " "              "Sector of the counterparty";*/
/*define       NACE         /display      " "              "NACE code";*/
define       OUTV_TOT_ORIG_EXP_AMT        /display &style_type.    " "              "Total original exposure";
define       OUTV_TOT_ORIG_EXP_DEFLT_AMT        /display &style_type.    " "              "Of which: defaulted";
define       OUTV_DIR_EXP_DEBT_AMT        /display &style_type.    " "              "Debt instruments";
define       OUTV_DIR_EXP_EQUITY_AMT        /display &style_type.    " "              "Equity instruments";
define       OUTV_DIR_EXP_DERIVATIVE_AMT        /display &style_type.    " "              "Derivatives";
define       OUTV_DIR_EXP_OBSI_LOAN_AMT        /display &style_type.    " "              "Loan commitments";
define       OUTV_DIR_EXP_OBSI_GUAR_AMT        /display &style_type.    " "              "Financial guarantees";
define       OUTV_DIR_EXP_OBSI_OTH_AMT        /display &style_type.    " "              "Other commitments";
define       OUTV_INDIR_EXP_DEBT_AMT        /display &style_type.    " "              "Debt instruments";
define       OUTV_INDIR_EXP_EQUITY_AMT        /display &style_type.    " "              "Equity instruments";
define       OUTV_INDIR_EXP_DERIVATIVE_AMT        /display &style_type.    " "              "Derivatives";
define       OUTV_INDIR_EXP_OBSI_LOAN_AMT        /display &style_type.    " "              "Loan commitments";
define       OUTV_INDIR_EXP_OBSI_GUAR_AMT        /display &style_type.    " "              "Financial guarantees";
define       OUTV_INDIR_EXP_OBSI_OTH_AMT        /display &style_type.    " "              "Other commitments";
define       OUTV_UNDERLYING_EXP_EAD_AMT        /display &style_type.    " "              "Additional exposures arising from transactions where there is an exposure to underlying assets";
define       OUTV_VALUE_ADJ_AMT        /display &style_type.    " "              "(-) Value adjustments and provisions";
define       OUTV_NOT_POPULATED        /display &style_type.    " "              "(-) Exposures deducted from own funds";
define       OUTV_EXP_PRE_CRM_AMT        /display &style_type.    " "              "Total ";
define       OUTV_EXP_PRE_CRM_TB_AMT        /display &style_type.    " "              "Of which: Non-trading book";
define       OUTV_EXP_PRE_CRM_PCT        /display &style_type.    " "              "% of eligible capital";
define       OUTV_CRM_EXP_DEBT_AMT        /display &style_type.    " "              "(-) Debt instruments";
define       OUTV_CRM_EXP_EQUITY_AMT        /display &style_type.    " "              "(-) Equity instruments";
define       OUTV_CRM_EXP_DERIVATIVE_AMT        /display &style_type.    " "              "(-) Derivatives";
define       OUTV_CRM_EXP_OBSI_LOAN_AMT        /display &style_type.    " "              "(-) Loan commitments";
define       OUTV_CRM_EXP_OBSI_GUAR_AMT        /display &style_type.    " "              "(-) Financial guarantees";
define       OUTV_CRM_EXP_OBSI_OTHER_AMT        /display &style_type.    " "              "(-) Other commitments";
define       OUTV_CR_PRTCTN_NOT_SUB_EFF_AMT        /display &style_type.    " "              "(-) Funded credit protection other than substitution effect";
define       OUTV_ELIG_CRM_REAL_ESTATE_AMT        /display &style_type.    " "              "(-) Real estate";
define       OUTV_LE_EXEMPTED_AMT        /display &style_type.    " "              "(-) Amounts exempted";
define       OUTV_EXP_POST_CRM_AMT        /display &style_type.    " "              "Total ";
define       OUTV_EXP_POST_CRM_TB_AMT        /display &style_type.    " "              "Of which: Non-trading book";
define       OUTV_EXP_POST_CRM_PCT        /display &style_type.    " "              "% of eligible capital";
     
    compute CPTY_CD;
       count+1;
       if mod(count,2) then do;
         call define(_row_,"Style", "Style=[background=#ffffff]");
       end;
    endcomp;

run;

 
 
%mend report_page;
 
 
%macro generate_report;
 
%if NOT %sysfunc(exist(work.current_regulatory)) or NOT %sysfunc(exist(work._LE2_GRP_IND_REPORT))
or %upcase(&SYSTEM_FATAL_ERROR) = %upcase (Y) %then %do;
%print_msg(warning,3,10);
%print_msg(warning,3,15);
%regulatory_reportnopage();
%return;
%goto FINAL;
%end;
 
/* Get number of report pages */
/*%let pages=%attrn(report_pages,NOBS);
 
%do this_page=1 %to &PAGES ;
*/ 
/*Change to &pages */
/*If data is not available for the report page then do no run report content */
%if NOT %sysfunc(exist(work._LE2_GRP_IND_REPORT)) %then %do;
%print_msg(warning,3,19);
%print_msg(note,3,20);
%regulatory_reportnopage();
%goto NOPAGE;
%end;

 
/* Displays the titles for the cross-classification variables */

/*%regulatory_reportheaders(work._LE2_GRP_IND_REPORT);*/
%if &report_type=XLS %then %do;

   ods tagsets.ExcelXP_Mod 
 		options(
		sheet_name="&rpt_cd."
		sheet_interval='none' autofit_height="yes");
		%_Report_Title(REPORT_TITLE_CD=rpt_cd2,REPORT_TITLE=rpt_title1);
   ods tagsets.ExcelXP_Mod 
 		options(
		autofit_height="NO"); 
%end;

%report_page (work._LE2_GRP_IND_REPORT);
 
/* subroutine for no data available for report page */
%NOPAGE:
 

 
%FINAL:
footnote ;
 
%mend generate_report; /* end reportbody macro */
 
%generate_report;
 

 
%mend regrpt_capital_le2_crd4;
