/*****************************************************************************
* Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
*
*    NAME:regrpt_d0_cap_crgb_3_crd4.sas
*
* PURPOSE: Creates data for the CR-GB 3 report
*
*****************************************************************************/

%macro regrpt_d0_cap_crgb_3_crd4;

/*---------------------------------------------------------------------------
* Step 0.
* Initialize parameters and temporary code storage
* -------------------------------------------------------------------------*/
%global numccfbuckets;
%let numccfbuckets=6;
%let class_depth=1;
%let number_of_headers = %eval(&class_depth);
%let starting_class = %eval(1 + &class_depth);
%let fact_table=regulatory;;
%let report_name=CRGB3; 
 
 
filename page catalog 'work.temp.pages.source';
filename lgd catalog 'work.temp.lgd.source';
filename ccf catalog 'work.temp.ccf.source';
 
 
%macro createRegulatoryView (fact_table=);
/*---------------------------------------------------------------------------
* Step 1.
* Check for data in the repository and create a dataset for the project
* the dataset is work.current_regulatory
* -------------------------------------------------------------------------*/
%if %upcase(&usertype) eq MASTER %then
%let projectview=%trim(%left(&PROJECT_SET))_%trim(%left(&REGPROJECTNAME))_%trim(%left(&MITIGANTS_ALLOCATION_METHOD))_%trim(%left(&system_id));
%else
%let projectview=%trim(%left(&PROJECT_SET))_%trim(%left(&REGPROJECTNAME))_%trim(%left(&MITIGANTS_ALLOCATION_METHOD))_%trim(%left(&system_id))_%trim(%left(&username));
/* Create SQL views into datamart with no history */
%create_risk_repository_views
(Project_name=&projectview,Fact_table=&fact_table,Current=YES,Year=NO,Allhistory=NO, where=NONE, obs=0);
 
%mend createRegulatoryView;
 
/* Create views of fact table with cross-class macro names */
%createRegulatoryView (fact_table=&fact_table);
    data work._all;
        set work.current_&fact_table ;
    run;
    
	data report_data;
	set work._all;
	run;


/*- get the report data into the right order for the report -*/
 
    proc sort   data=work.current_&fact_table (keep=&rptvar1) nodupkeys
            out=report_pages;
            by &rptvar1;
/*			where &rptvar1 ne '+';*/
    run;
 	data report_pages;
		set report_pages;
		rank=_n_;
	run;
	proc sort data=report_data;
	 by &rptvar1;
	run;
	proc sort data=report_pages;
	 by &rptvar1;
	run;
    
	data report_data;
	 merge report_data(in=a) report_pages(in=b);
	 by &rptvar1;
	 if a and b;
	 class_crgb_3="&CRGB_3_L_10.";
	 run;
 
%macro createReportPages;
 
 
/*---------------------------------------------------------------------------
* Create seperate page tables for the report
* Also, create CCF output values using the CCF cross-classification
* -------------------------------------------------------------------------*/
 
 
    data _null_;
       set work.report_pages;
       file page;
        put "data &regprojectname._"  _n_  ";";
        put ' set work.report_data;';
        put " where &rptvar1 eq '" &rptvar1 "';";
        put 'run;';
  
		 
		put "data &regprojectname._"  _n_  "(drop=rank);";
		put "set &regprojectname._"  _n_  ";";
		put "if PROJECT_SK=. then delete;";
		put 'run;';

run;
run;
 
%inc page;
 
%mend createReportPages;
%createReportPages;
 
%mend regrpt_d0_cap_crgb_3_crd4;
