/*****************************************************************************
* Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
*
*    NAME:regrpt_d0_cap_crgb_irba_crd4.sas
*
* PURPOSE: Creates data for the CR-GB SA report
*
*****************************************************************************/

%macro regrpt_d0_cap_crgb_irba_crd4;

/*---------------------------------------------------------------------------
* Step 0.
* Initialize parameters and temporary code storage
* -------------------------------------------------------------------------*/
%global numccfbuckets;
%let numccfbuckets=6;
%let class_depth=1;
%let number_of_headers = %eval(&class_depth);
%let starting_class = %eval(1 + &class_depth);
%let fact_table=regulatory;;
%let report_name=CRGB_IRBA; 
 
 
filename page catalog 'work.temp.pages.source';
filename lgd catalog 'work.temp.lgd.source';
filename ccf catalog 'work.temp.ccf.source';
 
%macro where_clause(prefix, start, end, value);
%do i=&start %to &end;
%if &i NE &end %then
%do;
(&&&prefix&i EQ &value) AND
%end;
%else %do;
(&&&prefix&i EQ &value)
%end;
%end;
%mend where_clause;

%macro get_fact_data (proj_name= , fact_table= , variable= , out_ds= );

/* 1. Create the current_* table, that contains info from the latest proj. */
%create_risk_repository_views
(Project_name=&proj_name, Fact_table=&fact_table, Current=YES, Year=NO, Allhistory=NO, where=NONE, obs=0);

 
/* 2. If the regulatory table (or the data) do not exist, exit */
%if %dsexist(work.current_&fact_table) EQ 0 %then %goto EXIT;
%else %if %attrn (work.current_&fact_table,NOBS) EQ 0 %then %goto EXIT; 
 
%else 
%do;
/*4. From the current_* table, select only the records used by the reports  */

/*data work.&out_ds (keep = NAME &rptvar4 &variable);*/
data work.&out_ds ;
set work.current_&fact_table;
where %where_clause(rptvar, 1, %EVAL(&nrptvar-1), '+');
RUN; 


%END; 
%EXIT:

%mend get_fact_data;
 
%macro createRegulatoryView (fact_table=);
/*---------------------------------------------------------------------------
* Step 1.
* Check for data in the repository and create a dataset for the project
* the dataset is work.current_regulatory
* -------------------------------------------------------------------------*/
%if %upcase(&usertype) eq MASTER %then
%let projectview=%trim(%left(&PROJECT_SET))_%trim(%left(&REGPROJECTNAME))_%trim(%left(&MITIGANTS_ALLOCATION_METHOD))_%trim(%left(&system_id));
%else
%let projectview=%trim(%left(&PROJECT_SET))_%trim(%left(&REGPROJECTNAME))_%trim(%left(&MITIGANTS_ALLOCATION_METHOD))_%trim(%left(&system_id))_%trim(%left(&username));
/* Create SQL views into datamart with no history */
%create_risk_repository_views
(Project_name=&projectview,Fact_table=&fact_table,Current=YES,Year=NO,Allhistory=NO, where=NONE, obs=0);
 
%mend createRegulatoryView;

%macro createRegulatoryView_eq (fact_table=);
/*---------------------------------------------------------------------------
* Step 1.
* Check for data in the repository and create a dataset for the project
* the dataset is work.current_regulatory
* -------------------------------------------------------------------------*/
%if %upcase(&usertype) eq MASTER %then
%let projectview=%trim(%left(&PROJECT_SET))_%trim(%left(CAPITAL_CREQU_CRD4))_%trim(%left(&MITIGANTS_ALLOCATION_METHOD))_%trim(%left(&system_id));
%else
%let projectview=%trim(%left(&PROJECT_SET))_%trim(%left(CAPITAL_CREQU_CRD4))_%trim(%left(&MITIGANTS_ALLOCATION_METHOD))_%trim(%left(&system_id))_%trim(%left(&username));
/* Create SQL views into datamart with no history */
%create_risk_repository_views
(Project_name=&projectview,Fact_table=&fact_table,Current=YES,Year=NO,Allhistory=NO, where=NONE, obs=0);
%get_fact_data(proj_name=&projectview,fact_table=REGULATORY, variable=&outvars, out_ds=equ_part);
 
%mend createRegulatoryView_eq;
/* Get the Equity data for GB-IRB */

%let outvars = PROJECT_SK OUTV_EXP_PRE_CCF_PRE_CRM OUTV_EAD OUTV_DEFAULTS_AMT OUTV_NEW_DEFAULTS_AMT OUTV_VALUE_ADJ_AMT OUTV_SPECIFIC_WRITEOFF_AMT OUTV_PROVISIONS_NEW_DFLT_AMT OUTV_RWA OUTV_EL_AMT;
%createRegulatoryView_eq (fact_table=&fact_table);

/* Create views of fact table with cross-class macro names */
%createRegulatoryView (fact_table=&fact_table);

/* Create GB-IRB specific dataset */
data equ_part;
	SET equ_part;
	attrib CLASS_CRGB_IRB length = $256;
	CLASS_CRGB_IRB='EQUITY';
	RANK=140;
	%do ii=2 %to &Nrptvar; &&RPTVAR&ii = '+'; %end;
run; 

    data work._all;
        set work.current_&fact_table
        (where=(&rptvar5 NE 'PAST_DUE'));
    run;

    data work._all_default (KEEP=&rptvar1 &rptvar2 &rptvar3 &rptvar4 &rptvar5 OUTV_DEFAULTS_AMT);
        set work.current_&fact_table
        (where=(&rptvar5='PAST_DUE'));
		RENAME OUTV_EXP_PRE_CCF_PRE_CRM=OUTV_DEFAULTS_AMT;
    run;
	proc sort data=work._all;
		by &rptvar1 &rptvar2 &rptvar3 &rptvar4 &rptvar5;
	run;
	proc sort data=work._all_default;
		by &rptvar1 &rptvar2 &rptvar3 &rptvar4 &rptvar5;
	run;
	data report_data;
	merge _all _all_default;
	by &rptvar1 &rptvar2 &rptvar3 &rptvar4 &rptvar5;
	run;


/*- get the report data into the right order for the report -*/
 
    proc sort   data=work.current_&fact_table (keep=&rptvar1) nodupkeys
            out=report_pages;
            by &rptvar1;
/*			where &rptvar1 ne '+';*/
    run;
 	data report_pages;
		set report_pages;
		rank=_n_;
	run;
	proc sort data=report_data;
	 by &rptvar1;
	run;
	proc sort data=report_pages;
	 by &rptvar1;
	run;
    

    proc sort   data=rd_root.report_line_seq (WHERE=(report_name="&report_name" and CONFIG_ID = "&CONFIG_SET" )) 
            out=work.report_line_seq_&report_name ;
            by report_line_no;
    run;

		data _EXP_CLASS_RANK (KEEP=REPORT_LINE_NO VARIABLE_VALUE _EXP_CLASS_table);
			set work.report_line_seq_&report_name ;
			where variable_name='EXPOSURE_CLASS';
			_EXP_CLASS_table='_EXP_CLASS_'||compress(report_line_no);
		RUN;
		
		data _OTH_RET_RANK (KEEP=REPORT_LINE_NO VARIABLE_VALUE _EXP_CLASS_table);
			set work.report_line_seq_&report_name ;
			where variable_name='OTHER_RETAIL';
			_EXP_CLASS_table='_OTH_RET_'||compress(report_line_no);
		RUN;
		
		data _RETAIL_ (KEEP=REPORT_LINE_NO VARIABLE_VALUE _EXP_CLASS_table);
			set work.report_line_seq_&report_name ;
			where variable_name='RETAIL';
			_EXP_CLASS_table='_RETAIL_'||compress(report_line_no);
		RUN;
		
		data _RET_OF_WCH (KEEP=REPORT_LINE_NO VARIABLE_VALUE _EXP_CLASS_table);
			set work.report_line_seq_&report_name ;
			where variable_name='RETAIL_OFWHICH';
			_EXP_CLASS_table='_RET_OF_WCH'||compress(report_line_no);
		RUN;

		
		data _RET_SEC_IMOV (KEEP=REPORT_LINE_NO VARIABLE_VALUE _EXP_CLASS_table);
			set work.report_line_seq_&report_name ;
			where variable_name='RETAIL_SEC_IMOV';
			_EXP_CLASS_table='_RET_SEC_IMO'||compress(report_line_no);
		RUN;

proc sql noprint;
select _EXP_CLASS_table into: _exp_class_table separated by ' '
from _EXP_CLASS_RANK;
quit;



%macro create_class_column (class_var=,new_class_var=,whereclause=,rptrank=,newline=,hier_order=,dsn=);
/*---------------------------------------------------------------------------
* Step 3.
* Create the classification column that is used in the report
* This column runs down the left-hand side of the report
* Create a rank variable to help sort in the order specified by the report
* -------------------------------------------------------------------------*/
/*---------------------------------------------------------------------------
* Get the first line in the report - represents everything rolled up
* -------------------------------------------------------------------------*/
 
%if &class_var=EXPOSURE_CLASS %then %do;

	
    data work._EXP_CLASS_&rptrank(where=(&new_class_var ne ""));
        set work.report_data
        (where=(&rptvar2 in &whereclause %do ii=3 %to &Nrptvar; and &&RPTVAR&ii eq '+' %end;));

        attrib &new_class_var length = $256;
            &new_class_var = &rptvar2;
            rank=&rptrank;
    run;


/*---------------------------------------------------------------------------
* Create an empty line as a header for some items
* -------------------------------------------------------------------------*/
 
%end; %else
%if &class_var=LINE %then %do;
    data work.newline;
        attrib &new_class_var length = $256 ;
        &new_class_var="&newline";
        BLANK_LINE='YES';
        rank=&rptrank;
    run;
 
    data work.&dsn;
        set work.&dsn work.newline;
    run;
 
%end;
 
/*---------------------------------------------------------------------------
* Create a breakdown by exposure type - On,Off balance,Derviatives,Repos etc
* -------------------------------------------------------------------------*/
%else %if &class_var=EXP_TYPE %then %do;
	data _exp_type_rank (KEEP=REPORT_LINE_NO VARIABLE_VALUE);
	set work.report_line_seq_&report_name ;
	where variable_name='EXP_TYPE';
	RUN;
	
    data work._exp_type (where=(&new_class_var ne ""));
        set work.current_&fact_table;
        attrib &new_class_var length = $256 ;
        if &rptvar3 NE '+' %do ii=5 %to &Nrptvar; and &&RPTVAR&ii eq '+' %end; then do;
            &new_class_var = &rptvar3;
			rank=&rptrank;
        end;
    run;
	proc sql;
		create table _exp_type1 as
		select a.*,b.report_line_no as rank1 from _exp_type a, _exp_type_rank b
		where a.CLASS_CRGB_IRB=b.VARIABLE_VALUE;
	quit;
	data _exp_type (rename=(rank1=rank));
	set _exp_type1(drop=rank);
	run;
	
	
%end;
/*---------------------------------------------------------------------------
* Create a breakdown by Total exposure type 
* -------------------------------------------------------------------------*/

%else %if &class_var=TOTAL_OFWHICH %then %do;

    data work._all_type_&rptrank (where=(&new_class_var ne ""));
        set work.current_&fact_table;
        attrib &new_class_var length = $256 ;
            &new_class_var = put (&rptvar7,$exptype_ofwhich.);
            rank=&rptrank; 
    where (&rptvar7 in &whereclause) and &rptvar2 in ('+','CORPORATES','RETAIL') and &rptvar3 eq '+' and &rptvar5 eq '+' and &rptvar6 eq '+'
    %do ii=8 %to &Nrptvar; 
		and	&&RPTVAR&ii eq '+'
	%end;;
    
    run;
%end;

/*---------------------------------------------------------------------------
* Create a breakdown by exposure type - CCP
* -------------------------------------------------------------------------*/

%else %if &class_var=EXP_OFWHICH %then %do;

    data work._exp_type_&rptrank (where=(&new_class_var ne ""));
        set work.current_&fact_table;

        attrib &new_class_var length = $256 ;
            &new_class_var = put (&rptvar7,$exptype_ofwhich.);
            rank=&rptrank; 
    where (&rptvar3 in &whereclause) %do ii=5 %to 7; and &&RPTVAR&ii eq '+' %end; and &rptvar8 eq 'CCP'
    %do ii=9 %to &Nrptvar; 
		and	&&RPTVAR&ii eq '+'
	%end;;
    
    run;
%end;

%mend;

data _null_;
set _EXP_CLASS_rank;
call execute ('%create_class_column (class_var=EXPOSURE_CLASS,new_class_var=CLASS_CRGB_IRB,whereclause=("'||compress(variable_value)||'"),rptrank='||report_line_no||')');
run;
%let new_class_var=CLASS_CRGB_IRB;

   	    data work._exp_class_40(where=(&new_class_var ne ""));
        set work.current_&fact_table;
           where upcase(&rptvar2) in ("CORPORATE") and    &rptvar3  in ("+") and    &rptvar4  in ("SPECIAL_LENDING")  and &rptvar5 eq '+';
		        attrib &new_class_var length = $256;
		            &new_class_var = "SPECIAL_LENDING";
		            rank=40;
		    run;
   	    data work._exp_class_50(where=(&new_class_var ne ""));
        set work.current_&fact_table;
           where upcase(&rptvar2) in ("CORPORATE") and    &rptvar3  in ("+") and    &rptvar4  in ("SME")  and &rptvar5 eq '+';
		        attrib &new_class_var length = $256;
		            &new_class_var = "CORP_SME";
		            rank=50;
		    run;
   	    data work._retail_70(where=(&new_class_var ne ""));
        set work.current_&fact_table;
           where upcase(&rptvar2) in ("RETAIL") and    &rptvar3  in ("RETAIL_SEC_IMOV") and    &rptvar4  in ("+")  and &rptvar5 eq '+';
		        attrib &new_class_var length = $256;
		            &new_class_var = &rptvar3;
		            rank=70;
		    run;

   	    data work._retail_80 (where=(&new_class_var ne ""));
        set work.current_&fact_table;
        where upcase(&rptvar2) in ("RETAIL") and    &rptvar3  in ("RETAIL_SEC_IMOV") and    &rptvar4  in ("SME")  and &rptvar5 eq '+';
		        attrib &new_class_var length = $256;
		            &new_class_var = &rptvar4;
		            rank=80;
		    run;
		    
   	    data work._retail_90 (where=(&new_class_var ne ""));
        set work.current_&fact_table;
  	        where upcase(&rptvar2) in ("RETAIL") and    &rptvar3  in ("RETAIL_SEC_IMOV") and    &rptvar4  in ("NON_SME")  and &rptvar5 eq '+';
		        attrib &new_class_var length = $256;
		            &new_class_var = &rptvar4;
		            rank=90;
		    run;

   	    data work._retail_100 (where=(&new_class_var ne ""));
        set work.current_&fact_table;
  	        where upcase(&rptvar2) in ("RETAIL") and    &rptvar3  in ("RETAIL") and    &rptvar4  in ("QRRE")  and &rptvar5 eq '+'  and &rptvar5 eq '+';
		        attrib &new_class_var length = $256;
		            &new_class_var = &rptvar4;
		            rank=100;
		    run;
		    
   	    data work._retail_110(where=(&new_class_var ne ""));
        set work.current_&fact_table;
  	        where upcase(&rptvar2) in ("RETAIL") and    &rptvar3  in ("RETAIL_OTHER") and    &rptvar4  in ("+")  and &rptvar5 eq '+';
		        attrib &new_class_var length = $256;
		            &new_class_var = "RETAIL_OTHER";
		            rank=110;
		    run;
		    
   	    data work._retail_120 (where=(&new_class_var ne ""));
        set work.current_&fact_table;
  	        where upcase(&rptvar2) in ("RETAIL") and    &rptvar3  in ("RETAIL_OTHER") and    &rptvar4  in ("SME")  and &rptvar5 eq '+';
		        attrib &new_class_var length = $256;
		            &new_class_var = "OTH_RET_OF_SME";
		            rank=120;
		    run;

   	    data work._retail_130(where=(&new_class_var ne ""));
        set work.current_&fact_table;
  	        where upcase(&rptvar2) in ("RETAIL") and    &rptvar3  in ("RETAIL_OTHER") and    &rptvar4  in ("NON_SME")  and &rptvar5 eq '+';
		        attrib &new_class_var length = $256;
		            &new_class_var = "OTH_RET_OF_NON_SME";
		            rank=130;
		    run;

   	    data work._total_exposures(where=(&new_class_var ne ""));
        set work.current_&fact_table
        (where=(&rptvar2 EQ '+' AND &rptvar3 EQ '+' AND &rptvar4 EQ '+' AND &rptvar5 EQ '+'));
		        attrib &new_class_var length = $256;
		            &new_class_var = "TOTAL_EXP";
		            rank=141;
		    run;

%IF  %SYSFUNC(EXIST(work.equ_part)) %THEN %DO;

	DATA work._total_exposures_equ ;
	 SET work._total_exposures ;
	 STOP;
	RUN;

	PROC APPEND BASE=_total_exposures_equ DATA=_total_exposures;RUN;
	PROC APPEND BASE=_total_exposures_equ DATA= equ_part FORCE;	RUN;
	PROC SORT   DATA=_total_exposures_equ ;
		BY &rptvar1;
	RUN;
	PROC SUMMARY DATA=_total_exposures_equ   ; 
		VAR _NUMERIC_;
		BY &RPTVAR1;
		OUTPUT OUT=_total_exposures_equ_sum
			SUM(_NUMERIC_)=;
	RUN;
	DATA _total_exposures;
	 SET _total_exposures_equ_sum;
		attrib &new_class_var length = $256;
		&new_class_var = "TOTAL_EXP";
		rank=141;
    RUN;


%END;


/*
data _null_;
set _OTH_RET_RANK;
call execute ('%create_class_column (class_var=OTHER_RETAIL,new_class_var=CLASS_CRGB_IRB,whereclause=('||compress(variable_value)||'),rptrank='||report_line_no||')');
run;
*/
    proc sort   data=rd_root.report_line_seq (WHERE=(report_name="&report_name" and CONFIG_ID = "&CONFIG_SET" )
											  rename=(variable_value=&rptvar2 report_line_no=rank)) 
            out=work.report_line_seq_&report_name;
            by rank;
    run; 

	data report_data;
	 	set &_EXP_CLASS_table _exp_class_40 _exp_class_50 _retail_70 _retail_80 _retail_90 _retail_100 _retail_110 _retail_120 _retail_130 equ_part _total_exposures;
	run;
	proc sort data=report_data;
	 by &rptvar1;
  run;
  
	data report_data;
	 merge report_data(in=a) report_pages(in=b drop=rank);
	 by &rptvar1;
	 if a and b;
	 OUTV_GEN_CR_ADJ=.;
	run;
	 
	
	 
	 	
%macro createReportPages;
 
 
/*---------------------------------------------------------------------------
* Create seperate page tables for the report
* Also, create CCF output values using the CCF cross-classification
* -------------------------------------------------------------------------*/
 
 
    data _null_;
       set work.report_pages;
       file page;
        put "data &regprojectname._"  _n_  ";";
        put ' set work.report_data;';
        put " where &rptvar1 eq '" &rptvar1 "' ; ";
        put 'run;';
  
		 
		put "data &regprojectname._"  _n_  " ;";
		put "set &regprojectname._"  _n_  ";";
		put "if PROJECT_SK=. then delete;";
		put 'run;';

		put "proc sort  data=&regprojectname._"  _n_  ";";
		put 'by rank;run;';

		put "data &regprojectname._"  _n_  ";";
		put "merge report_line_seq_&report_name. &regprojectname._"  _n_ ";";
		put 'by rank;';
		put 'run;';

		put "data &regprojectname._"  _n_  ";";
		put "set &regprojectname._"  _n_  ";";
 
		put 'if missing(CLASS_CRGB_IRB) and not missing(report_line_id)then CLASS_CRGB_IRB=symget(report_line_id);';
		put 'run;';
		
		put "data &regprojectname._"  _n_  ";";
		put "set &regprojectname._"  _n_  ";";
    put "&rptvar1 = '" &rptvar1 "';";
		put 'run;';
		
		put "proc sort  data=&regprojectname._"  _n_  ";";
		put 'by rank;run;';

  
run;
run;
 
%inc page;
 
%mend createReportPages;
%createReportPages;
 
%mend regrpt_d0_cap_crgb_irba_crd4;
/*%regrpt_d0_capital_crgb_sa;*/
