/*****************************************************************************
 * Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME: regrpt_d0_cap_sec_det_crd4
 *
 * PURPOSE: Creates data for Regulatory report template for Securitization report - SA
 *                        
 *
 *   NOTES: 06/29/07 - Creation
 *          
 *
 *****************************************************************************/
%macro regrpt_d0_cap_sec_det_crd4;

%global numberof_rw rpath rwvar subclassvar pastduevar ratingvar where numberofsec numberofexptype;

%macro capital_crsec_det_etl;

/* Create SQL views into datamart with no history */
%if %upcase(&usertype) eq MASTER %then 
  %let projectview=%trim(%left(&PROJECT_SET))_%trim(%left(&REGPROJECTNAME))_%trim(%left(&MITIGANTS_ALLOCATION_METHOD))_%trim(%left(&system_id));
  %else
  %let projectview=%trim(%left(&PROJECT_SET))_%trim(%left(&REGPROJECTNAME))_%trim(%left(&MITIGANTS_ALLOCATION_METHOD))_%trim(%left(&system_id))_%trim(%left(&username)) ;
 
/* Create SQL views into datamart with no history */

%create_risk_repository_views 
   (Project_name=&projectview,Fact_table=REGULATORY,Current=YES,Year=NO,Allhistory=NO, where=NONE, obs=0);
   
/* Check for report data else stop report processing */
%if NOT %sysfunc(exist(work.current_regulatory)) %then %do;
        %let SYSTEM_FATAL_ERROR=Y;
        %print_msg(warning,3,7);        
        %return;
%end;


	PROC SQL;
		CREATE TABLE page_1 as
		SELECT * 
		FROM current_regulatory 
		WHERE class_vars_values_txt NOT LIKE "%+%"
		ORDER BY &rptvar1.;
	quit;
/*Rename class vars for the purpose of reporting*/
  PROC SQL NOPRINT;
   CREATE TABLE labels AS 
   SELECT name,label
   FROM dictionary.columns
   WHERE UPCASE(libname)="WORK"
   AND   UPCASE(memname)="CURRENT_REGULATORY"
   AND   UPCASE(name) LIKE 'CLASS_VAR%_ID';
  QUIT;

  DATA labels;
   SET labels;
   old_name=COMPRESS("old_name"||PUT(_N_,8.));
   new_name=COMPRESS("new_name"||PUT(_N_,8.));
   	CALL SYMPUTX(old_name,name);
	CALL SYMPUTX(new_name,label);
  RUN;

  %let dsid=%sysfunc(open(labels));
  %let num_labels=%sysfunc(attrn(&dsid,nobs));
  %let rc=%sysfunc(close(&dsid));

  %put &num_labels;

%macro add_new_columns ;
 data work.page_1 ;
  set work.page_1;
	%DO loop=1 %TO &num_labels; 
		&&new_name&loop = &&old_name&loop ;
	%END;
  run;
%mend add_new_columns ;
%add_new_columns ;

 data work.page_1 (drop=TEMP_DATE TEMP_FIRST_TERM_DT TEMP_LEGAL_FINAL_DT TMP_EFFECTIVE_EXPOSURE_NO);
  set work.page_1 (rename=(
							NON_ABCP_ORIGINATION_DT=TEMP_DATE
							FIRST_TERM_DT=TEMP_FIRST_TERM_DT
							LEGAL_FINAL_DT=TEMP_LEGAL_FINAL_DT
							EFFECTIVE_EXPOSURE_NO=TMP_EFFECTIVE_EXPOSURE_NO));
  NON_ABCP_ORIGINATION_DT=put(TEMP_DATE,MMYYS.);
  FIRST_TERM_DT          =put(TEMP_FIRST_TERM_DT,MMYYS.);
  LEGAL_FINAL_DT         =put(TEMP_LEGAL_FINAL_DT,MMYYS.);
  EFFECTIVE_EXPOSURE_NO  =put(TMP_EFFECTIVE_EXPOSURE_NO,NUM_EFF_EXP.);
  
run;

%mend; /*capital_crequ_sa_etl macro*/

%capital_crsec_det_etl;
%mend regrpt_d0_cap_sec_det_crd4;
