/*****************************************************************************
* Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
*
*    NAME:regrpt_d0_capital_crgb_sa.sas
*
* PURPOSE: Creates data for the CR-GB SA report
*
*****************************************************************************/

%macro regrpt_d0_capital_crgb_sa;

/*---------------------------------------------------------------------------
* Step 0.
* Initialize parameters and temporary code storage
* -------------------------------------------------------------------------*/
%global numccfbuckets;
%let numccfbuckets=6;
%let class_depth=2;
%let number_of_headers = %eval(&class_depth);
%let starting_class = %eval(1 + &class_depth);
%let fact_table=regulatory;;
%let report_name=CRGB_SA; 
 
 
filename page catalog 'work.temp.pages.source';
filename lgd catalog 'work.temp.lgd.source';
filename ccf catalog 'work.temp.ccf.source';
 
 
%macro createRegulatoryView (fact_table=);
/*---------------------------------------------------------------------------
* Step 1.
* Check for data in the repository and create a dataset for the project
* the dataset is work.current_regulatory
* -------------------------------------------------------------------------*/
%if %upcase(&usertype) eq MASTER %then
%let projectview=%trim(%left(&PROJECT_SET))_%trim(%left(&REGPROJECTNAME))_%trim(%left(&MITIGANTS_ALLOCATION_METHOD))_%trim(%left(&system_id));
%else
%let projectview=%trim(%left(&PROJECT_SET))_%trim(%left(&REGPROJECTNAME))_%trim(%left(&MITIGANTS_ALLOCATION_METHOD))_%trim(%left(&system_id))_%trim(%left(&username));
/* Create SQL views into datamart with no history */
%create_risk_repository_views
(Project_name=&projectview,Fact_table=&fact_table,Current=YES,Year=NO,Allhistory=NO, where=NONE, obs=0);
 
%mend createRegulatoryView;
 
/* Create views of fact table with cross-class macro names */
%createRegulatoryView (fact_table=&fact_table);
    data work._all(DROP=OUTV_PROVISIONS_NEW_DFLT_AMT &rptvar4);
        set work.current_&fact_table
        (where=(&rptvar2 EQ '+' and &rptvar3 NE '+' AND &rptvar4 EQ '+'));

    run;
    
    data _total_exposures(DROP=&rptvar4);
        set work.current_&fact_table
        (where=(&rptvar2 EQ '+' AND &rptvar3 EQ '+' AND &rptvar4 EQ '+'));
        &rptvar3="TOTAL_EXP";
    run;
    	
    data work._all_default (KEEP=project_sk &rptvar1 &rptvar2 &rptvar3 OUTV_DEFAULTS_AMT OUTV_NEW_DEFAULTS_AMT OUTV_PROVISIONS_NEW_DFLT_AMT);
        set work.current_&fact_table
        (where=(&rptvar3='PAST_DUE' AND &rptvar4 NE '+'));
		&rptvar3 = &rptvar4;
		&rptvar2='+';
    run;
	proc sort data=work._total_exposures;
		by &rptvar1 &rptvar2 &rptvar3;
	run;
	proc sort data=work._all;
		by &rptvar1 &rptvar2 &rptvar3;
	run;
	proc sort data=work._all_default NODUPKEY;
		by &rptvar1  &rptvar2 &rptvar3;
	run;
	data report_data1;
	merge _all _all_default;
	by &rptvar1 &rptvar2 &rptvar3;
	IF &rptvar2 EQ '+' AND &rptvar3 EQ '+' THEN
		&rptvar3="TOTAL_EXP";
	run;

	proc sort data=work.report_data1;
		by &rptvar1 &rptvar2 &rptvar3;
	run;
	data report_data;
	merge report_data1 _total_exposures;
	by &rptvar1 &rptvar2 &rptvar3;
	run;


/*- get the report data into the right order for the report -*/
 
    proc sort   data=work.current_&fact_table (keep=&rptvar1) nodupkeys
            out=report_pages;
            by &rptvar1;
/*			where &rptvar1 ne '+';*/
    run;
 	data report_pages;
		set report_pages;
		rank=_n_;
	run;
	proc sort data=report_data;
	 by &rptvar1;
	run;
	proc sort data=report_pages;
	 by &rptvar1;
	run;
    
	data report_data;
	 merge report_data(in=a) report_pages(in=b);
	 by &rptvar1;
	 if a and b;
	 /*adding null value for OUTV_GEN_CR_ADJ as this is out of scope for CRMB4.8*/
	 OUTV_GEN_CR_ADJ=.;
	 run;
 

    proc sort   data=rd_root.report_line_seq (WHERE=(report_name="&report_name" and CONFIG_ID = "&CONFIG_SET" )
											  rename=(variable_value=&rptvar3)) 
            out=work.report_line_seq_&report_name (rename=(report_line_no=rank ));
            by &rptvar3;
    run;
 
	
%macro createReportPages;
 
 
/*---------------------------------------------------------------------------
* Create seperate page tables for the report
* Also, create CCF output values using the CCF cross-classification
* -------------------------------------------------------------------------*/
 
 
    data _null_;
       set work.report_pages;
       file page;
        put "data &regprojectname._"  _n_  ";";
        put ' set work.report_data;';
        put " where &rptvar1 eq '" &rptvar1 "';";
        put 'run;';
  
		 
		put "data &regprojectname._"  _n_  "(drop=rank);";
		put "set &regprojectname._"  _n_  ";";
		put "if PROJECT_SK=. then delete;";
		put 'run;';

		put "proc sort  data=&regprojectname._"  _n_  ";";
		put 'by &rptvar3;run;';

		put "data &regprojectname._"  _n_  ";";
		put "merge report_line_seq_&report_name. &regprojectname._"  _n_ ";";
		put 'by &rptvar3;';
		put 'run;';

		put "data &regprojectname._"  _n_  ";";
		put "set &regprojectname._"  _n_  ";";
		put 'class_crgb_sa=&rptvar3;';
		put 'if missing(class_crgb_sa) and not missing(report_line_id)then class_crgb_sa=symget(report_line_id);';
		put 'run;';
		
		put "data &regprojectname._"  _n_  ";";
		put "set &regprojectname._"  _n_  ";";
    put "&rptvar1 = '" &rptvar1 "';";
		put 'run;';

  	put "proc sort  data=&regprojectname._"  _n_  ";";
		put 'by rank;run;';
  
run;
run;
 
%inc page;
 
%mend createReportPages;
%createReportPages;
 
%mend regrpt_d0_capital_crgb_sa;
