/*****************************************************************************
* Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
*
*    NAME:regrpt_d0_capital_crirbf_crd4.sas
*
* PURPOSE: Creates data for the CR IRB report
*
*
*   USAGE:
*
*   NOTES: Modified for V4.2/V4.5
*   Macro Options:
*****************************************************************************/
%macro regrpt_d0_capital_crirbf_crd4;

/*---------------------------------------------------------------------------
* Step 0.
* Initialize parameters and temporary code storage
* -------------------------------------------------------------------------*/
 
filename page catalog 'work.temp.pages.source';
filename lgd catalog 'work.temp.lgd.source';
 
%let class_depth=3;
%let number_of_headers = %eval(&class_depth);
%let starting_class = %eval(1 + &class_depth);
%let fact_table=regulatory;;
%let report_name=CRIRB ; 
 
%macro createRegulatoryView (fact_table=);
 
/*---------------------------------------------------------------------------
* Step 1.
* Check for data in the repository and create a dataset for the project
* the dataset is work.current_regulatory
* -------------------------------------------------------------------------*/
 
%if %upcase(&usertype) eq MASTER %then
%let projectview=%trim(%left(&PROJECT_SET))_%trim(%left(&REGPROJECTNAME))_%trim(%left(&MITIGANTS_ALLOCATION_METHOD))_%trim(%left(&system_id));
%else
%let projectview=%trim(%left(&PROJECT_SET))_%trim(%left(&REGPROJECTNAME))_%trim(%left(&MITIGANTS_ALLOCATION_METHOD))_%trim(%left(&system_id))_%trim(%left(&username));
 
/* Create SQL views into datamart with no history */
%create_risk_repository_views
(Project_name=&projectview,Fact_table=&fact_table,Current=YES,Year=NO,Allhistory=NO, where=NONE, obs=0);
 
 
%mend createRegulatoryView;
 
 
/* Create views of fact table with cross-class macro names */
%createRegulatoryView (fact_table=&fact_table);
 
 
%macro create_vars;
 
/*---------------------------------------------------------------------------
* Step 2.
* We have to create a few variables on the 'fly' that depend upon values of cross-classification
* variables.  Create a table current_regulatory_extra that has these computed values
* then merge them back into the current_regulatory table
* -------------------------------------------------------------------------*/
 
 
data work.current_&fact_table;
set work.current_&fact_table;
format OUTV_GUARANTEE_UNFUNDED_AMT OUTV_CREDIT_PROTECT_UNFUND_AMT
outv_credit_deriv_unfunded_amt outv_credit_protect_funded_amt
outv_credit_protect_funded_amt outv_ead best30.;
attrib _crd_deriv_unfund_lgd _fund_cred_protect_lgd _guar_unfund_lgd
_guar_unfund_nlgd _crd_deriv_unfund_nlgd _fund_cred_protect_nlgd _off_bal_exp_pre_ccf_crm
_unfunded_cred_protect_lgd _off_bal_ead  _unfund_cred_protect_lgd_dd length=8;
        
/*---------------------------------------------------------------------------
* The CRM GROUP CC is a flag that is set if the exp is pre-mit
*--------------------------------------------------------------------------*/
/*
if &rptvar4 eq 'LGD_ADJ' then
do;
_crd_deriv_unfund_lgd  =  outv_credit_deriv_unfunded_amt    ;
_fund_cred_protect_lgd =  outv_credit_protect_funded_amt    ;
_guar_unfund_lgd       =  OUTV_GUARANTEE_UNFUNDED_AMT       ;
end;
else do;
_guar_unfund_nlgd       =  OUTV_GUARANTEE_UNFUNDED_AMT      ;
_crd_deriv_unfund_nlgd  =  outv_credit_deriv_unfunded_amt   ;
_fund_cred_protect_nlgd =  outv_credit_protect_funded_amt   ;
end;

*/ 
/*---------------------------------------------------------------------------
* The CRM GROUP CC is a flag that is set if the exp is post-mit
*--------------------------------------------------------------------------*/
/*
if &rptvar4 in ('NOT_ADJ', 'UNDEFINED') then
do;
_guar_unfund_nlgd       =  OUTV_GUARANTEE_UNFUNDED_AMT      ;
_crd_deriv_unfund_nlgd  =  outv_credit_deriv_unfunded_amt   ;
_fund_cred_protect_nlgd =  outv_credit_protect_funded_amt   ;
end;
*/ 
 
/*---------------------------------------------------------------------------
* The CRM GROUP CC is a flag that is set if the exp is double default
*--------------------------------------------------------------------------*/
/*
if &rptvar4 eq 'DOUBLE_DEF' then
do;
 _unfunded_cred_protect_lgd_dd=OUTV_CREDIT_PROTECT_UNFUND_AMT ;  

end;
*/
 
/*---------------------------------------------------------------------------
* The exposure type is a flag that is set if the exp is off balance
*--------------------------------------------------------------------------*/
/*
if &rptvar3 in ('OFF_BALANCE') then
do;
_off_bal_exp_pre_ccf_crm = outv_exp_pre_ccf_pre_crm ;
_off_bal_ead             = outv_ead ;
end;
*/ 

outv_crd_deriv_unfund_lgd = outv_crd_deriv_unfund_lgd ;		
outv_fund_cred_protect_lgd = outv_fund_cred_protect_lgd; 							
_guar_unfund_lgd = outv_guar_unfund_lgd       ;							
_guar_unfund_nlgd = outv_guar_unfund_nlgd     	;				  
_crd_deriv_unfund_nlgd = outv_crd_deriv_unfund_nlgd  ;					
_fund_cred_protect_nlgd = outv_fund_cred_protect_nlgd 	;		
_fund_cred_protect_lgd =  outv_fund_cred_protect_lgd    ;
_unfund_cred_protect_lgd_dd = outv_unfund_cred_protect_lgd_dd; 	
_off_bal_exp_pre_ccf_crm= outv_off_bal_exp_pre_ccf_crm 		;	
_off_bal_ead = outv_off_bal_ead            		;
 
run;
 
%mend create_vars;
    

 
%macro create_class_column (class_var=,new_class_var=,whereclause=,rptrank=,newline=,hier_order=,dsn=);
/*---------------------------------------------------------------------------
* Step 3.
* Create the classification column that is used in the report
* This column runs down the left-hand side of the report
* Create a rank variable to help sort in the order specified by the report
* -------------------------------------------------------------------------*/
 
/*---------------------------------------------------------------------------
* Get the first line in the report - represents everything rolled up
* -------------------------------------------------------------------------*/
 
%if &class_var=TOTALS %then
%do;
    
data work._all  (where=(&new_class_var ne ""));
set work.current_&fact_table
(where=(&rptvar3 eq '+' %do ii=4 %to &Nrptvar-2; and &&RPTVAR&ii eq '+' %end;));
attrib &new_class_var length = $256 ;
&new_class_var = "&TOTAL_EXPOSURES";
rank=&rptrank;
run;
 
 
%end;
/*---------------------------------------------------------------------------
* Create an empty line as a header for some items
* -------------------------------------------------------------------------*/
%else %if &class_var=LINE %then
%do;
 
data work.newline;
attrib &new_class_var length = $256 ;
&new_class_var="&newline";
BLANK_LINE='YES';
rank=&rptrank;
run;
 
    data work.&dsn;
        set work.&dsn work.newline;
    run;
 
%end;
/*---------------------------------------------------------------------------
* Create a breakdown by exposure type - On,Off balance,Derivatives,Repos etc
* -------------------------------------------------------------------------*/
%else %if &class_var=EXP_TYPE %then
%do;
 
data work._exp_type&rptrank. (where=(&new_class_var ne ""));
set work.current_&fact_table;
attrib &new_class_var length = $256 ;
where (&rptvar3 in &whereclause);
if &rptvar3 NOT IN ('+', 'Missing') %do ii=4 %to &Nrptvar-2; and &&RPTVAR&ii eq '+' %end; then
do;
&new_class_var = &rptvar3;
rank=&rptrank;
end;
run;
 
%end;
/*---------------------------------------------------------------------------
* Create a breakdown for exp that are tagged with an obligor grade
* -------------------------------------------------------------------------*/
%else %if &class_var=OBLIGOR %then
%do;
 
data work._obligor_&whereclause (where=(&new_class_var ne ""));
set work.current_&fact_table;
attrib &new_class_var length = $256 ;
%if &whereclause=TOTALS %then
 
%do;
if &rptvar5 EQ '001' and &rptvar3 eq '+' and &rptvar4 eq '+'
    %do ii=6 %to &Nrptvar-2; and &&RPTVAR&ii eq '+' %end; then do;
%end;
 
%else
%do;
if &rptvar5 NE '001' and &rptvar6 NE '+' and &rptvar3 eq '+' and &rptvar4 eq '+'
%do ii=7 %to &Nrptvar-2; and &&RPTVAR&ii eq '+' %end; then do;
%end;
 
if &rptvar5 = '001' then &new_class_var="&IRB_OBLIGOR_TOTALS";else
&new_class_var = put(&rptvar6, $MAP_OBLIGOR_POOL_REGRPT.);          
rank=&rptrank;end;
 
run;
 
 
%end;
/*---------------------------------------------------------------------------
* Create a breakdown of slotting exposures
* -------------------------------------------------------------------------*/
 
%else %if &class_var=SLOT %then
%do;
 
data work._allslot_&rptrank (where=(&new_class_var ne ""));
set work.current_&fact_table;
attrib &new_class_var length = $256 ;
outv_pd_eff = .;  /*The average PD is not reported for the slotting buckets*/

%if &whereclause=TOTALS %then %do;
if &rptvar8 EQ '001' and &rptvar3 eq '+' and &rptvar4 eq '+' and &rptvar9 eq '+' and &rptvar10 eq '+'
%do ii=5 %to &Nrptvar-5; and &&RPTVAR&ii eq '+' %end; then do;
%end;

%else %if &whereclause=SL_CAT_1 %then %do ; 
where (&rptvar10 in ("&whereclause"));
if &rptvar8 NE '001' and &rptvar10 NOT IN ('+', 'Missing') and &rptvar3 eq '+' and &rptvar4 eq '+' 
and &rptvar5 eq '+' and &rptvar6 eq '+' and &rptvar7 eq '+' and &rptvar9 eq '+' then do;
%end ; 

%else %do;
where (&rptvar9 in ("&whereclause"));
if &rptvar8 NE '001' and &rptvar9 NOT IN ('+', 'Missing') and &rptvar10 eq '+' %do ii=3 %to &Nrptvar-4; and &&RPTVAR&ii eq '+' %end; then do;
%end;

if &rptvar8 = '001' then &new_class_var="&specialized_lend_slot_total";
else if "&whereclause"="SL_CAT_1" then &new_class_var= &rptvar10;
else
	&new_class_var = &rptvar9;
rank=&rptrank;
end;
run;
 
%end;
/*---------------------------------------------------------------------------
* Create a breakdown of OTHER stuff
* -------------------------------------------------------------------------*/
%else %if &class_var=OTHERS %then
%do;
 
data work._other_&rptrank (where=(&new_class_var ne ""));
set work.current_&fact_table;
attrib &new_class_var length = $256 ;

%if &whereclause=ALT_TREATMENT %then %do;
where (&rptvar7 in ("&whereclause"));
if &rptvar7 not in ('+','Missing') %do ii=3 %to 6; and &&RPTVAR&ii eq '+' %end; and &rptvar8 eq '+' and &rptvar9 eq '+' and &rptvar10 eq '+' then do;
%end; 
%else %if &whereclause=OTHER_EXPOSURES %then %do;
where (&rptvar7 in ("&whereclause"));
if &rptvar7 not in ('+','Missing') %do ii=3 %to 6; and &&RPTVAR&ii eq '+' %end; and &rptvar8 eq '+' and &rptvar9 eq '+' and &rptvar10 eq '+' then do;
%end; 
%else %if &whereclause=DILUTION_RISK %then %do;
where (&rptvar7 in ("&whereclause"));
if &rptvar7 not in ('+','Missing') %do ii=3 %to 6; and &&RPTVAR&ii eq '+' %end; and &rptvar8 eq '+' and &rptvar9 eq '+' and &rptvar10 eq '+' then do;
%end; 
&new_class_var = &rptvar7;
rank=&rptrank;
end;
run;
%end;
 
%mend;
 
 
 
 
 
 
/* Create new columns (output variables) for the report */
%create_vars;

 /* Create sequence dataset for EXP_TYPE */
data __EXP_TYPE (KEEP=REPORT_LINE_NO VARIABLE_VALUE exp_type_table);
	set rd_root.report_line_seq;
	where report_name="IRB" and config_id="&CONFIG_SET" and  variable_name='EXP_TYPE';
		exp_type_table='_exp_type'||compress(report_line_no);

RUN;

/* Create sequence dataset for OBLIGOR */
data __OBLIGOR (KEEP=REPORT_LINE_NO VARIABLE_VALUE );
	set rd_root.report_line_seq;
	where report_name="IRB" and  config_id="&CONFIG_SET" and variable_name='OBLIGOR';
RUN;

/* Create sequence dataset for LINE*/
data __LINE (KEEP=REPORT_LINE_NO VARIABLE_VALUE );
	set rd_root.report_line_seq;
	where report_name="IRB" and  config_id="&CONFIG_SET" and  variable_name='LINE';
RUN;

/* Create sequence dataset for OTHERS*/
data __OTHERS(KEEP=REPORT_LINE_NO VARIABLE_VALUE other_type_table );
	set rd_root.report_line_seq;
	where report_name="IRB" and  config_id="&CONFIG_SET" and variable_name='OTHERS';
	other_type_table='_other_'||compress(report_line_no);
RUN;

/* Create sequence dataset for SLOT*/
data __SLOT(KEEP=REPORT_LINE_NO VARIABLE_VALUE slot_type_table);
	set rd_root.report_line_seq;
	where report_name="IRB" and  config_id="&CONFIG_SET" and variable_name='SLOT';
	slot_type_table='_allslot_'||compress(report_line_no);
RUN;

/* Create sequence dataset for TOTAL*/
data __TOTAL (KEEP=REPORT_LINE_NO VARIABLE_VALUE );
	set rd_root.report_line_seq;
	where report_name="IRB" and  config_id="&CONFIG_SET" and variable_name='TOTAL';
RUN;

/*---------------------------------------------------------------------------
* TOTAL EXPOSURES SECTION
* -------------------------------------------------------------------------*/

data _null_;
set __TOTAL;
call execute ('%create_class_column (class_var=TOTALS,new_class_var=CLASS_CR_IRBF,whereclause='||compress(variable_value)||',rptrank='||report_line_no||')');
run;
/*%create_class_column (class_var=TOTALS,new_class_var=CLASS_CR_IRBF,whereclause=,rptrank=1);*/

data _null_;
set __exp_type;
call execute ('%create_class_column (class_var=EXP_TYPE,new_class_var=CLASS_CR_IRBF,whereclause=("'||compress(variable_value)||'"),rptrank='||report_line_no||')');
run;
/*%create_class_column (class_var=EXP_TYPE,new_class_var=CLASS_CR_IRBF,whereclause=ALL,rptrank=3);*/

data _null_;
set __OBLIGOR;
call execute ('%create_class_column (class_var=OBLIGOR,new_class_var=CLASS_CR_IRBF,whereclause='||compress(variable_value)||',rptrank='||report_line_no||')');
run;
/**/
/*%create_class_column (class_var=OBLIGOR,new_class_var=CLASS_CR_IRBF,whereclause=TOTALS,rptrank=6);*/
/*%create_class_column (class_var=OBLIGOR,new_class_var=CLASS_CR_IRBF,whereclause=ALL,rptrank=12);*/
proc sort data=__slot out=__SLOT2 nodupkey;
 by variable_value;
run;

data _null_;
set __SLOT2;
call execute ('%create_class_column (class_var=SLOT,new_class_var=CLASS_CR_IRBF,whereclause='||compress(variable_value)||',rptrank='||report_line_no||')');
run;

/*%create_class_column (class_var=SLOT,new_class_var=CLASS_CR_IRBF,whereclause=TOTALS,rptrank=7);*/
/*%create_class_column (class_var=SLOT,new_class_var=CLASS_CR_IRBF,whereclause=ALL,rptrank=9);*/
/*%create_class_column (class_var=SLOT,new_class_var=CLASS_CR_IRBF,whereclause=SL_CAT1,rptrank=9);*/
/*%create_class_column (class_var=OTHER,new_class_var=CLASS_CR_IRBF,whereclause=ALL,rptrank=180);*/
 data _null_;
set __OTHERS;
call execute ('%create_class_column (class_var=OTHERS,new_class_var=CLASS_CR_IRBF,whereclause='||compress(variable_value)||',rptrank='||report_line_no||')');
run;
 
/*We need to sort the OBLIGOR_GRADE results from the smallest to the highest PD */
data work._obligor_all (where = (CLASS_CR_IRBF ne 'Missing'));
set work._obligor_all;
_order_=putn(substr(CLASS_CR_IRBF,length("&obligor_grade")+3,6), 3.);
run;

proc sort data=work._obligor_all;by _order_;run;
 

/*We need to sort the Slotting cross-class */
/*
data _allslot_all;
set _allslot_all;*/
/*
if CLASS_CR_IRBF EQ 'SL_RW_0_50' then _order_ =1;
else if CLASS_CR_IRBF EQ 'SL_RW_50_70' then _order_ =2;
else if CLASS_CR_IRBF EQ 'SL_PREF_CAT_1' then _order_ =3;
else if CLASS_CR_IRBF EQ 'SL_RW_70_90' then _order_ =4;
else if CLASS_CR_IRBF EQ 'SL_RW_90_115' then _order_ =5;
else if CLASS_CR_IRBF EQ 'SL_RW_115_250' then _order_ =6;
else if CLASS_CR_IRBF EQ 'SL_RW_250_1250' then _order_ =7;
*/
/*
if CLASS_CR_IRBF EQ 'SL_RW_0_0' then _order_ =1;
else if CLASS_CR_IRBF EQ 'SL_RW_50_50' then _order_ =2;
else if CLASS_CR_IRBF EQ 'SL_PREF_CAT_1' then _order_ =3;
else if CLASS_CR_IRBF EQ 'SL_RW_70_70' then _order_ =4;
else if CLASS_CR_IRBF EQ 'SL_RW_90_90' then _order_ =5;
else if CLASS_CR_IRBF EQ 'SL_RW_115_115' then _order_ =6;
else if CLASS_CR_IRBF EQ 'SL_RW_250_250' then _order_ =7;
else if CLASS_CR_IRBF EQ 'SL_RW_250_1250' then _order_ =8;

run;
 
proc sort data=work._allslot_all;by _order_;run;
*/ 
 
/*We need to sort the exposure type cross-class */
/*
data _exp_type;
set _exp_type;
if CLASS_CR_IRBF EQ 'ON_BALANCE' then _order_ =1;
else if CLASS_CR_IRBF EQ 'OFF_BALANCE' then _order_ =2;
else if CLASS_CR_IRBF EQ 'REPOS' then _order_ =3;
else if CLASS_CR_IRBF EQ 'NETTING' then _order_ =4;
run;
 
proc sort data=work._exp_type;by _order_;run;
*/ 
 
 
 
 
/*---------------------------------------------------------------------------
* Merge all results back into one data table
* -------------------------------------------------------------------------*/
/* Exposure Type tables */
proc sql noprint;
select exp_type_table into: exp_type_table separated by ' '
from __exp_type;
quit;

/* Exposure Type tables */
proc sql noprint;
select slot_type_table into: slot_type_table separated by ' '
from __slot;
quit;

/*Other type tables */ 
proc sql noprint;
select other_type_table into: other_type_table separated by ' '
from __others;
quit;

data work.report_data;
set work._all /*work._exp_type (drop=_order_)*/ work._obligor_all work._obligor_totals &exp_type_table
/* work._allslot_totals*/ /*work._allslot_all(drop=_order_)*/&slot_type_table /*work._allslot_SL_CAT1*/ &other_type_table /*work._other*/;
/*Fields with a "Missing" cross-class are not needed for the report
Also, an UNDEFINED cross-class for the obligor_grade is not needed.
It is already caputed in Obligor Grade: UNDEFINED*/
if (&rptvar5 eq 'Missing') or (&rptvar6 in ('UNDEFINED','Missing')) or (&rptvar7 eq 'Missing') or (&rptvar9 eq 'Missing')or (&rptvar10 eq 'Missing') then delete;
run;
 
 
 
 
 
 
 
 
%macro createReportPages;
/*- Create empty lines in the report as needed for headers -*/
 
%create_class_column (class_var=LINE,new_class_var=CLASS_CR_IRBF,whereclause=,rptrank=11,
             newline=&_breakdown_exptype,dsn=report_data);

%create_class_column (class_var=LINE,new_class_var=CLASS_CR_IRBF,whereclause=,rptrank=181,
             newline=&_breakdown_obligor ,dsn=report_data);
 
%create_class_column (class_var=LINE,new_class_var=CLASS_CR_IRBF,whereclause=,rptrank=81,
             newline=&_breakdown_rw_slotting ,dsn=report_data);
             
%create_class_column (class_var=LINE,new_class_var=CLASS_CR_IRBF,whereclause=,rptrank=31,
             newline=Exposures / Transactions subject to counterparty credit risk ,dsn=report_data);
/*%create_class_column (class_var=LINE,new_class_var=CLASS_CR_IRBF,whereclause=,rptrank=40,
             newline=Securities Financing Transactions ,dsn=report_data);
*/
/*
%create_class_column (class_var=LINE,new_class_var=CLASS_CR_IRBF,whereclause=,rptrank=50,
             newline=Derivatives & Long Settlement Transactions ,dsn=report_data);
             */
%create_class_column (class_var=LINE,new_class_var=CLASS_CR_IRBF,whereclause=,rptrank=60,
             newline=&IRB_L_60,dsn=report_data);
%create_class_column (class_var=LINE,new_class_var=CLASS_CR_IRBF,whereclause=,rptrank=160,
             newline=&IRB_L_160 ,dsn=report_data);
%create_class_column (class_var=LINE,new_class_var=CLASS_CR_IRBF,whereclause=,rptrank=170,
             newline=&IRB_L_170 ,dsn=report_data);
/*%create_class_column (class_var=LINE,new_class_var=CLASS_CR_IRBF,whereclause=,rptrank=180,
             newline=DILUTION RISK: TOTAL PURCHASED RECEIVABLES ,dsn=report_data);*/
             
             
             
             
 
/*- get the report data into the right order for the report -*/
 
proc sort data=work.report_data;
by rank;
where rank ne .;
run;


proc sort data=work.report_data (WHERE=(blank_line NE 'yes') keep=&rptvar1 &rptvar2 &rptvar11 &rptvar12 blank_line) nodupkeys
out=report_pages;
by &rptvar1 &rptvar2 &rptvar11 &rptvar12;   
run;

/*---------------------------------------------------------------------------
* Delete the unwanted report combinations
* -------------------------------------------------------------------------*/

/*Delete OWN_LGD_CCF_ESTIMATES at + level and SME_SUPPORT_FACTOR at NOTAPP level */   
 
data work.report_pages ; 
	set  work.report_pages ; 
	 where &rptvar11 ne "+" ;
   if &rptvar12 not in ("NOTAPP") ;
run ; 

/* Delete where EXPOSURE_CLASS_LEVEL_1 and EXPOSURE_CLASS_LEVEL_2 is + and SME_SUPPORT_FACTOR at "SME_SUPPORT" level */
data work.report_pages ; 
	set  work.report_pages ; 
	if &rptvar1 = "+" and &rptvar2 =  "+"  and &rptvar12 = "SME_SUPPORT"  then delete ; 
run ; 

/*Delete where EXPOSURE_CLASS_LEVEL_1 is + and EXPOSURE_CLASS_LEVEL_2 is not + */
data work.report_pages ; 
	set  work.report_pages ; 
	if &rptvar1 = "+" and &rptvar2 ne "+" then delete ; 
run ; 

/*CP50 reports doesn't require retail and corporate at aggregate level */
 data work.report_pages ; 
	set  work.report_pages ; 
	if &rptvar1 = "RETAIL" and &rptvar2 = "+" then delete ; 
	if &rptvar1 = "CORPORATE" and &rptvar2 = "+" then delete ; 
	if &rptvar1 = "RETAIL_SEC_IMOV" and &rptvar2 = "+" then delete ; 
	if &rptvar1 = "RETAIL_OTHER" and &rptvar2 = "+" then delete ; 
run ; 

/*CP50 reports require soverigns and institutions only at aggregate level */
 data work.report_pages ; 
	set  work.report_pages ; 
	if &rptvar1 = "INSTITUTIONS" and &rptvar2 ne "+" then delete ; 
	if &rptvar1 = "CENTRAL_GOV_BANK" and &rptvar2 ne "+" then delete ; 
run ; 
/*---------------------------------------------------------------------------
* Create seperate page tables for the report
* -------------------------------------------------------------------------*/

  proc sort   data=rd_root.report_line_seq (WHERE=(report_name="IRB" and CONFIG_ID = "&CONFIG_SET" )) 
          out=work.report_line_seq_&report_name (rename=(report_line_no=rank));
          by report_line_no;
  run;
 
data _null_;
set work.report_pages (where=(&rptvar1 ne '' or &rptvar2 ne "" or &rptvar11 ne ""));
file page;
put "data &regprojectname._"  _n_  ";";
put ' set work.report_data;';
put " where &rptvar1 eq '" &rptvar1 "' and &rptvar2 eq '" &rptvar2 "' and &rptvar11 eq '" &rptvar11"' and &rptvar12 eq '" &rptvar12"' OR blank_line eq 'YES';";
put 'run;';

put "proc sort  data=&regprojectname._"  _n_  ";";
put 'by rank;run;';

put "data &regprojectname._"  _n_  ";";
put "merge report_line_seq_&report_name. &regprojectname._"  _n_ ";";
put 'by rank;';
put 'run;';

put "data &regprojectname._"  _n_  ";";
put "set &regprojectname._"  _n_  ";";
put 'if missing(CLASS_CR_IRBF) and not missing(report_line_id)then CLASS_CR_IRBF=symget(report_line_id);';
put 'run;';

put "proc sort  data=&regprojectname._"  _n_  ";";
put 'by rank;run;';


run;
 
%inc page;
 
%mend createReportPages;
 
 
 
%createReportPages;
    
 
     
 
%mend regrpt_d0_capital_crirbf_crd4;
