/*****************************************************************************
* Copyright (c) 2013 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
*
*    NAME:regrpt_d0_capital_lr4.sas
*
* PURPOSE: Creates data for the LE 2 report
*
*
*   USAGE:
*
*   NOTES: Modified for V4.8
*   Macro Options:
*****************************************************************************/
%macro regrpt_d0_capital_lr4;

%let report_name=LR4; 

/*MACRO TO CREATE ROW CONDITON IN WHERE CLAUSE FORMAT*/

%macro create_rowwhere(sectype, page);;
data _rowwhere_clause_;
set _rowcond;
length where_clause $1000 ;
where_clause=
			"&rptvar1 ='" || trim(&rptvar1 ) || "' and " ||
			"&rptvar2 ='" || trim(&rptvar2 ) || "' and " ||
			"&rptvar3 ='" || trim(&rptvar3 ) || "' and " ||
			"&rptvar4 ='" || trim(&rptvar4 ) || "' and " ||
			"&rptvar5 ='" || trim(&rptvar5 ) || "' and " ||
			"&rptvar6 ='" || trim(&rptvar6 ) || "'" ;
label = symget( compress("LR4_L_" || put(rownum,8.)));
RANK=rownum;
table_name=compress("lr4_row_"||rank);

run;
%mend create_rowwhere;

/*MACRO TO EXTRACT A ROW FOR EACH RANK*/
%macro getrows(rowclause, rank);

data work.lr4_row_&rank;
   set work.current_regulatory;
   length label $256;
   where &rowclause;
   rank=&rank;
   label = symget( compress("LR4_L_" || put(rank,8.)));
run;    
%mend getrows;


%macro createRegulatoryView (fact_table=);
/*---------------------------------------------------------------------------
* Step 1.
* Check for data in the repository and create a dataset for the project
* the dataset is work.current_regulatory
* -------------------------------------------------------------------------*/
%if %upcase(&usertype) eq MASTER %then
%let projectview=%trim(%left(&PROJECT_SET))_%trim(%left(&REGPROJECTNAME))_%trim(%left(&MITIGANTS_ALLOCATION_METHOD))_%trim(%left(&system_id));
%else
%let projectview=%trim(%left(&PROJECT_SET))_%trim(%left(&REGPROJECTNAME))_%trim(%left(&MITIGANTS_ALLOCATION_METHOD))_%trim(%left(&system_id))_%trim(%left(&username));
%put projectview=&projectview;
/* Create SQL views into datamart with no history */
%create_risk_repository_views
(Project_name=&projectview,Fact_table=&fact_table,Current=YES,Year=NO,Allhistory=NO, where=NONE, obs=0);
 
%mend createRegulatoryView;

/* Create views of fact table with cross-class macro names */
%createRegulatoryView (fact_table=regulatory);


/*CREATE _ROWCOND DATASET*/
%create_lr4_types_crd4;

/*CREATE ROW CONDITON IN WHERE CLAUSE FORMAT*/
%create_rowwhere;


/*EXTRACT A ROW FOR EACH RANK*/
data _null_;
 set _rowwhere_clause_;
	call execute ('%getrows (rowclause='||where_clause||",rank="||rownum||")");
run;

/*GET DATSET NAMES IN A MACRO VARIABLE*/
proc sql noprint;
 select upcase( table_name) into :TABLE_NAME separated by "  "
 from _rowwhere_clause_;
quit;

/*COMBINE ALL ROWS IN TO DATASET REQUIRED IN FORMAT FOR REPORTING*/
DATA CAPITAL_LR4_RPT;
 SET &TABLE_NAME;
RUN;

/*ADD ANY MISSING ROWS*/
proc sort data=rd_root.report_line_Seq(where=(upcase(REPORT_NAME)="&report_name" and upcase(config_id)=upcase("&config_set"))) 
out=report_line_seq_lr4(rename=REPORT_LINE_NO= rank);
 by report_line_no;
run;

data CAPITAL_LR4_RPT;
 merge REPORT_LINE_SEQ_&REPORT_NAME.(in=a) CAPITAL_LR4_RPT(in=B);
 length CLASS_CR_LR4 $256.;
 by rank;
 if A;
 CLASS_CR_LR4= symget(report_line_id);
run;

/*SEGREGATE DATA COMPATIBLE FOR REPORTING BASED ON ON-BALANCE AND OFF-BALANCE*/
data CAPITAL_LR4_RPT_SET1 
	 CAPITAL_LR4_RPT_SET2 ;
 set CAPITAL_LR4_RPT;
 if (10 le rank le 70 ) then output CAPITAL_LR4_RPT_SET1;
 else if (80 le rank le 320 ) then output CAPITAL_LR4_RPT_SET2;
run;
	
%mend regrpt_d0_capital_lr4;
