/*****************************************************************************
 * Copyright (c) 2013 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME: regulatory_irb_obligors_crd4
 *
 *    PURPOSE: To generate obligor related information for IRB Report
 *
 *    USAGE: 
 *
 *    NOTES: 1. This runs data for regulatory projects
 *    MODIFIED V4.8
 *****************************************************************************/


%macro regulatory_irb_obligors_crd4;
ods _all_ close;
%let regprojectname_old=&regprojectname;
%let regprojectname=&regprojectname._oblig_info;
%put regprojectname_aft_2=&regprojectname;

%let regrpt_whereclause = %quote(where upcase(rpt_cd) eq %upcase("&REGPROJECTNAME")
/*  and upcase(system_id) eq "%upcase(&system_id)" */
  and upcase(allocation_method) eq "%upcase(&MITIGANTS_ALLOCATION_METHOD)"
  and upcase(config_set) eq "%upcase(&CONFIG_SET)");


	%if %sysfunc (exist( rd_nls.regulatory_report_list_&REPORTING_LANGUAGE. )) %then %do;
		data _null_;
		 set rd_nls.regulatory_report_list_&REPORTING_LANGUAGE.;
		     &regrpt_whereclause;
			 call symputx("title1",title1);
			 call symputx("title2",title2);
		 run;

	%end;


%regulatory_reportoutputbegin;

%let regprojectname=&regprojectname_old;
%put regprojectname_aft_old=&regprojectname;
data _null_;
run;


%if NOT %sysfunc(exist(work.current_regulatory)) or NOT %sysfunc(exist(work.&regprojectname._1))
or %upcase(&SYSTEM_FATAL_ERROR) = %upcase (Y) %then %do;
%print_msg(warning,3,10);
%print_msg(warning,3,15);
%regulatory_reportnopage();
%return;
%goto OBLIGOR_END;
%end;

/* Get number of report pages */
%let pages=%attrn(report_pages,NOBS);

%do this_page=1 %to &PAGES ;

/*Change to &pages */
/*If data is not available for the report page then do no run report content */
%if NOT %sysfunc(exist(work.&regprojectname._&this_page)) %then %do;
%print_msg(warning,3,19);
%print_msg(note,3,20);
%regulatory_reportnopage();
%goto NOPAGE;
%end;

   %if &APPLY_CCF_AFTER_CRM EQ NO %then %do;

       %let ccf_crm_msg=%print_msg(,3,108,1);
      footnote "&ccf_crm_msg";
  %end;

/* Displays the titles for the cross-classification variables */
%if %upcase(&REPORT_TYPE)=%upcase(XLS) %then %do;

   data _null_;
    set report_pages(firstobs=&this_page obs=&this_page);
    /* call symputx("sheet_nm",put(&class_sa_lev1,$aggregate.));*/
    call symputx("sheet_nm",&this_page);

   run;

   ods tagsets.ExcelXP_Mod
        options(
        sheet_name="&sheet_nm"
        sheet_interval='none' autofit_height="yes");
			%let regprojectname_old=&regprojectname;
			%let regprojectname=&regprojectname._oblig_info;
			%put regprojectname_aft_2=&regprojectname;

        %_Report_Title(REPORT_TITLE_CD=rpt_cd2,REPORT_TITLE=rpt_title1);
			%let regprojectname=&regprojectname_old;
			%put regprojectname_aft_old=&regprojectname;
			data _null_;
			run;

   ods tagsets.ExcelXP_Mod
        options(
        autofit_height="NO");

%end;


 %regulatory_reportheaders_IRB(work.&regprojectname._&this_page);



	data _order_check_&this_page. ;
		set  work.&regprojectname._&this_page.(where=(rank in (200))) ;
		if  not missing (_order_) ;
	run;

 %if (%attrn(_order_check_&this_page.,nobs) > 0 ) %then %do ;


	%if %upcase(&REPORT_TYPE)=%upcase(XLS) %then %do;

	%end;
      %report_page (work.&regprojectname._&this_page.(where=(rank in (181,200))));

  %end;

/* subroutine for no data available for report page */
%NOPAGE:

%end;

%OBLIGOR_END:
%mend regulatory_irb_obligors_crd4;
