/*****************************************************************************
 * Copyright (c) 2014 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 * NAME: regulatory_report_le1_crd4
 *
 * PURPOSE: Batch interface for CRiskM Reporting
 *
 * USAGE: This code is exclusively for Large Exposures Report(LE1)
 *        Since there is no registering of project in to rd_rpt.project_dim
 *
 * NOTES: need to clean up macro vars that are created for next run
 *
 * CREATED: 11/29/2013
 *          

 *****************************************************************************/
%macro regulatory_report_le1_crd4 (submit=yes);

%global proj_id_hold proj_id;
options noquotelenmax;
%u00_recreate_macro_definitions;

/*---------------------------------------------------------------------------
 *
 * Check environment variables necessary for report run
 * 
 * -------------------------------------------------------------------------*/

/* Get environment variables */
%a00_init_options;

/* Determine the REPORT_TYPE */
%if %symglobl (REPORT_TYPE) = 0 and %symlocal (REPORT_TYPE)= 0 %then %do;
    %let REPORT_TYPE=PDF;
%end;
%let report_type=%upcase(&report_type);


/* Determine the REPORTING_LANGUAGE */
%if %symglobl (RPT_LANG) = 0 and %symlocal (RPT_LANG)= 0 %then;
  %let RPT_LANG=EN;
%if %symglobl (REPORTING_LANGUAGE) = 0 and %symlocal (REPORT_LANGUAGE)= 0 %then %do;
  /* Requested language is not available - set to English */
  %let REPORTING_LANGUAGE=&RPT_LANG;
%end;


/* Determine the REGPROJECTNAME */
%if %symglobl (REGPROJECTNAME) = 0 and %symlocal (REGPROJECTNAME)= 0 %then %do;
  %print_msg (ERROR,3,104);
  %goto SKIPRPT;
%end;

/* Test for multilanguage support */
%if %symglobl(REPORTING_LANGUAGE0) = 0 and %symlocal (REPORTING_LANGUAGE0)= 0 %then %do;
  %let MULTI_LANGUAGES = NO;
  %let REPORTING_LANGUAGE0=1;
  %let REPORTING_LANGUAGE1=&REPORTING_LANGUAGE;
%end;
%else %if %eval(&REPORTING_LANGUAGE0) = 1 %then %let MULTI_LANGUAGES=NO;
%else %if %eval(&REPORTING_LANGUAGE0) > 1 %then %let MULTI_LANGUAGES=YES;




/*---------------------------------------------------------------------------
 *
 * Produce Report Statements for Submit
 * 
 * -------------------------------------------------------------------------*/

/* Create reports for each report language */
%DO LANG_NUM=1 %TO &REPORTING_LANGUAGE0;
  %let REPORTING_LANGUAGE=&&REPORTING_LANGUAGE&LANG_NUM;
    
  /* Check that the requested language table is available */
  %if NOT %sysfunc (exist(rd_nls.Regulatory_report_list_&&REPORTING_LANGUAGE)) %then %do;
      %print_msg(warning,3,44);  

      /* If requested language table is not available try default language table */
      %if %sysfunc (exist( rd_nls.regulatory_report_list_en )) %then %do;
        %let REPORTING_LANGUAGE=en;
          %print_msg(warning,3,43);
      %end;
      %else %do; /* No language available - abort running report */
        %print_msg(warning,3,45); 
        %goto SKIPRPT;
      %end;

   %end; 

    /* Set fileref tmprpt for report invocation statements */
    filename rptout catalog 'work.temp.regrpt.source'; 

    /* Determine if a report grouping has been specified */
    %if %upcase(&regprojectname) eq %upcase(ALL) %then 
    %let regrpt_whereclause = %quote(where upcase(rpt_cd) eq  %upcase("CAPITAL_LE1_CRD4")
	  and  upcase(system_id) eq "%upcase(&system_id)" 
      and upcase(allocation_method) eq "%upcase(&MITIGANTS_ALLOCATION_METHOD)"
      and upcase(config_set) eq "%upcase(&CONFIG_SET)");
    %if %upcase(&regprojectname) eq %upcase(STD) %then 
    %let regrpt_whereclause = %quote(where upcase(report_group) eq "%upcase(STD)"
      and upcase(system_id) eq "%upcase(&system_id)" 
      and upcase(allocation_method) eq "%upcase(&MITIGANTS_ALLOCATION_METHOD)"
      and upcase(config_set) eq "%upcase(&CONFIG_SET)");
    %if %upcase(&regprojectname) eq %upcase(IRB) %then 
    %let regrpt_whereclause = %quote(where upcase(report_group) eq "%upcase(IRB)"
      and upcase(system_id) eq "%upcase(&system_id)" 
      and upcase(allocation_method) eq "%upcase(&MITIGANTS_ALLOCATION_METHOD)"
      and upcase(config_set) eq "%upcase(&CONFIG_SET)");
    %else %if %upcase(&regprojectname) ne %upcase(ALL) and
            %upcase(&regprojectname) ne %upcase(STD) and
        %upcase(&regprojectname) ne %upcase(IRB) %then 
    %let regrpt_whereclause = %quote(where upcase(rpt_cd) eq %upcase("CAPITAL_LE1_CRD4")
      /*and upcase(system_id) eq "%upcase(&system_id)" */
      and upcase(allocation_method) eq "%upcase(&MITIGANTS_ALLOCATION_METHOD)"
      and upcase(config_set) eq "%upcase(&CONFIG_SET)");
  
    /* Subset the regulatory_report_list and get the number of reports to run */
    data work.regulatory_reportlist;
     
      set rd_nls.regulatory_report_list_&&REPORTING_LANGUAGE&LANG_NUM;
    &regrpt_whereclause;
  run;

  /* Get the total number of reports to run */
    %let report_totalnum = %attrn (work.regulatory_reportlist, NOBS);

  %if %quote(&report_totalnum) = %quote(0) %then %do;
    %print_msg (ERROR,3,104);
    %goto SKIPRPT;
  %end;

    /* Iterate through each observation and produce the report statements */
    %do report_num = 1 %to &report_totalnum;
    
    /* Create a single row (instance) of the report */
      data work.regulatory_reportinstance;  
      if _n_ = 1 then do;
        currobs = symgetn ('report_num');
        set work.regulatory_reportlist point=currobs;
        call symput ("report_name",trim(left(rpt_cd)));
        output;
      end;
    run;

/***********************************************************************/
/*This section adds the project_id_sk to the end of the report file name*/



data work.regulatory_reportinstance;  
    set work.regulatory_reportinstance;  
        proj_id=0;
    run;

/*************************************************/

      /* Open dataset with report descriptions */
      proc transpose data=work.regulatory_reportinstance
        out=work.regulatory_reportstatements (rename=(_name_=name col1=value));
        var _all_;
      run;

      /* Test that we have a valid regulatory project */
      %if %sysfunc (exist (work.regulatory_reportstatements)) and 
        %attrn(work.regulatory_reportstatements,NOBS) ne 0 
        %then %do;

        /* Create macro vars of report parameters for report statement creation */
		data _null_;
		    call symputx ('rundate', &rundate);
		run;

        data _null_;
            set work.regulatory_reportstatements;
            call symput (trim(left(name)), trim(left(value)));
        run;

        /* Write out the regulatory report statements */
          data _null_;                                                                      
            set work.regulatory_reportstatements nobs=maxobs;
            attrib line length=$1024;
              file rptout mod ; 
              file_name=compress('regrpt_'||value);
            /* Write the report title as a comment block */
            /* Start the datastep containing the report statements */
            if _n_ = 1 then do;
              put "/* &title1 */";
              put "/* &title2 */";
              put 'data _null_;';
              put "call symput ('reporting_language','&&REPORTING_LANGUAGE&LANG_NUM');";
          put "call symput ('report_type','&REPORT_TYPE');";
          put "call symput ('rundate', '%trim(&rundate)');";
            put "call symput ('report_ccy', '&report_ccy');";
            put "call symput ('config_set', '%trim(%left(&config_set))');";

          end;

            /* Write out report parameters */
            line = 'call symput ("' || trim(left(name)) || '", "' 
                || trim(left(value)) || '");';
            put line;
    
            /* Close datastep */
            if _n_=maxobs then do;
              put 'run;';
              put;
            end;

        run;

        /* Write out invocation of regulatory report macros */
        /* Write out the regulatory report to be run */
        data _null_;
            set work.regulatory_reportstatements;
            file rptout mod ;
            file_name=compress('regrpt_'||value);
            if name = "rpt_cd" then do;
              put '/* Submit the Report */';
              put 'Ods listing close;';
              put '%let regprojectname=' value ';';
              put '%regulatory_reportlanguage;';
                put '%regulatory_reportoutputbegin;';
                put '%'file_name';';
                /*put '%runsasfile(REGFILES, ' value ');';*/
                put '%regulatory_reportoutputend;'; 
              put;
                put;
            end;
        run;
  
      %end; /* end regulatory report statements */

  %end; /* end report group iteration */

%end; /* end report generation */

/* Submit reports for processing */
%if %upcase (&submit) = %upcase (yes) %then %do;

  %inc rptout; 

  /* Delete the source member containing the report statements */
  proc catalog cat=work.temp;
      delete regrpt.source;
  quit;

%end;

/* Skip report creation*/
%SKIPRPT:


%mend regulatory_report_le1_crd4;
