/*****************************************************************************
 * Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 * NAME: regulatory_reportheaders_irb
 *
 * PURPOSE: 
 *      
 *****************************************************************************/

%macro regulatory_reportheaders_irb (dsn);  


/*---------------------------------------------------------------------------
 *
 *  Produce the header with PDF or HTML layout.
 *
 * -------------------------------------------------------------------------*/
  
%if %upcase(&REPORT_TYPE)=%upcase(PDF) %then %do;
  ods ptitle;
  ods proclabel "&title2";
  ods pdf text='^4P ';
  ods pdf text='^S={just=left preimage=shortbar}';
  ods pdf text="^S={ font_size=&titlesize font_weight=bold just=left foreground=black} &title2";
  ods pdf text='^S={just=left preimage=shortbar}';
  ods pdf startpage=no;
%end;

%if %upcase(&REPORT_TYPE)=%upcase(HTML) or %upcase(&REPORT_TYPE)=%upcase(STREAM)  %then %do;
  ods tagsets.regtext text="<p><br><br></p>";
  ods tagsets.regtext text="<img src='&shortbar'><p></p>";
  ods tagsets.regtext text="<div class='regReportClassificationTitle'>&title2</div><p></p>";
  ods tagsets.regtext text="<img src='&shortbar'><p></p> "; %end;

%if %upcase(&REPORT_TYPE)=%upcase(XLS) %then %do;
  ods tagsets.ExcelXP_Mod text="<p><br><br></p>";
  ods tagsets.ExcelXP_Mod text="<img src='&shortbar'><p></p>";
  ods tagsets.ExcelXP_Mod text="<div class='regReportClassificationTitle'>&title2</div><p></p>";
  ods tagsets.ExcelXP_Mod text="<img src='&shortbar'><p></p> ";
  ods tagsets.ExcelXP_Mod startpage=no;
%end;


/*---------------------------------------------------------------------------
 *
 *  Create the report header dataset
 *
 * -------------------------------------------------------------------------*/

/* Proc report statemetns for header titles */ %if %upcase(&class_depth) ne %upcase(0) %then %do;

  /* Create header dataset */
  proc transpose data=&dsn (obs=1 keep= &rptvar1 &rptvar2 &rptvar11 &rptvar12 /*%do numcc=1 %to &class_depth;&&rptvar&numcc %end;*/ )  
    out=work.report_header;
      var /* %do numcc=1 %to &class_depth; */ 
      		/* &&rptvar&numcc */ /*Temporary commented   */  
      		   &rptvar1 &rptvar2 &rptvar11 &rptvar12;
      		/* %end;; */ 
  run;
  
 /*data work.report_header (rename=_name_=_label_);
  set work.report_header;
 run;*/
  /* Format the header dataset */

  proc sort data=rd_nls.rpt_lang_ccvar_&reporting_language
  (rename=macro_name=_label_) out=work.ccvarlang;
  by _label_;
  run;

  data work.ccvarlang (rename=temp=_label_);;
    length temp $40;
    set work.ccvarlang;    
    temp=substr(_label_,1,40);
    drop _label_;
  run;

  proc sort data=work.report_header;
  by _label_;
  run;
  
  data work.ccvarlangtrans;
    merge work.report_header (in=a) work.ccvarlang;
    by _label_;
    if a;
  run;  

  data _null_ ;
      set work.ccvarlangtrans;
      format title $1000. ;
    retain title;
      if _n_=1 then do;
    title=trim(left(trim(left(macro_value))||'='||col1));
  end;
    else do;
    title=trim(left(trim(left(title))||', '||trim(left(macro_value))||'='||trim(left(col1))));
  end;
    call symput ("proclabel",trim(left(title)));
  run;
%if %upcase(&REPORT_TYPE)=%upcase(XLS) %then %do;
  ods tagsets.ExcelXP_Mod startpage=no;
%end;


/***************************************************
* Code change to create CP50 IRB reporting header
****************************************************/
%symdel delete_flag /NOWARN;
%global delete_flag;
data work.report_header_irb_exp_class (keep= COL1 macro_value) ;
set &dsn (obs =1 ) ;
length macro_value COL1 $100. delete_flag $3.;
START   = compress(&rptvar1||&rptvar2||&rptvar11||&rptvar12) ;
COL1 =put(start,map_irb_group.);
MACRO_VALUE = "IRB Exposure class:" ;
if upcase(start) in ("CORPORATESMEYESSME_SUPPORT" 
					 "CORPORATESMENOSME_SUPPORT"
					 "RETAIL_OTHERSMEYESSME_SUPPORT" 
					 "RETAIL_SEC_IMOVSMEYESSME_SUPPORT" ) then delete_flag="YES";
else delete_flag="NO";
call symputx("delete_flag",delete_flag);

run ;
%put delete_flag=&delete_flag;

proc sql noprint;
 select count(*) into :CCLANGNO
 	from ccvarlangtrans;
quit;

data ccvarlangtrans2  (keep= COL1 macro_value);
length macro_value COL1 $100.;
 set ccvarlangtrans  end=last;
/* if last then output ; */
/* adding the following line to pick only the last but 1 record*/
/* which contains OWN_LGD_CCF_ESTIMATES information*/
 if _n_ =&cclangno-1;
run;

proc append base=report_header_irb_exp_class data=ccvarlangtrans2 force;
run;

  /* output the header */
  proc report data=work.report_header_irb_exp_class  nowd LS=160 PS=50 SPLIT="*" nocenter contents=''
    style(report)={ bordercolor=gray  }
      style(header)={background=white  cellspacing=15 };
      column macro_value col1;
      define macro_value / width=100 spacing=10 display "&hierarchy";
      define col1 / format=$ccvar. display "&hierarchy_values";
  run;
%end;
%else %do;
  %let proclabel=&title2;
%end;

%if %upcase(&REPORT_TYPE)=%upcase(PDF) %then %do;
  ods ptitle;
  ods proclabel "&proclabel";
  ods pdf text='^S={just=left preimage=lngbar}';
  ods pdf startpage=no;
%end;

%if %upcase(&REPORT_TYPE)=%upcase(HTML) or %upcase(&REPORT_TYPE)=%upcase(STREAM) %then %do;
  ods tagsets.regtext text="<p></p>";
  ods tagsets.regtext text='<div class="regReportClassificationTitle">';
  ods tagsets.regtext text="<img src='&lngbar' >";
  ods ptitle;
  ods proclabel "&title1";
  ods tagsets.regtext text ='</div><p></p>';
%end;

%if %upcase(&REPORT_TYPE)=%upcase(XLS) %then %do;
  ods tagsets.ExcelXP_Mod text="<p></p>";
  ods tagsets.ExcelXP_Mod text='<div class="regReportClassificationTitle">';
  ods tagsets.ExcelXP_Mod text="<img src='&lngbar' >";
  ods ptitle;
  ods proclabel "&title1";
  ods tagsets.ExcelXP_Mod text ='</div><p></p>';
  ods tagsets.ExcelXP_Mod startpage=no;
%end;

%mend regulatory_reportheaders_irb; /* end headertitles macro */
